import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CatalogAccessControlConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of Catalog to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#catalog_id CatalogAccessControl#catalog_id}
    */
    readonly catalogId: string;
    /**
    * Access level when the catalog is shared with everyone (only ReadOnly is available). Required when shared_with_everyone is set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#everyone_access_level CatalogAccessControl#everyone_access_level}
    */
    readonly everyoneAccessLevel?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#id CatalogAccessControl#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#org CatalogAccessControl#org}
    */
    readonly org?: string;
    /**
    * If true, the catalog is shared as read-only with all organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#read_only_shared_with_all_orgs CatalogAccessControl#read_only_shared_with_all_orgs}
    */
    readonly readOnlySharedWithAllOrgs?: boolean | cdktf.IResolvable;
    /**
    * Whether the Catalog is shared with everyone
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#shared_with_everyone CatalogAccessControl#shared_with_everyone}
    */
    readonly sharedWithEveryone: boolean | cdktf.IResolvable;
    /**
    * shared_with block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#shared_with CatalogAccessControl#shared_with}
    */
    readonly sharedWith?: CatalogAccessControlSharedWith[] | cdktf.IResolvable;
}
export interface CatalogAccessControlSharedWith {
    /**
    * The access level for the org, user, or group to which we are sharing. One of [ReadOnly, Change, FullControl] for users and groups, but just ReadOnly for Organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#access_level CatalogAccessControl#access_level}
    */
    readonly accessLevel: string;
    /**
    * ID of the group to which we are sharing. Required if user_id or org_id is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#group_id CatalogAccessControl#group_id}
    */
    readonly groupId?: string;
    /**
    * ID of the Org to which we are sharing. Required if user_id or group_id is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#org_id CatalogAccessControl#org_id}
    */
    readonly orgId?: string;
    /**
    * ID of the user to which we are sharing. Required if group_id or org_id is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#user_id CatalogAccessControl#user_id}
    */
    readonly userId?: string;
}
export declare function catalogAccessControlSharedWithToTerraform(struct?: CatalogAccessControlSharedWith | cdktf.IResolvable): any;
export declare function catalogAccessControlSharedWithToHclTerraform(struct?: CatalogAccessControlSharedWith | cdktf.IResolvable): any;
export declare class CatalogAccessControlSharedWithOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CatalogAccessControlSharedWith | cdktf.IResolvable | undefined;
    set internalValue(value: CatalogAccessControlSharedWith | cdktf.IResolvable | undefined);
    private _accessLevel?;
    get accessLevel(): string;
    set accessLevel(value: string);
    get accessLevelInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    resetGroupId(): void;
    get groupIdInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    resetOrgId(): void;
    get orgIdInput(): string | undefined;
    get subjectName(): string;
    private _userId?;
    get userId(): string;
    set userId(value: string);
    resetUserId(): void;
    get userIdInput(): string | undefined;
}
export declare class CatalogAccessControlSharedWithList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CatalogAccessControlSharedWith[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CatalogAccessControlSharedWithOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control vcd_catalog_access_control}
*/
export declare class CatalogAccessControl extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_catalog_access_control";
    /**
    * Generates CDKTF code for importing a CatalogAccessControl resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CatalogAccessControl to import
    * @param importFromId The id of the existing CatalogAccessControl that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CatalogAccessControl to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_access_control vcd_catalog_access_control} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CatalogAccessControlConfig
    */
    constructor(scope: Construct, id: string, config: CatalogAccessControlConfig);
    private _catalogId?;
    get catalogId(): string;
    set catalogId(value: string);
    get catalogIdInput(): string | undefined;
    private _everyoneAccessLevel?;
    get everyoneAccessLevel(): string;
    set everyoneAccessLevel(value: string);
    resetEveryoneAccessLevel(): void;
    get everyoneAccessLevelInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _readOnlySharedWithAllOrgs?;
    get readOnlySharedWithAllOrgs(): boolean | cdktf.IResolvable;
    set readOnlySharedWithAllOrgs(value: boolean | cdktf.IResolvable);
    resetReadOnlySharedWithAllOrgs(): void;
    get readOnlySharedWithAllOrgsInput(): boolean | cdktf.IResolvable | undefined;
    private _sharedWithEveryone?;
    get sharedWithEveryone(): boolean | cdktf.IResolvable;
    set sharedWithEveryone(value: boolean | cdktf.IResolvable);
    get sharedWithEveryoneInput(): boolean | cdktf.IResolvable | undefined;
    private _sharedWith;
    get sharedWith(): CatalogAccessControlSharedWithList;
    putSharedWith(value: CatalogAccessControlSharedWith[] | cdktf.IResolvable): void;
    resetSharedWith(): void;
    get sharedWithInput(): cdktf.IResolvable | CatalogAccessControlSharedWith[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
