import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CatalogItemConfig extends cdktf.TerraformMetaArguments {
    /**
    * catalog name where upload the OVA file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#catalog CatalogItem#catalog}
    */
    readonly catalog: string;
    /**
    * Key and value pairs for catalog item metadata
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#catalog_item_metadata CatalogItem#catalog_item_metadata}
    */
    readonly catalogItemMetadata?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#description CatalogItem#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#id CatalogItem#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key and value pairs for the metadata of the vApp template associated to this catalog item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#metadata CatalogItem#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * catalog item name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#name CatalogItem#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#org CatalogItem#org}
    */
    readonly org?: string;
    /**
    * Absolute or relative path to OVA
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#ova_path CatalogItem#ova_path}
    */
    readonly ovaPath?: string;
    /**
    * URL of OVF file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#ovf_url CatalogItem#ovf_url}
    */
    readonly ovfUrl?: string;
    /**
    * shows upload progress in stdout
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#show_upload_progress CatalogItem#show_upload_progress}
    */
    readonly showUploadProgress?: boolean | cdktf.IResolvable;
    /**
    * size of upload file piece size in mega bytes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#upload_piece_size CatalogItem#upload_piece_size}
    */
    readonly uploadPieceSize?: number;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#metadata_entry CatalogItem#metadata_entry}
    */
    readonly metadataEntry?: CatalogItemMetadataEntry[] | cdktf.IResolvable;
}
export interface CatalogItemMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#is_system CatalogItem#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#key CatalogItem#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#type CatalogItem#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#user_access CatalogItem#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#value CatalogItem#value}
    */
    readonly value?: string;
}
export declare function catalogItemMetadataEntryToTerraform(struct?: CatalogItemMetadataEntry | cdktf.IResolvable): any;
export declare function catalogItemMetadataEntryToHclTerraform(struct?: CatalogItemMetadataEntry | cdktf.IResolvable): any;
export declare class CatalogItemMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CatalogItemMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: CatalogItemMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class CatalogItemMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CatalogItemMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CatalogItemMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item vcd_catalog_item}
*/
export declare class CatalogItem extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_catalog_item";
    /**
    * Generates CDKTF code for importing a CatalogItem resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CatalogItem to import
    * @param importFromId The id of the existing CatalogItem that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CatalogItem to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_item vcd_catalog_item} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CatalogItemConfig
    */
    constructor(scope: Construct, id: string, config: CatalogItemConfig);
    private _catalog?;
    get catalog(): string;
    set catalog(value: string);
    get catalogInput(): string | undefined;
    private _catalogItemMetadata?;
    get catalogItemMetadata(): {
        [key: string]: string;
    };
    set catalogItemMetadata(value: {
        [key: string]: string;
    });
    resetCatalogItemMetadata(): void;
    get catalogItemMetadataInput(): {
        [key: string]: string;
    } | undefined;
    get created(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _ovaPath?;
    get ovaPath(): string;
    set ovaPath(value: string);
    resetOvaPath(): void;
    get ovaPathInput(): string | undefined;
    private _ovfUrl?;
    get ovfUrl(): string;
    set ovfUrl(value: string);
    resetOvfUrl(): void;
    get ovfUrlInput(): string | undefined;
    private _showUploadProgress?;
    get showUploadProgress(): boolean | cdktf.IResolvable;
    set showUploadProgress(value: boolean | cdktf.IResolvable);
    resetShowUploadProgress(): void;
    get showUploadProgressInput(): boolean | cdktf.IResolvable | undefined;
    private _uploadPieceSize?;
    get uploadPieceSize(): number;
    set uploadPieceSize(value: number);
    resetUploadPieceSize(): void;
    get uploadPieceSizeInput(): number | undefined;
    private _metadataEntry;
    get metadataEntry(): CatalogItemMetadataEntryList;
    putMetadataEntry(value: CatalogItemMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | CatalogItemMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
