import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CatalogMediaConfig extends cdktf.TerraformMetaArguments {
    /**
    * catalog name where to upload the Media file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#catalog CatalogMedia#catalog}
    */
    readonly catalog?: string;
    /**
    * ID of the catalog where to upload the Media file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#catalog_id CatalogMedia#catalog_id}
    */
    readonly catalogId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#description CatalogMedia#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#id CatalogMedia#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * absolute or relative path to Media file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#media_path CatalogMedia#media_path}
    */
    readonly mediaPath?: string;
    /**
    * Key and value pairs for catalog item metadata
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#metadata CatalogMedia#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * media name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#name CatalogMedia#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#org CatalogMedia#org}
    */
    readonly org?: string;
    /**
    * shows upload progress in stdout
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#show_upload_progress CatalogMedia#show_upload_progress}
    */
    readonly showUploadProgress?: boolean | cdktf.IResolvable;
    /**
    * If true, will allow uploading any file type, not only .ISO
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#upload_any_file CatalogMedia#upload_any_file}
    */
    readonly uploadAnyFile?: boolean | cdktf.IResolvable;
    /**
    * size of upload file piece size in mega bytes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#upload_piece_size CatalogMedia#upload_piece_size}
    */
    readonly uploadPieceSize?: number;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#metadata_entry CatalogMedia#metadata_entry}
    */
    readonly metadataEntry?: CatalogMediaMetadataEntry[] | cdktf.IResolvable;
}
export interface CatalogMediaMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#is_system CatalogMedia#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#key CatalogMedia#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#type CatalogMedia#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#user_access CatalogMedia#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#value CatalogMedia#value}
    */
    readonly value?: string;
}
export declare function catalogMediaMetadataEntryToTerraform(struct?: CatalogMediaMetadataEntry | cdktf.IResolvable): any;
export declare function catalogMediaMetadataEntryToHclTerraform(struct?: CatalogMediaMetadataEntry | cdktf.IResolvable): any;
export declare class CatalogMediaMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CatalogMediaMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: CatalogMediaMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class CatalogMediaMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CatalogMediaMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CatalogMediaMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media vcd_catalog_media}
*/
export declare class CatalogMedia extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_catalog_media";
    /**
    * Generates CDKTF code for importing a CatalogMedia resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CatalogMedia to import
    * @param importFromId The id of the existing CatalogMedia that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CatalogMedia to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_media vcd_catalog_media} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CatalogMediaConfig
    */
    constructor(scope: Construct, id: string, config: CatalogMediaConfig);
    private _catalog?;
    get catalog(): string;
    set catalog(value: string);
    resetCatalog(): void;
    get catalogInput(): string | undefined;
    private _catalogId?;
    get catalogId(): string;
    set catalogId(value: string);
    resetCatalogId(): void;
    get catalogIdInput(): string | undefined;
    get creationDate(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isIso(): cdktf.IResolvable;
    get isPublished(): cdktf.IResolvable;
    private _mediaPath?;
    get mediaPath(): string;
    set mediaPath(value: string);
    resetMediaPath(): void;
    get mediaPathInput(): string | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get ownerName(): string;
    private _showUploadProgress?;
    get showUploadProgress(): boolean | cdktf.IResolvable;
    set showUploadProgress(value: boolean | cdktf.IResolvable);
    resetShowUploadProgress(): void;
    get showUploadProgressInput(): boolean | cdktf.IResolvable | undefined;
    get size(): number;
    get status(): string;
    get storageProfileName(): string;
    private _uploadAnyFile?;
    get uploadAnyFile(): boolean | cdktf.IResolvable;
    set uploadAnyFile(value: boolean | cdktf.IResolvable);
    resetUploadAnyFile(): void;
    get uploadAnyFileInput(): boolean | cdktf.IResolvable | undefined;
    private _uploadPieceSize?;
    get uploadPieceSize(): number;
    set uploadPieceSize(value: number);
    resetUploadPieceSize(): void;
    get uploadPieceSizeInput(): number | undefined;
    private _metadataEntry;
    get metadataEntry(): CatalogMediaMetadataEntryList;
    putMetadataEntry(value: CatalogMediaMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | CatalogMediaMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
