import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CatalogVappTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the Catalog where to upload the OVA file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#catalog_id CatalogVappTemplate#catalog_id}
    */
    readonly catalogId: string;
    /**
    * Description of the vApp Template. Not to be used with `ovf_url` when target OVA has a description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#description CatalogVappTemplate#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#id CatalogVappTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key and value pairs for the metadata of this vApp Template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#metadata CatalogVappTemplate#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * vApp Template name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#name CatalogVappTemplate#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#org CatalogVappTemplate#org}
    */
    readonly org?: string;
    /**
    * Absolute or relative path to OVA
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#ova_path CatalogVappTemplate#ova_path}
    */
    readonly ovaPath?: string;
    /**
    * URL of OVF file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#ovf_url CatalogVappTemplate#ovf_url}
    */
    readonly ovfUrl?: string;
    /**
    * Size of upload file piece size in megabytes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#upload_piece_size CatalogVappTemplate#upload_piece_size}
    */
    readonly uploadPieceSize?: number;
    /**
    * capture_vapp block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#capture_vapp CatalogVappTemplate#capture_vapp}
    */
    readonly captureVapp?: CatalogVappTemplateCaptureVapp;
    /**
    * lease block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#lease CatalogVappTemplate#lease}
    */
    readonly lease?: CatalogVappTemplateLease;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#metadata_entry CatalogVappTemplate#metadata_entry}
    */
    readonly metadataEntry?: CatalogVappTemplateMetadataEntry[] | cdktf.IResolvable;
}
export interface CatalogVappTemplateCaptureVapp {
    /**
    * Defines if Trusted Platform Module should be copied (false) or created (true). Default 'false'. VCD 10.4.2+
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#copy_tpm_on_instantiate CatalogVappTemplate#copy_tpm_on_instantiate}
    */
    readonly copyTpmOnInstantiate?: boolean | cdktf.IResolvable;
    /**
    * Marks if instantiating applies customization settings ('true'). Default is 'false` - create an identical copy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#customize_on_instantiate CatalogVappTemplate#customize_on_instantiate}
    */
    readonly customizeOnInstantiate?: boolean | cdktf.IResolvable;
    /**
    * An existing catalog item ID to overwrite
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#overwrite_catalog_item_id CatalogVappTemplate#overwrite_catalog_item_id}
    */
    readonly overwriteCatalogItemId?: string;
    /**
    * Source vApp ID (can be a vApp ID or 'vapp_id' field of standalone VM 'vcd_vm')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#source_id CatalogVappTemplate#source_id}
    */
    readonly sourceId?: string;
}
export declare function catalogVappTemplateCaptureVappToTerraform(struct?: CatalogVappTemplateCaptureVappOutputReference | CatalogVappTemplateCaptureVapp): any;
export declare function catalogVappTemplateCaptureVappToHclTerraform(struct?: CatalogVappTemplateCaptureVappOutputReference | CatalogVappTemplateCaptureVapp): any;
export declare class CatalogVappTemplateCaptureVappOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CatalogVappTemplateCaptureVapp | undefined;
    set internalValue(value: CatalogVappTemplateCaptureVapp | undefined);
    private _copyTpmOnInstantiate?;
    get copyTpmOnInstantiate(): boolean | cdktf.IResolvable;
    set copyTpmOnInstantiate(value: boolean | cdktf.IResolvable);
    resetCopyTpmOnInstantiate(): void;
    get copyTpmOnInstantiateInput(): boolean | cdktf.IResolvable | undefined;
    private _customizeOnInstantiate?;
    get customizeOnInstantiate(): boolean | cdktf.IResolvable;
    set customizeOnInstantiate(value: boolean | cdktf.IResolvable);
    resetCustomizeOnInstantiate(): void;
    get customizeOnInstantiateInput(): boolean | cdktf.IResolvable | undefined;
    private _overwriteCatalogItemId?;
    get overwriteCatalogItemId(): string;
    set overwriteCatalogItemId(value: string);
    resetOverwriteCatalogItemId(): void;
    get overwriteCatalogItemIdInput(): string | undefined;
    private _sourceId?;
    get sourceId(): string;
    set sourceId(value: string);
    resetSourceId(): void;
    get sourceIdInput(): string | undefined;
}
export interface CatalogVappTemplateLease {
    /**
    * How long the vApp template is available before being automatically deleted or marked as expired. 0 means never expires (or expires at the maximum limit provided by the parent Org)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#storage_lease_in_sec CatalogVappTemplate#storage_lease_in_sec}
    */
    readonly storageLeaseInSec: number;
}
export declare function catalogVappTemplateLeaseToTerraform(struct?: CatalogVappTemplateLeaseOutputReference | CatalogVappTemplateLease): any;
export declare function catalogVappTemplateLeaseToHclTerraform(struct?: CatalogVappTemplateLeaseOutputReference | CatalogVappTemplateLease): any;
export declare class CatalogVappTemplateLeaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CatalogVappTemplateLease | undefined;
    set internalValue(value: CatalogVappTemplateLease | undefined);
    private _storageLeaseInSec?;
    get storageLeaseInSec(): number;
    set storageLeaseInSec(value: number);
    get storageLeaseInSecInput(): number | undefined;
}
export interface CatalogVappTemplateMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#is_system CatalogVappTemplate#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#key CatalogVappTemplate#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#type CatalogVappTemplate#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#user_access CatalogVappTemplate#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#value CatalogVappTemplate#value}
    */
    readonly value?: string;
}
export declare function catalogVappTemplateMetadataEntryToTerraform(struct?: CatalogVappTemplateMetadataEntry | cdktf.IResolvable): any;
export declare function catalogVappTemplateMetadataEntryToHclTerraform(struct?: CatalogVappTemplateMetadataEntry | cdktf.IResolvable): any;
export declare class CatalogVappTemplateMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CatalogVappTemplateMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: CatalogVappTemplateMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class CatalogVappTemplateMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CatalogVappTemplateMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CatalogVappTemplateMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template vcd_catalog_vapp_template}
*/
export declare class CatalogVappTemplate extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_catalog_vapp_template";
    /**
    * Generates CDKTF code for importing a CatalogVappTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CatalogVappTemplate to import
    * @param importFromId The id of the existing CatalogVappTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CatalogVappTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog_vapp_template vcd_catalog_vapp_template} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CatalogVappTemplateConfig
    */
    constructor(scope: Construct, id: string, config: CatalogVappTemplateConfig);
    private _catalogId?;
    get catalogId(): string;
    set catalogId(value: string);
    get catalogIdInput(): string | undefined;
    get catalogItemId(): string;
    get created(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inheritedMetadata;
    get inheritedMetadata(): cdktf.StringMap;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _ovaPath?;
    get ovaPath(): string;
    set ovaPath(value: string);
    resetOvaPath(): void;
    get ovaPathInput(): string | undefined;
    private _ovfUrl?;
    get ovfUrl(): string;
    set ovfUrl(value: string);
    resetOvfUrl(): void;
    get ovfUrlInput(): string | undefined;
    private _uploadPieceSize?;
    get uploadPieceSize(): number;
    set uploadPieceSize(value: number);
    resetUploadPieceSize(): void;
    get uploadPieceSizeInput(): number | undefined;
    get vdcId(): string;
    get vmNames(): string[];
    private _captureVapp;
    get captureVapp(): CatalogVappTemplateCaptureVappOutputReference;
    putCaptureVapp(value: CatalogVappTemplateCaptureVapp): void;
    resetCaptureVapp(): void;
    get captureVappInput(): CatalogVappTemplateCaptureVapp | undefined;
    private _lease;
    get lease(): CatalogVappTemplateLeaseOutputReference;
    putLease(value: CatalogVappTemplateLease): void;
    resetLease(): void;
    get leaseInput(): CatalogVappTemplateLease | undefined;
    private _metadataEntry;
    get metadataEntry(): CatalogVappTemplateMetadataEntryList;
    putMetadataEntry(value: CatalogVappTemplateMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | CatalogVappTemplateMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
