import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CatalogConfig extends cdktf.TerraformMetaArguments {
    /**
    * True enables early catalog export to optimize synchronization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#cache_enabled Catalog#cache_enabled}
    */
    readonly cacheEnabled?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_force=True with delete_recursive=True to remove a catalog and any objects it contains, regardless of their state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#delete_force Catalog#delete_force}
    */
    readonly deleteForce?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_recursive=True to remove the catalog and any objects it contains that are in a state that normally allows removal.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#delete_recursive Catalog#delete_recursive}
    */
    readonly deleteRecursive?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#description Catalog#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#id Catalog#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key and value pairs for catalog metadata.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#metadata Catalog#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#name Catalog#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#org Catalog#org}
    */
    readonly org?: string;
    /**
    * An optional password to access the catalog. Only ASCII characters are allowed in a valid password.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#password Catalog#password}
    */
    readonly password?: string;
    /**
    * Include BIOS UUIDs and MAC addresses in the downloaded OVF package. Preserving the identity information limits the portability of the package and you should use it only when necessary.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#preserve_identity_information Catalog#preserve_identity_information}
    */
    readonly preserveIdentityInformation?: boolean | cdktf.IResolvable;
    /**
    * True allows to publish a catalog externally to make its vApp templates and media files available for subscription by organizations outside the Cloud Director installation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#publish_enabled Catalog#publish_enabled}
    */
    readonly publishEnabled?: boolean | cdktf.IResolvable;
    /**
    * Optional storage profile ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#storage_profile_id Catalog#storage_profile_id}
    */
    readonly storageProfileId?: string;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#metadata_entry Catalog#metadata_entry}
    */
    readonly metadataEntry?: CatalogMetadataEntry[] | cdktf.IResolvable;
}
export interface CatalogMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#is_system Catalog#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#key Catalog#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#type Catalog#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#user_access Catalog#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#value Catalog#value}
    */
    readonly value?: string;
}
export declare function catalogMetadataEntryToTerraform(struct?: CatalogMetadataEntry | cdktf.IResolvable): any;
export declare function catalogMetadataEntryToHclTerraform(struct?: CatalogMetadataEntry | cdktf.IResolvable): any;
export declare class CatalogMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CatalogMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: CatalogMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class CatalogMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CatalogMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CatalogMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog vcd_catalog}
*/
export declare class Catalog extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_catalog";
    /**
    * Generates CDKTF code for importing a Catalog resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Catalog to import
    * @param importFromId The id of the existing Catalog that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Catalog to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/catalog vcd_catalog} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CatalogConfig
    */
    constructor(scope: Construct, id: string, config: CatalogConfig);
    private _cacheEnabled?;
    get cacheEnabled(): boolean | cdktf.IResolvable;
    set cacheEnabled(value: boolean | cdktf.IResolvable);
    resetCacheEnabled(): void;
    get cacheEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get catalogVersion(): number;
    get created(): string;
    private _deleteForce?;
    get deleteForce(): boolean | cdktf.IResolvable;
    set deleteForce(value: boolean | cdktf.IResolvable);
    resetDeleteForce(): void;
    get deleteForceInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteRecursive?;
    get deleteRecursive(): boolean | cdktf.IResolvable;
    set deleteRecursive(value: boolean | cdktf.IResolvable);
    resetDeleteRecursive(): void;
    get deleteRecursiveInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isLocal(): cdktf.IResolvable;
    get isPublished(): cdktf.IResolvable;
    get isShared(): cdktf.IResolvable;
    get mediaItemList(): string[];
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numberOfMedia(): number;
    get numberOfVappTemplates(): number;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get ownerName(): string;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _preserveIdentityInformation?;
    get preserveIdentityInformation(): boolean | cdktf.IResolvable;
    set preserveIdentityInformation(value: boolean | cdktf.IResolvable);
    resetPreserveIdentityInformation(): void;
    get preserveIdentityInformationInput(): boolean | cdktf.IResolvable | undefined;
    private _publishEnabled?;
    get publishEnabled(): boolean | cdktf.IResolvable;
    set publishEnabled(value: boolean | cdktf.IResolvable);
    resetPublishEnabled(): void;
    get publishEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get publishSubscriptionType(): string;
    get publishSubscriptionUrl(): string;
    private _storageProfileId?;
    get storageProfileId(): string;
    set storageProfileId(value: string);
    resetStorageProfileId(): void;
    get storageProfileIdInput(): string | undefined;
    get vappTemplateList(): string[];
    private _metadataEntry;
    get metadataEntry(): CatalogMetadataEntryList;
    putMetadataEntry(value: CatalogMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | CatalogMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
