import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ClonedVappConfig extends cdktf.TerraformMetaArguments {
    /**
    * If true, it will delete the source (vApp or template) after creating the new vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#delete_source ClonedVapp#delete_source}
    */
    readonly deleteSource?: boolean | cdktf.IResolvable;
    /**
    * Optional description of the vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#description ClonedVapp#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#id ClonedVapp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A name for the vApp, unique withing the VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#name ClonedVapp#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#org ClonedVapp#org}
    */
    readonly org?: string;
    /**
    * A boolean value stating if this vApp should be powered on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#power_on ClonedVapp#power_on}
    */
    readonly powerOn?: boolean | cdktf.IResolvable;
    /**
    * The identifier of the source to use for the creation of this vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#source_id ClonedVapp#source_id}
    */
    readonly sourceId: string;
    /**
    * The type of the source to use for the creation of this vApp (one of 'vapp' or 'template')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#source_type ClonedVapp#source_type}
    */
    readonly sourceType: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#vdc ClonedVapp#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp vcd_cloned_vapp}
*/
export declare class ClonedVapp extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_cloned_vapp";
    /**
    * Generates CDKTF code for importing a ClonedVapp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ClonedVapp to import
    * @param importFromId The id of the existing ClonedVapp that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ClonedVapp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cloned_vapp vcd_cloned_vapp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ClonedVappConfig
    */
    constructor(scope: Construct, id: string, config: ClonedVappConfig);
    private _deleteSource?;
    get deleteSource(): boolean | cdktf.IResolvable;
    set deleteSource(value: boolean | cdktf.IResolvable);
    resetDeleteSource(): void;
    get deleteSourceInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _powerOn?;
    get powerOn(): boolean | cdktf.IResolvable;
    set powerOn(value: boolean | cdktf.IResolvable);
    resetPowerOn(): void;
    get powerOnInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceId?;
    get sourceId(): string;
    set sourceId(value: string);
    get sourceIdInput(): string | undefined;
    private _sourceType?;
    get sourceType(): string;
    set sourceType(value: string);
    get sourceTypeInput(): string | undefined;
    get status(): number;
    get statusText(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    get vmList(): string[];
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
