import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CseKubernetesClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * A file generated by 'vcd_api_token' resource, that stores the API token used to create and manage the cluster, owned by the user specified in 'owner'. Be careful about this file, as it contains sensitive information
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#api_token_file CseKubernetesCluster#api_token_file}
    */
    readonly apiTokenFile?: string;
    /**
    * If errors occur before the Kubernetes cluster becomes available, and this argument is 'true', CSE Server will automatically attempt to repair the cluster
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#auto_repair_on_errors CseKubernetesCluster#auto_repair_on_errors}
    */
    readonly autoRepairOnErrors?: boolean | cdktf.IResolvable;
    /**
    * The CSE version to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#cse_version CseKubernetesCluster#cse_version}
    */
    readonly cseVersion: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#id CseKubernetesCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the vApp Template that corresponds to a Kubernetes template OVA
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#kubernetes_template_id CseKubernetesCluster#kubernetes_template_id}
    */
    readonly kubernetesTemplateId: string;
    /**
    * The name of the Kubernetes cluster
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#name CseKubernetesCluster#name}
    */
    readonly name: string;
    /**
    * The ID of the network that the Kubernetes cluster will use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#network_id CseKubernetesCluster#network_id}
    */
    readonly networkId: string;
    /**
    * After the Kubernetes cluster becomes available, nodes that become unhealthy will be remediated according to unhealthy node conditions and remediation rules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#node_health_check CseKubernetesCluster#node_health_check}
    */
    readonly nodeHealthCheck?: boolean | cdktf.IResolvable;
    /**
    * The time, in minutes, to wait for the cluster operations to be successfully completed. For example, during cluster creation, it should be in `provisioned`state before the timeout is reached, otherwise the operation will return an error. For cluster deletion, this timeoutspecifies the time to wait until the cluster is completely deleted. Setting this argument to `0` means to wait indefinitely
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#operations_timeout_minutes CseKubernetesCluster#operations_timeout_minutes}
    */
    readonly operationsTimeoutMinutes?: number;
    /**
    * The name of organization that will own this Kubernetes cluster, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#org CseKubernetesCluster#org}
    */
    readonly org?: string;
    /**
    * The user that creates the cluster and owns the API token specified in 'api_token'. It must have the 'Kubernetes Cluster Author' role. If not specified, it assumes it's the user from the provider configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#owner CseKubernetesCluster#owner}
    */
    readonly owner?: string;
    /**
    * CIDR that the Kubernetes pods will use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#pods_cidr CseKubernetesCluster#pods_cidr}
    */
    readonly podsCidr?: string;
    /**
    * The Kubernetes runtime for the cluster. Only 'tkg' (Tanzu Kubernetes Grid) is supported
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#runtime CseKubernetesCluster#runtime}
    */
    readonly runtime?: string;
    /**
    * CIDR that the Kubernetes services will use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#services_cidr CseKubernetesCluster#services_cidr}
    */
    readonly servicesCidr?: string;
    /**
    * The SSH public key used to login into the cluster nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#ssh_public_key CseKubernetesCluster#ssh_public_key}
    */
    readonly sshPublicKey?: string;
    /**
    * The ID of the VDC that hosts the Kubernetes cluster
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#vdc_id CseKubernetesCluster#vdc_id}
    */
    readonly vdcId: string;
    /**
    * Virtual IP subnet for the cluster
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#virtual_ip_subnet CseKubernetesCluster#virtual_ip_subnet}
    */
    readonly virtualIpSubnet?: string;
    /**
    * control_plane block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#control_plane CseKubernetesCluster#control_plane}
    */
    readonly controlPlane: CseKubernetesClusterControlPlane;
    /**
    * default_storage_class block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#default_storage_class CseKubernetesCluster#default_storage_class}
    */
    readonly defaultStorageClass?: CseKubernetesClusterDefaultStorageClass;
    /**
    * worker_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#worker_pool CseKubernetesCluster#worker_pool}
    */
    readonly workerPool: CseKubernetesClusterWorkerPool[] | cdktf.IResolvable;
}
export interface CseKubernetesClusterEvents {
}
export declare function cseKubernetesClusterEventsToTerraform(struct?: CseKubernetesClusterEvents): any;
export declare function cseKubernetesClusterEventsToHclTerraform(struct?: CseKubernetesClusterEvents): any;
export declare class CseKubernetesClusterEventsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CseKubernetesClusterEvents | undefined;
    set internalValue(value: CseKubernetesClusterEvents | undefined);
    get details(): string;
    get name(): string;
    get occurredAt(): string;
    get resourceId(): string;
    get type(): string;
}
export declare class CseKubernetesClusterEventsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CseKubernetesClusterEventsOutputReference;
}
export interface CseKubernetesClusterControlPlane {
    /**
    * Disk size, in Gibibytes (Gi), for the control plane nodes. Must be at least 20
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#disk_size_gi CseKubernetesCluster#disk_size_gi}
    */
    readonly diskSizeGi?: number;
    /**
    * IP for the control plane. It will be automatically assigned during cluster creation if left empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#ip CseKubernetesCluster#ip}
    */
    readonly ip?: string;
    /**
    * The number of nodes that the control plane has. Must be an odd number and higher than 0
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#machine_count CseKubernetesCluster#machine_count}
    */
    readonly machineCount?: number;
    /**
    * VM Placement policy for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#placement_policy_id CseKubernetesCluster#placement_policy_id}
    */
    readonly placementPolicyId?: string;
    /**
    * VM Sizing policy for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#sizing_policy_id CseKubernetesCluster#sizing_policy_id}
    */
    readonly sizingPolicyId?: string;
    /**
    * Storage profile for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#storage_profile_id CseKubernetesCluster#storage_profile_id}
    */
    readonly storageProfileId?: string;
}
export declare function cseKubernetesClusterControlPlaneToTerraform(struct?: CseKubernetesClusterControlPlaneOutputReference | CseKubernetesClusterControlPlane): any;
export declare function cseKubernetesClusterControlPlaneToHclTerraform(struct?: CseKubernetesClusterControlPlaneOutputReference | CseKubernetesClusterControlPlane): any;
export declare class CseKubernetesClusterControlPlaneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CseKubernetesClusterControlPlane | undefined;
    set internalValue(value: CseKubernetesClusterControlPlane | undefined);
    private _diskSizeGi?;
    get diskSizeGi(): number;
    set diskSizeGi(value: number);
    resetDiskSizeGi(): void;
    get diskSizeGiInput(): number | undefined;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _machineCount?;
    get machineCount(): number;
    set machineCount(value: number);
    resetMachineCount(): void;
    get machineCountInput(): number | undefined;
    private _placementPolicyId?;
    get placementPolicyId(): string;
    set placementPolicyId(value: string);
    resetPlacementPolicyId(): void;
    get placementPolicyIdInput(): string | undefined;
    private _sizingPolicyId?;
    get sizingPolicyId(): string;
    set sizingPolicyId(value: string);
    resetSizingPolicyId(): void;
    get sizingPolicyIdInput(): string | undefined;
    private _storageProfileId?;
    get storageProfileId(): string;
    set storageProfileId(value: string);
    resetStorageProfileId(): void;
    get storageProfileIdInput(): string | undefined;
}
export interface CseKubernetesClusterDefaultStorageClass {
    /**
    * Filesystem of the storage class, can be either 'ext4' or 'xfs'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#filesystem CseKubernetesCluster#filesystem}
    */
    readonly filesystem: string;
    /**
    * Name to give to this storage class
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#name CseKubernetesCluster#name}
    */
    readonly name: string;
    /**
    * Reclaim policy. Possible values are: `delete` deletes the volume when the `PersistentVolumeClaim` is deleted; `retain` does not delete, and the volume can be manually reclaimed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#reclaim_policy CseKubernetesCluster#reclaim_policy}
    */
    readonly reclaimPolicy: string;
    /**
    * ID of the storage profile to use for the storage class
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#storage_profile_id CseKubernetesCluster#storage_profile_id}
    */
    readonly storageProfileId: string;
}
export declare function cseKubernetesClusterDefaultStorageClassToTerraform(struct?: CseKubernetesClusterDefaultStorageClassOutputReference | CseKubernetesClusterDefaultStorageClass): any;
export declare function cseKubernetesClusterDefaultStorageClassToHclTerraform(struct?: CseKubernetesClusterDefaultStorageClassOutputReference | CseKubernetesClusterDefaultStorageClass): any;
export declare class CseKubernetesClusterDefaultStorageClassOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): CseKubernetesClusterDefaultStorageClass | undefined;
    set internalValue(value: CseKubernetesClusterDefaultStorageClass | undefined);
    private _filesystem?;
    get filesystem(): string;
    set filesystem(value: string);
    get filesystemInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _reclaimPolicy?;
    get reclaimPolicy(): string;
    set reclaimPolicy(value: string);
    get reclaimPolicyInput(): string | undefined;
    private _storageProfileId?;
    get storageProfileId(): string;
    set storageProfileId(value: string);
    get storageProfileIdInput(): string | undefined;
}
export interface CseKubernetesClusterWorkerPool {
    /**
    * Disk size, in Gibibytes (Gi), for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#disk_size_gi CseKubernetesCluster#disk_size_gi}
    */
    readonly diskSizeGi?: number;
    /**
    * The number of nodes that this worker pool has. Must be higher than or equal to 0
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#machine_count CseKubernetesCluster#machine_count}
    */
    readonly machineCount?: number;
    /**
    * The name of this worker pool. Must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#name CseKubernetesCluster#name}
    */
    readonly name: string;
    /**
    * VM Placement policy for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#placement_policy_id CseKubernetesCluster#placement_policy_id}
    */
    readonly placementPolicyId?: string;
    /**
    * VM Sizing policy for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#sizing_policy_id CseKubernetesCluster#sizing_policy_id}
    */
    readonly sizingPolicyId?: string;
    /**
    * Storage profile for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#storage_profile_id CseKubernetesCluster#storage_profile_id}
    */
    readonly storageProfileId?: string;
    /**
    * vGPU policy for the control plane nodes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#vgpu_policy_id CseKubernetesCluster#vgpu_policy_id}
    */
    readonly vgpuPolicyId?: string;
}
export declare function cseKubernetesClusterWorkerPoolToTerraform(struct?: CseKubernetesClusterWorkerPool | cdktf.IResolvable): any;
export declare function cseKubernetesClusterWorkerPoolToHclTerraform(struct?: CseKubernetesClusterWorkerPool | cdktf.IResolvable): any;
export declare class CseKubernetesClusterWorkerPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CseKubernetesClusterWorkerPool | cdktf.IResolvable | undefined;
    set internalValue(value: CseKubernetesClusterWorkerPool | cdktf.IResolvable | undefined);
    private _diskSizeGi?;
    get diskSizeGi(): number;
    set diskSizeGi(value: number);
    resetDiskSizeGi(): void;
    get diskSizeGiInput(): number | undefined;
    private _machineCount?;
    get machineCount(): number;
    set machineCount(value: number);
    resetMachineCount(): void;
    get machineCountInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _placementPolicyId?;
    get placementPolicyId(): string;
    set placementPolicyId(value: string);
    resetPlacementPolicyId(): void;
    get placementPolicyIdInput(): string | undefined;
    private _sizingPolicyId?;
    get sizingPolicyId(): string;
    set sizingPolicyId(value: string);
    resetSizingPolicyId(): void;
    get sizingPolicyIdInput(): string | undefined;
    private _storageProfileId?;
    get storageProfileId(): string;
    set storageProfileId(value: string);
    resetStorageProfileId(): void;
    get storageProfileIdInput(): string | undefined;
    private _vgpuPolicyId?;
    get vgpuPolicyId(): string;
    set vgpuPolicyId(value: string);
    resetVgpuPolicyId(): void;
    get vgpuPolicyIdInput(): string | undefined;
}
export declare class CseKubernetesClusterWorkerPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CseKubernetesClusterWorkerPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CseKubernetesClusterWorkerPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster vcd_cse_kubernetes_cluster}
*/
export declare class CseKubernetesCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_cse_kubernetes_cluster";
    /**
    * Generates CDKTF code for importing a CseKubernetesCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CseKubernetesCluster to import
    * @param importFromId The id of the existing CseKubernetesCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CseKubernetesCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/cse_kubernetes_cluster vcd_cse_kubernetes_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CseKubernetesClusterConfig
    */
    constructor(scope: Construct, id: string, config: CseKubernetesClusterConfig);
    private _apiTokenFile?;
    get apiTokenFile(): string;
    set apiTokenFile(value: string);
    resetApiTokenFile(): void;
    get apiTokenFileInput(): string | undefined;
    private _autoRepairOnErrors?;
    get autoRepairOnErrors(): boolean | cdktf.IResolvable;
    set autoRepairOnErrors(value: boolean | cdktf.IResolvable);
    resetAutoRepairOnErrors(): void;
    get autoRepairOnErrorsInput(): boolean | cdktf.IResolvable | undefined;
    get capvcdVersion(): string;
    get clusterResourceSetBindings(): string[];
    get cpiVersion(): string;
    private _cseVersion?;
    get cseVersion(): string;
    set cseVersion(value: string);
    get cseVersionInput(): string | undefined;
    get csiVersion(): string;
    private _events;
    get events(): CseKubernetesClusterEventsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get kubeconfig(): string;
    private _kubernetesTemplateId?;
    get kubernetesTemplateId(): string;
    set kubernetesTemplateId(value: string);
    get kubernetesTemplateIdInput(): string | undefined;
    get kubernetesVersion(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkId?;
    get networkId(): string;
    set networkId(value: string);
    get networkIdInput(): string | undefined;
    private _nodeHealthCheck?;
    get nodeHealthCheck(): boolean | cdktf.IResolvable;
    set nodeHealthCheck(value: boolean | cdktf.IResolvable);
    resetNodeHealthCheck(): void;
    get nodeHealthCheckInput(): boolean | cdktf.IResolvable | undefined;
    private _operationsTimeoutMinutes?;
    get operationsTimeoutMinutes(): number;
    set operationsTimeoutMinutes(value: number);
    resetOperationsTimeoutMinutes(): void;
    get operationsTimeoutMinutesInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _owner?;
    get owner(): string;
    set owner(value: string);
    resetOwner(): void;
    get ownerInput(): string | undefined;
    private _podsCidr?;
    get podsCidr(): string;
    set podsCidr(value: string);
    resetPodsCidr(): void;
    get podsCidrInput(): string | undefined;
    private _runtime?;
    get runtime(): string;
    set runtime(value: string);
    resetRuntime(): void;
    get runtimeInput(): string | undefined;
    private _servicesCidr?;
    get servicesCidr(): string;
    set servicesCidr(value: string);
    resetServicesCidr(): void;
    get servicesCidrInput(): string | undefined;
    private _sshPublicKey?;
    get sshPublicKey(): string;
    set sshPublicKey(value: string);
    resetSshPublicKey(): void;
    get sshPublicKeyInput(): string | undefined;
    get state(): string;
    get supportedUpgrades(): string[];
    get tkgProductVersion(): string;
    private _vdcId?;
    get vdcId(): string;
    set vdcId(value: string);
    get vdcIdInput(): string | undefined;
    private _virtualIpSubnet?;
    get virtualIpSubnet(): string;
    set virtualIpSubnet(value: string);
    resetVirtualIpSubnet(): void;
    get virtualIpSubnetInput(): string | undefined;
    private _controlPlane;
    get controlPlane(): CseKubernetesClusterControlPlaneOutputReference;
    putControlPlane(value: CseKubernetesClusterControlPlane): void;
    get controlPlaneInput(): CseKubernetesClusterControlPlane | undefined;
    private _defaultStorageClass;
    get defaultStorageClass(): CseKubernetesClusterDefaultStorageClassOutputReference;
    putDefaultStorageClass(value: CseKubernetesClusterDefaultStorageClass): void;
    resetDefaultStorageClass(): void;
    get defaultStorageClassInput(): CseKubernetesClusterDefaultStorageClass | undefined;
    private _workerPool;
    get workerPool(): CseKubernetesClusterWorkerPoolList;
    putWorkerPool(value: CseKubernetesClusterWorkerPool[] | cdktf.IResolvable): void;
    get workerPoolInput(): cdktf.IResolvable | CseKubernetesClusterWorkerPool[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
