import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdCatalogItemConfig extends cdktf.TerraformMetaArguments {
    /**
    * catalog containing the item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#catalog DataVcdCatalogItem#catalog}
    */
    readonly catalog: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#id DataVcdCatalogItem#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the item. It is optional when a filter is provided
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#name DataVcdCatalogItem#name}
    */
    readonly name?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#org DataVcdCatalogItem#org}
    */
    readonly org?: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#filter DataVcdCatalogItem#filter}
    */
    readonly filter?: DataVcdCatalogItemFilter;
}
export interface DataVcdCatalogItemMetadataEntry {
}
export declare function dataVcdCatalogItemMetadataEntryToTerraform(struct?: DataVcdCatalogItemMetadataEntry): any;
export declare function dataVcdCatalogItemMetadataEntryToHclTerraform(struct?: DataVcdCatalogItemMetadataEntry): any;
export declare class DataVcdCatalogItemMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCatalogItemMetadataEntry | undefined;
    set internalValue(value: DataVcdCatalogItemMetadataEntry | undefined);
    get isSystem(): cdktf.IResolvable;
    get key(): string;
    get type(): string;
    get userAccess(): string;
    get value(): string;
}
export declare class DataVcdCatalogItemMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCatalogItemMetadataEntryOutputReference;
}
export interface DataVcdCatalogItemFilterMetadata {
    /**
    * True if is a metadata@SYSTEM key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#is_system DataVcdCatalogItem#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Metadata key (field name)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#key DataVcdCatalogItem#key}
    */
    readonly key: string;
    /**
    * Type of metadata value (needed only if "use_api_search" is true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#type DataVcdCatalogItem#type}
    */
    readonly type?: string;
    /**
    * If true, will search the vCD using native metadata query (without regular expressions)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#use_api_search DataVcdCatalogItem#use_api_search}
    */
    readonly useApiSearch?: boolean | cdktf.IResolvable;
    /**
    * Metadata value (can be a regular expression if "use_api_search" is false)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#value DataVcdCatalogItem#value}
    */
    readonly value: string;
}
export declare function dataVcdCatalogItemFilterMetadataToTerraform(struct?: DataVcdCatalogItemFilterMetadata | cdktf.IResolvable): any;
export declare function dataVcdCatalogItemFilterMetadataToHclTerraform(struct?: DataVcdCatalogItemFilterMetadata | cdktf.IResolvable): any;
export declare class DataVcdCatalogItemFilterMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCatalogItemFilterMetadata | cdktf.IResolvable | undefined;
    set internalValue(value: DataVcdCatalogItemFilterMetadata | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _useApiSearch?;
    get useApiSearch(): boolean | cdktf.IResolvable;
    set useApiSearch(value: boolean | cdktf.IResolvable);
    resetUseApiSearch(): void;
    get useApiSearchInput(): boolean | cdktf.IResolvable | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class DataVcdCatalogItemFilterMetadataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataVcdCatalogItemFilterMetadata[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCatalogItemFilterMetadataOutputReference;
}
export interface DataVcdCatalogItemFilter {
    /**
    * Search by date comparison ({>|>=|<|<=|==} yyyy-mm-dd[ hh[:mm[:ss]]])
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#date DataVcdCatalogItem#date}
    */
    readonly date?: string;
    /**
    * Retrieves the oldest item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#earliest DataVcdCatalogItem#earliest}
    */
    readonly earliest?: boolean | cdktf.IResolvable;
    /**
    * Retrieves the newest item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#latest DataVcdCatalogItem#latest}
    */
    readonly latest?: boolean | cdktf.IResolvable;
    /**
    * Search by name with a regular expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#name_regex DataVcdCatalogItem#name_regex}
    */
    readonly nameRegex?: string;
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#metadata DataVcdCatalogItem#metadata}
    */
    readonly metadata?: DataVcdCatalogItemFilterMetadata[] | cdktf.IResolvable;
}
export declare function dataVcdCatalogItemFilterToTerraform(struct?: DataVcdCatalogItemFilterOutputReference | DataVcdCatalogItemFilter): any;
export declare function dataVcdCatalogItemFilterToHclTerraform(struct?: DataVcdCatalogItemFilterOutputReference | DataVcdCatalogItemFilter): any;
export declare class DataVcdCatalogItemFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataVcdCatalogItemFilter | undefined;
    set internalValue(value: DataVcdCatalogItemFilter | undefined);
    private _date?;
    get date(): string;
    set date(value: string);
    resetDate(): void;
    get dateInput(): string | undefined;
    private _earliest?;
    get earliest(): boolean | cdktf.IResolvable;
    set earliest(value: boolean | cdktf.IResolvable);
    resetEarliest(): void;
    get earliestInput(): boolean | cdktf.IResolvable | undefined;
    private _latest?;
    get latest(): boolean | cdktf.IResolvable;
    set latest(value: boolean | cdktf.IResolvable);
    resetLatest(): void;
    get latestInput(): boolean | cdktf.IResolvable | undefined;
    private _nameRegex?;
    get nameRegex(): string;
    set nameRegex(value: string);
    resetNameRegex(): void;
    get nameRegexInput(): string | undefined;
    private _metadata;
    get metadata(): DataVcdCatalogItemFilterMetadataList;
    putMetadata(value: DataVcdCatalogItemFilterMetadata[] | cdktf.IResolvable): void;
    resetMetadata(): void;
    get metadataInput(): cdktf.IResolvable | DataVcdCatalogItemFilterMetadata[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item vcd_catalog_item}
*/
export declare class DataVcdCatalogItem extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_catalog_item";
    /**
    * Generates CDKTF code for importing a DataVcdCatalogItem resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdCatalogItem to import
    * @param importFromId The id of the existing DataVcdCatalogItem that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdCatalogItem to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_item vcd_catalog_item} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdCatalogItemConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdCatalogItemConfig);
    private _catalog?;
    get catalog(): string;
    set catalog(value: string);
    get catalogInput(): string | undefined;
    private _catalogItemMetadata;
    get catalogItemMetadata(): cdktf.StringMap;
    get created(): string;
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _metadataEntry;
    get metadataEntry(): DataVcdCatalogItemMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _filter;
    get filter(): DataVcdCatalogItemFilterOutputReference;
    putFilter(value: DataVcdCatalogItemFilter): void;
    resetFilter(): void;
    get filterInput(): DataVcdCatalogItemFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
