import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdCatalogMediaConfig extends cdktf.TerraformMetaArguments {
    /**
    * catalog name where upload the Media file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#catalog DataVcdCatalogMedia#catalog}
    */
    readonly catalog?: string;
    /**
    * ID of the catalog from where to retrieve the Media item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#catalog_id DataVcdCatalogMedia#catalog_id}
    */
    readonly catalogId?: string;
    /**
    * Will download the contents of the media item into the given file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#download_to_file DataVcdCatalogMedia#download_to_file}
    */
    readonly downloadToFile?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#id DataVcdCatalogMedia#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * media name (Optional when 'filter' is used)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#name DataVcdCatalogMedia#name}
    */
    readonly name?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#org DataVcdCatalogMedia#org}
    */
    readonly org?: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#filter DataVcdCatalogMedia#filter}
    */
    readonly filter?: DataVcdCatalogMediaFilter;
}
export interface DataVcdCatalogMediaMetadataEntry {
}
export declare function dataVcdCatalogMediaMetadataEntryToTerraform(struct?: DataVcdCatalogMediaMetadataEntry): any;
export declare function dataVcdCatalogMediaMetadataEntryToHclTerraform(struct?: DataVcdCatalogMediaMetadataEntry): any;
export declare class DataVcdCatalogMediaMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCatalogMediaMetadataEntry | undefined;
    set internalValue(value: DataVcdCatalogMediaMetadataEntry | undefined);
    get isSystem(): cdktf.IResolvable;
    get key(): string;
    get type(): string;
    get userAccess(): string;
    get value(): string;
}
export declare class DataVcdCatalogMediaMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCatalogMediaMetadataEntryOutputReference;
}
export interface DataVcdCatalogMediaFilterMetadata {
    /**
    * True if is a metadata@SYSTEM key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#is_system DataVcdCatalogMedia#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Metadata key (field name)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#key DataVcdCatalogMedia#key}
    */
    readonly key: string;
    /**
    * Type of metadata value (needed only if "use_api_search" is true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#type DataVcdCatalogMedia#type}
    */
    readonly type?: string;
    /**
    * If true, will search the vCD using native metadata query (without regular expressions)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#use_api_search DataVcdCatalogMedia#use_api_search}
    */
    readonly useApiSearch?: boolean | cdktf.IResolvable;
    /**
    * Metadata value (can be a regular expression if "use_api_search" is false)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#value DataVcdCatalogMedia#value}
    */
    readonly value: string;
}
export declare function dataVcdCatalogMediaFilterMetadataToTerraform(struct?: DataVcdCatalogMediaFilterMetadata | cdktf.IResolvable): any;
export declare function dataVcdCatalogMediaFilterMetadataToHclTerraform(struct?: DataVcdCatalogMediaFilterMetadata | cdktf.IResolvable): any;
export declare class DataVcdCatalogMediaFilterMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCatalogMediaFilterMetadata | cdktf.IResolvable | undefined;
    set internalValue(value: DataVcdCatalogMediaFilterMetadata | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _useApiSearch?;
    get useApiSearch(): boolean | cdktf.IResolvable;
    set useApiSearch(value: boolean | cdktf.IResolvable);
    resetUseApiSearch(): void;
    get useApiSearchInput(): boolean | cdktf.IResolvable | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class DataVcdCatalogMediaFilterMetadataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataVcdCatalogMediaFilterMetadata[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCatalogMediaFilterMetadataOutputReference;
}
export interface DataVcdCatalogMediaFilter {
    /**
    * Search by date comparison ({>|>=|<|<=|==} yyyy-mm-dd[ hh[:mm[:ss]]])
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#date DataVcdCatalogMedia#date}
    */
    readonly date?: string;
    /**
    * Retrieves the oldest item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#earliest DataVcdCatalogMedia#earliest}
    */
    readonly earliest?: boolean | cdktf.IResolvable;
    /**
    * Retrieves the newest item
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#latest DataVcdCatalogMedia#latest}
    */
    readonly latest?: boolean | cdktf.IResolvable;
    /**
    * Search by name with a regular expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#name_regex DataVcdCatalogMedia#name_regex}
    */
    readonly nameRegex?: string;
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#metadata DataVcdCatalogMedia#metadata}
    */
    readonly metadata?: DataVcdCatalogMediaFilterMetadata[] | cdktf.IResolvable;
}
export declare function dataVcdCatalogMediaFilterToTerraform(struct?: DataVcdCatalogMediaFilterOutputReference | DataVcdCatalogMediaFilter): any;
export declare function dataVcdCatalogMediaFilterToHclTerraform(struct?: DataVcdCatalogMediaFilterOutputReference | DataVcdCatalogMediaFilter): any;
export declare class DataVcdCatalogMediaFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataVcdCatalogMediaFilter | undefined;
    set internalValue(value: DataVcdCatalogMediaFilter | undefined);
    private _date?;
    get date(): string;
    set date(value: string);
    resetDate(): void;
    get dateInput(): string | undefined;
    private _earliest?;
    get earliest(): boolean | cdktf.IResolvable;
    set earliest(value: boolean | cdktf.IResolvable);
    resetEarliest(): void;
    get earliestInput(): boolean | cdktf.IResolvable | undefined;
    private _latest?;
    get latest(): boolean | cdktf.IResolvable;
    set latest(value: boolean | cdktf.IResolvable);
    resetLatest(): void;
    get latestInput(): boolean | cdktf.IResolvable | undefined;
    private _nameRegex?;
    get nameRegex(): string;
    set nameRegex(value: string);
    resetNameRegex(): void;
    get nameRegexInput(): string | undefined;
    private _metadata;
    get metadata(): DataVcdCatalogMediaFilterMetadataList;
    putMetadata(value: DataVcdCatalogMediaFilterMetadata[] | cdktf.IResolvable): void;
    resetMetadata(): void;
    get metadataInput(): cdktf.IResolvable | DataVcdCatalogMediaFilterMetadata[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media vcd_catalog_media}
*/
export declare class DataVcdCatalogMedia extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_catalog_media";
    /**
    * Generates CDKTF code for importing a DataVcdCatalogMedia resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdCatalogMedia to import
    * @param importFromId The id of the existing DataVcdCatalogMedia that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdCatalogMedia to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/catalog_media vcd_catalog_media} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdCatalogMediaConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataVcdCatalogMediaConfig);
    private _catalog?;
    get catalog(): string;
    set catalog(value: string);
    resetCatalog(): void;
    get catalogInput(): string | undefined;
    private _catalogId?;
    get catalogId(): string;
    set catalogId(value: string);
    resetCatalogId(): void;
    get catalogIdInput(): string | undefined;
    get creationDate(): string;
    get description(): string;
    private _downloadToFile?;
    get downloadToFile(): string;
    set downloadToFile(value: string);
    resetDownloadToFile(): void;
    get downloadToFileInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isIso(): cdktf.IResolvable;
    get isPublished(): cdktf.IResolvable;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _metadataEntry;
    get metadataEntry(): DataVcdCatalogMediaMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get ownerName(): string;
    get size(): number;
    get status(): string;
    get storageProfileName(): string;
    private _filter;
    get filter(): DataVcdCatalogMediaFilterOutputReference;
    putFilter(value: DataVcdCatalogMediaFilter): void;
    resetFilter(): void;
    get filterInput(): DataVcdCatalogMediaFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
