import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdCseKubernetesClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique ID of the Kubernetes cluster to read
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#cluster_id DataVcdCseKubernetesCluster#cluster_id}
    */
    readonly clusterId?: string;
    /**
    * The CSE version used by the cluster, only required if 'name' is set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#cse_version DataVcdCseKubernetesCluster#cse_version}
    */
    readonly cseVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#id DataVcdCseKubernetesCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Kubernetes cluster to read. If there is more than one Kubernetes cluster with the same name, searching by name will fail
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#name DataVcdCseKubernetesCluster#name}
    */
    readonly name?: string;
    /**
    * The ID of organization that owns the Kubernetes cluster, only required if 'name' is set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#org_id DataVcdCseKubernetesCluster#org_id}
    */
    readonly orgId?: string;
}
export interface DataVcdCseKubernetesClusterControlPlane {
}
export declare function dataVcdCseKubernetesClusterControlPlaneToTerraform(struct?: DataVcdCseKubernetesClusterControlPlane): any;
export declare function dataVcdCseKubernetesClusterControlPlaneToHclTerraform(struct?: DataVcdCseKubernetesClusterControlPlane): any;
export declare class DataVcdCseKubernetesClusterControlPlaneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCseKubernetesClusterControlPlane | undefined;
    set internalValue(value: DataVcdCseKubernetesClusterControlPlane | undefined);
    get diskSizeGi(): number;
    get ip(): string;
    get machineCount(): number;
    get placementPolicyId(): string;
    get sizingPolicyId(): string;
    get storageProfileId(): string;
}
export declare class DataVcdCseKubernetesClusterControlPlaneList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCseKubernetesClusterControlPlaneOutputReference;
}
export interface DataVcdCseKubernetesClusterDefaultStorageClass {
}
export declare function dataVcdCseKubernetesClusterDefaultStorageClassToTerraform(struct?: DataVcdCseKubernetesClusterDefaultStorageClass): any;
export declare function dataVcdCseKubernetesClusterDefaultStorageClassToHclTerraform(struct?: DataVcdCseKubernetesClusterDefaultStorageClass): any;
export declare class DataVcdCseKubernetesClusterDefaultStorageClassOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCseKubernetesClusterDefaultStorageClass | undefined;
    set internalValue(value: DataVcdCseKubernetesClusterDefaultStorageClass | undefined);
    get filesystem(): string;
    get name(): string;
    get reclaimPolicy(): string;
    get storageProfileId(): string;
}
export declare class DataVcdCseKubernetesClusterDefaultStorageClassList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCseKubernetesClusterDefaultStorageClassOutputReference;
}
export interface DataVcdCseKubernetesClusterEvents {
}
export declare function dataVcdCseKubernetesClusterEventsToTerraform(struct?: DataVcdCseKubernetesClusterEvents): any;
export declare function dataVcdCseKubernetesClusterEventsToHclTerraform(struct?: DataVcdCseKubernetesClusterEvents): any;
export declare class DataVcdCseKubernetesClusterEventsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCseKubernetesClusterEvents | undefined;
    set internalValue(value: DataVcdCseKubernetesClusterEvents | undefined);
    get details(): string;
    get name(): string;
    get occurredAt(): string;
    get resourceId(): string;
    get type(): string;
}
export declare class DataVcdCseKubernetesClusterEventsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCseKubernetesClusterEventsOutputReference;
}
export interface DataVcdCseKubernetesClusterWorkerPool {
}
export declare function dataVcdCseKubernetesClusterWorkerPoolToTerraform(struct?: DataVcdCseKubernetesClusterWorkerPool): any;
export declare function dataVcdCseKubernetesClusterWorkerPoolToHclTerraform(struct?: DataVcdCseKubernetesClusterWorkerPool): any;
export declare class DataVcdCseKubernetesClusterWorkerPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdCseKubernetesClusterWorkerPool | undefined;
    set internalValue(value: DataVcdCseKubernetesClusterWorkerPool | undefined);
    get diskSizeGi(): number;
    get machineCount(): number;
    get name(): string;
    get placementPolicyId(): string;
    get sizingPolicyId(): string;
    get storageProfileId(): string;
    get vgpuPolicyId(): string;
}
export declare class DataVcdCseKubernetesClusterWorkerPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdCseKubernetesClusterWorkerPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster vcd_cse_kubernetes_cluster}
*/
export declare class DataVcdCseKubernetesCluster extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_cse_kubernetes_cluster";
    /**
    * Generates CDKTF code for importing a DataVcdCseKubernetesCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdCseKubernetesCluster to import
    * @param importFromId The id of the existing DataVcdCseKubernetesCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdCseKubernetesCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/cse_kubernetes_cluster vcd_cse_kubernetes_cluster} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdCseKubernetesClusterConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataVcdCseKubernetesClusterConfig);
    get autoRepairOnErrors(): cdktf.IResolvable;
    get capvcdVersion(): string;
    private _clusterId?;
    get clusterId(): string;
    set clusterId(value: string);
    resetClusterId(): void;
    get clusterIdInput(): string | undefined;
    get clusterResourceSetBindings(): string[];
    private _controlPlane;
    get controlPlane(): DataVcdCseKubernetesClusterControlPlaneList;
    get cpiVersion(): string;
    private _cseVersion?;
    get cseVersion(): string;
    set cseVersion(value: string);
    resetCseVersion(): void;
    get cseVersionInput(): string | undefined;
    get csiVersion(): string;
    private _defaultStorageClass;
    get defaultStorageClass(): DataVcdCseKubernetesClusterDefaultStorageClassList;
    private _events;
    get events(): DataVcdCseKubernetesClusterEventsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get kubeconfig(): string;
    get kubernetesTemplateId(): string;
    get kubernetesVersion(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get networkId(): string;
    get nodeHealthCheck(): cdktf.IResolvable;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    resetOrgId(): void;
    get orgIdInput(): string | undefined;
    get owner(): string;
    get podsCidr(): string;
    get runtime(): string;
    get servicesCidr(): string;
    get sshPublicKey(): string;
    get state(): string;
    get supportedUpgrades(): string[];
    get tkgProductVersion(): string;
    get vdcId(): string;
    get virtualIpSubnet(): string;
    private _workerPool;
    get workerPool(): DataVcdCseKubernetesClusterWorkerPoolList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
