import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdLbAppProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the LB Application Profile is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#edge_gateway DataVcdLbAppProfile#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#id DataVcdLbAppProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * LB Application Profile name for lookup
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#name DataVcdLbAppProfile#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#org DataVcdLbAppProfile#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#vdc DataVcdLbAppProfile#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile vcd_lb_app_profile}
*/
export declare class DataVcdLbAppProfile extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_lb_app_profile";
    /**
    * Generates CDKTF code for importing a DataVcdLbAppProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdLbAppProfile to import
    * @param importFromId The id of the existing DataVcdLbAppProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdLbAppProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_app_profile vcd_lb_app_profile} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdLbAppProfileConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdLbAppProfileConfig);
    get cookieMode(): string;
    get cookieName(): string;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    get enablePoolSideSsl(): cdktf.IResolvable;
    get enableSslPassthrough(): cdktf.IResolvable;
    get expiration(): number;
    get httpRedirectUrl(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get insertXForwardedHttpHeader(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get persistenceMechanism(): string;
    get type(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
