import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdLbServerPoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the LB Server Pool is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#edge_gateway DataVcdLbServerPool#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#id DataVcdLbServerPool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Server Pool name for lookup
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#name DataVcdLbServerPool#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#org DataVcdLbServerPool#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#vdc DataVcdLbServerPool#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdLbServerPoolMember {
}
export declare function dataVcdLbServerPoolMemberToTerraform(struct?: DataVcdLbServerPoolMember): any;
export declare function dataVcdLbServerPoolMemberToHclTerraform(struct?: DataVcdLbServerPoolMember): any;
export declare class DataVcdLbServerPoolMemberOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdLbServerPoolMember | undefined;
    set internalValue(value: DataVcdLbServerPoolMember | undefined);
    get condition(): string;
    get id(): string;
    get ipAddress(): string;
    get maxConnections(): number;
    get minConnections(): number;
    get monitorPort(): number;
    get name(): string;
    get port(): number;
    get weight(): number;
}
export declare class DataVcdLbServerPoolMemberList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdLbServerPoolMemberOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool vcd_lb_server_pool}
*/
export declare class DataVcdLbServerPool extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_lb_server_pool";
    /**
    * Generates CDKTF code for importing a DataVcdLbServerPool resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdLbServerPool to import
    * @param importFromId The id of the existing DataVcdLbServerPool that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdLbServerPool to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_server_pool vcd_lb_server_pool} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdLbServerPoolConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdLbServerPoolConfig);
    get algorithm(): string;
    get algorithmParameters(): string;
    get description(): string;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    get enableTransparency(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _member;
    get member(): DataVcdLbServerPoolMemberList;
    get monitorId(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
