import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdLbServiceMonitorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the LB Service Monitor is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#edge_gateway DataVcdLbServiceMonitor#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#id DataVcdLbServiceMonitor#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * LB Service Monitor name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#name DataVcdLbServiceMonitor#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#org DataVcdLbServiceMonitor#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#vdc DataVcdLbServiceMonitor#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor vcd_lb_service_monitor}
*/
export declare class DataVcdLbServiceMonitor extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_lb_service_monitor";
    /**
    * Generates CDKTF code for importing a DataVcdLbServiceMonitor resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdLbServiceMonitor to import
    * @param importFromId The id of the existing DataVcdLbServiceMonitor that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdLbServiceMonitor to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_service_monitor vcd_lb_service_monitor} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdLbServiceMonitorConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdLbServiceMonitorConfig);
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    get expected(): string;
    private _extension;
    get extension(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get interval(): number;
    get maxRetries(): number;
    get method(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get receive(): string;
    get send(): string;
    get timeout(): number;
    get type(): string;
    get url(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
