import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdLbVirtualServerConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the Virtual Server is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#edge_gateway DataVcdLbVirtualServer#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#id DataVcdLbVirtualServer#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Virtual Server name for lookup
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#name DataVcdLbVirtualServer#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#org DataVcdLbVirtualServer#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#vdc DataVcdLbVirtualServer#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server vcd_lb_virtual_server}
*/
export declare class DataVcdLbVirtualServer extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_lb_virtual_server";
    /**
    * Generates CDKTF code for importing a DataVcdLbVirtualServer resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdLbVirtualServer to import
    * @param importFromId The id of the existing DataVcdLbVirtualServer that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdLbVirtualServer to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/lb_virtual_server vcd_lb_virtual_server} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdLbVirtualServerConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdLbVirtualServerConfig);
    get appProfileId(): string;
    get appRuleIds(): string[];
    get connectionLimit(): number;
    get connectionRateLimit(): number;
    get description(): string;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    get enableAcceleration(): cdktf.IResolvable;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get ipAddress(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get port(): number;
    get protocol(): string;
    get serverPoolId(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
