import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNetworkDirectConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#id DataVcdNetworkDirect#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A unique name for this network (optional if 'filter' is used)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#name DataVcdNetworkDirect#name}
    */
    readonly name?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#org DataVcdNetworkDirect#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#vdc DataVcdNetworkDirect#vdc}
    */
    readonly vdc?: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#filter DataVcdNetworkDirect#filter}
    */
    readonly filter?: DataVcdNetworkDirectFilter;
}
export interface DataVcdNetworkDirectMetadataEntry {
}
export declare function dataVcdNetworkDirectMetadataEntryToTerraform(struct?: DataVcdNetworkDirectMetadataEntry): any;
export declare function dataVcdNetworkDirectMetadataEntryToHclTerraform(struct?: DataVcdNetworkDirectMetadataEntry): any;
export declare class DataVcdNetworkDirectMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdNetworkDirectMetadataEntry | undefined;
    set internalValue(value: DataVcdNetworkDirectMetadataEntry | undefined);
    get isSystem(): cdktf.IResolvable;
    get key(): string;
    get type(): string;
    get userAccess(): string;
    get value(): string;
}
export declare class DataVcdNetworkDirectMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdNetworkDirectMetadataEntryOutputReference;
}
export interface DataVcdNetworkDirectFilterMetadata {
    /**
    * True if is a metadata@SYSTEM key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#is_system DataVcdNetworkDirect#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Metadata key (field name)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#key DataVcdNetworkDirect#key}
    */
    readonly key: string;
    /**
    * Type of metadata value (needed only if "use_api_search" is true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#type DataVcdNetworkDirect#type}
    */
    readonly type?: string;
    /**
    * If true, will search the vCD using native metadata query (without regular expressions)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#use_api_search DataVcdNetworkDirect#use_api_search}
    */
    readonly useApiSearch?: boolean | cdktf.IResolvable;
    /**
    * Metadata value (can be a regular expression if "use_api_search" is false)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#value DataVcdNetworkDirect#value}
    */
    readonly value: string;
}
export declare function dataVcdNetworkDirectFilterMetadataToTerraform(struct?: DataVcdNetworkDirectFilterMetadata | cdktf.IResolvable): any;
export declare function dataVcdNetworkDirectFilterMetadataToHclTerraform(struct?: DataVcdNetworkDirectFilterMetadata | cdktf.IResolvable): any;
export declare class DataVcdNetworkDirectFilterMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdNetworkDirectFilterMetadata | cdktf.IResolvable | undefined;
    set internalValue(value: DataVcdNetworkDirectFilterMetadata | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _useApiSearch?;
    get useApiSearch(): boolean | cdktf.IResolvable;
    set useApiSearch(value: boolean | cdktf.IResolvable);
    resetUseApiSearch(): void;
    get useApiSearchInput(): boolean | cdktf.IResolvable | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class DataVcdNetworkDirectFilterMetadataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataVcdNetworkDirectFilterMetadata[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdNetworkDirectFilterMetadataOutputReference;
}
export interface DataVcdNetworkDirectFilter {
    /**
    * Search by IP. The value can be a regular expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#ip DataVcdNetworkDirect#ip}
    */
    readonly ip?: string;
    /**
    * Search by name with a regular expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#name_regex DataVcdNetworkDirect#name_regex}
    */
    readonly nameRegex?: string;
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#metadata DataVcdNetworkDirect#metadata}
    */
    readonly metadata?: DataVcdNetworkDirectFilterMetadata[] | cdktf.IResolvable;
}
export declare function dataVcdNetworkDirectFilterToTerraform(struct?: DataVcdNetworkDirectFilterOutputReference | DataVcdNetworkDirectFilter): any;
export declare function dataVcdNetworkDirectFilterToHclTerraform(struct?: DataVcdNetworkDirectFilterOutputReference | DataVcdNetworkDirectFilter): any;
export declare class DataVcdNetworkDirectFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataVcdNetworkDirectFilter | undefined;
    set internalValue(value: DataVcdNetworkDirectFilter | undefined);
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _nameRegex?;
    get nameRegex(): string;
    set nameRegex(value: string);
    resetNameRegex(): void;
    get nameRegexInput(): string | undefined;
    private _metadata;
    get metadata(): DataVcdNetworkDirectFilterMetadataList;
    putMetadata(value: DataVcdNetworkDirectFilterMetadata[] | cdktf.IResolvable): void;
    resetMetadata(): void;
    get metadataInput(): cdktf.IResolvable | DataVcdNetworkDirectFilterMetadata[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct vcd_network_direct}
*/
export declare class DataVcdNetworkDirect extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_network_direct";
    /**
    * Generates CDKTF code for importing a DataVcdNetworkDirect resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNetworkDirect to import
    * @param importFromId The id of the existing DataVcdNetworkDirect that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNetworkDirect to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/network_direct vcd_network_direct} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNetworkDirectConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataVcdNetworkDirectConfig);
    get description(): string;
    get externalNetwork(): string;
    get externalNetworkDns1(): string;
    get externalNetworkDns2(): string;
    get externalNetworkDnsSuffix(): string;
    get externalNetworkGateway(): string;
    get externalNetworkNetmask(): string;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _metadataEntry;
    get metadataEntry(): DataVcdNetworkDirectMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get shared(): cdktf.IResolvable;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _filter;
    get filter(): DataVcdNetworkDirectFilterOutputReference;
    putFilter(value: DataVcdNetworkDirectFilter): void;
    resetFilter(): void;
    get filterInput(): DataVcdNetworkDirectFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
