import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNsxtAlbVirtualServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway ID in which ALB Virtual Service is
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#edge_gateway_id DataVcdNsxtAlbVirtualService#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#id DataVcdNsxtAlbVirtualService#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of ALB Virtual Service
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#name DataVcdNsxtAlbVirtualService#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#org DataVcdNsxtAlbVirtualService#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#vdc DataVcdNsxtAlbVirtualService#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdNsxtAlbVirtualServiceServicePort {
}
export declare function dataVcdNsxtAlbVirtualServiceServicePortToTerraform(struct?: DataVcdNsxtAlbVirtualServiceServicePort): any;
export declare function dataVcdNsxtAlbVirtualServiceServicePortToHclTerraform(struct?: DataVcdNsxtAlbVirtualServiceServicePort): any;
export declare class DataVcdNsxtAlbVirtualServiceServicePortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdNsxtAlbVirtualServiceServicePort | undefined;
    set internalValue(value: DataVcdNsxtAlbVirtualServiceServicePort | undefined);
    get endPort(): number;
    get sslEnabled(): cdktf.IResolvable;
    get startPort(): number;
    get type(): string;
}
export declare class DataVcdNsxtAlbVirtualServiceServicePortList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdNsxtAlbVirtualServiceServicePortOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service vcd_nsxt_alb_virtual_service}
*/
export declare class DataVcdNsxtAlbVirtualService extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_nsxt_alb_virtual_service";
    /**
    * Generates CDKTF code for importing a DataVcdNsxtAlbVirtualService resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNsxtAlbVirtualService to import
    * @param importFromId The id of the existing DataVcdNsxtAlbVirtualService that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNsxtAlbVirtualService to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_alb_virtual_service vcd_nsxt_alb_virtual_service} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNsxtAlbVirtualServiceConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdNsxtAlbVirtualServiceConfig);
    get applicationProfileType(): string;
    get caCertificateId(): string;
    get description(): string;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get ipv6VirtualIpAddress(): string;
    get isTransparentModeEnabled(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get poolId(): string;
    get serviceEngineGroupId(): string;
    private _servicePort;
    get servicePort(): DataVcdNsxtAlbVirtualServiceServicePortList;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    get virtualIpAddress(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
