import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNsxtAppPortProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of VDC, VDC Group, or NSX-T Manager. Required if the VCD instance has more than one NSX-T manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#context_id DataVcdNsxtAppPortProfile#context_id}
    */
    readonly contextId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#id DataVcdNsxtAppPortProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Application Port Profile name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#name DataVcdNsxtAppPortProfile#name}
    */
    readonly name: string;
    /**
    * ID of NSX-T manager. Only required for 'PROVIDER' scope
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#nsxt_manager_id DataVcdNsxtAppPortProfile#nsxt_manager_id}
    */
    readonly nsxtManagerId?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#org DataVcdNsxtAppPortProfile#org}
    */
    readonly org?: string;
    /**
    * Scope - 'SYSTEM', 'PROVIDER' or 'TENANT'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#scope DataVcdNsxtAppPortProfile#scope}
    */
    readonly scope: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#vdc DataVcdNsxtAppPortProfile#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdNsxtAppPortProfileAppPort {
}
export declare function dataVcdNsxtAppPortProfileAppPortToTerraform(struct?: DataVcdNsxtAppPortProfileAppPort): any;
export declare function dataVcdNsxtAppPortProfileAppPortToHclTerraform(struct?: DataVcdNsxtAppPortProfileAppPort): any;
export declare class DataVcdNsxtAppPortProfileAppPortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdNsxtAppPortProfileAppPort | undefined;
    set internalValue(value: DataVcdNsxtAppPortProfileAppPort | undefined);
    get port(): string[];
    get protocol(): string;
}
export declare class DataVcdNsxtAppPortProfileAppPortList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdNsxtAppPortProfileAppPortOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile vcd_nsxt_app_port_profile}
*/
export declare class DataVcdNsxtAppPortProfile extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_nsxt_app_port_profile";
    /**
    * Generates CDKTF code for importing a DataVcdNsxtAppPortProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNsxtAppPortProfile to import
    * @param importFromId The id of the existing DataVcdNsxtAppPortProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNsxtAppPortProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_app_port_profile vcd_nsxt_app_port_profile} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNsxtAppPortProfileConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdNsxtAppPortProfileConfig);
    private _appPort;
    get appPort(): DataVcdNsxtAppPortProfileAppPortList;
    private _contextId?;
    get contextId(): string;
    set contextId(value: string);
    resetContextId(): void;
    get contextIdInput(): string | undefined;
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nsxtManagerId?;
    get nsxtManagerId(): string;
    set nsxtManagerId(value: string);
    resetNsxtManagerId(): void;
    get nsxtManagerIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    get scopeInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
