import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNsxtNatRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which NAT Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#edge_gateway_id DataVcdNsxtNatRule#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#id DataVcdNsxtNatRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of NAT rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#name DataVcdNsxtNatRule#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#org DataVcdNsxtNatRule#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#vdc DataVcdNsxtNatRule#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule vcd_nsxt_nat_rule}
*/
export declare class DataVcdNsxtNatRule extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_nsxt_nat_rule";
    /**
    * Generates CDKTF code for importing a DataVcdNsxtNatRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNsxtNatRule to import
    * @param importFromId The id of the existing DataVcdNsxtNatRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNsxtNatRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_nat_rule vcd_nsxt_nat_rule} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNsxtNatRuleConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdNsxtNatRuleConfig);
    get appPortProfileId(): string;
    get description(): string;
    get dnatExternalPort(): string;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    get enabled(): cdktf.IResolvable;
    get externalAddress(): string;
    get firewallMatch(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get internalAddress(): string;
    get logging(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get priority(): number;
    get ruleType(): string;
    get snatDestinationAddress(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
