import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNsxtNetworkDhcpConfig extends cdktf.TerraformMetaArguments {
    /**
    * The DNS server IPs to be assigned by this DHCP service. 2 values maximum.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#dns_servers DataVcdNsxtNetworkDhcp#dns_servers}
    */
    readonly dnsServers?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#id DataVcdNsxtNetworkDhcp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#org DataVcdNsxtNetworkDhcp#org}
    */
    readonly org?: string;
    /**
    * Parent Org VDC network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#org_network_id DataVcdNsxtNetworkDhcp#org_network_id}
    */
    readonly orgNetworkId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#vdc DataVcdNsxtNetworkDhcp#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdNsxtNetworkDhcpPool {
}
export declare function dataVcdNsxtNetworkDhcpPoolToTerraform(struct?: DataVcdNsxtNetworkDhcpPool): any;
export declare function dataVcdNsxtNetworkDhcpPoolToHclTerraform(struct?: DataVcdNsxtNetworkDhcpPool): any;
export declare class DataVcdNsxtNetworkDhcpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdNsxtNetworkDhcpPool | undefined;
    set internalValue(value: DataVcdNsxtNetworkDhcpPool | undefined);
    get endAddress(): string;
    get startAddress(): string;
}
export declare class DataVcdNsxtNetworkDhcpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdNsxtNetworkDhcpPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp vcd_nsxt_network_dhcp}
*/
export declare class DataVcdNsxtNetworkDhcp extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_nsxt_network_dhcp";
    /**
    * Generates CDKTF code for importing a DataVcdNsxtNetworkDhcp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNsxtNetworkDhcp to import
    * @param importFromId The id of the existing DataVcdNsxtNetworkDhcp that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNsxtNetworkDhcp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_network_dhcp vcd_nsxt_network_dhcp} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNsxtNetworkDhcpConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdNsxtNetworkDhcpConfig);
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    resetDnsServers(): void;
    get dnsServersInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get leaseTime(): number;
    get listenerIpAddress(): string;
    get mode(): string;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkId?;
    get orgNetworkId(): string;
    set orgNetworkId(value: string);
    get orgNetworkIdInput(): string | undefined;
    private _pool;
    get pool(): DataVcdNsxtNetworkDhcpPoolList;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
