import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdNsxtSegmentSecurityProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Indicates pre-defined list of allowed MAC addresses to be excluded from BPDU filtering
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#bpdu_filter_allow_list DataVcdNsxtSegmentSecurityProfile#bpdu_filter_allow_list}
    */
    readonly bpduFilterAllowList?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#id DataVcdNsxtSegmentSecurityProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of Segment Security Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#name DataVcdNsxtSegmentSecurityProfile#name}
    */
    readonly name: string;
    /**
    * ID of NSX-T Manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#nsxt_manager_id DataVcdNsxtSegmentSecurityProfile#nsxt_manager_id}
    */
    readonly nsxtManagerId?: string;
    /**
    * ID of VDC Group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#vdc_group_id DataVcdNsxtSegmentSecurityProfile#vdc_group_id}
    */
    readonly vdcGroupId?: string;
    /**
    * ID of VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#vdc_id DataVcdNsxtSegmentSecurityProfile#vdc_id}
    */
    readonly vdcId?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile vcd_nsxt_segment_security_profile}
*/
export declare class DataVcdNsxtSegmentSecurityProfile extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_nsxt_segment_security_profile";
    /**
    * Generates CDKTF code for importing a DataVcdNsxtSegmentSecurityProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdNsxtSegmentSecurityProfile to import
    * @param importFromId The id of the existing DataVcdNsxtSegmentSecurityProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdNsxtSegmentSecurityProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/nsxt_segment_security_profile vcd_nsxt_segment_security_profile} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdNsxtSegmentSecurityProfileConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdNsxtSegmentSecurityProfileConfig);
    private _bpduFilterAllowList?;
    get bpduFilterAllowList(): string[];
    set bpduFilterAllowList(value: string[]);
    resetBpduFilterAllowList(): void;
    get bpduFilterAllowListInput(): string[] | undefined;
    get description(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isBpduFilterEnabled(): cdktf.IResolvable;
    get isDhcpV4ClientBlockEnabled(): cdktf.IResolvable;
    get isDhcpV4ServerBlockEnabled(): cdktf.IResolvable;
    get isDhcpV6ClientBlockEnabled(): cdktf.IResolvable;
    get isDhcpV6ServerBlockEnabled(): cdktf.IResolvable;
    get isNonIpTrafficBlockEnabled(): cdktf.IResolvable;
    get isRaGuardEnabled(): cdktf.IResolvable;
    get isRateLimittingEnabled(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nsxtManagerId?;
    get nsxtManagerId(): string;
    set nsxtManagerId(value: string);
    resetNsxtManagerId(): void;
    get nsxtManagerIdInput(): string | undefined;
    get rxBroadcastLimit(): number;
    get rxMulticastLimit(): number;
    get txBroadcastLimit(): number;
    get txMulticastLimit(): number;
    private _vdcGroupId?;
    get vdcGroupId(): string;
    set vdcGroupId(value: string);
    resetVdcGroupId(): void;
    get vdcGroupIdInput(): string | undefined;
    private _vdcId?;
    get vdcId(): string;
    set vdcId(value: string);
    resetVdcId(): void;
    get vdcIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
