import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdRdeBehaviorInvocationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The arguments to be passed to the invoked Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#arguments DataVcdRdeBehaviorInvocation#arguments}
    */
    readonly arguments?: {
        [key: string]: string;
    };
    /**
    * The ID of either a RDE Interface Behavior or RDE Type Behavior to be invoked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#behavior_id DataVcdRdeBehaviorInvocation#behavior_id}
    */
    readonly behaviorId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#id DataVcdRdeBehaviorInvocation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * If 'true', invokes the Behavior on every refresh
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#invoke_on_refresh DataVcdRdeBehaviorInvocation#invoke_on_refresh}
    */
    readonly invokeOnRefresh?: boolean | cdktf.IResolvable;
    /**
    * Metadata to be passed to the invoked Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#metadata DataVcdRdeBehaviorInvocation#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * The ID of the RDE for which the Behavior will be invoked
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#rde_id DataVcdRdeBehaviorInvocation#rde_id}
    */
    readonly rdeId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation vcd_rde_behavior_invocation}
*/
export declare class DataVcdRdeBehaviorInvocation extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_rde_behavior_invocation";
    /**
    * Generates CDKTF code for importing a DataVcdRdeBehaviorInvocation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdRdeBehaviorInvocation to import
    * @param importFromId The id of the existing DataVcdRdeBehaviorInvocation that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdRdeBehaviorInvocation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_behavior_invocation vcd_rde_behavior_invocation} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdRdeBehaviorInvocationConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdRdeBehaviorInvocationConfig);
    private _arguments?;
    get arguments(): {
        [key: string]: string;
    };
    set arguments(value: {
        [key: string]: string;
    });
    resetArguments(): void;
    get argumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _behaviorId?;
    get behaviorId(): string;
    set behaviorId(value: string);
    get behaviorIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _invokeOnRefresh?;
    get invokeOnRefresh(): boolean | cdktf.IResolvable;
    set invokeOnRefresh(value: boolean | cdktf.IResolvable);
    resetInvokeOnRefresh(): void;
    get invokeOnRefreshInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _rdeId?;
    get rdeId(): string;
    set rdeId(value: string);
    get rdeIdInput(): string | undefined;
    get result(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
