import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdRdeTypeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type#id DataVcdRdeType#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A unique namespace associated with the Runtime Defined Entity Type. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type#nss DataVcdRdeType#nss}
    */
    readonly nss: string;
    /**
    * The vendor name of the Runtime Defined Entity Type. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type#vendor DataVcdRdeType#vendor}
    */
    readonly vendor: string;
    /**
    * The version of the Runtime Defined Entity Type. The version string follows semantic versioning rules. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type#version DataVcdRdeType#version}
    */
    readonly version: string;
}
export interface DataVcdRdeTypeHook {
}
export declare function dataVcdRdeTypeHookToTerraform(struct?: DataVcdRdeTypeHook): any;
export declare function dataVcdRdeTypeHookToHclTerraform(struct?: DataVcdRdeTypeHook): any;
export declare class DataVcdRdeTypeHookOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdRdeTypeHook | undefined;
    set internalValue(value: DataVcdRdeTypeHook | undefined);
    get behaviorId(): string;
    get event(): string;
}
export declare class DataVcdRdeTypeHookList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdRdeTypeHookOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type vcd_rde_type}
*/
export declare class DataVcdRdeType extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_rde_type";
    /**
    * Generates CDKTF code for importing a DataVcdRdeType resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdRdeType to import
    * @param importFromId The id of the existing DataVcdRdeType that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdRdeType to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde_type vcd_rde_type} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdRdeTypeConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdRdeTypeConfig);
    get description(): string;
    get externalId(): string;
    private _hook;
    get hook(): DataVcdRdeTypeHookList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get inheritedVersion(): string;
    get interfaceIds(): string[];
    get name(): string;
    private _nss?;
    get nss(): string;
    set nss(value: string);
    get nssInput(): string | undefined;
    get readonly(): cdktf.IResolvable;
    get schema(): string;
    private _vendor?;
    get vendor(): string;
    set vendor(value: string);
    get vendorInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
