import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdRdeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde#id DataVcdRde#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Runtime Defined Entity
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde#name DataVcdRde#name}
    */
    readonly name: string;
    /**
    * The name of organization that owns this Runtime Defined Entity, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde#org DataVcdRde#org}
    */
    readonly org?: string;
    /**
    * The Runtime Defined Entity Type ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde#rde_type_id DataVcdRde#rde_type_id}
    */
    readonly rdeTypeId: string;
}
export interface DataVcdRdeMetadataEntry {
}
export declare function dataVcdRdeMetadataEntryToTerraform(struct?: DataVcdRdeMetadataEntry): any;
export declare function dataVcdRdeMetadataEntryToHclTerraform(struct?: DataVcdRdeMetadataEntry): any;
export declare class DataVcdRdeMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdRdeMetadataEntry | undefined;
    set internalValue(value: DataVcdRdeMetadataEntry | undefined);
    get domain(): string;
    get id(): string;
    get key(): string;
    get namespace(): string;
    get persistent(): cdktf.IResolvable;
    get readonly(): cdktf.IResolvable;
    get type(): string;
    get value(): string;
}
export declare class DataVcdRdeMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdRdeMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde vcd_rde}
*/
export declare class DataVcdRde extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_rde";
    /**
    * Generates CDKTF code for importing a DataVcdRde resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdRde to import
    * @param importFromId The id of the existing DataVcdRde that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdRde to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/rde vcd_rde} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdRdeConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdRdeConfig);
    get entity(): string;
    get externalId(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadataEntry;
    get metadataEntry(): DataVcdRdeMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get orgId(): string;
    get ownerUserId(): string;
    private _rdeTypeId?;
    get rdeTypeId(): string;
    set rdeTypeId(value: string);
    get rdeTypeIdInput(): string | undefined;
    get state(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
