import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdResourceListConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#id DataVcdResourceList#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * File where to store the import info - Only used with 'import' list mode
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#import_file_name DataVcdResourceList#import_file_name}
    */
    readonly importFileName?: string;
    /**
    * How the list should be built
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#list_mode DataVcdResourceList#list_mode}
    */
    readonly listMode?: string;
    /**
    * Unique name of the Info
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#name DataVcdResourceList#name}
    */
    readonly name: string;
    /**
    * Separator for name_id combination
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#name_id_separator DataVcdResourceList#name_id_separator}
    */
    readonly nameIdSeparator?: string;
    /**
    * Optional regular expression filter on the resource names - Only the matching resources will be fetched
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#name_regex DataVcdResourceList#name_regex}
    */
    readonly nameRegex?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#org DataVcdResourceList#org}
    */
    readonly org?: string;
    /**
    * The name of the parent to the resources being retrieved
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#parent DataVcdResourceList#parent}
    */
    readonly parent?: string;
    /**
    * Which resource we should list
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#resource_type DataVcdResourceList#resource_type}
    */
    readonly resourceType: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#vdc DataVcdResourceList#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list vcd_resource_list}
*/
export declare class DataVcdResourceList extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_resource_list";
    /**
    * Generates CDKTF code for importing a DataVcdResourceList resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdResourceList to import
    * @param importFromId The id of the existing DataVcdResourceList that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdResourceList to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/resource_list vcd_resource_list} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdResourceListConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdResourceListConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _importFileName?;
    get importFileName(): string;
    set importFileName(value: string);
    resetImportFileName(): void;
    get importFileNameInput(): string | undefined;
    get list(): string[];
    private _listMode?;
    get listMode(): string;
    set listMode(value: string);
    resetListMode(): void;
    get listModeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nameIdSeparator?;
    get nameIdSeparator(): string;
    set nameIdSeparator(value: string);
    resetNameIdSeparator(): void;
    get nameIdSeparatorInput(): string | undefined;
    private _nameRegex?;
    get nameRegex(): string;
    set nameRegex(value: string);
    resetNameRegex(): void;
    get nameRegexInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    resetParent(): void;
    get parentInput(): string | undefined;
    private _resourceType?;
    get resourceType(): string;
    set resourceType(value: string);
    get resourceTypeInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
