import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdStorageProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile#id DataVcdStorageProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of storage profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile#name DataVcdStorageProfile#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile#org DataVcdStorageProfile#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile#vdc DataVcdStorageProfile#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdStorageProfileIopsSettings {
}
export declare function dataVcdStorageProfileIopsSettingsToTerraform(struct?: DataVcdStorageProfileIopsSettings): any;
export declare function dataVcdStorageProfileIopsSettingsToHclTerraform(struct?: DataVcdStorageProfileIopsSettings): any;
export declare class DataVcdStorageProfileIopsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdStorageProfileIopsSettings | undefined;
    set internalValue(value: DataVcdStorageProfileIopsSettings | undefined);
    get defaultDiskIops(): number;
    get diskIopsPerGbMax(): number;
    get iopsLimit(): number;
    get iopsLimitingEnabled(): cdktf.IResolvable;
    get maximumDiskIops(): number;
}
export declare class DataVcdStorageProfileIopsSettingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdStorageProfileIopsSettingsOutputReference;
}
export interface DataVcdStorageProfileMetadataEntry {
}
export declare function dataVcdStorageProfileMetadataEntryToTerraform(struct?: DataVcdStorageProfileMetadataEntry): any;
export declare function dataVcdStorageProfileMetadataEntryToHclTerraform(struct?: DataVcdStorageProfileMetadataEntry): any;
export declare class DataVcdStorageProfileMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdStorageProfileMetadataEntry | undefined;
    set internalValue(value: DataVcdStorageProfileMetadataEntry | undefined);
    get isSystem(): cdktf.IResolvable;
    get key(): string;
    get type(): string;
    get userAccess(): string;
    get value(): string;
}
export declare class DataVcdStorageProfileMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdStorageProfileMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile vcd_storage_profile}
*/
export declare class DataVcdStorageProfile extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_storage_profile";
    /**
    * Generates CDKTF code for importing a DataVcdStorageProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdStorageProfile to import
    * @param importFromId The id of the existing DataVcdStorageProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdStorageProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/storage_profile vcd_storage_profile} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdStorageProfileConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdStorageProfileConfig);
    get default(): cdktf.IResolvable;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get iopsAllocated(): number;
    private _iopsSettings;
    get iopsSettings(): DataVcdStorageProfileIopsSettingsList;
    get limit(): number;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _metadataEntry;
    get metadataEntry(): DataVcdStorageProfileMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get units(): string;
    get usedStorage(): number;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
