import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdVersionConfig extends cdktf.TerraformMetaArguments {
    /**
    * A condition to check against the VCD version
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version#condition DataVcdVersion#condition}
    */
    readonly condition?: string;
    /**
    * This data source fails if the VCD doesn't match the version constraint set in 'condition'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version#fail_if_not_match DataVcdVersion#fail_if_not_match}
    */
    readonly failIfNotMatch?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version#id DataVcdVersion#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version vcd_version}
*/
export declare class DataVcdVersion extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_version";
    /**
    * Generates CDKTF code for importing a DataVcdVersion resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdVersion to import
    * @param importFromId The id of the existing DataVcdVersion that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdVersion to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/version vcd_version} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdVersionConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataVcdVersionConfig);
    get apiVersion(): string;
    private _condition?;
    get condition(): string;
    set condition(value: string);
    resetCondition(): void;
    get conditionInput(): string | undefined;
    private _failIfNotMatch?;
    get failIfNotMatch(): boolean | cdktf.IResolvable;
    set failIfNotMatch(value: boolean | cdktf.IResolvable);
    resetFailIfNotMatch(): void;
    get failIfNotMatchInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get matchesCondition(): cdktf.IResolvable;
    get vcdVersion(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
