import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdVmConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#id DataVcdVm#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A name for the VM, unique within the vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#name DataVcdVm#name}
    */
    readonly name: string;
    /**
    * Optional number of seconds to try and wait for DHCP IP (valid for 'network' block only)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#network_dhcp_wait_seconds DataVcdVm#network_dhcp_wait_seconds}
    */
    readonly networkDhcpWaitSeconds?: number;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#org DataVcdVm#org}
    */
    readonly org?: string;
    /**
    * VM placement policy ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#placement_policy_id DataVcdVm#placement_policy_id}
    */
    readonly placementPolicyId?: string;
    /**
    * VM sizing policy ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#sizing_policy_id DataVcdVm#sizing_policy_id}
    */
    readonly sizingPolicyId?: string;
    /**
    * The vApp this VM belongs to - Required, unless it is a standalone VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#vapp_name DataVcdVm#vapp_name}
    */
    readonly vappName?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#vdc DataVcdVm#vdc}
    */
    readonly vdc?: string;
}
export interface DataVcdVmBootOptions {
}
export declare function dataVcdVmBootOptionsToTerraform(struct?: DataVcdVmBootOptions): any;
export declare function dataVcdVmBootOptionsToHclTerraform(struct?: DataVcdVmBootOptions): any;
export declare class DataVcdVmBootOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmBootOptions | undefined;
    set internalValue(value: DataVcdVmBootOptions | undefined);
    get bootDelay(): number;
    get bootRetryDelay(): number;
    get bootRetryEnabled(): cdktf.IResolvable;
    get efiSecureBoot(): cdktf.IResolvable;
    get enterBiosSetupOnNextBoot(): cdktf.IResolvable;
}
export declare class DataVcdVmBootOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmBootOptionsOutputReference;
}
export interface DataVcdVmCustomization {
}
export declare function dataVcdVmCustomizationToTerraform(struct?: DataVcdVmCustomization): any;
export declare function dataVcdVmCustomizationToHclTerraform(struct?: DataVcdVmCustomization): any;
export declare class DataVcdVmCustomizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmCustomization | undefined;
    set internalValue(value: DataVcdVmCustomization | undefined);
    get adminPassword(): string;
    get allowLocalAdminPassword(): cdktf.IResolvable;
    get autoGeneratePassword(): cdktf.IResolvable;
    get changeSid(): cdktf.IResolvable;
    get enabled(): cdktf.IResolvable;
    get force(): cdktf.IResolvable;
    get initscript(): string;
    get joinDomain(): cdktf.IResolvable;
    get joinDomainAccountOu(): string;
    get joinDomainName(): string;
    get joinDomainPassword(): string;
    get joinDomainUser(): string;
    get joinOrgDomain(): cdktf.IResolvable;
    get mustChangePasswordOnFirstLogin(): cdktf.IResolvable;
    get numberOfAutoLogons(): number;
}
export declare class DataVcdVmCustomizationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmCustomizationOutputReference;
}
export interface DataVcdVmDisk {
}
export declare function dataVcdVmDiskToTerraform(struct?: DataVcdVmDisk): any;
export declare function dataVcdVmDiskToHclTerraform(struct?: DataVcdVmDisk): any;
export declare class DataVcdVmDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmDisk | undefined;
    set internalValue(value: DataVcdVmDisk | undefined);
    get busNumber(): string;
    get name(): string;
    get sizeInMb(): number;
    get unitNumber(): string;
}
export declare class DataVcdVmDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmDiskOutputReference;
}
export interface DataVcdVmInternalDisk {
}
export declare function dataVcdVmInternalDiskToTerraform(struct?: DataVcdVmInternalDisk): any;
export declare function dataVcdVmInternalDiskToHclTerraform(struct?: DataVcdVmInternalDisk): any;
export declare class DataVcdVmInternalDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmInternalDisk | undefined;
    set internalValue(value: DataVcdVmInternalDisk | undefined);
    get busNumber(): number;
    get busType(): string;
    get diskId(): string;
    get iops(): number;
    get sizeInMb(): number;
    get storageProfile(): string;
    get thinProvisioned(): cdktf.IResolvable;
    get unitNumber(): number;
}
export declare class DataVcdVmInternalDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmInternalDiskOutputReference;
}
export interface DataVcdVmMetadataEntry {
}
export declare function dataVcdVmMetadataEntryToTerraform(struct?: DataVcdVmMetadataEntry): any;
export declare function dataVcdVmMetadataEntryToHclTerraform(struct?: DataVcdVmMetadataEntry): any;
export declare class DataVcdVmMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmMetadataEntry | undefined;
    set internalValue(value: DataVcdVmMetadataEntry | undefined);
    get isSystem(): cdktf.IResolvable;
    get key(): string;
    get type(): string;
    get userAccess(): string;
    get value(): string;
}
export declare class DataVcdVmMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmMetadataEntryOutputReference;
}
export interface DataVcdVmNetwork {
}
export declare function dataVcdVmNetworkToTerraform(struct?: DataVcdVmNetwork): any;
export declare function dataVcdVmNetworkToHclTerraform(struct?: DataVcdVmNetwork): any;
export declare class DataVcdVmNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdVmNetwork | undefined;
    set internalValue(value: DataVcdVmNetwork | undefined);
    get adapterType(): string;
    get connected(): cdktf.IResolvable;
    get ip(): string;
    get ipAllocationMode(): string;
    get isPrimary(): cdktf.IResolvable;
    get mac(): string;
    get name(): string;
    get type(): string;
}
export declare class DataVcdVmNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdVmNetworkOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm vcd_vm}
*/
export declare class DataVcdVm extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_vm";
    /**
    * Generates CDKTF code for importing a DataVcdVm resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdVm to import
    * @param importFromId The id of the existing DataVcdVm that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdVm to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/data-sources/vm vcd_vm} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdVmConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdVmConfig);
    private _bootOptions;
    get bootOptions(): DataVcdVmBootOptionsList;
    get computerName(): string;
    get cpuCores(): number;
    get cpuHotAddEnabled(): cdktf.IResolvable;
    get cpuLimit(): number;
    get cpuPriority(): string;
    get cpuReservation(): number;
    get cpuShares(): number;
    get cpus(): number;
    private _customization;
    get customization(): DataVcdVmCustomizationList;
    get description(): string;
    private _disk;
    get disk(): DataVcdVmDiskList;
    get exposeHardwareVirtualization(): cdktf.IResolvable;
    get firmware(): string;
    private _guestProperties;
    get guestProperties(): cdktf.StringMap;
    get hardwareVersion(): string;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inheritedMetadata;
    get inheritedMetadata(): cdktf.StringMap;
    private _internalDisk;
    get internalDisk(): DataVcdVmInternalDiskList;
    get memory(): number;
    get memoryHotAddEnabled(): cdktf.IResolvable;
    get memoryLimit(): number;
    get memoryPriority(): string;
    get memoryReservation(): number;
    get memoryShares(): number;
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _metadataEntry;
    get metadataEntry(): DataVcdVmMetadataEntryList;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _network;
    get network(): DataVcdVmNetworkList;
    private _networkDhcpWaitSeconds?;
    get networkDhcpWaitSeconds(): number;
    set networkDhcpWaitSeconds(value: number);
    resetNetworkDhcpWaitSeconds(): void;
    get networkDhcpWaitSecondsInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get osType(): string;
    private _placementPolicyId?;
    get placementPolicyId(): string;
    set placementPolicyId(value: string);
    resetPlacementPolicyId(): void;
    get placementPolicyIdInput(): string | undefined;
    get securityTags(): string[];
    private _sizingPolicyId?;
    get sizingPolicyId(): string;
    set sizingPolicyId(value: string);
    resetSizingPolicyId(): void;
    get sizingPolicyIdInput(): string | undefined;
    get status(): number;
    get statusText(): string;
    get storageProfile(): string;
    get vappId(): string;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    resetVappName(): void;
    get vappNameInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    get vmType(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
