import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgegatewaySettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the edge gateway. Required when 'edge_gateway_name' is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#edge_gateway_id EdgegatewaySettings#edge_gateway_id}
    */
    readonly edgeGatewayId?: string;
    /**
    * Name of the edge gateway. Required when 'edge_gateway_id' is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#edge_gateway_name EdgegatewaySettings#edge_gateway_name}
    */
    readonly edgeGatewayName?: string;
    /**
    * 'accept' or 'deny'. Default 'deny'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#fw_default_rule_action EdgegatewaySettings#fw_default_rule_action}
    */
    readonly fwDefaultRuleAction?: string;
    /**
    * Enable logging for default rule. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#fw_default_rule_logging_enabled EdgegatewaySettings#fw_default_rule_logging_enabled}
    */
    readonly fwDefaultRuleLoggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable firewall. Default 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#fw_enabled EdgegatewaySettings#fw_enabled}
    */
    readonly fwEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#id EdgegatewaySettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Enable load balancer acceleration. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#lb_acceleration_enabled EdgegatewaySettings#lb_acceleration_enabled}
    */
    readonly lbAccelerationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable load balancing. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#lb_enabled EdgegatewaySettings#lb_enabled}
    */
    readonly lbEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable load balancer logging. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#lb_logging_enabled EdgegatewaySettings#lb_logging_enabled}
    */
    readonly lbLoggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Log level. One of 'emergency', 'alert', 'critical', 'error', 'warning', 'notice', 'info', 'debug'. ('info' by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#lb_loglevel EdgegatewaySettings#lb_loglevel}
    */
    readonly lbLoglevel?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#org EdgegatewaySettings#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#vdc EdgegatewaySettings#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings vcd_edgegateway_settings}
*/
export declare class EdgegatewaySettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_edgegateway_settings";
    /**
    * Generates CDKTF code for importing a EdgegatewaySettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EdgegatewaySettings to import
    * @param importFromId The id of the existing EdgegatewaySettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EdgegatewaySettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway_settings vcd_edgegateway_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgegatewaySettingsConfig = {}
    */
    constructor(scope: Construct, id: string, config?: EdgegatewaySettingsConfig);
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    resetEdgeGatewayId(): void;
    get edgeGatewayIdInput(): string | undefined;
    private _edgeGatewayName?;
    get edgeGatewayName(): string;
    set edgeGatewayName(value: string);
    resetEdgeGatewayName(): void;
    get edgeGatewayNameInput(): string | undefined;
    private _fwDefaultRuleAction?;
    get fwDefaultRuleAction(): string;
    set fwDefaultRuleAction(value: string);
    resetFwDefaultRuleAction(): void;
    get fwDefaultRuleActionInput(): string | undefined;
    private _fwDefaultRuleLoggingEnabled?;
    get fwDefaultRuleLoggingEnabled(): boolean | cdktf.IResolvable;
    set fwDefaultRuleLoggingEnabled(value: boolean | cdktf.IResolvable);
    resetFwDefaultRuleLoggingEnabled(): void;
    get fwDefaultRuleLoggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fwEnabled?;
    get fwEnabled(): boolean | cdktf.IResolvable;
    set fwEnabled(value: boolean | cdktf.IResolvable);
    resetFwEnabled(): void;
    get fwEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _lbAccelerationEnabled?;
    get lbAccelerationEnabled(): boolean | cdktf.IResolvable;
    set lbAccelerationEnabled(value: boolean | cdktf.IResolvable);
    resetLbAccelerationEnabled(): void;
    get lbAccelerationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbEnabled?;
    get lbEnabled(): boolean | cdktf.IResolvable;
    set lbEnabled(value: boolean | cdktf.IResolvable);
    resetLbEnabled(): void;
    get lbEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbLoggingEnabled?;
    get lbLoggingEnabled(): boolean | cdktf.IResolvable;
    set lbLoggingEnabled(value: boolean | cdktf.IResolvable);
    resetLbLoggingEnabled(): void;
    get lbLoggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbLoglevel?;
    get lbLoglevel(): string;
    set lbLoglevel(value: string);
    resetLbLoglevel(): void;
    get lbLoglevelInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
