import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgegatewayConfig extends cdktf.TerraformMetaArguments {
    /**
    * Configuration of the vShield edge VM for this gateway. One of: compact, full ("Large"), full4 ("Quad Large"), x-large
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#configuration Edgegateway#configuration}
    */
    readonly configuration: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#description Edgegateway#description}
    */
    readonly description?: string;
    /**
    * Enable distributed routing
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#distributed_routing Edgegateway#distributed_routing}
    */
    readonly distributedRouting?: boolean | cdktf.IResolvable;
    /**
    * Enable FIPS mode. FIPS mode turns on the cipher suites that comply with FIPS. (False by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#fips_mode_enabled Edgegateway#fips_mode_enabled}
    */
    readonly fipsModeEnabled?: boolean | cdktf.IResolvable;
    /**
    * 'accept' or 'deny'. Default 'deny'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#fw_default_rule_action Edgegateway#fw_default_rule_action}
    */
    readonly fwDefaultRuleAction?: string;
    /**
    * Enable logging for default rule. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#fw_default_rule_logging_enabled Edgegateway#fw_default_rule_logging_enabled}
    */
    readonly fwDefaultRuleLoggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable firewall. Default 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#fw_enabled Edgegateway#fw_enabled}
    */
    readonly fwEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable high availability on this edge gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#ha_enabled Edgegateway#ha_enabled}
    */
    readonly haEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#id Edgegateway#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Enable load balancer acceleration. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#lb_acceleration_enabled Edgegateway#lb_acceleration_enabled}
    */
    readonly lbAccelerationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable load balancing. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#lb_enabled Edgegateway#lb_enabled}
    */
    readonly lbEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enable load balancer logging. (Disabled by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#lb_logging_enabled Edgegateway#lb_logging_enabled}
    */
    readonly lbLoggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Log level. One of 'emergency', 'alert', 'critical', 'error', 'warning', 'notice', 'info', 'debug'. ('info' by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#lb_loglevel Edgegateway#lb_loglevel}
    */
    readonly lbLoglevel?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#name Edgegateway#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#org Edgegateway#org}
    */
    readonly org?: string;
    /**
    * If true, default gateway will be used for the edge gateways' default routing and DNS forwarding.(False by default)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#use_default_route_for_dns_relay Edgegateway#use_default_route_for_dns_relay}
    */
    readonly useDefaultRouteForDnsRelay?: boolean | cdktf.IResolvable;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#vdc Edgegateway#vdc}
    */
    readonly vdc?: string;
    /**
    * external_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#external_network Edgegateway#external_network}
    */
    readonly externalNetwork: EdgegatewayExternalNetwork[] | cdktf.IResolvable;
}
export interface EdgegatewayExternalNetworkSubnetSuballocatePool {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#end_address Edgegateway#end_address}
    */
    readonly endAddress: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#start_address Edgegateway#start_address}
    */
    readonly startAddress: string;
}
export declare function edgegatewayExternalNetworkSubnetSuballocatePoolToTerraform(struct?: EdgegatewayExternalNetworkSubnetSuballocatePool | cdktf.IResolvable): any;
export declare function edgegatewayExternalNetworkSubnetSuballocatePoolToHclTerraform(struct?: EdgegatewayExternalNetworkSubnetSuballocatePool | cdktf.IResolvable): any;
export declare class EdgegatewayExternalNetworkSubnetSuballocatePoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgegatewayExternalNetworkSubnetSuballocatePool | cdktf.IResolvable | undefined;
    set internalValue(value: EdgegatewayExternalNetworkSubnetSuballocatePool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class EdgegatewayExternalNetworkSubnetSuballocatePoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EdgegatewayExternalNetworkSubnetSuballocatePool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgegatewayExternalNetworkSubnetSuballocatePoolOutputReference;
}
export interface EdgegatewayExternalNetworkSubnet {
    /**
    * Gateway address for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#gateway Edgegateway#gateway}
    */
    readonly gateway: string;
    /**
    * IP address on the edge gateway - will be auto-assigned if not defined
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#ip_address Edgegateway#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * Netmask address for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#netmask Edgegateway#netmask}
    */
    readonly netmask: string;
    /**
    * Defines if this subnet should be used as default gateway for edge
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#use_for_default_route Edgegateway#use_for_default_route}
    */
    readonly useForDefaultRoute?: boolean | cdktf.IResolvable;
    /**
    * suballocate_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#suballocate_pool Edgegateway#suballocate_pool}
    */
    readonly suballocatePool?: EdgegatewayExternalNetworkSubnetSuballocatePool[] | cdktf.IResolvable;
}
export declare function edgegatewayExternalNetworkSubnetToTerraform(struct?: EdgegatewayExternalNetworkSubnet | cdktf.IResolvable): any;
export declare function edgegatewayExternalNetworkSubnetToHclTerraform(struct?: EdgegatewayExternalNetworkSubnet | cdktf.IResolvable): any;
export declare class EdgegatewayExternalNetworkSubnetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgegatewayExternalNetworkSubnet | cdktf.IResolvable | undefined;
    set internalValue(value: EdgegatewayExternalNetworkSubnet | cdktf.IResolvable | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    get netmaskInput(): string | undefined;
    private _useForDefaultRoute?;
    get useForDefaultRoute(): boolean | cdktf.IResolvable;
    set useForDefaultRoute(value: boolean | cdktf.IResolvable);
    resetUseForDefaultRoute(): void;
    get useForDefaultRouteInput(): boolean | cdktf.IResolvable | undefined;
    private _suballocatePool;
    get suballocatePool(): EdgegatewayExternalNetworkSubnetSuballocatePoolList;
    putSuballocatePool(value: EdgegatewayExternalNetworkSubnetSuballocatePool[] | cdktf.IResolvable): void;
    resetSuballocatePool(): void;
    get suballocatePoolInput(): cdktf.IResolvable | EdgegatewayExternalNetworkSubnetSuballocatePool[] | undefined;
}
export declare class EdgegatewayExternalNetworkSubnetList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EdgegatewayExternalNetworkSubnet[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgegatewayExternalNetworkSubnetOutputReference;
}
export interface EdgegatewayExternalNetwork {
    /**
    * Enable rate limiting
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#enable_rate_limit Edgegateway#enable_rate_limit}
    */
    readonly enableRateLimit?: boolean | cdktf.IResolvable;
    /**
    * Incoming rate limit (Mbps)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#incoming_rate_limit Edgegateway#incoming_rate_limit}
    */
    readonly incomingRateLimit?: number;
    /**
    * External network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#name Edgegateway#name}
    */
    readonly name: string;
    /**
    * Outgoing rate limit (Mbps)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#outgoing_rate_limit Edgegateway#outgoing_rate_limit}
    */
    readonly outgoingRateLimit?: number;
    /**
    * subnet block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#subnet Edgegateway#subnet}
    */
    readonly subnet?: EdgegatewayExternalNetworkSubnet[] | cdktf.IResolvable;
}
export declare function edgegatewayExternalNetworkToTerraform(struct?: EdgegatewayExternalNetwork | cdktf.IResolvable): any;
export declare function edgegatewayExternalNetworkToHclTerraform(struct?: EdgegatewayExternalNetwork | cdktf.IResolvable): any;
export declare class EdgegatewayExternalNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgegatewayExternalNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: EdgegatewayExternalNetwork | cdktf.IResolvable | undefined);
    private _enableRateLimit?;
    get enableRateLimit(): boolean | cdktf.IResolvable;
    set enableRateLimit(value: boolean | cdktf.IResolvable);
    resetEnableRateLimit(): void;
    get enableRateLimitInput(): boolean | cdktf.IResolvable | undefined;
    private _incomingRateLimit?;
    get incomingRateLimit(): number;
    set incomingRateLimit(value: number);
    resetIncomingRateLimit(): void;
    get incomingRateLimitInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _outgoingRateLimit?;
    get outgoingRateLimit(): number;
    set outgoingRateLimit(value: number);
    resetOutgoingRateLimit(): void;
    get outgoingRateLimitInput(): number | undefined;
    private _subnet;
    get subnet(): EdgegatewayExternalNetworkSubnetList;
    putSubnet(value: EdgegatewayExternalNetworkSubnet[] | cdktf.IResolvable): void;
    resetSubnet(): void;
    get subnetInput(): cdktf.IResolvable | EdgegatewayExternalNetworkSubnet[] | undefined;
}
export declare class EdgegatewayExternalNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: EdgegatewayExternalNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgegatewayExternalNetworkOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway vcd_edgegateway}
*/
export declare class Edgegateway extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_edgegateway";
    /**
    * Generates CDKTF code for importing a Edgegateway resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Edgegateway to import
    * @param importFromId The id of the existing Edgegateway that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Edgegateway to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/edgegateway vcd_edgegateway} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgegatewayConfig
    */
    constructor(scope: Construct, id: string, config: EdgegatewayConfig);
    private _configuration?;
    get configuration(): string;
    set configuration(value: string);
    get configurationInput(): string | undefined;
    get defaultExternalNetworkIp(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _distributedRouting?;
    get distributedRouting(): boolean | cdktf.IResolvable;
    set distributedRouting(value: boolean | cdktf.IResolvable);
    resetDistributedRouting(): void;
    get distributedRoutingInput(): boolean | cdktf.IResolvable | undefined;
    get externalNetworkIps(): string[];
    private _fipsModeEnabled?;
    get fipsModeEnabled(): boolean | cdktf.IResolvable;
    set fipsModeEnabled(value: boolean | cdktf.IResolvable);
    resetFipsModeEnabled(): void;
    get fipsModeEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fwDefaultRuleAction?;
    get fwDefaultRuleAction(): string;
    set fwDefaultRuleAction(value: string);
    resetFwDefaultRuleAction(): void;
    get fwDefaultRuleActionInput(): string | undefined;
    private _fwDefaultRuleLoggingEnabled?;
    get fwDefaultRuleLoggingEnabled(): boolean | cdktf.IResolvable;
    set fwDefaultRuleLoggingEnabled(value: boolean | cdktf.IResolvable);
    resetFwDefaultRuleLoggingEnabled(): void;
    get fwDefaultRuleLoggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fwEnabled?;
    get fwEnabled(): boolean | cdktf.IResolvable;
    set fwEnabled(value: boolean | cdktf.IResolvable);
    resetFwEnabled(): void;
    get fwEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _haEnabled?;
    get haEnabled(): boolean | cdktf.IResolvable;
    set haEnabled(value: boolean | cdktf.IResolvable);
    resetHaEnabled(): void;
    get haEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _lbAccelerationEnabled?;
    get lbAccelerationEnabled(): boolean | cdktf.IResolvable;
    set lbAccelerationEnabled(value: boolean | cdktf.IResolvable);
    resetLbAccelerationEnabled(): void;
    get lbAccelerationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbEnabled?;
    get lbEnabled(): boolean | cdktf.IResolvable;
    set lbEnabled(value: boolean | cdktf.IResolvable);
    resetLbEnabled(): void;
    get lbEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbLoggingEnabled?;
    get lbLoggingEnabled(): boolean | cdktf.IResolvable;
    set lbLoggingEnabled(value: boolean | cdktf.IResolvable);
    resetLbLoggingEnabled(): void;
    get lbLoggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _lbLoglevel?;
    get lbLoglevel(): string;
    set lbLoglevel(value: string);
    resetLbLoglevel(): void;
    get lbLoglevelInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _useDefaultRouteForDnsRelay?;
    get useDefaultRouteForDnsRelay(): boolean | cdktf.IResolvable;
    set useDefaultRouteForDnsRelay(value: boolean | cdktf.IResolvable);
    resetUseDefaultRouteForDnsRelay(): void;
    get useDefaultRouteForDnsRelayInput(): boolean | cdktf.IResolvable | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _externalNetwork;
    get externalNetwork(): EdgegatewayExternalNetworkList;
    putExternalNetwork(value: EdgegatewayExternalNetwork[] | cdktf.IResolvable): void;
    get externalNetworkInput(): cdktf.IResolvable | EdgegatewayExternalNetwork[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
