import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ExternalNetworkV2Config extends cdktf.TerraformMetaArguments {
    /**
    * Dedicate this External Network to an Org ID (only with IP Spaces, VCD 10.4.1+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#dedicated_org_id ExternalNetworkV2#dedicated_org_id}
    */
    readonly dedicatedOrgId?: string;
    /**
    * Network description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#description ExternalNetworkV2#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#id ExternalNetworkV2#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#name ExternalNetworkV2#name}
    */
    readonly name: string;
    /**
    * Enables IP Spaces for this network (default 'false'). VCD 10.4.1+
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#use_ip_spaces ExternalNetworkV2#use_ip_spaces}
    */
    readonly useIpSpaces?: boolean | cdktf.IResolvable;
    /**
    * ip_scope block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#ip_scope ExternalNetworkV2#ip_scope}
    */
    readonly ipScope?: ExternalNetworkV2IpScope[] | cdktf.IResolvable;
    /**
    * nsxt_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#nsxt_network ExternalNetworkV2#nsxt_network}
    */
    readonly nsxtNetwork?: ExternalNetworkV2NsxtNetwork;
    /**
    * vsphere_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#vsphere_network ExternalNetworkV2#vsphere_network}
    */
    readonly vsphereNetwork?: ExternalNetworkV2VsphereNetwork[] | cdktf.IResolvable;
}
export interface ExternalNetworkV2IpScopeStaticIpPool {
    /**
    * End address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#end_address ExternalNetworkV2#end_address}
    */
    readonly endAddress: string;
    /**
    * Start address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#start_address ExternalNetworkV2#start_address}
    */
    readonly startAddress: string;
}
export declare function externalNetworkV2IpScopeStaticIpPoolToTerraform(struct?: ExternalNetworkV2IpScopeStaticIpPool | cdktf.IResolvable): any;
export declare function externalNetworkV2IpScopeStaticIpPoolToHclTerraform(struct?: ExternalNetworkV2IpScopeStaticIpPool | cdktf.IResolvable): any;
export declare class ExternalNetworkV2IpScopeStaticIpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ExternalNetworkV2IpScopeStaticIpPool | cdktf.IResolvable | undefined;
    set internalValue(value: ExternalNetworkV2IpScopeStaticIpPool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class ExternalNetworkV2IpScopeStaticIpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ExternalNetworkV2IpScopeStaticIpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ExternalNetworkV2IpScopeStaticIpPoolOutputReference;
}
export interface ExternalNetworkV2IpScope {
    /**
    * Primary DNS server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#dns1 ExternalNetworkV2#dns1}
    */
    readonly dns1?: string;
    /**
    * Secondary DNS server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#dns2 ExternalNetworkV2#dns2}
    */
    readonly dns2?: string;
    /**
    * DNS suffix
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#dns_suffix ExternalNetworkV2#dns_suffix}
    */
    readonly dnsSuffix?: string;
    /**
    * If subnet is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#enabled ExternalNetworkV2#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Gateway of the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#gateway ExternalNetworkV2#gateway}
    */
    readonly gateway: string;
    /**
    * Network mask
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#prefix_length ExternalNetworkV2#prefix_length}
    */
    readonly prefixLength: number;
    /**
    * static_ip_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#static_ip_pool ExternalNetworkV2#static_ip_pool}
    */
    readonly staticIpPool?: ExternalNetworkV2IpScopeStaticIpPool[] | cdktf.IResolvable;
}
export declare function externalNetworkV2IpScopeToTerraform(struct?: ExternalNetworkV2IpScope | cdktf.IResolvable): any;
export declare function externalNetworkV2IpScopeToHclTerraform(struct?: ExternalNetworkV2IpScope | cdktf.IResolvable): any;
export declare class ExternalNetworkV2IpScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ExternalNetworkV2IpScope | cdktf.IResolvable | undefined;
    set internalValue(value: ExternalNetworkV2IpScope | cdktf.IResolvable | undefined);
    private _dns1?;
    get dns1(): string;
    set dns1(value: string);
    resetDns1(): void;
    get dns1Input(): string | undefined;
    private _dns2?;
    get dns2(): string;
    set dns2(value: string);
    resetDns2(): void;
    get dns2Input(): string | undefined;
    private _dnsSuffix?;
    get dnsSuffix(): string;
    set dnsSuffix(value: string);
    resetDnsSuffix(): void;
    get dnsSuffixInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): number;
    set prefixLength(value: number);
    get prefixLengthInput(): number | undefined;
    private _staticIpPool;
    get staticIpPool(): ExternalNetworkV2IpScopeStaticIpPoolList;
    putStaticIpPool(value: ExternalNetworkV2IpScopeStaticIpPool[] | cdktf.IResolvable): void;
    resetStaticIpPool(): void;
    get staticIpPoolInput(): cdktf.IResolvable | ExternalNetworkV2IpScopeStaticIpPool[] | undefined;
}
export declare class ExternalNetworkV2IpScopeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ExternalNetworkV2IpScope[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ExternalNetworkV2IpScopeOutputReference;
}
export interface ExternalNetworkV2NsxtNetwork {
    /**
    * ID of NSX-T manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#nsxt_manager_id ExternalNetworkV2#nsxt_manager_id}
    */
    readonly nsxtManagerId: string;
    /**
    * Name of NSX-T segment (for NSX-T segment backed external network)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#nsxt_segment_name ExternalNetworkV2#nsxt_segment_name}
    */
    readonly nsxtSegmentName?: string;
    /**
    * ID of NSX-T Tier-0 router (for T0 gateway backed external network)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#nsxt_tier0_router_id ExternalNetworkV2#nsxt_tier0_router_id}
    */
    readonly nsxtTier0RouterId?: string;
}
export declare function externalNetworkV2NsxtNetworkToTerraform(struct?: ExternalNetworkV2NsxtNetworkOutputReference | ExternalNetworkV2NsxtNetwork): any;
export declare function externalNetworkV2NsxtNetworkToHclTerraform(struct?: ExternalNetworkV2NsxtNetworkOutputReference | ExternalNetworkV2NsxtNetwork): any;
export declare class ExternalNetworkV2NsxtNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ExternalNetworkV2NsxtNetwork | undefined;
    set internalValue(value: ExternalNetworkV2NsxtNetwork | undefined);
    private _nsxtManagerId?;
    get nsxtManagerId(): string;
    set nsxtManagerId(value: string);
    get nsxtManagerIdInput(): string | undefined;
    private _nsxtSegmentName?;
    get nsxtSegmentName(): string;
    set nsxtSegmentName(value: string);
    resetNsxtSegmentName(): void;
    get nsxtSegmentNameInput(): string | undefined;
    private _nsxtTier0RouterId?;
    get nsxtTier0RouterId(): string;
    set nsxtTier0RouterId(value: string);
    resetNsxtTier0RouterId(): void;
    get nsxtTier0RouterIdInput(): string | undefined;
}
export interface ExternalNetworkV2VsphereNetwork {
    /**
    * The name of the port group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#portgroup_id ExternalNetworkV2#portgroup_id}
    */
    readonly portgroupId: string;
    /**
    * The vCenter server name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#vcenter_id ExternalNetworkV2#vcenter_id}
    */
    readonly vcenterId: string;
}
export declare function externalNetworkV2VsphereNetworkToTerraform(struct?: ExternalNetworkV2VsphereNetwork | cdktf.IResolvable): any;
export declare function externalNetworkV2VsphereNetworkToHclTerraform(struct?: ExternalNetworkV2VsphereNetwork | cdktf.IResolvable): any;
export declare class ExternalNetworkV2VsphereNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ExternalNetworkV2VsphereNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: ExternalNetworkV2VsphereNetwork | cdktf.IResolvable | undefined);
    private _portgroupId?;
    get portgroupId(): string;
    set portgroupId(value: string);
    get portgroupIdInput(): string | undefined;
    private _vcenterId?;
    get vcenterId(): string;
    set vcenterId(value: string);
    get vcenterIdInput(): string | undefined;
}
export declare class ExternalNetworkV2VsphereNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ExternalNetworkV2VsphereNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ExternalNetworkV2VsphereNetworkOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2 vcd_external_network_v2}
*/
export declare class ExternalNetworkV2 extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_external_network_v2";
    /**
    * Generates CDKTF code for importing a ExternalNetworkV2 resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ExternalNetworkV2 to import
    * @param importFromId The id of the existing ExternalNetworkV2 that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ExternalNetworkV2 to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/external_network_v2 vcd_external_network_v2} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ExternalNetworkV2Config
    */
    constructor(scope: Construct, id: string, config: ExternalNetworkV2Config);
    private _dedicatedOrgId?;
    get dedicatedOrgId(): string;
    set dedicatedOrgId(value: string);
    resetDedicatedOrgId(): void;
    get dedicatedOrgIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _useIpSpaces?;
    get useIpSpaces(): boolean | cdktf.IResolvable;
    set useIpSpaces(value: boolean | cdktf.IResolvable);
    resetUseIpSpaces(): void;
    get useIpSpacesInput(): boolean | cdktf.IResolvable | undefined;
    private _ipScope;
    get ipScope(): ExternalNetworkV2IpScopeList;
    putIpScope(value: ExternalNetworkV2IpScope[] | cdktf.IResolvable): void;
    resetIpScope(): void;
    get ipScopeInput(): cdktf.IResolvable | ExternalNetworkV2IpScope[] | undefined;
    private _nsxtNetwork;
    get nsxtNetwork(): ExternalNetworkV2NsxtNetworkOutputReference;
    putNsxtNetwork(value: ExternalNetworkV2NsxtNetwork): void;
    resetNsxtNetwork(): void;
    get nsxtNetworkInput(): ExternalNetworkV2NsxtNetwork | undefined;
    private _vsphereNetwork;
    get vsphereNetwork(): ExternalNetworkV2VsphereNetworkList;
    putVsphereNetwork(value: ExternalNetworkV2VsphereNetwork[] | cdktf.IResolvable): void;
    resetVsphereNetwork(): void;
    get vsphereNetworkInput(): cdktf.IResolvable | ExternalNetworkV2VsphereNetwork[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
