import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface InsertedMediaConfig extends cdktf.TerraformMetaArguments {
    /**
    * catalog name where to find media file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#catalog InsertedMedia#catalog}
    */
    readonly catalog: string;
    /**
    * When ejecting answers automatically to question yes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#eject_force InsertedMedia#eject_force}
    */
    readonly ejectForce?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#id InsertedMedia#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * media name to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#name InsertedMedia#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#org InsertedMedia#org}
    */
    readonly org?: string;
    /**
    * vApp to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#vapp_name InsertedMedia#vapp_name}
    */
    readonly vappName: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#vdc InsertedMedia#vdc}
    */
    readonly vdc?: string;
    /**
    * VM in vApp in which media will be inserted or ejected
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#vm_name InsertedMedia#vm_name}
    */
    readonly vmName: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media vcd_inserted_media}
*/
export declare class InsertedMedia extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_inserted_media";
    /**
    * Generates CDKTF code for importing a InsertedMedia resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the InsertedMedia to import
    * @param importFromId The id of the existing InsertedMedia that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the InsertedMedia to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/inserted_media vcd_inserted_media} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options InsertedMediaConfig
    */
    constructor(scope: Construct, id: string, config: InsertedMediaConfig);
    private _catalog?;
    get catalog(): string;
    set catalog(value: string);
    get catalogInput(): string | undefined;
    private _ejectForce?;
    get ejectForce(): boolean | cdktf.IResolvable;
    set ejectForce(value: boolean | cdktf.IResolvable);
    resetEjectForce(): void;
    get ejectForceInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    get vappNameInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _vmName?;
    get vmName(): string;
    set vmName(value: string);
    get vmNameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
