import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IpSpaceCustomQuotaConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#id IpSpaceCustomQuota#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP range quota. '-1' - unlimited, '0' - no quota
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#ip_range_quota IpSpaceCustomQuota#ip_range_quota}
    */
    readonly ipRangeQuota?: string;
    /**
    * ID of IP Space
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#ip_space_id IpSpaceCustomQuota#ip_space_id}
    */
    readonly ipSpaceId: string;
    /**
    * Organization ID for setting custom quota
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#org_id IpSpaceCustomQuota#org_id}
    */
    readonly orgId: string;
    /**
    * ip_prefix_quota block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#ip_prefix_quota IpSpaceCustomQuota#ip_prefix_quota}
    */
    readonly ipPrefixQuota?: IpSpaceCustomQuotaIpPrefixQuota[] | cdktf.IResolvable;
}
export interface IpSpaceCustomQuotaIpPrefixQuota {
    /**
    * Prefix length
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#prefix_length IpSpaceCustomQuota#prefix_length}
    */
    readonly prefixLength: string;
    /**
    * IP Prefix Quota
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#quota IpSpaceCustomQuota#quota}
    */
    readonly quota: string;
}
export declare function ipSpaceCustomQuotaIpPrefixQuotaToTerraform(struct?: IpSpaceCustomQuotaIpPrefixQuota | cdktf.IResolvable): any;
export declare function ipSpaceCustomQuotaIpPrefixQuotaToHclTerraform(struct?: IpSpaceCustomQuotaIpPrefixQuota | cdktf.IResolvable): any;
export declare class IpSpaceCustomQuotaIpPrefixQuotaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IpSpaceCustomQuotaIpPrefixQuota | cdktf.IResolvable | undefined;
    set internalValue(value: IpSpaceCustomQuotaIpPrefixQuota | cdktf.IResolvable | undefined);
    private _prefixLength?;
    get prefixLength(): string;
    set prefixLength(value: string);
    get prefixLengthInput(): string | undefined;
    private _quota?;
    get quota(): string;
    set quota(value: string);
    get quotaInput(): string | undefined;
}
export declare class IpSpaceCustomQuotaIpPrefixQuotaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IpSpaceCustomQuotaIpPrefixQuota[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IpSpaceCustomQuotaIpPrefixQuotaOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota vcd_ip_space_custom_quota}
*/
export declare class IpSpaceCustomQuota extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_ip_space_custom_quota";
    /**
    * Generates CDKTF code for importing a IpSpaceCustomQuota resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IpSpaceCustomQuota to import
    * @param importFromId The id of the existing IpSpaceCustomQuota that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IpSpaceCustomQuota to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_custom_quota vcd_ip_space_custom_quota} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IpSpaceCustomQuotaConfig
    */
    constructor(scope: Construct, id: string, config: IpSpaceCustomQuotaConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipRangeQuota?;
    get ipRangeQuota(): string;
    set ipRangeQuota(value: string);
    resetIpRangeQuota(): void;
    get ipRangeQuotaInput(): string | undefined;
    private _ipSpaceId?;
    get ipSpaceId(): string;
    set ipSpaceId(value: string);
    get ipSpaceIdInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _ipPrefixQuota;
    get ipPrefixQuota(): IpSpaceCustomQuotaIpPrefixQuotaList;
    putIpPrefixQuota(value: IpSpaceCustomQuotaIpPrefixQuota[] | cdktf.IResolvable): void;
    resetIpPrefixQuota(): void;
    get ipPrefixQuotaInput(): cdktf.IResolvable | IpSpaceCustomQuotaIpPrefixQuota[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
