import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IpSpaceIpAllocationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Custom description can only be set when usage_state is set to 'USED_MANUAL'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#description IpSpaceIpAllocation#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#id IpSpaceIpAllocation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP Space ID for IP Allocation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#ip_space_id IpSpaceIpAllocation#ip_space_id}
    */
    readonly ipSpaceId?: string;
    /**
    * Org ID for IP Allocation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#org_id IpSpaceIpAllocation#org_id}
    */
    readonly orgId: string;
    /**
    * Required if 'type' is IP_PREFIX and no custom 'value` is provided
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#prefix_length IpSpaceIpAllocation#prefix_length}
    */
    readonly prefixLength?: string;
    /**
    * Type of allocation. One of `FLOATING_IP``, `IP_PREFIX`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#type IpSpaceIpAllocation#type}
    */
    readonly type: string;
    /**
    * Can be set to 'USED_MANUAL' to mark the IP Allocation for manual use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#usage_state IpSpaceIpAllocation#usage_state}
    */
    readonly usageState?: string;
    /**
    * IP address or CIDR to use. (VCD 10.4.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#value IpSpaceIpAllocation#value}
    */
    readonly value?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation vcd_ip_space_ip_allocation}
*/
export declare class IpSpaceIpAllocation extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_ip_space_ip_allocation";
    /**
    * Generates CDKTF code for importing a IpSpaceIpAllocation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IpSpaceIpAllocation to import
    * @param importFromId The id of the existing IpSpaceIpAllocation that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IpSpaceIpAllocation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space_ip_allocation vcd_ip_space_ip_allocation} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IpSpaceIpAllocationConfig
    */
    constructor(scope: Construct, id: string, config: IpSpaceIpAllocationConfig);
    get allocationDate(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get ip(): string;
    get ipAddress(): string;
    private _ipSpaceId?;
    get ipSpaceId(): string;
    set ipSpaceId(value: string);
    resetIpSpaceId(): void;
    get ipSpaceIdInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): string;
    set prefixLength(value: string);
    resetPrefixLength(): void;
    get prefixLengthInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _usageState?;
    get usageState(): string;
    set usageState(value: string);
    resetUsageState(): void;
    get usageStateInput(): string | undefined;
    get usedById(): string;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
