import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IpSpaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Flag exposing whether default firewall rule creation should be enabled (VCD 10.5.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#default_firewall_rule_creation_enabled IpSpace#default_firewall_rule_creation_enabled}
    */
    readonly defaultFirewallRuleCreationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Flag whether NO SNAT rule creation should be enabled (VCD 10.5.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#default_no_snat_rule_creation_enabled IpSpace#default_no_snat_rule_creation_enabled}
    */
    readonly defaultNoSnatRuleCreationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Flag whether SNAT rule creation should be enabled (VCD 10.5.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#default_snat_rule_creation_enabled IpSpace#default_snat_rule_creation_enabled}
    */
    readonly defaultSnatRuleCreationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Description of IP space
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#description IpSpace#description}
    */
    readonly description?: string;
    /**
    * External scope in CIDR format
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#external_scope IpSpace#external_scope}
    */
    readonly externalScope?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#id IpSpace#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of internal scope IPs in CIDR format
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#internal_scope IpSpace#internal_scope}
    */
    readonly internalScope: string[];
    /**
    * IP ranges quota. '-1' - unlimited, '0' - no quota
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#ip_range_quota IpSpace#ip_range_quota}
    */
    readonly ipRangeQuota?: string;
    /**
    * Name of IP space
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#name IpSpace#name}
    */
    readonly name: string;
    /**
    * Org ID for 'SHARED' IP spaces
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#org_id IpSpace#org_id}
    */
    readonly orgId?: string;
    /**
    * Flag whether route advertisement should be enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#route_advertisement_enabled IpSpace#route_advertisement_enabled}
    */
    readonly routeAdvertisementEnabled?: boolean | cdktf.IResolvable;
    /**
    * Type of IP space
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#type IpSpace#type}
    */
    readonly type: string;
    /**
    * ip_prefix block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#ip_prefix IpSpace#ip_prefix}
    */
    readonly ipPrefix?: IpSpaceIpPrefix[] | cdktf.IResolvable;
    /**
    * ip_range block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#ip_range IpSpace#ip_range}
    */
    readonly ipRange?: IpSpaceIpRange[] | cdktf.IResolvable;
}
export interface IpSpaceIpPrefixPrefix {
    /**
    * First IP
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#first_ip IpSpace#first_ip}
    */
    readonly firstIp: string;
    /**
    * Number of prefixes to define
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#prefix_count IpSpace#prefix_count}
    */
    readonly prefixCount: string;
    /**
    * Prefix length
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#prefix_length IpSpace#prefix_length}
    */
    readonly prefixLength: string;
}
export declare function ipSpaceIpPrefixPrefixToTerraform(struct?: IpSpaceIpPrefixPrefix | cdktf.IResolvable): any;
export declare function ipSpaceIpPrefixPrefixToHclTerraform(struct?: IpSpaceIpPrefixPrefix | cdktf.IResolvable): any;
export declare class IpSpaceIpPrefixPrefixOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IpSpaceIpPrefixPrefix | cdktf.IResolvable | undefined;
    set internalValue(value: IpSpaceIpPrefixPrefix | cdktf.IResolvable | undefined);
    private _firstIp?;
    get firstIp(): string;
    set firstIp(value: string);
    get firstIpInput(): string | undefined;
    get id(): string;
    private _prefixCount?;
    get prefixCount(): string;
    set prefixCount(value: string);
    get prefixCountInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): string;
    set prefixLength(value: string);
    get prefixLengthInput(): string | undefined;
}
export declare class IpSpaceIpPrefixPrefixList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IpSpaceIpPrefixPrefix[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IpSpaceIpPrefixPrefixOutputReference;
}
export interface IpSpaceIpPrefix {
    /**
    * Floating IP quota
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#default_quota IpSpace#default_quota}
    */
    readonly defaultQuota?: string;
    /**
    * prefix block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#prefix IpSpace#prefix}
    */
    readonly prefix: IpSpaceIpPrefixPrefix[] | cdktf.IResolvable;
}
export declare function ipSpaceIpPrefixToTerraform(struct?: IpSpaceIpPrefix | cdktf.IResolvable): any;
export declare function ipSpaceIpPrefixToHclTerraform(struct?: IpSpaceIpPrefix | cdktf.IResolvable): any;
export declare class IpSpaceIpPrefixOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IpSpaceIpPrefix | cdktf.IResolvable | undefined;
    set internalValue(value: IpSpaceIpPrefix | cdktf.IResolvable | undefined);
    private _defaultQuota?;
    get defaultQuota(): string;
    set defaultQuota(value: string);
    resetDefaultQuota(): void;
    get defaultQuotaInput(): string | undefined;
    private _prefix;
    get prefix(): IpSpaceIpPrefixPrefixList;
    putPrefix(value: IpSpaceIpPrefixPrefix[] | cdktf.IResolvable): void;
    get prefixInput(): cdktf.IResolvable | IpSpaceIpPrefixPrefix[] | undefined;
}
export declare class IpSpaceIpPrefixList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IpSpaceIpPrefix[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IpSpaceIpPrefixOutputReference;
}
export interface IpSpaceIpRange {
    /**
    * End address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#end_address IpSpace#end_address}
    */
    readonly endAddress: string;
    /**
    * Start address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#start_address IpSpace#start_address}
    */
    readonly startAddress: string;
}
export declare function ipSpaceIpRangeToTerraform(struct?: IpSpaceIpRange | cdktf.IResolvable): any;
export declare function ipSpaceIpRangeToHclTerraform(struct?: IpSpaceIpRange | cdktf.IResolvable): any;
export declare class IpSpaceIpRangeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IpSpaceIpRange | cdktf.IResolvable | undefined;
    set internalValue(value: IpSpaceIpRange | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    get id(): string;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class IpSpaceIpRangeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IpSpaceIpRange[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IpSpaceIpRangeOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space vcd_ip_space}
*/
export declare class IpSpace extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_ip_space";
    /**
    * Generates CDKTF code for importing a IpSpace resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IpSpace to import
    * @param importFromId The id of the existing IpSpace that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IpSpace to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ip_space vcd_ip_space} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IpSpaceConfig
    */
    constructor(scope: Construct, id: string, config: IpSpaceConfig);
    private _defaultFirewallRuleCreationEnabled?;
    get defaultFirewallRuleCreationEnabled(): boolean | cdktf.IResolvable;
    set defaultFirewallRuleCreationEnabled(value: boolean | cdktf.IResolvable);
    resetDefaultFirewallRuleCreationEnabled(): void;
    get defaultFirewallRuleCreationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultNoSnatRuleCreationEnabled?;
    get defaultNoSnatRuleCreationEnabled(): boolean | cdktf.IResolvable;
    set defaultNoSnatRuleCreationEnabled(value: boolean | cdktf.IResolvable);
    resetDefaultNoSnatRuleCreationEnabled(): void;
    get defaultNoSnatRuleCreationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultSnatRuleCreationEnabled?;
    get defaultSnatRuleCreationEnabled(): boolean | cdktf.IResolvable;
    set defaultSnatRuleCreationEnabled(value: boolean | cdktf.IResolvable);
    resetDefaultSnatRuleCreationEnabled(): void;
    get defaultSnatRuleCreationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _externalScope?;
    get externalScope(): string;
    set externalScope(value: string);
    resetExternalScope(): void;
    get externalScopeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _internalScope?;
    get internalScope(): string[];
    set internalScope(value: string[]);
    get internalScopeInput(): string[] | undefined;
    private _ipRangeQuota?;
    get ipRangeQuota(): string;
    set ipRangeQuota(value: string);
    resetIpRangeQuota(): void;
    get ipRangeQuotaInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    resetOrgId(): void;
    get orgIdInput(): string | undefined;
    private _routeAdvertisementEnabled?;
    get routeAdvertisementEnabled(): boolean | cdktf.IResolvable;
    set routeAdvertisementEnabled(value: boolean | cdktf.IResolvable);
    resetRouteAdvertisementEnabled(): void;
    get routeAdvertisementEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _ipPrefix;
    get ipPrefix(): IpSpaceIpPrefixList;
    putIpPrefix(value: IpSpaceIpPrefix[] | cdktf.IResolvable): void;
    resetIpPrefix(): void;
    get ipPrefixInput(): cdktf.IResolvable | IpSpaceIpPrefix[] | undefined;
    private _ipRange;
    get ipRange(): IpSpaceIpRangeList;
    putIpRange(value: IpSpaceIpRange[] | cdktf.IResolvable): void;
    resetIpRange(): void;
    get ipRangeInput(): cdktf.IResolvable | IpSpaceIpRange[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
