import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LbAppProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * The mode by which the cookie should be inserted. One of 'insert', 'prefix', or 'appsession'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#cookie_mode LbAppProfile#cookie_mode}
    */
    readonly cookieMode?: string;
    /**
    * Used to uniquely identify the session the first time a client accesses the site. The load balancer refers to this cookie when connecting subsequent requests in the session, so that they all go to the same virtual server. Only applies for persistence_mechanism 'cookie'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#cookie_name LbAppProfile#cookie_name}
    */
    readonly cookieName?: string;
    /**
    * Edge gateway name in which the LB Application Profile is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#edge_gateway LbAppProfile#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Enable to define the certificate, CAs, or CRLs used to authenticate the load balancer from the server side
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#enable_pool_side_ssl LbAppProfile#enable_pool_side_ssl}
    */
    readonly enablePoolSideSsl?: boolean | cdktf.IResolvable;
    /**
    * Enable SSL authentication to be passed through to the virtual server. Otherwise SSL authentication takes place at the destination address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#enable_ssl_passthrough LbAppProfile#enable_ssl_passthrough}
    */
    readonly enableSslPassthrough?: boolean | cdktf.IResolvable;
    /**
    * Length of time in seconds that persistence stays in effect
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#expiration LbAppProfile#expiration}
    */
    readonly expiration?: number;
    /**
    * The URL to which traffic that arrives at the destination address should be redirected. Only applies for types 'http' and 'https'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#http_redirect_url LbAppProfile#http_redirect_url}
    */
    readonly httpRedirectUrl?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#id LbAppProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Enables 'X-Forwarded-For' header for identifying the originating IP address of a client connecting to a Web server through the load balancer. Only applies for types HTTP and HTTPS
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#insert_x_forwarded_http_header LbAppProfile#insert_x_forwarded_http_header}
    */
    readonly insertXForwardedHttpHeader?: boolean | cdktf.IResolvable;
    /**
    * Unique LB Application Profile name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#name LbAppProfile#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#org LbAppProfile#org}
    */
    readonly org?: string;
    /**
    * Persistence mechanism for the profile. One of 'cookie', 'ssl-sessionid', 'sourceip'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#persistence_mechanism LbAppProfile#persistence_mechanism}
    */
    readonly persistenceMechanism?: string;
    /**
    * Protocol type used to send requests to the server. One of 'tcp', 'udp', 'http' org 'https'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#type LbAppProfile#type}
    */
    readonly type: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#vdc LbAppProfile#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile vcd_lb_app_profile}
*/
export declare class LbAppProfile extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_lb_app_profile";
    /**
    * Generates CDKTF code for importing a LbAppProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LbAppProfile to import
    * @param importFromId The id of the existing LbAppProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LbAppProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_profile vcd_lb_app_profile} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LbAppProfileConfig
    */
    constructor(scope: Construct, id: string, config: LbAppProfileConfig);
    private _cookieMode?;
    get cookieMode(): string;
    set cookieMode(value: string);
    resetCookieMode(): void;
    get cookieModeInput(): string | undefined;
    private _cookieName?;
    get cookieName(): string;
    set cookieName(value: string);
    resetCookieName(): void;
    get cookieNameInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enablePoolSideSsl?;
    get enablePoolSideSsl(): boolean | cdktf.IResolvable;
    set enablePoolSideSsl(value: boolean | cdktf.IResolvable);
    resetEnablePoolSideSsl(): void;
    get enablePoolSideSslInput(): boolean | cdktf.IResolvable | undefined;
    private _enableSslPassthrough?;
    get enableSslPassthrough(): boolean | cdktf.IResolvable;
    set enableSslPassthrough(value: boolean | cdktf.IResolvable);
    resetEnableSslPassthrough(): void;
    get enableSslPassthroughInput(): boolean | cdktf.IResolvable | undefined;
    private _expiration?;
    get expiration(): number;
    set expiration(value: number);
    resetExpiration(): void;
    get expirationInput(): number | undefined;
    private _httpRedirectUrl?;
    get httpRedirectUrl(): string;
    set httpRedirectUrl(value: string);
    resetHttpRedirectUrl(): void;
    get httpRedirectUrlInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _insertXForwardedHttpHeader?;
    get insertXForwardedHttpHeader(): boolean | cdktf.IResolvable;
    set insertXForwardedHttpHeader(value: boolean | cdktf.IResolvable);
    resetInsertXForwardedHttpHeader(): void;
    get insertXForwardedHttpHeaderInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _persistenceMechanism?;
    get persistenceMechanism(): string;
    set persistenceMechanism(value: string);
    resetPersistenceMechanism(): void;
    get persistenceMechanismInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
