import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LbAppRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the LB Application Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#edge_gateway LbAppRule#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#id LbAppRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Unique LB Application Rule name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#name LbAppRule#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#org LbAppRule#org}
    */
    readonly org?: string;
    /**
    * The script for the application rule. Note - you may find HEREDOC useful to pass multiline strings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#script LbAppRule#script}
    */
    readonly script: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#vdc LbAppRule#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule vcd_lb_app_rule}
*/
export declare class LbAppRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_lb_app_rule";
    /**
    * Generates CDKTF code for importing a LbAppRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LbAppRule to import
    * @param importFromId The id of the existing LbAppRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LbAppRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_app_rule vcd_lb_app_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LbAppRuleConfig
    */
    constructor(scope: Construct, id: string, config: LbAppRuleConfig);
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _script?;
    get script(): string;
    set script(value: string);
    get scriptInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
