import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LbServerPoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Balancing method for the service. One of 'ip-hash', 'round-robin', 'uri', 'leastconn', 'url', or 'httpheader'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#algorithm LbServerPool#algorithm}
    */
    readonly algorithm: string;
    /**
    * Additional options for load balancing algorithm for httpheader or url algorithms
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#algorithm_parameters LbServerPool#algorithm_parameters}
    */
    readonly algorithmParameters?: string;
    /**
    * Server pool description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#description LbServerPool#description}
    */
    readonly description?: string;
    /**
    * Edge gateway name in which the LB Server Pool is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#edge_gateway LbServerPool#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Makes client IP addresses visible to the backend servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#enable_transparency LbServerPool#enable_transparency}
    */
    readonly enableTransparency?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#id LbServerPool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Load Balancer Service Monitor ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#monitor_id LbServerPool#monitor_id}
    */
    readonly monitorId?: string;
    /**
    * Unique LB Server Pool name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#name LbServerPool#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#org LbServerPool#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#vdc LbServerPool#vdc}
    */
    readonly vdc?: string;
    /**
    * member block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#member LbServerPool#member}
    */
    readonly member?: LbServerPoolMember[] | cdktf.IResolvable;
}
export interface LbServerPoolMember {
    /**
    * Defines member state. One of enabled, drain, disabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#condition LbServerPool#condition}
    */
    readonly condition: string;
    /**
    * IP address of member in server pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#ip_address LbServerPool#ip_address}
    */
    readonly ipAddress: string;
    /**
    * The maximum number of concurrent connections the member can handle. If exceeded requests are queued and the load balancer waits for a connection to be released
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#max_connections LbServerPool#max_connections}
    */
    readonly maxConnections?: number;
    /**
    * Minimum number of concurrent connections a member must always accept
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#min_connections LbServerPool#min_connections}
    */
    readonly minConnections?: number;
    /**
    * Port at which the member is to receive health monitor requests. Can be the same as port
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#monitor_port LbServerPool#monitor_port}
    */
    readonly monitorPort: number;
    /**
    * Name of pool member
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#name LbServerPool#name}
    */
    readonly name: string;
    /**
    * Port at which the member is to receive traffic from the load balancer
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#port LbServerPool#port}
    */
    readonly port: number;
    /**
    * Proportion of traffic this member is to handle. Must be an integer in the range 1-256
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#weight LbServerPool#weight}
    */
    readonly weight: number;
}
export declare function lbServerPoolMemberToTerraform(struct?: LbServerPoolMember | cdktf.IResolvable): any;
export declare function lbServerPoolMemberToHclTerraform(struct?: LbServerPoolMember | cdktf.IResolvable): any;
export declare class LbServerPoolMemberOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LbServerPoolMember | cdktf.IResolvable | undefined;
    set internalValue(value: LbServerPoolMember | cdktf.IResolvable | undefined);
    private _condition?;
    get condition(): string;
    set condition(value: string);
    get conditionInput(): string | undefined;
    get id(): string;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    private _maxConnections?;
    get maxConnections(): number;
    set maxConnections(value: number);
    resetMaxConnections(): void;
    get maxConnectionsInput(): number | undefined;
    private _minConnections?;
    get minConnections(): number;
    set minConnections(value: number);
    resetMinConnections(): void;
    get minConnectionsInput(): number | undefined;
    private _monitorPort?;
    get monitorPort(): number;
    set monitorPort(value: number);
    get monitorPortInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    get weightInput(): number | undefined;
}
export declare class LbServerPoolMemberList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LbServerPoolMember[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LbServerPoolMemberOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool vcd_lb_server_pool}
*/
export declare class LbServerPool extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_lb_server_pool";
    /**
    * Generates CDKTF code for importing a LbServerPool resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LbServerPool to import
    * @param importFromId The id of the existing LbServerPool that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LbServerPool to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_server_pool vcd_lb_server_pool} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LbServerPoolConfig
    */
    constructor(scope: Construct, id: string, config: LbServerPoolConfig);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    get algorithmInput(): string | undefined;
    private _algorithmParameters?;
    get algorithmParameters(): string;
    set algorithmParameters(value: string);
    resetAlgorithmParameters(): void;
    get algorithmParametersInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enableTransparency?;
    get enableTransparency(): boolean | cdktf.IResolvable;
    set enableTransparency(value: boolean | cdktf.IResolvable);
    resetEnableTransparency(): void;
    get enableTransparencyInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _monitorId?;
    get monitorId(): string;
    set monitorId(value: string);
    resetMonitorId(): void;
    get monitorIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _member;
    get member(): LbServerPoolMemberList;
    putMember(value: LbServerPoolMember[] | cdktf.IResolvable): void;
    resetMember(): void;
    get memberInput(): cdktf.IResolvable | LbServerPoolMember[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
