import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LbServiceMonitorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway name in which the LB Service Monitor is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#edge_gateway LbServiceMonitor#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * String that the monitor expects to match in the status line of the http or https response (for example, HTTP/1.1)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#expected LbServiceMonitor#expected}
    */
    readonly expected?: string;
    /**
    * Advanced monitor parameters as key=value pairs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#extension LbServiceMonitor#extension}
    */
    readonly extension?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#id LbServiceMonitor#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Interval in seconds at which a server is to be monitored (defaults to 10)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#interval LbServiceMonitor#interval}
    */
    readonly interval?: number;
    /**
    * Number of times the specified monitoring Method must fail sequentially before the server is declared down  (defaults to 3)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#max_retries LbServiceMonitor#max_retries}
    */
    readonly maxRetries?: number;
    /**
    * Method to be used to detect server status. One of OPTIONS, GET, HEAD, POST, PUT, DELETE, TRACE, or CONNECT
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#method LbServiceMonitor#method}
    */
    readonly method?: string;
    /**
    * Unique LB Service Monitor name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#name LbServiceMonitor#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#org LbServiceMonitor#org}
    */
    readonly org?: string;
    /**
    * String to be matched in the response content
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#receive LbServiceMonitor#receive}
    */
    readonly receive?: string;
    /**
    * Data to be sent
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#send LbServiceMonitor#send}
    */
    readonly send?: string;
    /**
    * Maximum time in seconds within which a response from the server must be received  (defaults to 15)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#timeout LbServiceMonitor#timeout}
    */
    readonly timeout?: number;
    /**
    * Way in which you want to send the health check request to the server. One of http, https, tcp, icmp, or udp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#type LbServiceMonitor#type}
    */
    readonly type: string;
    /**
    * URL to be used in the server status request
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#url LbServiceMonitor#url}
    */
    readonly url?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#vdc LbServiceMonitor#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor vcd_lb_service_monitor}
*/
export declare class LbServiceMonitor extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_lb_service_monitor";
    /**
    * Generates CDKTF code for importing a LbServiceMonitor resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LbServiceMonitor to import
    * @param importFromId The id of the existing LbServiceMonitor that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LbServiceMonitor to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_service_monitor vcd_lb_service_monitor} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LbServiceMonitorConfig
    */
    constructor(scope: Construct, id: string, config: LbServiceMonitorConfig);
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _expected?;
    get expected(): string;
    set expected(value: string);
    resetExpected(): void;
    get expectedInput(): string | undefined;
    private _extension?;
    get extension(): {
        [key: string]: string;
    };
    set extension(value: {
        [key: string]: string;
    });
    resetExtension(): void;
    get extensionInput(): {
        [key: string]: string;
    } | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interval?;
    get interval(): number;
    set interval(value: number);
    resetInterval(): void;
    get intervalInput(): number | undefined;
    private _maxRetries?;
    get maxRetries(): number;
    set maxRetries(value: number);
    resetMaxRetries(): void;
    get maxRetriesInput(): number | undefined;
    private _method?;
    get method(): string;
    set method(value: string);
    resetMethod(): void;
    get methodInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _receive?;
    get receive(): string;
    set receive(value: string);
    resetReceive(): void;
    get receiveInput(): string | undefined;
    private _send?;
    get send(): string;
    set send(value: string);
    resetSend(): void;
    get sendInput(): string | undefined;
    private _timeout?;
    get timeout(): number;
    set timeout(value: number);
    resetTimeout(): void;
    get timeoutInput(): number | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    resetUrl(): void;
    get urlInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
