import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LbVirtualServerConfig extends cdktf.TerraformMetaArguments {
    /**
    * Application profile ID to be associated with the virtual server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#app_profile_id LbVirtualServer#app_profile_id}
    */
    readonly appProfileId?: string;
    /**
    * List of attached application rule IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#app_rule_ids LbVirtualServer#app_rule_ids}
    */
    readonly appRuleIds?: string[];
    /**
    * Maximum concurrent connections that the virtual server can process
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#connection_limit LbVirtualServer#connection_limit}
    */
    readonly connectionLimit?: number;
    /**
    * Maximum incoming new connection requests per second
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#connection_rate_limit LbVirtualServer#connection_rate_limit}
    */
    readonly connectionRateLimit?: number;
    /**
    * Virtual Server description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#description LbVirtualServer#description}
    */
    readonly description?: string;
    /**
    * Edge gateway name in which the LB Virtual Server is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#edge_gateway LbVirtualServer#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Enable virtual server acceleration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#enable_acceleration LbVirtualServer#enable_acceleration}
    */
    readonly enableAcceleration?: boolean | cdktf.IResolvable;
    /**
    * Defines if the virtual server is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#enabled LbVirtualServer#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#id LbVirtualServer#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP address that the load balancer listens on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#ip_address LbVirtualServer#ip_address}
    */
    readonly ipAddress: string;
    /**
    * Unique Virtual Server name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#name LbVirtualServer#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#org LbVirtualServer#org}
    */
    readonly org?: string;
    /**
    * Port number that the load balancer listens on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#port LbVirtualServer#port}
    */
    readonly port: number;
    /**
    * Protocol that the virtual server accepts
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#protocol LbVirtualServer#protocol}
    */
    readonly protocol: string;
    /**
    * The server pool that the load balancer will use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#server_pool_id LbVirtualServer#server_pool_id}
    */
    readonly serverPoolId?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#vdc LbVirtualServer#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server vcd_lb_virtual_server}
*/
export declare class LbVirtualServer extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_lb_virtual_server";
    /**
    * Generates CDKTF code for importing a LbVirtualServer resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LbVirtualServer to import
    * @param importFromId The id of the existing LbVirtualServer that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LbVirtualServer to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/lb_virtual_server vcd_lb_virtual_server} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LbVirtualServerConfig
    */
    constructor(scope: Construct, id: string, config: LbVirtualServerConfig);
    private _appProfileId?;
    get appProfileId(): string;
    set appProfileId(value: string);
    resetAppProfileId(): void;
    get appProfileIdInput(): string | undefined;
    private _appRuleIds?;
    get appRuleIds(): string[];
    set appRuleIds(value: string[]);
    resetAppRuleIds(): void;
    get appRuleIdsInput(): string[] | undefined;
    private _connectionLimit?;
    get connectionLimit(): number;
    set connectionLimit(value: number);
    resetConnectionLimit(): void;
    get connectionLimitInput(): number | undefined;
    private _connectionRateLimit?;
    get connectionRateLimit(): number;
    set connectionRateLimit(value: number);
    resetConnectionRateLimit(): void;
    get connectionRateLimitInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enableAcceleration?;
    get enableAcceleration(): boolean | cdktf.IResolvable;
    set enableAcceleration(value: boolean | cdktf.IResolvable);
    resetEnableAcceleration(): void;
    get enableAccelerationInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _serverPoolId?;
    get serverPoolId(): string;
    set serverPoolId(value: string);
    resetServerPoolId(): void;
    get serverPoolIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
