import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LibraryCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
    * Alias of certificate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#alias LibraryCertificate#alias}
    */
    readonly alias: string;
    /**
    * Certificate content
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#certificate LibraryCertificate#certificate}
    */
    readonly certificate: string;
    /**
    * Certificate description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#description LibraryCertificate#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#id LibraryCertificate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#org LibraryCertificate#org}
    */
    readonly org?: string;
    /**
    * Certificate private key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#private_key LibraryCertificate#private_key}
    */
    readonly privateKey?: string;
    /**
    * Certificate private pass phrase
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#private_key_passphrase LibraryCertificate#private_key_passphrase}
    */
    readonly privateKeyPassphrase?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate vcd_library_certificate}
*/
export declare class LibraryCertificate extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_library_certificate";
    /**
    * Generates CDKTF code for importing a LibraryCertificate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the LibraryCertificate to import
    * @param importFromId The id of the existing LibraryCertificate that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the LibraryCertificate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/library_certificate vcd_library_certificate} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LibraryCertificateConfig
    */
    constructor(scope: Construct, id: string, config: LibraryCertificateConfig);
    private _alias?;
    get alias(): string;
    set alias(value: string);
    get aliasInput(): string | undefined;
    private _certificate?;
    get certificate(): string;
    set certificate(value: string);
    get certificateInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _privateKey?;
    get privateKey(): string;
    set privateKey(value: string);
    resetPrivateKey(): void;
    get privateKeyInput(): string | undefined;
    private _privateKeyPassphrase?;
    get privateKeyPassphrase(): string;
    set privateKeyPassphrase(value: string);
    resetPrivateKeyPassphrase(): void;
    get privateKeyPassphraseInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
