import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkIsolatedConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional description for the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#description NetworkIsolated#description}
    */
    readonly description?: string;
    /**
    * First DNS server to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#dns1 NetworkIsolated#dns1}
    */
    readonly dns1?: string;
    /**
    * Second DNS server to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#dns2 NetworkIsolated#dns2}
    */
    readonly dns2?: string;
    /**
    * A FQDN for the virtual machines on this network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#dns_suffix NetworkIsolated#dns_suffix}
    */
    readonly dnsSuffix?: string;
    /**
    * The gateway for this network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#gateway NetworkIsolated#gateway}
    */
    readonly gateway?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#id NetworkIsolated#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key value map of metadata to assign to this network. Key and value can be any string
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#metadata NetworkIsolated#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * A unique name for this network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#name NetworkIsolated#name}
    */
    readonly name: string;
    /**
    * The netmask for the new network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#netmask NetworkIsolated#netmask}
    */
    readonly netmask?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#org NetworkIsolated#org}
    */
    readonly org?: string;
    /**
    * Defines if this network is shared between multiple VDCs in the Org
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#shared NetworkIsolated#shared}
    */
    readonly shared?: boolean | cdktf.IResolvable;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#vdc NetworkIsolated#vdc}
    */
    readonly vdc?: string;
    /**
    * dhcp_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#dhcp_pool NetworkIsolated#dhcp_pool}
    */
    readonly dhcpPool?: NetworkIsolatedDhcpPool[] | cdktf.IResolvable;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#metadata_entry NetworkIsolated#metadata_entry}
    */
    readonly metadataEntry?: NetworkIsolatedMetadataEntry[] | cdktf.IResolvable;
    /**
    * static_ip_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#static_ip_pool NetworkIsolated#static_ip_pool}
    */
    readonly staticIpPool?: NetworkIsolatedStaticIpPool[] | cdktf.IResolvable;
}
export interface NetworkIsolatedDhcpPool {
    /**
    * The default DHCP lease time to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#default_lease_time NetworkIsolated#default_lease_time}
    */
    readonly defaultLeaseTime?: number;
    /**
    * The final address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#end_address NetworkIsolated#end_address}
    */
    readonly endAddress: string;
    /**
    * The maximum DHCP lease time to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#max_lease_time NetworkIsolated#max_lease_time}
    */
    readonly maxLeaseTime?: number;
    /**
    * The first address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#start_address NetworkIsolated#start_address}
    */
    readonly startAddress: string;
}
export declare function networkIsolatedDhcpPoolToTerraform(struct?: NetworkIsolatedDhcpPool | cdktf.IResolvable): any;
export declare function networkIsolatedDhcpPoolToHclTerraform(struct?: NetworkIsolatedDhcpPool | cdktf.IResolvable): any;
export declare class NetworkIsolatedDhcpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkIsolatedDhcpPool | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkIsolatedDhcpPool | cdktf.IResolvable | undefined);
    private _defaultLeaseTime?;
    get defaultLeaseTime(): number;
    set defaultLeaseTime(value: number);
    resetDefaultLeaseTime(): void;
    get defaultLeaseTimeInput(): number | undefined;
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _maxLeaseTime?;
    get maxLeaseTime(): number;
    set maxLeaseTime(value: number);
    resetMaxLeaseTime(): void;
    get maxLeaseTimeInput(): number | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NetworkIsolatedDhcpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkIsolatedDhcpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkIsolatedDhcpPoolOutputReference;
}
export interface NetworkIsolatedMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#is_system NetworkIsolated#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#key NetworkIsolated#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#type NetworkIsolated#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#user_access NetworkIsolated#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#value NetworkIsolated#value}
    */
    readonly value?: string;
}
export declare function networkIsolatedMetadataEntryToTerraform(struct?: NetworkIsolatedMetadataEntry | cdktf.IResolvable): any;
export declare function networkIsolatedMetadataEntryToHclTerraform(struct?: NetworkIsolatedMetadataEntry | cdktf.IResolvable): any;
export declare class NetworkIsolatedMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkIsolatedMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkIsolatedMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class NetworkIsolatedMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkIsolatedMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkIsolatedMetadataEntryOutputReference;
}
export interface NetworkIsolatedStaticIpPool {
    /**
    * The final address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#end_address NetworkIsolated#end_address}
    */
    readonly endAddress: string;
    /**
    * The first address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#start_address NetworkIsolated#start_address}
    */
    readonly startAddress: string;
}
export declare function networkIsolatedStaticIpPoolToTerraform(struct?: NetworkIsolatedStaticIpPool | cdktf.IResolvable): any;
export declare function networkIsolatedStaticIpPoolToHclTerraform(struct?: NetworkIsolatedStaticIpPool | cdktf.IResolvable): any;
export declare class NetworkIsolatedStaticIpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkIsolatedStaticIpPool | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkIsolatedStaticIpPool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NetworkIsolatedStaticIpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkIsolatedStaticIpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkIsolatedStaticIpPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated vcd_network_isolated}
*/
export declare class NetworkIsolated extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_network_isolated";
    /**
    * Generates CDKTF code for importing a NetworkIsolated resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkIsolated to import
    * @param importFromId The id of the existing NetworkIsolated that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkIsolated to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_isolated vcd_network_isolated} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkIsolatedConfig
    */
    constructor(scope: Construct, id: string, config: NetworkIsolatedConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dns1?;
    get dns1(): string;
    set dns1(value: string);
    resetDns1(): void;
    get dns1Input(): string | undefined;
    private _dns2?;
    get dns2(): string;
    set dns2(value: string);
    resetDns2(): void;
    get dns2Input(): string | undefined;
    private _dnsSuffix?;
    get dnsSuffix(): string;
    set dnsSuffix(value: string);
    resetDnsSuffix(): void;
    get dnsSuffixInput(): string | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    resetGateway(): void;
    get gatewayInput(): string | undefined;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    resetNetmask(): void;
    get netmaskInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _shared?;
    get shared(): boolean | cdktf.IResolvable;
    set shared(value: boolean | cdktf.IResolvable);
    resetShared(): void;
    get sharedInput(): boolean | cdktf.IResolvable | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _dhcpPool;
    get dhcpPool(): NetworkIsolatedDhcpPoolList;
    putDhcpPool(value: NetworkIsolatedDhcpPool[] | cdktf.IResolvable): void;
    resetDhcpPool(): void;
    get dhcpPoolInput(): cdktf.IResolvable | NetworkIsolatedDhcpPool[] | undefined;
    private _metadataEntry;
    get metadataEntry(): NetworkIsolatedMetadataEntryList;
    putMetadataEntry(value: NetworkIsolatedMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | NetworkIsolatedMetadataEntry[] | undefined;
    private _staticIpPool;
    get staticIpPool(): NetworkIsolatedStaticIpPoolList;
    putStaticIpPool(value: NetworkIsolatedStaticIpPool[] | cdktf.IResolvable): void;
    resetStaticIpPool(): void;
    get staticIpPoolInput(): cdktf.IResolvable | NetworkIsolatedStaticIpPool[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
