import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkPoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Defines how backing components are accepted
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#backing_selection_constraint NetworkPool#backing_selection_constraint}
    */
    readonly backingSelectionConstraint?: string;
    /**
    * Description of the network pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#description NetworkPool#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#id NetworkPool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of network pool.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#name NetworkPool#name}
    */
    readonly name: string;
    /**
    * Id of the network provider (either vCenter or NSX-T manager)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#network_provider_id NetworkPool#network_provider_id}
    */
    readonly networkProviderId: string;
    /**
    * Type of the network pool (one of `GENEVE`, `VLAN`, `PORTGROUP_BACKED`)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#type NetworkPool#type}
    */
    readonly type: string;
    /**
    * backing block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#backing NetworkPool#backing}
    */
    readonly backing?: NetworkPoolBacking;
}
export interface NetworkPoolBackingDistributedSwitch {
    /**
    * Backing name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#name NetworkPool#name}
    */
    readonly name?: string;
}
export declare function networkPoolBackingDistributedSwitchToTerraform(struct?: NetworkPoolBackingDistributedSwitchOutputReference | NetworkPoolBackingDistributedSwitch): any;
export declare function networkPoolBackingDistributedSwitchToHclTerraform(struct?: NetworkPoolBackingDistributedSwitchOutputReference | NetworkPoolBackingDistributedSwitch): any;
export declare class NetworkPoolBackingDistributedSwitchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkPoolBackingDistributedSwitch | undefined;
    set internalValue(value: NetworkPoolBackingDistributedSwitch | undefined);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get type(): string;
}
export interface NetworkPoolBackingPortGroup {
    /**
    * Backing name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#name NetworkPool#name}
    */
    readonly name?: string;
}
export declare function networkPoolBackingPortGroupToTerraform(struct?: NetworkPoolBackingPortGroup | cdktf.IResolvable): any;
export declare function networkPoolBackingPortGroupToHclTerraform(struct?: NetworkPoolBackingPortGroup | cdktf.IResolvable): any;
export declare class NetworkPoolBackingPortGroupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkPoolBackingPortGroup | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkPoolBackingPortGroup | cdktf.IResolvable | undefined);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get type(): string;
}
export declare class NetworkPoolBackingPortGroupList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkPoolBackingPortGroup[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkPoolBackingPortGroupOutputReference;
}
export interface NetworkPoolBackingRangeId {
    /**
    * End of the IDs range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#end_id NetworkPool#end_id}
    */
    readonly endId: number;
    /**
    * Start of the IDs range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#start_id NetworkPool#start_id}
    */
    readonly startId: number;
}
export declare function networkPoolBackingRangeIdToTerraform(struct?: NetworkPoolBackingRangeId | cdktf.IResolvable): any;
export declare function networkPoolBackingRangeIdToHclTerraform(struct?: NetworkPoolBackingRangeId | cdktf.IResolvable): any;
export declare class NetworkPoolBackingRangeIdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkPoolBackingRangeId | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkPoolBackingRangeId | cdktf.IResolvable | undefined);
    private _endId?;
    get endId(): number;
    set endId(value: number);
    get endIdInput(): number | undefined;
    private _startId?;
    get startId(): number;
    set startId(value: number);
    get startIdInput(): number | undefined;
}
export declare class NetworkPoolBackingRangeIdList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkPoolBackingRangeId[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkPoolBackingRangeIdOutputReference;
}
export interface NetworkPoolBackingTransportZone {
    /**
    * Backing name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#name NetworkPool#name}
    */
    readonly name?: string;
}
export declare function networkPoolBackingTransportZoneToTerraform(struct?: NetworkPoolBackingTransportZoneOutputReference | NetworkPoolBackingTransportZone): any;
export declare function networkPoolBackingTransportZoneToHclTerraform(struct?: NetworkPoolBackingTransportZoneOutputReference | NetworkPoolBackingTransportZone): any;
export declare class NetworkPoolBackingTransportZoneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkPoolBackingTransportZone | undefined;
    set internalValue(value: NetworkPoolBackingTransportZone | undefined);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get type(): string;
}
export interface NetworkPoolBacking {
    /**
    * distributed_switch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#distributed_switch NetworkPool#distributed_switch}
    */
    readonly distributedSwitch?: NetworkPoolBackingDistributedSwitch;
    /**
    * port_group block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#port_group NetworkPool#port_group}
    */
    readonly portGroup?: NetworkPoolBackingPortGroup[] | cdktf.IResolvable;
    /**
    * range_id block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#range_id NetworkPool#range_id}
    */
    readonly rangeId?: NetworkPoolBackingRangeId[] | cdktf.IResolvable;
    /**
    * transport_zone block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#transport_zone NetworkPool#transport_zone}
    */
    readonly transportZone?: NetworkPoolBackingTransportZone;
}
export declare function networkPoolBackingToTerraform(struct?: NetworkPoolBackingOutputReference | NetworkPoolBacking): any;
export declare function networkPoolBackingToHclTerraform(struct?: NetworkPoolBackingOutputReference | NetworkPoolBacking): any;
export declare class NetworkPoolBackingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkPoolBacking | undefined;
    set internalValue(value: NetworkPoolBacking | undefined);
    private _distributedSwitch;
    get distributedSwitch(): NetworkPoolBackingDistributedSwitchOutputReference;
    putDistributedSwitch(value: NetworkPoolBackingDistributedSwitch): void;
    resetDistributedSwitch(): void;
    get distributedSwitchInput(): NetworkPoolBackingDistributedSwitch | undefined;
    private _portGroup;
    get portGroup(): NetworkPoolBackingPortGroupList;
    putPortGroup(value: NetworkPoolBackingPortGroup[] | cdktf.IResolvable): void;
    resetPortGroup(): void;
    get portGroupInput(): cdktf.IResolvable | NetworkPoolBackingPortGroup[] | undefined;
    private _rangeId;
    get rangeId(): NetworkPoolBackingRangeIdList;
    putRangeId(value: NetworkPoolBackingRangeId[] | cdktf.IResolvable): void;
    resetRangeId(): void;
    get rangeIdInput(): cdktf.IResolvable | NetworkPoolBackingRangeId[] | undefined;
    private _transportZone;
    get transportZone(): NetworkPoolBackingTransportZoneOutputReference;
    putTransportZone(value: NetworkPoolBackingTransportZone): void;
    resetTransportZone(): void;
    get transportZoneInput(): NetworkPoolBackingTransportZone | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool vcd_network_pool}
*/
export declare class NetworkPool extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_network_pool";
    /**
    * Generates CDKTF code for importing a NetworkPool resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkPool to import
    * @param importFromId The id of the existing NetworkPool that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkPool to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_pool vcd_network_pool} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkPoolConfig
    */
    constructor(scope: Construct, id: string, config: NetworkPoolConfig);
    private _backingSelectionConstraint?;
    get backingSelectionConstraint(): string;
    set backingSelectionConstraint(value: string);
    resetBackingSelectionConstraint(): void;
    get backingSelectionConstraintInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkProviderId?;
    get networkProviderId(): string;
    set networkProviderId(value: string);
    get networkProviderIdInput(): string | undefined;
    get networkProviderName(): string;
    get networkProviderType(): string;
    get promiscuousMode(): cdktf.IResolvable;
    get status(): string;
    get totalBackingsCount(): number;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    get usedBackingsCount(): number;
    private _backing;
    get backing(): NetworkPoolBackingOutputReference;
    putBacking(value: NetworkPoolBacking): void;
    resetBacking(): void;
    get backingInput(): NetworkPoolBacking | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
