import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkRoutedConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional description for the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#description NetworkRouted#description}
    */
    readonly description?: string;
    /**
    * First DNS server to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#dns1 NetworkRouted#dns1}
    */
    readonly dns1?: string;
    /**
    * Second DNS server to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#dns2 NetworkRouted#dns2}
    */
    readonly dns2?: string;
    /**
    * A FQDN for the virtual machines on this network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#dns_suffix NetworkRouted#dns_suffix}
    */
    readonly dnsSuffix?: string;
    /**
    * The name of the edge gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#edge_gateway NetworkRouted#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * The gateway of this network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#gateway NetworkRouted#gateway}
    */
    readonly gateway?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#id NetworkRouted#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Which interface to use (one of `internal`, `subinterface`, `distributed`)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#interface_type NetworkRouted#interface_type}
    */
    readonly interfaceType?: string;
    /**
    * Key value map of metadata to assign to this network. Key and value can be any string
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#metadata NetworkRouted#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * A unique name for the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#name NetworkRouted#name}
    */
    readonly name: string;
    /**
    * The netmask for the new network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#netmask NetworkRouted#netmask}
    */
    readonly netmask?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#org NetworkRouted#org}
    */
    readonly org?: string;
    /**
    * Defines if this network is shared between multiple VDCs in the Org
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#shared NetworkRouted#shared}
    */
    readonly shared?: boolean | cdktf.IResolvable;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#vdc NetworkRouted#vdc}
    */
    readonly vdc?: string;
    /**
    * dhcp_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#dhcp_pool NetworkRouted#dhcp_pool}
    */
    readonly dhcpPool?: NetworkRoutedDhcpPool[] | cdktf.IResolvable;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#metadata_entry NetworkRouted#metadata_entry}
    */
    readonly metadataEntry?: NetworkRoutedMetadataEntry[] | cdktf.IResolvable;
    /**
    * static_ip_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#static_ip_pool NetworkRouted#static_ip_pool}
    */
    readonly staticIpPool?: NetworkRoutedStaticIpPool[] | cdktf.IResolvable;
}
export interface NetworkRoutedDhcpPool {
    /**
    * The final address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#end_address NetworkRouted#end_address}
    */
    readonly endAddress: string;
    /**
    * The maximum DHCP lease time to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#max_lease_time NetworkRouted#max_lease_time}
    */
    readonly maxLeaseTime?: number;
    /**
    * The first address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#start_address NetworkRouted#start_address}
    */
    readonly startAddress: string;
}
export declare function networkRoutedDhcpPoolToTerraform(struct?: NetworkRoutedDhcpPool | cdktf.IResolvable): any;
export declare function networkRoutedDhcpPoolToHclTerraform(struct?: NetworkRoutedDhcpPool | cdktf.IResolvable): any;
export declare class NetworkRoutedDhcpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkRoutedDhcpPool | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkRoutedDhcpPool | cdktf.IResolvable | undefined);
    get defaultLeaseTime(): number;
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _maxLeaseTime?;
    get maxLeaseTime(): number;
    set maxLeaseTime(value: number);
    resetMaxLeaseTime(): void;
    get maxLeaseTimeInput(): number | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NetworkRoutedDhcpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkRoutedDhcpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkRoutedDhcpPoolOutputReference;
}
export interface NetworkRoutedMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#is_system NetworkRouted#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#key NetworkRouted#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#type NetworkRouted#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#user_access NetworkRouted#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#value NetworkRouted#value}
    */
    readonly value?: string;
}
export declare function networkRoutedMetadataEntryToTerraform(struct?: NetworkRoutedMetadataEntry | cdktf.IResolvable): any;
export declare function networkRoutedMetadataEntryToHclTerraform(struct?: NetworkRoutedMetadataEntry | cdktf.IResolvable): any;
export declare class NetworkRoutedMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkRoutedMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkRoutedMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class NetworkRoutedMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkRoutedMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkRoutedMetadataEntryOutputReference;
}
export interface NetworkRoutedStaticIpPool {
    /**
    * The final address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#end_address NetworkRouted#end_address}
    */
    readonly endAddress: string;
    /**
    * The first address in the IP Range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#start_address NetworkRouted#start_address}
    */
    readonly startAddress: string;
}
export declare function networkRoutedStaticIpPoolToTerraform(struct?: NetworkRoutedStaticIpPool | cdktf.IResolvable): any;
export declare function networkRoutedStaticIpPoolToHclTerraform(struct?: NetworkRoutedStaticIpPool | cdktf.IResolvable): any;
export declare class NetworkRoutedStaticIpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkRoutedStaticIpPool | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkRoutedStaticIpPool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NetworkRoutedStaticIpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkRoutedStaticIpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkRoutedStaticIpPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed vcd_network_routed}
*/
export declare class NetworkRouted extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_network_routed";
    /**
    * Generates CDKTF code for importing a NetworkRouted resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkRouted to import
    * @param importFromId The id of the existing NetworkRouted that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkRouted to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/network_routed vcd_network_routed} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkRoutedConfig
    */
    constructor(scope: Construct, id: string, config: NetworkRoutedConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dns1?;
    get dns1(): string;
    set dns1(value: string);
    resetDns1(): void;
    get dns1Input(): string | undefined;
    private _dns2?;
    get dns2(): string;
    set dns2(value: string);
    resetDns2(): void;
    get dns2Input(): string | undefined;
    private _dnsSuffix?;
    get dnsSuffix(): string;
    set dnsSuffix(value: string);
    resetDnsSuffix(): void;
    get dnsSuffixInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    resetGateway(): void;
    get gatewayInput(): string | undefined;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interfaceType?;
    get interfaceType(): string;
    set interfaceType(value: string);
    resetInterfaceType(): void;
    get interfaceTypeInput(): string | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    resetNetmask(): void;
    get netmaskInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _shared?;
    get shared(): boolean | cdktf.IResolvable;
    set shared(value: boolean | cdktf.IResolvable);
    resetShared(): void;
    get sharedInput(): boolean | cdktf.IResolvable | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _dhcpPool;
    get dhcpPool(): NetworkRoutedDhcpPoolList;
    putDhcpPool(value: NetworkRoutedDhcpPool[] | cdktf.IResolvable): void;
    resetDhcpPool(): void;
    get dhcpPoolInput(): cdktf.IResolvable | NetworkRoutedDhcpPool[] | undefined;
    private _metadataEntry;
    get metadataEntry(): NetworkRoutedMetadataEntryList;
    putMetadataEntry(value: NetworkRoutedMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | NetworkRoutedMetadataEntry[] | undefined;
    private _staticIpPool;
    get staticIpPool(): NetworkRoutedStaticIpPoolList;
    putStaticIpPool(value: NetworkRoutedStaticIpPool[] | cdktf.IResolvable): void;
    resetStaticIpPool(): void;
    get staticIpPoolInput(): cdktf.IResolvable | NetworkRoutedStaticIpPool[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
