import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtAlbPoolConfig extends cdktf.TerraformMetaArguments {
    /**
    * Algorithm for choosing pool members (default LEAST_CONNECTIONS). Other `ROUND_ROBIN`,`CONSISTENT_HASH`, `FASTEST_RESPONSE`, `LEAST_LOAD`, `FEWEST_SERVERS`, `RANDOM`, `FEWEST_TASKS`,`CORE_AFFINITY`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#algorithm NsxtAlbPool#algorithm}
    */
    readonly algorithm?: string;
    /**
    * A set of root certificate IDs to use when validating certificates presented by pool members
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#ca_certificate_ids NsxtAlbPool#ca_certificate_ids}
    */
    readonly caCertificateIds?: string[];
    /**
    * Boolean flag if common name check of the certificate should be enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#cn_check_enabled NsxtAlbPool#cn_check_enabled}
    */
    readonly cnCheckEnabled?: boolean | cdktf.IResolvable;
    /**
    * Default Port defines destination server port used by the traffic sent to the member (default 80)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#default_port NsxtAlbPool#default_port}
    */
    readonly defaultPort?: number;
    /**
    * Description of ALB Pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#description NsxtAlbPool#description}
    */
    readonly description?: string;
    /**
    * List of domain names which will be used to verify common names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#domain_names NsxtAlbPool#domain_names}
    */
    readonly domainNames?: string[];
    /**
    * Edge gateway ID in which ALB Pool should be created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#edge_gateway_id NsxtAlbPool#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Boolean value if ALB Pool is enabled or not (default true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#enabled NsxtAlbPool#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Maximum time in minutes to gracefully disable pool member (default 1)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#graceful_timeout_period NsxtAlbPool#graceful_timeout_period}
    */
    readonly gracefulTimeoutPeriod?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#id NsxtAlbPool#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * ID of Firewall Group to use for Pool Membership (VCD 10.4.1+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#member_group_id NsxtAlbPool#member_group_id}
    */
    readonly memberGroupId?: string;
    /**
    * Name of ALB Pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#name NsxtAlbPool#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#org NsxtAlbPool#org}
    */
    readonly org?: string;
    /**
    * Monitors if the traffic is accepted by node (default true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#passive_monitoring_enabled NsxtAlbPool#passive_monitoring_enabled}
    */
    readonly passiveMonitoringEnabled?: boolean | cdktf.IResolvable;
    /**
    * Enables SSL - Must be on when CA certificates are used
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#ssl_enabled NsxtAlbPool#ssl_enabled}
    */
    readonly sslEnabled?: boolean | cdktf.IResolvable;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#vdc NsxtAlbPool#vdc}
    */
    readonly vdc?: string;
    /**
    * health_monitor block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#health_monitor NsxtAlbPool#health_monitor}
    */
    readonly healthMonitor?: NsxtAlbPoolHealthMonitor[] | cdktf.IResolvable;
    /**
    * member block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#member NsxtAlbPool#member}
    */
    readonly member?: NsxtAlbPoolMember[] | cdktf.IResolvable;
    /**
    * persistence_profile block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#persistence_profile NsxtAlbPool#persistence_profile}
    */
    readonly persistenceProfile?: NsxtAlbPoolPersistenceProfile;
}
export interface NsxtAlbPoolHealthMonitor {
    /**
    * Type of health monitor. One of `HTTP`, `HTTPS`, `TCP`, `UDP`, `PING`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#type NsxtAlbPool#type}
    */
    readonly type: string;
}
export declare function nsxtAlbPoolHealthMonitorToTerraform(struct?: NsxtAlbPoolHealthMonitor | cdktf.IResolvable): any;
export declare function nsxtAlbPoolHealthMonitorToHclTerraform(struct?: NsxtAlbPoolHealthMonitor | cdktf.IResolvable): any;
export declare class NsxtAlbPoolHealthMonitorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtAlbPoolHealthMonitor | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtAlbPoolHealthMonitor | cdktf.IResolvable | undefined);
    get name(): string;
    get systemDefined(): cdktf.IResolvable;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export declare class NsxtAlbPoolHealthMonitorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtAlbPoolHealthMonitor[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtAlbPoolHealthMonitorOutputReference;
}
export interface NsxtAlbPoolMember {
    /**
    * Defines if pool member is accepts traffic (default 'true')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#enabled NsxtAlbPool#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * IP address of pool member
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#ip_address NsxtAlbPool#ip_address}
    */
    readonly ipAddress: string;
    /**
    * Member port
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#port NsxtAlbPool#port}
    */
    readonly port?: number;
    /**
    * Ratio of selecting eligible servers in the pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#ratio NsxtAlbPool#ratio}
    */
    readonly ratio?: number;
}
export declare function nsxtAlbPoolMemberToTerraform(struct?: NsxtAlbPoolMember | cdktf.IResolvable): any;
export declare function nsxtAlbPoolMemberToHclTerraform(struct?: NsxtAlbPoolMember | cdktf.IResolvable): any;
export declare class NsxtAlbPoolMemberOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtAlbPoolMember | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtAlbPoolMember | cdktf.IResolvable | undefined);
    get detailedHealthMessage(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get healthStatus(): string;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    get markedDownBy(): string[];
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _ratio?;
    get ratio(): number;
    set ratio(value: number);
    resetRatio(): void;
    get ratioInput(): number | undefined;
}
export declare class NsxtAlbPoolMemberList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtAlbPoolMember[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtAlbPoolMemberOutputReference;
}
export interface NsxtAlbPoolPersistenceProfile {
    /**
    * Type of persistence strategy. One of `CLIENT_IP`, `HTTP_COOKIE`, `CUSTOM_HTTP_HEADER`, `APP_COOKIE`, `TLS`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#type NsxtAlbPool#type}
    */
    readonly type: string;
    /**
    * Value of attribute based on persistence type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#value NsxtAlbPool#value}
    */
    readonly value?: string;
}
export declare function nsxtAlbPoolPersistenceProfileToTerraform(struct?: NsxtAlbPoolPersistenceProfileOutputReference | NsxtAlbPoolPersistenceProfile): any;
export declare function nsxtAlbPoolPersistenceProfileToHclTerraform(struct?: NsxtAlbPoolPersistenceProfileOutputReference | NsxtAlbPoolPersistenceProfile): any;
export declare class NsxtAlbPoolPersistenceProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtAlbPoolPersistenceProfile | undefined;
    set internalValue(value: NsxtAlbPoolPersistenceProfile | undefined);
    get name(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool vcd_nsxt_alb_pool}
*/
export declare class NsxtAlbPool extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_alb_pool";
    /**
    * Generates CDKTF code for importing a NsxtAlbPool resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtAlbPool to import
    * @param importFromId The id of the existing NsxtAlbPool that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtAlbPool to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_pool vcd_nsxt_alb_pool} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtAlbPoolConfig
    */
    constructor(scope: Construct, id: string, config: NsxtAlbPoolConfig);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    resetAlgorithm(): void;
    get algorithmInput(): string | undefined;
    get associatedVirtualServiceIds(): string[];
    get associatedVirtualServices(): string[];
    private _caCertificateIds?;
    get caCertificateIds(): string[];
    set caCertificateIds(value: string[]);
    resetCaCertificateIds(): void;
    get caCertificateIdsInput(): string[] | undefined;
    private _cnCheckEnabled?;
    get cnCheckEnabled(): boolean | cdktf.IResolvable;
    set cnCheckEnabled(value: boolean | cdktf.IResolvable);
    resetCnCheckEnabled(): void;
    get cnCheckEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _defaultPort?;
    get defaultPort(): number;
    set defaultPort(value: number);
    resetDefaultPort(): void;
    get defaultPortInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _domainNames?;
    get domainNames(): string[];
    set domainNames(value: string[]);
    resetDomainNames(): void;
    get domainNamesInput(): string[] | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get enabledMemberCount(): number;
    private _gracefulTimeoutPeriod?;
    get gracefulTimeoutPeriod(): number;
    set gracefulTimeoutPeriod(value: number);
    resetGracefulTimeoutPeriod(): void;
    get gracefulTimeoutPeriodInput(): number | undefined;
    get healthMessage(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get memberCount(): number;
    private _memberGroupId?;
    get memberGroupId(): string;
    set memberGroupId(value: string);
    resetMemberGroupId(): void;
    get memberGroupIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _passiveMonitoringEnabled?;
    get passiveMonitoringEnabled(): boolean | cdktf.IResolvable;
    set passiveMonitoringEnabled(value: boolean | cdktf.IResolvable);
    resetPassiveMonitoringEnabled(): void;
    get passiveMonitoringEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _sslEnabled?;
    get sslEnabled(): boolean | cdktf.IResolvable;
    set sslEnabled(value: boolean | cdktf.IResolvable);
    resetSslEnabled(): void;
    get sslEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get upMemberCount(): number;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _healthMonitor;
    get healthMonitor(): NsxtAlbPoolHealthMonitorList;
    putHealthMonitor(value: NsxtAlbPoolHealthMonitor[] | cdktf.IResolvable): void;
    resetHealthMonitor(): void;
    get healthMonitorInput(): cdktf.IResolvable | NsxtAlbPoolHealthMonitor[] | undefined;
    private _member;
    get member(): NsxtAlbPoolMemberList;
    putMember(value: NsxtAlbPoolMember[] | cdktf.IResolvable): void;
    resetMember(): void;
    get memberInput(): cdktf.IResolvable | NsxtAlbPoolMember[] | undefined;
    private _persistenceProfile;
    get persistenceProfile(): NsxtAlbPoolPersistenceProfileOutputReference;
    putPersistenceProfile(value: NsxtAlbPoolPersistenceProfile): void;
    resetPersistenceProfile(): void;
    get persistenceProfileInput(): NsxtAlbPoolPersistenceProfile | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
