import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtAlbServiceEngineGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * NSX-T ALB backing Cloud ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#alb_cloud_id NsxtAlbServiceEngineGroup#alb_cloud_id}
    */
    readonly albCloudId: string;
    /**
    * NSX-T ALB Service Engine Group description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#description NsxtAlbServiceEngineGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#id NsxtAlbServiceEngineGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * NSX-T ALB Importable Service Engine Group Name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#importable_service_engine_group_name NsxtAlbServiceEngineGroup#importable_service_engine_group_name}
    */
    readonly importableServiceEngineGroupName: string;
    /**
    * NSX-T ALB Service Engine Group name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#name NsxtAlbServiceEngineGroup#name}
    */
    readonly name: string;
    /**
    * Boolean value that shows if virtual services are overallocated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#overallocated NsxtAlbServiceEngineGroup#overallocated}
    */
    readonly overallocated?: boolean | cdktf.IResolvable;
    /**
    * NSX-T ALB Service Engine Group reservation model. One of 'DEDICATED', 'SHARED'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#reservation_model NsxtAlbServiceEngineGroup#reservation_model}
    */
    readonly reservationModel: string;
    /**
    * Feature set for this ALB Service Engine Group. One of 'STANDARD', 'PREMIUM'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#supported_feature_set NsxtAlbServiceEngineGroup#supported_feature_set}
    */
    readonly supportedFeatureSet?: string;
    /**
    * Boolean value that shows if sync should be performed on every refresh
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#sync_on_refresh NsxtAlbServiceEngineGroup#sync_on_refresh}
    */
    readonly syncOnRefresh?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group vcd_nsxt_alb_service_engine_group}
*/
export declare class NsxtAlbServiceEngineGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_alb_service_engine_group";
    /**
    * Generates CDKTF code for importing a NsxtAlbServiceEngineGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtAlbServiceEngineGroup to import
    * @param importFromId The id of the existing NsxtAlbServiceEngineGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtAlbServiceEngineGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_service_engine_group vcd_nsxt_alb_service_engine_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtAlbServiceEngineGroupConfig
    */
    constructor(scope: Construct, id: string, config: NsxtAlbServiceEngineGroupConfig);
    private _albCloudId?;
    get albCloudId(): string;
    set albCloudId(value: string);
    get albCloudIdInput(): string | undefined;
    get deployedVirtualServices(): number;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get haMode(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _importableServiceEngineGroupName?;
    get importableServiceEngineGroupName(): string;
    set importableServiceEngineGroupName(value: string);
    get importableServiceEngineGroupNameInput(): string | undefined;
    get maxVirtualServices(): number;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _overallocated?;
    get overallocated(): boolean | cdktf.IResolvable;
    set overallocated(value: boolean | cdktf.IResolvable);
    resetOverallocated(): void;
    get overallocatedInput(): boolean | cdktf.IResolvable | undefined;
    private _reservationModel?;
    get reservationModel(): string;
    set reservationModel(value: string);
    get reservationModelInput(): string | undefined;
    get reservedVirtualServices(): number;
    private _supportedFeatureSet?;
    get supportedFeatureSet(): string;
    set supportedFeatureSet(value: string);
    resetSupportedFeatureSet(): void;
    get supportedFeatureSetInput(): string | undefined;
    private _syncOnRefresh?;
    get syncOnRefresh(): boolean | cdktf.IResolvable;
    set syncOnRefresh(value: boolean | cdktf.IResolvable);
    resetSyncOnRefresh(): void;
    get syncOnRefreshInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
