import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtAlbSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#edge_gateway_id NsxtAlbSettings#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#id NsxtAlbSettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The IPv6 network definition in Gateway CIDR format which will be used by Load Balancer service on Edge (VCD 10.4.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#ipv6_service_network_specification NsxtAlbSettings#ipv6_service_network_specification}
    */
    readonly ipv6ServiceNetworkSpecification?: string;
    /**
    * Defines if ALB is enabled on Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#is_active NsxtAlbSettings#is_active}
    */
    readonly isActive: boolean | cdktf.IResolvable;
    /**
    * Enabling transparent mode allows to configure Preserve Client IP on a Virtual Service (VCD 10.4.1+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#is_transparent_mode_enabled NsxtAlbSettings#is_transparent_mode_enabled}
    */
    readonly isTransparentModeEnabled?: boolean | cdktf.IResolvable;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#org NsxtAlbSettings#org}
    */
    readonly org?: string;
    /**
    * Optional custom network CIDR definition for ALB Service Engine placement (VCD default is 192.168.255.1/25)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#service_network_specification NsxtAlbSettings#service_network_specification}
    */
    readonly serviceNetworkSpecification?: string;
    /**
    * Feature set for ALB in this Edge Gateway. One of 'STANDARD', 'PREMIUM'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#supported_feature_set NsxtAlbSettings#supported_feature_set}
    */
    readonly supportedFeatureSet?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#vdc NsxtAlbSettings#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings vcd_nsxt_alb_settings}
*/
export declare class NsxtAlbSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_alb_settings";
    /**
    * Generates CDKTF code for importing a NsxtAlbSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtAlbSettings to import
    * @param importFromId The id of the existing NsxtAlbSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtAlbSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_alb_settings vcd_nsxt_alb_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtAlbSettingsConfig
    */
    constructor(scope: Construct, id: string, config: NsxtAlbSettingsConfig);
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipv6ServiceNetworkSpecification?;
    get ipv6ServiceNetworkSpecification(): string;
    set ipv6ServiceNetworkSpecification(value: string);
    resetIpv6ServiceNetworkSpecification(): void;
    get ipv6ServiceNetworkSpecificationInput(): string | undefined;
    private _isActive?;
    get isActive(): boolean | cdktf.IResolvable;
    set isActive(value: boolean | cdktf.IResolvable);
    get isActiveInput(): boolean | cdktf.IResolvable | undefined;
    private _isTransparentModeEnabled?;
    get isTransparentModeEnabled(): boolean | cdktf.IResolvable;
    set isTransparentModeEnabled(value: boolean | cdktf.IResolvable);
    resetIsTransparentModeEnabled(): void;
    get isTransparentModeEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _serviceNetworkSpecification?;
    get serviceNetworkSpecification(): string;
    set serviceNetworkSpecification(value: string);
    resetServiceNetworkSpecification(): void;
    get serviceNetworkSpecificationInput(): string | undefined;
    private _supportedFeatureSet?;
    get supportedFeatureSet(): string;
    set supportedFeatureSet(value: string);
    resetSupportedFeatureSet(): void;
    get supportedFeatureSetInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
