import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtAppPortProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of VDC, VDC Group, or NSX-T Manager
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#context_id NsxtAppPortProfile#context_id}
    */
    readonly contextId?: string;
    /**
    * Application Port Profile description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#description NsxtAppPortProfile#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#id NsxtAppPortProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Application Port Profile name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#name NsxtAppPortProfile#name}
    */
    readonly name: string;
    /**
    * ID of NSX-T manager. Only required for 'PROVIDER' scope
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#nsxt_manager_id NsxtAppPortProfile#nsxt_manager_id}
    */
    readonly nsxtManagerId?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#org NsxtAppPortProfile#org}
    */
    readonly org?: string;
    /**
    * Scope - 'PROVIDER' or 'TENANT'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#scope NsxtAppPortProfile#scope}
    */
    readonly scope: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#vdc NsxtAppPortProfile#vdc}
    */
    readonly vdc?: string;
    /**
    * app_port block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#app_port NsxtAppPortProfile#app_port}
    */
    readonly appPort: NsxtAppPortProfileAppPort[] | cdktf.IResolvable;
}
export interface NsxtAppPortProfileAppPort {
    /**
    * Set of ports or ranges
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#port NsxtAppPortProfile#port}
    */
    readonly port?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#protocol NsxtAppPortProfile#protocol}
    */
    readonly protocol: string;
}
export declare function nsxtAppPortProfileAppPortToTerraform(struct?: NsxtAppPortProfileAppPort | cdktf.IResolvable): any;
export declare function nsxtAppPortProfileAppPortToHclTerraform(struct?: NsxtAppPortProfileAppPort | cdktf.IResolvable): any;
export declare class NsxtAppPortProfileAppPortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtAppPortProfileAppPort | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtAppPortProfileAppPort | cdktf.IResolvable | undefined);
    private _port?;
    get port(): string[];
    set port(value: string[]);
    resetPort(): void;
    get portInput(): string[] | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
}
export declare class NsxtAppPortProfileAppPortList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtAppPortProfileAppPort[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtAppPortProfileAppPortOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile vcd_nsxt_app_port_profile}
*/
export declare class NsxtAppPortProfile extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_app_port_profile";
    /**
    * Generates CDKTF code for importing a NsxtAppPortProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtAppPortProfile to import
    * @param importFromId The id of the existing NsxtAppPortProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtAppPortProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_app_port_profile vcd_nsxt_app_port_profile} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtAppPortProfileConfig
    */
    constructor(scope: Construct, id: string, config: NsxtAppPortProfileConfig);
    private _contextId?;
    get contextId(): string;
    set contextId(value: string);
    resetContextId(): void;
    get contextIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nsxtManagerId?;
    get nsxtManagerId(): string;
    set nsxtManagerId(value: string);
    resetNsxtManagerId(): void;
    get nsxtManagerIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    get scopeInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _appPort;
    get appPort(): NsxtAppPortProfileAppPortList;
    putAppPort(value: NsxtAppPortProfileAppPort[] | cdktf.IResolvable): void;
    get appPortInput(): cdktf.IResolvable | NsxtAppPortProfileAppPort[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
