import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtDistributedFirewallRuleAConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional firewall rule ID, to put new rule above during creation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#above_rule_id NsxtDistributedFirewallRuleA#above_rule_id}
    */
    readonly aboveRuleId?: string;
    /**
    * Defines if the rule should 'ALLOW', 'DROP', 'REJECT' matching traffic
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#action NsxtDistributedFirewallRuleA#action}
    */
    readonly action: string;
    /**
    * A set of Application Port Profile IDs. Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#app_port_profile_ids NsxtDistributedFirewallRuleA#app_port_profile_ids}
    */
    readonly appPortProfileIds?: string[];
    /**
    * Comment that is shown next to rule in UI (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#comment NsxtDistributedFirewallRuleA#comment}
    */
    readonly comment?: string;
    /**
    * Description is not shown in UI
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#description NsxtDistributedFirewallRuleA#description}
    */
    readonly description?: string;
    /**
    * Reverses firewall matching for to match all except Destinations Groups specified in 'destination_ids' (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#destination_groups_excluded NsxtDistributedFirewallRuleA#destination_groups_excluded}
    */
    readonly destinationGroupsExcluded?: boolean | cdktf.IResolvable;
    /**
    * A set of Destination Firewall Group IDs (IP Sets or Security Groups). Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#destination_ids NsxtDistributedFirewallRuleA#destination_ids}
    */
    readonly destinationIds?: string[];
    /**
    * Direction on which Firewall Rule applies (one of 'IN', 'OUT', 'IN_OUT')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#direction NsxtDistributedFirewallRuleA#direction}
    */
    readonly direction?: string;
    /**
    * Defined if Firewall Rule is active
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#enabled NsxtDistributedFirewallRuleA#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#id NsxtDistributedFirewallRuleA#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Firewall Rule Protocol (one of 'IPV4', 'IPV6', 'IPV4_IPV6')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#ip_protocol NsxtDistributedFirewallRuleA#ip_protocol}
    */
    readonly ipProtocol?: string;
    /**
    * Defines if matching traffic should be logged
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#logging NsxtDistributedFirewallRuleA#logging}
    */
    readonly logging?: boolean | cdktf.IResolvable;
    /**
    * Firewall Rule name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#name NsxtDistributedFirewallRuleA#name}
    */
    readonly name: string;
    /**
    * A set of Network Context Profile IDs. Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#network_context_profile_ids NsxtDistributedFirewallRuleA#network_context_profile_ids}
    */
    readonly networkContextProfileIds?: string[];
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#org NsxtDistributedFirewallRuleA#org}
    */
    readonly org?: string;
    /**
    * Reverses firewall matching for to match all except Source Groups specified in 'source_ids' (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#source_groups_excluded NsxtDistributedFirewallRuleA#source_groups_excluded}
    */
    readonly sourceGroupsExcluded?: boolean | cdktf.IResolvable;
    /**
    * A set of Source Firewall Group IDs (IP Sets or Security Groups). Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#source_ids NsxtDistributedFirewallRuleA#source_ids}
    */
    readonly sourceIds?: string[];
    /**
    * ID of VDC Group for Distributed Firewall
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#vdc_group_id NsxtDistributedFirewallRuleA#vdc_group_id}
    */
    readonly vdcGroupId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule vcd_nsxt_distributed_firewall_rule}
*/
export declare class NsxtDistributedFirewallRuleA extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_distributed_firewall_rule";
    /**
    * Generates CDKTF code for importing a NsxtDistributedFirewallRuleA resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtDistributedFirewallRuleA to import
    * @param importFromId The id of the existing NsxtDistributedFirewallRuleA that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtDistributedFirewallRuleA to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall_rule vcd_nsxt_distributed_firewall_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtDistributedFirewallRuleAConfig
    */
    constructor(scope: Construct, id: string, config: NsxtDistributedFirewallRuleAConfig);
    private _aboveRuleId?;
    get aboveRuleId(): string;
    set aboveRuleId(value: string);
    resetAboveRuleId(): void;
    get aboveRuleIdInput(): string | undefined;
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _appPortProfileIds?;
    get appPortProfileIds(): string[];
    set appPortProfileIds(value: string[]);
    resetAppPortProfileIds(): void;
    get appPortProfileIdsInput(): string[] | undefined;
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _destinationGroupsExcluded?;
    get destinationGroupsExcluded(): boolean | cdktf.IResolvable;
    set destinationGroupsExcluded(value: boolean | cdktf.IResolvable);
    resetDestinationGroupsExcluded(): void;
    get destinationGroupsExcludedInput(): boolean | cdktf.IResolvable | undefined;
    private _destinationIds?;
    get destinationIds(): string[];
    set destinationIds(value: string[]);
    resetDestinationIds(): void;
    get destinationIdsInput(): string[] | undefined;
    private _direction?;
    get direction(): string;
    set direction(value: string);
    resetDirection(): void;
    get directionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipProtocol?;
    get ipProtocol(): string;
    set ipProtocol(value: string);
    resetIpProtocol(): void;
    get ipProtocolInput(): string | undefined;
    private _logging?;
    get logging(): boolean | cdktf.IResolvable;
    set logging(value: boolean | cdktf.IResolvable);
    resetLogging(): void;
    get loggingInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkContextProfileIds?;
    get networkContextProfileIds(): string[];
    set networkContextProfileIds(value: string[]);
    resetNetworkContextProfileIds(): void;
    get networkContextProfileIdsInput(): string[] | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _sourceGroupsExcluded?;
    get sourceGroupsExcluded(): boolean | cdktf.IResolvable;
    set sourceGroupsExcluded(value: boolean | cdktf.IResolvable);
    resetSourceGroupsExcluded(): void;
    get sourceGroupsExcludedInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceIds?;
    get sourceIds(): string[];
    set sourceIds(value: string[]);
    resetSourceIds(): void;
    get sourceIdsInput(): string[] | undefined;
    private _vdcGroupId?;
    get vdcGroupId(): string;
    set vdcGroupId(value: string);
    get vdcGroupIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
