import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtDistributedFirewallConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#id NsxtDistributedFirewall#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#org NsxtDistributedFirewall#org}
    */
    readonly org?: string;
    /**
    * ID of VDC Group for Distributed Firewall
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#vdc_group_id NsxtDistributedFirewall#vdc_group_id}
    */
    readonly vdcGroupId: string;
    /**
    * rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#rule NsxtDistributedFirewall#rule}
    */
    readonly rule: NsxtDistributedFirewallRule[] | cdktf.IResolvable;
}
export interface NsxtDistributedFirewallRule {
    /**
    * Defines if the rule should 'ALLOW', 'DROP', 'REJECT' matching traffic
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#action NsxtDistributedFirewall#action}
    */
    readonly action: string;
    /**
    * A set of Application Port Profile IDs. Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#app_port_profile_ids NsxtDistributedFirewall#app_port_profile_ids}
    */
    readonly appPortProfileIds?: string[];
    /**
    * Comment that is shown next to rule in UI (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#comment NsxtDistributedFirewall#comment}
    */
    readonly comment?: string;
    /**
    * Description is not shown in UI
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#description NsxtDistributedFirewall#description}
    */
    readonly description?: string;
    /**
    * Reverses firewall matching for to match all except Destinations Groups specified in 'destination_ids' (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#destination_groups_excluded NsxtDistributedFirewall#destination_groups_excluded}
    */
    readonly destinationGroupsExcluded?: boolean | cdktf.IResolvable;
    /**
    * A set of Destination Firewall Group IDs (IP Sets or Security Groups). Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#destination_ids NsxtDistributedFirewall#destination_ids}
    */
    readonly destinationIds?: string[];
    /**
    * Direction on which Firewall Rule applies (One of 'IN', 'OUT', 'IN_OUT')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#direction NsxtDistributedFirewall#direction}
    */
    readonly direction?: string;
    /**
    * Defined if Firewall Rule is active
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#enabled NsxtDistributedFirewall#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Firewall Rule Protocol (One of 'IPV4', 'IPV6', 'IPV4_IPV6')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#ip_protocol NsxtDistributedFirewall#ip_protocol}
    */
    readonly ipProtocol?: string;
    /**
    * Defines if matching traffic should be logged
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#logging NsxtDistributedFirewall#logging}
    */
    readonly logging?: boolean | cdktf.IResolvable;
    /**
    * Firewall Rule name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#name NsxtDistributedFirewall#name}
    */
    readonly name: string;
    /**
    * A set of Network Context Profile IDs. Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#network_context_profile_ids NsxtDistributedFirewall#network_context_profile_ids}
    */
    readonly networkContextProfileIds?: string[];
    /**
    * Reverses firewall matching for to match all except Source Groups specified in 'source_ids' (VCD 10.3.2+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#source_groups_excluded NsxtDistributedFirewall#source_groups_excluded}
    */
    readonly sourceGroupsExcluded?: boolean | cdktf.IResolvable;
    /**
    * A set of Source Firewall Group IDs (IP Sets or Security Groups). Leaving it empty means 'Any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#source_ids NsxtDistributedFirewall#source_ids}
    */
    readonly sourceIds?: string[];
}
export declare function nsxtDistributedFirewallRuleToTerraform(struct?: NsxtDistributedFirewallRule | cdktf.IResolvable): any;
export declare function nsxtDistributedFirewallRuleToHclTerraform(struct?: NsxtDistributedFirewallRule | cdktf.IResolvable): any;
export declare class NsxtDistributedFirewallRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtDistributedFirewallRule | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtDistributedFirewallRule | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    get actionInput(): string | undefined;
    private _appPortProfileIds?;
    get appPortProfileIds(): string[];
    set appPortProfileIds(value: string[]);
    resetAppPortProfileIds(): void;
    get appPortProfileIdsInput(): string[] | undefined;
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _destinationGroupsExcluded?;
    get destinationGroupsExcluded(): boolean | cdktf.IResolvable;
    set destinationGroupsExcluded(value: boolean | cdktf.IResolvable);
    resetDestinationGroupsExcluded(): void;
    get destinationGroupsExcludedInput(): boolean | cdktf.IResolvable | undefined;
    private _destinationIds?;
    get destinationIds(): string[];
    set destinationIds(value: string[]);
    resetDestinationIds(): void;
    get destinationIdsInput(): string[] | undefined;
    private _direction?;
    get direction(): string;
    set direction(value: string);
    resetDirection(): void;
    get directionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _ipProtocol?;
    get ipProtocol(): string;
    set ipProtocol(value: string);
    resetIpProtocol(): void;
    get ipProtocolInput(): string | undefined;
    private _logging?;
    get logging(): boolean | cdktf.IResolvable;
    set logging(value: boolean | cdktf.IResolvable);
    resetLogging(): void;
    get loggingInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkContextProfileIds?;
    get networkContextProfileIds(): string[];
    set networkContextProfileIds(value: string[]);
    resetNetworkContextProfileIds(): void;
    get networkContextProfileIdsInput(): string[] | undefined;
    private _sourceGroupsExcluded?;
    get sourceGroupsExcluded(): boolean | cdktf.IResolvable;
    set sourceGroupsExcluded(value: boolean | cdktf.IResolvable);
    resetSourceGroupsExcluded(): void;
    get sourceGroupsExcludedInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceIds?;
    get sourceIds(): string[];
    set sourceIds(value: string[]);
    resetSourceIds(): void;
    get sourceIdsInput(): string[] | undefined;
}
export declare class NsxtDistributedFirewallRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtDistributedFirewallRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtDistributedFirewallRuleOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall vcd_nsxt_distributed_firewall}
*/
export declare class NsxtDistributedFirewall extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_distributed_firewall";
    /**
    * Generates CDKTF code for importing a NsxtDistributedFirewall resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtDistributedFirewall to import
    * @param importFromId The id of the existing NsxtDistributedFirewall that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtDistributedFirewall to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_distributed_firewall vcd_nsxt_distributed_firewall} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtDistributedFirewallConfig
    */
    constructor(scope: Construct, id: string, config: NsxtDistributedFirewallConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdcGroupId?;
    get vdcGroupId(): string;
    set vdcGroupId(value: string);
    get vdcGroupIdInput(): string | undefined;
    private _rule;
    get rule(): NsxtDistributedFirewallRuleList;
    putRule(value: NsxtDistributedFirewallRule[] | cdktf.IResolvable): void;
    get ruleInput(): cdktf.IResolvable | NsxtDistributedFirewallRule[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
