import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtDynamicSecurityGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Dynamic Security Group description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#description NsxtDynamicSecurityGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#id NsxtDynamicSecurityGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Dynamic Security Group name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#name NsxtDynamicSecurityGroup#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#org NsxtDynamicSecurityGroup#org}
    */
    readonly org?: string;
    /**
    * VDC Group ID in which Dynamic Security Group is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#vdc_group_id NsxtDynamicSecurityGroup#vdc_group_id}
    */
    readonly vdcGroupId: string;
    /**
    * criteria block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#criteria NsxtDynamicSecurityGroup#criteria}
    */
    readonly criteria?: NsxtDynamicSecurityGroupCriteria[] | cdktf.IResolvable;
}
export interface NsxtDynamicSecurityGroupMemberVms {
}
export declare function nsxtDynamicSecurityGroupMemberVmsToTerraform(struct?: NsxtDynamicSecurityGroupMemberVms): any;
export declare function nsxtDynamicSecurityGroupMemberVmsToHclTerraform(struct?: NsxtDynamicSecurityGroupMemberVms): any;
export declare class NsxtDynamicSecurityGroupMemberVmsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtDynamicSecurityGroupMemberVms | undefined;
    set internalValue(value: NsxtDynamicSecurityGroupMemberVms | undefined);
    get vappId(): string;
    get vappName(): string;
    get vmId(): string;
    get vmName(): string;
}
export declare class NsxtDynamicSecurityGroupMemberVmsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtDynamicSecurityGroupMemberVmsOutputReference;
}
export interface NsxtDynamicSecurityGroupCriteriaRule {
    /**
    * Operator can be one of 'EQUALS', 'CONTAINS', 'STARTS_WITH', 'ENDS_WITH'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#operator NsxtDynamicSecurityGroup#operator}
    */
    readonly operator: string;
    /**
    * Type of object matching 'VM_TAG' or 'VM_NAME'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#type NsxtDynamicSecurityGroup#type}
    */
    readonly type: string;
    /**
    * Filter value
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#value NsxtDynamicSecurityGroup#value}
    */
    readonly value: string;
}
export declare function nsxtDynamicSecurityGroupCriteriaRuleToTerraform(struct?: NsxtDynamicSecurityGroupCriteriaRule | cdktf.IResolvable): any;
export declare function nsxtDynamicSecurityGroupCriteriaRuleToHclTerraform(struct?: NsxtDynamicSecurityGroupCriteriaRule | cdktf.IResolvable): any;
export declare class NsxtDynamicSecurityGroupCriteriaRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtDynamicSecurityGroupCriteriaRule | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtDynamicSecurityGroupCriteriaRule | cdktf.IResolvable | undefined);
    private _operator?;
    get operator(): string;
    set operator(value: string);
    get operatorInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class NsxtDynamicSecurityGroupCriteriaRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtDynamicSecurityGroupCriteriaRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtDynamicSecurityGroupCriteriaRuleOutputReference;
}
export interface NsxtDynamicSecurityGroupCriteria {
    /**
    * rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#rule NsxtDynamicSecurityGroup#rule}
    */
    readonly rule?: NsxtDynamicSecurityGroupCriteriaRule[] | cdktf.IResolvable;
}
export declare function nsxtDynamicSecurityGroupCriteriaToTerraform(struct?: NsxtDynamicSecurityGroupCriteria | cdktf.IResolvable): any;
export declare function nsxtDynamicSecurityGroupCriteriaToHclTerraform(struct?: NsxtDynamicSecurityGroupCriteria | cdktf.IResolvable): any;
export declare class NsxtDynamicSecurityGroupCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtDynamicSecurityGroupCriteria | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtDynamicSecurityGroupCriteria | cdktf.IResolvable | undefined);
    private _rule;
    get rule(): NsxtDynamicSecurityGroupCriteriaRuleList;
    putRule(value: NsxtDynamicSecurityGroupCriteriaRule[] | cdktf.IResolvable): void;
    resetRule(): void;
    get ruleInput(): cdktf.IResolvable | NsxtDynamicSecurityGroupCriteriaRule[] | undefined;
}
export declare class NsxtDynamicSecurityGroupCriteriaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtDynamicSecurityGroupCriteria[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtDynamicSecurityGroupCriteriaOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group vcd_nsxt_dynamic_security_group}
*/
export declare class NsxtDynamicSecurityGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_dynamic_security_group";
    /**
    * Generates CDKTF code for importing a NsxtDynamicSecurityGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtDynamicSecurityGroup to import
    * @param importFromId The id of the existing NsxtDynamicSecurityGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtDynamicSecurityGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_dynamic_security_group vcd_nsxt_dynamic_security_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtDynamicSecurityGroupConfig
    */
    constructor(scope: Construct, id: string, config: NsxtDynamicSecurityGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _memberVms;
    get memberVms(): NsxtDynamicSecurityGroupMemberVmsList;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdcGroupId?;
    get vdcGroupId(): string;
    set vdcGroupId(value: string);
    get vdcGroupIdInput(): string | undefined;
    private _criteria;
    get criteria(): NsxtDynamicSecurityGroupCriteriaList;
    putCriteria(value: NsxtDynamicSecurityGroupCriteria[] | cdktf.IResolvable): void;
    resetCriteria(): void;
    get criteriaInput(): cdktf.IResolvable | NsxtDynamicSecurityGroupCriteria[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
