import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayBgpConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Defines if ECMP (Equal-cost multi-path routing) is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#ecmp_enabled NsxtEdgegatewayBgpConfiguration#ecmp_enabled}
    */
    readonly ecmpEnabled?: boolean | cdktf.IResolvable;
    /**
    * Edge gateway ID for BGP Configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#edge_gateway_id NsxtEdgegatewayBgpConfiguration#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Defines if BGP service is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#enabled NsxtEdgegatewayBgpConfiguration#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Graceful restart configuration on Edge Gateway. One of 'DISABLE', 'HELPER_ONLY', 'GRACEFUL_AND_HELPER'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#graceful_restart_mode NsxtEdgegatewayBgpConfiguration#graceful_restart_mode}
    */
    readonly gracefulRestartMode?: string;
    /**
    * Maximum time taken (in seconds) for a BGP session to be established after a restart
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#graceful_restart_timer NsxtEdgegatewayBgpConfiguration#graceful_restart_timer}
    */
    readonly gracefulRestartTimer?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#id NsxtEdgegatewayBgpConfiguration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Autonomous system number
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#local_as_number NsxtEdgegatewayBgpConfiguration#local_as_number}
    */
    readonly localAsNumber?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#org NsxtEdgegatewayBgpConfiguration#org}
    */
    readonly org?: string;
    /**
    * Maximum time (in seconds) before stale routes are removed when BGP restarts
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#stale_route_timer NsxtEdgegatewayBgpConfiguration#stale_route_timer}
    */
    readonly staleRouteTimer?: number;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration vcd_nsxt_edgegateway_bgp_configuration}
*/
export declare class NsxtEdgegatewayBgpConfiguration extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_bgp_configuration";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayBgpConfiguration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayBgpConfiguration to import
    * @param importFromId The id of the existing NsxtEdgegatewayBgpConfiguration that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayBgpConfiguration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_configuration vcd_nsxt_edgegateway_bgp_configuration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayBgpConfigurationConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayBgpConfigurationConfig);
    private _ecmpEnabled?;
    get ecmpEnabled(): boolean | cdktf.IResolvable;
    set ecmpEnabled(value: boolean | cdktf.IResolvable);
    resetEcmpEnabled(): void;
    get ecmpEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _gracefulRestartMode?;
    get gracefulRestartMode(): string;
    set gracefulRestartMode(value: string);
    resetGracefulRestartMode(): void;
    get gracefulRestartModeInput(): string | undefined;
    private _gracefulRestartTimer?;
    get gracefulRestartTimer(): number;
    set gracefulRestartTimer(value: number);
    resetGracefulRestartTimer(): void;
    get gracefulRestartTimerInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _localAsNumber?;
    get localAsNumber(): string;
    set localAsNumber(value: string);
    resetLocalAsNumber(): void;
    get localAsNumberInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _staleRouteTimer?;
    get staleRouteTimer(): number;
    set staleRouteTimer(value: number);
    resetStaleRouteTimer(): void;
    get staleRouteTimerInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
