import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayBgpNeighborConfig extends cdktf.TerraformMetaArguments {
    /**
    * A flag indicating whether BGP neighbors can receive routes with same Autonomous System (AS) (default 'false')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#allow_as_in NsxtEdgegatewayBgpNeighbor#allow_as_in}
    */
    readonly allowAsIn?: boolean | cdktf.IResolvable;
    /**
    * Number of times a heartbeat packet is missed before BFD declares that the neighbor is down
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#bfd_dead_multiple NsxtEdgegatewayBgpNeighbor#bfd_dead_multiple}
    */
    readonly bfdDeadMultiple?: number;
    /**
    * BFD configuration for failure detection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#bfd_enabled NsxtEdgegatewayBgpNeighbor#bfd_enabled}
    */
    readonly bfdEnabled?: boolean | cdktf.IResolvable;
    /**
    * Time interval (in milliseconds) between heartbeat packets
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#bfd_interval NsxtEdgegatewayBgpNeighbor#bfd_interval}
    */
    readonly bfdInterval?: number;
    /**
    * Edge gateway ID for BGP Neighbor Configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#edge_gateway_id NsxtEdgegatewayBgpNeighbor#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * One of 'DISABLE', 'HELPER_ONLY', 'GRACEFUL_AND_HELPER'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#graceful_restart_mode NsxtEdgegatewayBgpNeighbor#graceful_restart_mode}
    */
    readonly gracefulRestartMode?: string;
    /**
    * Time interval (in seconds) before declaring a peer dead
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#hold_down_timer NsxtEdgegatewayBgpNeighbor#hold_down_timer}
    */
    readonly holdDownTimer?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#id NsxtEdgegatewayBgpNeighbor#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * An optional IP Prefix List ID for filtering 'IN' direction.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#in_filter_ip_prefix_list_id NsxtEdgegatewayBgpNeighbor#in_filter_ip_prefix_list_id}
    */
    readonly inFilterIpPrefixListId?: string;
    /**
    * BGP Neighbor IP address (IPv4 or IPv6)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#ip_address NsxtEdgegatewayBgpNeighbor#ip_address}
    */
    readonly ipAddress: string;
    /**
    * Time interval (in seconds) between sending keep alive messages to a peer
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#keep_alive_timer NsxtEdgegatewayBgpNeighbor#keep_alive_timer}
    */
    readonly keepAliveTimer?: number;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#org NsxtEdgegatewayBgpNeighbor#org}
    */
    readonly org?: string;
    /**
    * An optional IP Prefix List ID for filtering 'OUT' direction.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#out_filter_ip_prefix_list_id NsxtEdgegatewayBgpNeighbor#out_filter_ip_prefix_list_id}
    */
    readonly outFilterIpPrefixListId?: string;
    /**
    * Neighbor password
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#password NsxtEdgegatewayBgpNeighbor#password}
    */
    readonly password?: string;
    /**
    * Remote Autonomous System (AS) number
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#remote_as_number NsxtEdgegatewayBgpNeighbor#remote_as_number}
    */
    readonly remoteAsNumber: string;
    /**
    * One of 'DISABLED', 'IPV4', 'IPV6'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#route_filtering NsxtEdgegatewayBgpNeighbor#route_filtering}
    */
    readonly routeFiltering?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor vcd_nsxt_edgegateway_bgp_neighbor}
*/
export declare class NsxtEdgegatewayBgpNeighbor extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_bgp_neighbor";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayBgpNeighbor resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayBgpNeighbor to import
    * @param importFromId The id of the existing NsxtEdgegatewayBgpNeighbor that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayBgpNeighbor to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_bgp_neighbor vcd_nsxt_edgegateway_bgp_neighbor} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayBgpNeighborConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayBgpNeighborConfig);
    private _allowAsIn?;
    get allowAsIn(): boolean | cdktf.IResolvable;
    set allowAsIn(value: boolean | cdktf.IResolvable);
    resetAllowAsIn(): void;
    get allowAsInInput(): boolean | cdktf.IResolvable | undefined;
    private _bfdDeadMultiple?;
    get bfdDeadMultiple(): number;
    set bfdDeadMultiple(value: number);
    resetBfdDeadMultiple(): void;
    get bfdDeadMultipleInput(): number | undefined;
    private _bfdEnabled?;
    get bfdEnabled(): boolean | cdktf.IResolvable;
    set bfdEnabled(value: boolean | cdktf.IResolvable);
    resetBfdEnabled(): void;
    get bfdEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _bfdInterval?;
    get bfdInterval(): number;
    set bfdInterval(value: number);
    resetBfdInterval(): void;
    get bfdIntervalInput(): number | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _gracefulRestartMode?;
    get gracefulRestartMode(): string;
    set gracefulRestartMode(value: string);
    resetGracefulRestartMode(): void;
    get gracefulRestartModeInput(): string | undefined;
    private _holdDownTimer?;
    get holdDownTimer(): number;
    set holdDownTimer(value: number);
    resetHoldDownTimer(): void;
    get holdDownTimerInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inFilterIpPrefixListId?;
    get inFilterIpPrefixListId(): string;
    set inFilterIpPrefixListId(value: string);
    resetInFilterIpPrefixListId(): void;
    get inFilterIpPrefixListIdInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    private _keepAliveTimer?;
    get keepAliveTimer(): number;
    set keepAliveTimer(value: number);
    resetKeepAliveTimer(): void;
    get keepAliveTimerInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _outFilterIpPrefixListId?;
    get outFilterIpPrefixListId(): string;
    set outFilterIpPrefixListId(value: string);
    resetOutFilterIpPrefixListId(): void;
    get outFilterIpPrefixListIdInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _remoteAsNumber?;
    get remoteAsNumber(): string;
    set remoteAsNumber(value: string);
    get remoteAsNumberInput(): string | undefined;
    private _routeFiltering?;
    get routeFiltering(): string;
    set routeFiltering(value: string);
    resetRouteFiltering(): void;
    get routeFilteringInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
