import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayDhcpForwardingConfig extends cdktf.TerraformMetaArguments {
    /**
    * IP addresses of the DHCP servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#dhcp_servers NsxtEdgegatewayDhcpForwarding#dhcp_servers}
    */
    readonly dhcpServers: string[];
    /**
    * Edge gateway ID for DHCP forwarding configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#edge_gateway_id NsxtEdgegatewayDhcpForwarding#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Status of DHCP Forwarding for the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#enabled NsxtEdgegatewayDhcpForwarding#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#id NsxtEdgegatewayDhcpForwarding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#org NsxtEdgegatewayDhcpForwarding#org}
    */
    readonly org?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding vcd_nsxt_edgegateway_dhcp_forwarding}
*/
export declare class NsxtEdgegatewayDhcpForwarding extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_dhcp_forwarding";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayDhcpForwarding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayDhcpForwarding to import
    * @param importFromId The id of the existing NsxtEdgegatewayDhcpForwarding that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayDhcpForwarding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcp_forwarding vcd_nsxt_edgegateway_dhcp_forwarding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayDhcpForwardingConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayDhcpForwardingConfig);
    private _dhcpServers?;
    get dhcpServers(): string[];
    set dhcpServers(value: string[]);
    get dhcpServersInput(): string[] | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
