import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayDhcpv6Config extends cdktf.TerraformMetaArguments {
    /**
    * A set of DNS Servers (only applicable for 'SLAAC' mode)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#dns_servers NsxtEdgegatewayDhcpv6#dns_servers}
    */
    readonly dnsServers?: string[];
    /**
    * A set of domain names (only applicable for 'SLAAC' mode)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#domain_names NsxtEdgegatewayDhcpv6#domain_names}
    */
    readonly domainNames?: string[];
    /**
    * Edge gateway ID for Rate limiting (DHCPv6) configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#edge_gateway_id NsxtEdgegatewayDhcpv6#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#id NsxtEdgegatewayDhcpv6#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * DHCPv6 configuration mode. One of 'SLAAC', 'DHCPv6', 'DISABLED'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#mode NsxtEdgegatewayDhcpv6#mode}
    */
    readonly mode: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#org NsxtEdgegatewayDhcpv6#org}
    */
    readonly org?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6 vcd_nsxt_edgegateway_dhcpv6}
*/
export declare class NsxtEdgegatewayDhcpv6 extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_dhcpv6";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayDhcpv6 resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayDhcpv6 to import
    * @param importFromId The id of the existing NsxtEdgegatewayDhcpv6 that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayDhcpv6 to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dhcpv6 vcd_nsxt_edgegateway_dhcpv6} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayDhcpv6Config
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayDhcpv6Config);
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    resetDnsServers(): void;
    get dnsServersInput(): string[] | undefined;
    private _domainNames?;
    get domainNames(): string[];
    set domainNames(value: string[]);
    resetDomainNames(): void;
    get domainNamesInput(): string[] | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
