import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayDnsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway ID for DNS configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#edge_gateway_id NsxtEdgegatewayDns#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Status of the DNS Forwarder. Defaults to `true`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#enabled NsxtEdgegatewayDns#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#id NsxtEdgegatewayDns#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP on which the DNS forwarder listens.Can be modified only if the Edge Gateway has a dedicated external network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#listener_ip NsxtEdgegatewayDns#listener_ip}
    */
    readonly listenerIp?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#org NsxtEdgegatewayDns#org}
    */
    readonly org?: string;
    /**
    * The external IP address of the SNAT rule. Can be modified only if the Edge Gateway's external network is using IP spaces. (VCD 10.5.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#snat_rule_ip_address NsxtEdgegatewayDns#snat_rule_ip_address}
    */
    readonly snatRuleIpAddress?: string;
    /**
    * conditional_forwarder_zone block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#conditional_forwarder_zone NsxtEdgegatewayDns#conditional_forwarder_zone}
    */
    readonly conditionalForwarderZone?: NsxtEdgegatewayDnsConditionalForwarderZone[] | cdktf.IResolvable;
    /**
    * default_forwarder_zone block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#default_forwarder_zone NsxtEdgegatewayDns#default_forwarder_zone}
    */
    readonly defaultForwarderZone: NsxtEdgegatewayDnsDefaultForwarderZone;
}
export interface NsxtEdgegatewayDnsConditionalForwarderZone {
    /**
    * Set of domain names on which conditional forwarding is based.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#domain_names NsxtEdgegatewayDns#domain_names}
    */
    readonly domainNames: string[];
    /**
    * Name of the forwarder zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#name NsxtEdgegatewayDns#name}
    */
    readonly name: string;
    /**
    * Servers to which DNS requests should be forwarded to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#upstream_servers NsxtEdgegatewayDns#upstream_servers}
    */
    readonly upstreamServers: string[];
}
export declare function nsxtEdgegatewayDnsConditionalForwarderZoneToTerraform(struct?: NsxtEdgegatewayDnsConditionalForwarderZone | cdktf.IResolvable): any;
export declare function nsxtEdgegatewayDnsConditionalForwarderZoneToHclTerraform(struct?: NsxtEdgegatewayDnsConditionalForwarderZone | cdktf.IResolvable): any;
export declare class NsxtEdgegatewayDnsConditionalForwarderZoneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewayDnsConditionalForwarderZone | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewayDnsConditionalForwarderZone | cdktf.IResolvable | undefined);
    private _domainNames?;
    get domainNames(): string[];
    set domainNames(value: string[]);
    get domainNamesInput(): string[] | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _upstreamServers?;
    get upstreamServers(): string[];
    set upstreamServers(value: string[]);
    get upstreamServersInput(): string[] | undefined;
}
export declare class NsxtEdgegatewayDnsConditionalForwarderZoneList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewayDnsConditionalForwarderZone[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewayDnsConditionalForwarderZoneOutputReference;
}
export interface NsxtEdgegatewayDnsDefaultForwarderZone {
    /**
    * Name of the forwarder zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#name NsxtEdgegatewayDns#name}
    */
    readonly name: string;
    /**
    * Servers to which DNS requests should be forwarded to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#upstream_servers NsxtEdgegatewayDns#upstream_servers}
    */
    readonly upstreamServers: string[];
}
export declare function nsxtEdgegatewayDnsDefaultForwarderZoneToTerraform(struct?: NsxtEdgegatewayDnsDefaultForwarderZoneOutputReference | NsxtEdgegatewayDnsDefaultForwarderZone): any;
export declare function nsxtEdgegatewayDnsDefaultForwarderZoneToHclTerraform(struct?: NsxtEdgegatewayDnsDefaultForwarderZoneOutputReference | NsxtEdgegatewayDnsDefaultForwarderZone): any;
export declare class NsxtEdgegatewayDnsDefaultForwarderZoneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtEdgegatewayDnsDefaultForwarderZone | undefined;
    set internalValue(value: NsxtEdgegatewayDnsDefaultForwarderZone | undefined);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _upstreamServers?;
    get upstreamServers(): string[];
    set upstreamServers(value: string[]);
    get upstreamServersInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns vcd_nsxt_edgegateway_dns}
*/
export declare class NsxtEdgegatewayDns extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_dns";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayDns resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayDns to import
    * @param importFromId The id of the existing NsxtEdgegatewayDns that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayDns to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_dns vcd_nsxt_edgegateway_dns} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayDnsConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayDnsConfig);
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _listenerIp?;
    get listenerIp(): string;
    set listenerIp(value: string);
    resetListenerIp(): void;
    get listenerIpInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get snatRuleEnabled(): cdktf.IResolvable;
    private _snatRuleIpAddress?;
    get snatRuleIpAddress(): string;
    set snatRuleIpAddress(value: string);
    resetSnatRuleIpAddress(): void;
    get snatRuleIpAddressInput(): string | undefined;
    private _conditionalForwarderZone;
    get conditionalForwarderZone(): NsxtEdgegatewayDnsConditionalForwarderZoneList;
    putConditionalForwarderZone(value: NsxtEdgegatewayDnsConditionalForwarderZone[] | cdktf.IResolvable): void;
    resetConditionalForwarderZone(): void;
    get conditionalForwarderZoneInput(): cdktf.IResolvable | NsxtEdgegatewayDnsConditionalForwarderZone[] | undefined;
    private _defaultForwarderZone;
    get defaultForwarderZone(): NsxtEdgegatewayDnsDefaultForwarderZoneOutputReference;
    putDefaultForwarderZone(value: NsxtEdgegatewayDnsDefaultForwarderZone): void;
    get defaultForwarderZoneInput(): NsxtEdgegatewayDnsDefaultForwarderZone | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
