import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayL2VpnTunnelConfig extends cdktf.TerraformMetaArguments {
    /**
    * Connector initation mode of the session describing how a connection is made. Needs to be set only if `session_mode` is set to `SERVER`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#connector_initiation_mode NsxtEdgegatewayL2VpnTunnel#connector_initiation_mode}
    */
    readonly connectorInitiationMode?: string;
    /**
    * Description of the L2 VPN Tunnel session
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#description NsxtEdgegatewayL2VpnTunnel#description}
    */
    readonly description?: string;
    /**
    * Edge Gateway ID for the tunnel
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#edge_gateway_id NsxtEdgegatewayL2VpnTunnel#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Status of the L2 VPN Tunnel session. Always set to `true` for CLIENT sessions. Defaults to true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#enabled NsxtEdgegatewayL2VpnTunnel#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#id NsxtEdgegatewayL2VpnTunnel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Local endpoint IP of the tunnel session, the IP must be sub-allocated to the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#local_endpoint_ip NsxtEdgegatewayL2VpnTunnel#local_endpoint_ip}
    */
    readonly localEndpointIp: string;
    /**
    * Name of the L2 VPN Tunnel session
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#name NsxtEdgegatewayL2VpnTunnel#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#org NsxtEdgegatewayL2VpnTunnel#org}
    */
    readonly org?: string;
    /**
    * Base64 encoded string of the full configuration of the tunnel provided by the SERVER session. It is a computed field for SERVER sessions and is a required field for CLIENT sessions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#peer_code NsxtEdgegatewayL2VpnTunnel#peer_code}
    */
    readonly peerCode?: string;
    /**
    * Pre-shared key used for authentication, needs to be provided only for`SERVER` sessions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#pre_shared_key NsxtEdgegatewayL2VpnTunnel#pre_shared_key}
    */
    readonly preSharedKey?: string;
    /**
    * The IP address of the remote endpoint, which corresponds to the deviceon the remote site terminating the VPN tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#remote_endpoint_ip NsxtEdgegatewayL2VpnTunnel#remote_endpoint_ip}
    */
    readonly remoteEndpointIp: string;
    /**
    * Mode of the tunnel session, must be CLIENT or SERVER
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#session_mode NsxtEdgegatewayL2VpnTunnel#session_mode}
    */
    readonly sessionMode: string;
    /**
    * Network CIDR block over which the session interfaces. Only relevant if `session_mode` is set to `SERVER`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#tunnel_interface NsxtEdgegatewayL2VpnTunnel#tunnel_interface}
    */
    readonly tunnelInterface?: string;
    /**
    * stretched_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#stretched_network NsxtEdgegatewayL2VpnTunnel#stretched_network}
    */
    readonly stretchedNetwork?: NsxtEdgegatewayL2VpnTunnelStretchedNetwork[] | cdktf.IResolvable;
}
export interface NsxtEdgegatewayL2VpnTunnelStretchedNetwork {
    /**
    * ID of the Org VDC network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#network_id NsxtEdgegatewayL2VpnTunnel#network_id}
    */
    readonly networkId: string;
    /**
    * Tunnel ID of the network for the tunnel. Read-only for `SERVER` sessions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#tunnel_id NsxtEdgegatewayL2VpnTunnel#tunnel_id}
    */
    readonly tunnelId?: number;
}
export declare function nsxtEdgegatewayL2VpnTunnelStretchedNetworkToTerraform(struct?: NsxtEdgegatewayL2VpnTunnelStretchedNetwork | cdktf.IResolvable): any;
export declare function nsxtEdgegatewayL2VpnTunnelStretchedNetworkToHclTerraform(struct?: NsxtEdgegatewayL2VpnTunnelStretchedNetwork | cdktf.IResolvable): any;
export declare class NsxtEdgegatewayL2VpnTunnelStretchedNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewayL2VpnTunnelStretchedNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewayL2VpnTunnelStretchedNetwork | cdktf.IResolvable | undefined);
    private _networkId?;
    get networkId(): string;
    set networkId(value: string);
    get networkIdInput(): string | undefined;
    private _tunnelId?;
    get tunnelId(): number;
    set tunnelId(value: number);
    resetTunnelId(): void;
    get tunnelIdInput(): number | undefined;
}
export declare class NsxtEdgegatewayL2VpnTunnelStretchedNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewayL2VpnTunnelStretchedNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewayL2VpnTunnelStretchedNetworkOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel vcd_nsxt_edgegateway_l2_vpn_tunnel}
*/
export declare class NsxtEdgegatewayL2VpnTunnel extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_l2_vpn_tunnel";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayL2VpnTunnel resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayL2VpnTunnel to import
    * @param importFromId The id of the existing NsxtEdgegatewayL2VpnTunnel that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayL2VpnTunnel to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_l2_vpn_tunnel vcd_nsxt_edgegateway_l2_vpn_tunnel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayL2VpnTunnelConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayL2VpnTunnelConfig);
    private _connectorInitiationMode?;
    get connectorInitiationMode(): string;
    set connectorInitiationMode(value: string);
    resetConnectorInitiationMode(): void;
    get connectorInitiationModeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _localEndpointIp?;
    get localEndpointIp(): string;
    set localEndpointIp(value: string);
    get localEndpointIpInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _peerCode?;
    get peerCode(): string;
    set peerCode(value: string);
    resetPeerCode(): void;
    get peerCodeInput(): string | undefined;
    private _preSharedKey?;
    get preSharedKey(): string;
    set preSharedKey(value: string);
    resetPreSharedKey(): void;
    get preSharedKeyInput(): string | undefined;
    private _remoteEndpointIp?;
    get remoteEndpointIp(): string;
    set remoteEndpointIp(value: string);
    get remoteEndpointIpInput(): string | undefined;
    private _sessionMode?;
    get sessionMode(): string;
    set sessionMode(value: string);
    get sessionModeInput(): string | undefined;
    private _tunnelInterface?;
    get tunnelInterface(): string;
    set tunnelInterface(value: string);
    resetTunnelInterface(): void;
    get tunnelInterfaceInput(): string | undefined;
    private _stretchedNetwork;
    get stretchedNetwork(): NsxtEdgegatewayL2VpnTunnelStretchedNetworkList;
    putStretchedNetwork(value: NsxtEdgegatewayL2VpnTunnelStretchedNetwork[] | cdktf.IResolvable): void;
    resetStretchedNetwork(): void;
    get stretchedNetworkInput(): cdktf.IResolvable | NsxtEdgegatewayL2VpnTunnelStretchedNetwork[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
