import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayRateLimitingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edge gateway ID for Rate limiting (QoS) configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#edge_gateway_id NsxtEdgegatewayRateLimiting#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Egress profile ID for Rate limiting (QoS) configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#egress_profile_id NsxtEdgegatewayRateLimiting#egress_profile_id}
    */
    readonly egressProfileId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#id NsxtEdgegatewayRateLimiting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Ingress profile ID for Rate limiting (QoS) configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#ingress_profile_id NsxtEdgegatewayRateLimiting#ingress_profile_id}
    */
    readonly ingressProfileId?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#org NsxtEdgegatewayRateLimiting#org}
    */
    readonly org?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting vcd_nsxt_edgegateway_rate_limiting}
*/
export declare class NsxtEdgegatewayRateLimiting extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_rate_limiting";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayRateLimiting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayRateLimiting to import
    * @param importFromId The id of the existing NsxtEdgegatewayRateLimiting that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayRateLimiting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_rate_limiting vcd_nsxt_edgegateway_rate_limiting} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayRateLimitingConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayRateLimitingConfig);
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _egressProfileId?;
    get egressProfileId(): string;
    set egressProfileId(value: string);
    resetEgressProfileId(): void;
    get egressProfileIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ingressProfileId?;
    get ingressProfileId(): string;
    set ingressProfileId(value: string);
    resetIngressProfileId(): void;
    get ingressProfileIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
