import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayStaticRouteConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of Static Route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#description NsxtEdgegatewayStaticRoute#description}
    */
    readonly description?: string;
    /**
    * Edge gateway ID for Static Route configuration
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#edge_gateway_id NsxtEdgegatewayStaticRoute#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#id NsxtEdgegatewayStaticRoute#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of Static Route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#name NsxtEdgegatewayStaticRoute#name}
    */
    readonly name: string;
    /**
    * Network CIDR (e.g. 192.168.1.1/24) for Static Route
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#network_cidr NsxtEdgegatewayStaticRoute#network_cidr}
    */
    readonly networkCidr: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#org NsxtEdgegatewayStaticRoute#org}
    */
    readonly org?: string;
    /**
    * next_hop block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#next_hop NsxtEdgegatewayStaticRoute#next_hop}
    */
    readonly nextHop: NsxtEdgegatewayStaticRouteNextHop[] | cdktf.IResolvable;
}
export interface NsxtEdgegatewayStaticRouteNextHopScope {
    /**
    * ID of Scope element
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#id NsxtEdgegatewayStaticRoute#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Scope type - One of 'NETWORK', 'SYSTEM_OWNED'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#type NsxtEdgegatewayStaticRoute#type}
    */
    readonly type: string;
}
export declare function nsxtEdgegatewayStaticRouteNextHopScopeToTerraform(struct?: NsxtEdgegatewayStaticRouteNextHopScopeOutputReference | NsxtEdgegatewayStaticRouteNextHopScope): any;
export declare function nsxtEdgegatewayStaticRouteNextHopScopeToHclTerraform(struct?: NsxtEdgegatewayStaticRouteNextHopScopeOutputReference | NsxtEdgegatewayStaticRouteNextHopScope): any;
export declare class NsxtEdgegatewayStaticRouteNextHopScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtEdgegatewayStaticRouteNextHopScope | undefined;
    set internalValue(value: NsxtEdgegatewayStaticRouteNextHopScope | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get name(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface NsxtEdgegatewayStaticRouteNextHop {
    /**
    * Admin distance of next hop
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#admin_distance NsxtEdgegatewayStaticRoute#admin_distance}
    */
    readonly adminDistance: number;
    /**
    * IP Address of next hop
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#ip_address NsxtEdgegatewayStaticRoute#ip_address}
    */
    readonly ipAddress: string;
    /**
    * scope block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#scope NsxtEdgegatewayStaticRoute#scope}
    */
    readonly scope?: NsxtEdgegatewayStaticRouteNextHopScope;
}
export declare function nsxtEdgegatewayStaticRouteNextHopToTerraform(struct?: NsxtEdgegatewayStaticRouteNextHop | cdktf.IResolvable): any;
export declare function nsxtEdgegatewayStaticRouteNextHopToHclTerraform(struct?: NsxtEdgegatewayStaticRouteNextHop | cdktf.IResolvable): any;
export declare class NsxtEdgegatewayStaticRouteNextHopOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewayStaticRouteNextHop | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewayStaticRouteNextHop | cdktf.IResolvable | undefined);
    private _adminDistance?;
    get adminDistance(): number;
    set adminDistance(value: number);
    get adminDistanceInput(): number | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    private _scope;
    get scope(): NsxtEdgegatewayStaticRouteNextHopScopeOutputReference;
    putScope(value: NsxtEdgegatewayStaticRouteNextHopScope): void;
    resetScope(): void;
    get scopeInput(): NsxtEdgegatewayStaticRouteNextHopScope | undefined;
}
export declare class NsxtEdgegatewayStaticRouteNextHopList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewayStaticRouteNextHop[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewayStaticRouteNextHopOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route vcd_nsxt_edgegateway_static_route}
*/
export declare class NsxtEdgegatewayStaticRoute extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway_static_route";
    /**
    * Generates CDKTF code for importing a NsxtEdgegatewayStaticRoute resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegatewayStaticRoute to import
    * @param importFromId The id of the existing NsxtEdgegatewayStaticRoute that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegatewayStaticRoute to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway_static_route vcd_nsxt_edgegateway_static_route} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayStaticRouteConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayStaticRouteConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkCidr?;
    get networkCidr(): string;
    set networkCidr(value: string);
    get networkCidrInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _nextHop;
    get nextHop(): NsxtEdgegatewayStaticRouteNextHopList;
    putNextHop(value: NsxtEdgegatewayStaticRouteNextHop[] | cdktf.IResolvable): void;
    get nextHopInput(): cdktf.IResolvable | NsxtEdgegatewayStaticRouteNextHop[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
