import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtEdgegatewayConfig extends cdktf.TerraformMetaArguments {
    /**
    * Dedicating the External Network will enable Route Advertisement for this Edge Gateway.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#dedicate_external_network NsxtEdgegateway#dedicate_external_network}
    */
    readonly dedicateExternalNetwork?: boolean | cdktf.IResolvable;
    /**
    * Edge Gateway description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#description NsxtEdgegateway#description}
    */
    readonly description?: string;
    /**
    * Select specific NSX-T Edge Cluster. Will be inherited from external network if not specified
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#edge_cluster_id NsxtEdgegateway#edge_cluster_id}
    */
    readonly edgeClusterId?: string;
    /**
    * External network ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#external_network_id NsxtEdgegateway#external_network_id}
    */
    readonly externalNetworkId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#id NsxtEdgegateway#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Edge Gateway name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#name NsxtEdgegateway#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#org NsxtEdgegateway#org}
    */
    readonly org?: string;
    /**
    * ID of VDC or VDC Group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#owner_id NsxtEdgegateway#owner_id}
    */
    readonly ownerId?: string;
    /**
    * Optional ID of starting VDC if the 'owner_id' is a VDC Group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#starting_vdc_id NsxtEdgegateway#starting_vdc_id}
    */
    readonly startingVdcId?: string;
    /**
    * Total number of IP addresses allocated for this gateway from Tier0 uplink. Can be set with 'subnet_with_total_ip_count' definitions only
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#total_allocated_ip_count NsxtEdgegateway#total_allocated_ip_count}
    */
    readonly totalAllocatedIpCount?: number;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#vdc NsxtEdgegateway#vdc}
    */
    readonly vdc?: string;
    /**
    * external_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#external_network NsxtEdgegateway#external_network}
    */
    readonly externalNetwork?: NsxtEdgegatewayExternalNetwork[] | cdktf.IResolvable;
    /**
    * subnet block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#subnet NsxtEdgegateway#subnet}
    */
    readonly subnet?: NsxtEdgegatewaySubnet[] | cdktf.IResolvable;
    /**
    * subnet_with_ip_count block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#subnet_with_ip_count NsxtEdgegateway#subnet_with_ip_count}
    */
    readonly subnetWithIpCount?: NsxtEdgegatewaySubnetWithIpCount[] | cdktf.IResolvable;
    /**
    * subnet_with_total_ip_count block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#subnet_with_total_ip_count NsxtEdgegateway#subnet_with_total_ip_count}
    */
    readonly subnetWithTotalIpCount?: NsxtEdgegatewaySubnetWithTotalIpCount[] | cdktf.IResolvable;
}
export interface NsxtEdgegatewayExternalNetwork {
    /**
    * Number of allocated IPs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#allocated_ip_count NsxtEdgegateway#allocated_ip_count}
    */
    readonly allocatedIpCount: number;
    /**
    * NSX-T Segment backed External Network ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#external_network_id NsxtEdgegateway#external_network_id}
    */
    readonly externalNetworkId: string;
    /**
    * Gateway IP Address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#gateway NsxtEdgegateway#gateway}
    */
    readonly gateway: string;
    /**
    * Prefix length for a subnet (e.g. 24)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#prefix_length NsxtEdgegateway#prefix_length}
    */
    readonly prefixLength: number;
    /**
    * Primary IP address for the Edge Gateway - will be auto-assigned if not defined
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#primary_ip NsxtEdgegateway#primary_ip}
    */
    readonly primaryIp?: string;
}
export declare function nsxtEdgegatewayExternalNetworkToTerraform(struct?: NsxtEdgegatewayExternalNetwork | cdktf.IResolvable): any;
export declare function nsxtEdgegatewayExternalNetworkToHclTerraform(struct?: NsxtEdgegatewayExternalNetwork | cdktf.IResolvable): any;
export declare class NsxtEdgegatewayExternalNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewayExternalNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewayExternalNetwork | cdktf.IResolvable | undefined);
    private _allocatedIpCount?;
    get allocatedIpCount(): number;
    set allocatedIpCount(value: number);
    get allocatedIpCountInput(): number | undefined;
    private _externalNetworkId?;
    get externalNetworkId(): string;
    set externalNetworkId(value: string);
    get externalNetworkIdInput(): string | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): number;
    set prefixLength(value: number);
    get prefixLengthInput(): number | undefined;
    private _primaryIp?;
    get primaryIp(): string;
    set primaryIp(value: string);
    resetPrimaryIp(): void;
    get primaryIpInput(): string | undefined;
}
export declare class NsxtEdgegatewayExternalNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewayExternalNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewayExternalNetworkOutputReference;
}
export interface NsxtEdgegatewaySubnetAllocatedIps {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#end_address NsxtEdgegateway#end_address}
    */
    readonly endAddress: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#start_address NsxtEdgegateway#start_address}
    */
    readonly startAddress: string;
}
export declare function nsxtEdgegatewaySubnetAllocatedIpsToTerraform(struct?: NsxtEdgegatewaySubnetAllocatedIps | cdktf.IResolvable): any;
export declare function nsxtEdgegatewaySubnetAllocatedIpsToHclTerraform(struct?: NsxtEdgegatewaySubnetAllocatedIps | cdktf.IResolvable): any;
export declare class NsxtEdgegatewaySubnetAllocatedIpsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewaySubnetAllocatedIps | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewaySubnetAllocatedIps | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NsxtEdgegatewaySubnetAllocatedIpsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewaySubnetAllocatedIps[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewaySubnetAllocatedIpsOutputReference;
}
export interface NsxtEdgegatewaySubnet {
    /**
    * Gateway address for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#gateway NsxtEdgegateway#gateway}
    */
    readonly gateway: string;
    /**
    * Prefix length for a subnet (e.g. 24)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#prefix_length NsxtEdgegateway#prefix_length}
    */
    readonly prefixLength: number;
    /**
    * Primary IP address for the edge gateway - will be auto-assigned if not defined
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#primary_ip NsxtEdgegateway#primary_ip}
    */
    readonly primaryIp?: string;
    /**
    * allocated_ips block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#allocated_ips NsxtEdgegateway#allocated_ips}
    */
    readonly allocatedIps?: NsxtEdgegatewaySubnetAllocatedIps[] | cdktf.IResolvable;
}
export declare function nsxtEdgegatewaySubnetToTerraform(struct?: NsxtEdgegatewaySubnet | cdktf.IResolvable): any;
export declare function nsxtEdgegatewaySubnetToHclTerraform(struct?: NsxtEdgegatewaySubnet | cdktf.IResolvable): any;
export declare class NsxtEdgegatewaySubnetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewaySubnet | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewaySubnet | cdktf.IResolvable | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): number;
    set prefixLength(value: number);
    get prefixLengthInput(): number | undefined;
    private _primaryIp?;
    get primaryIp(): string;
    set primaryIp(value: string);
    resetPrimaryIp(): void;
    get primaryIpInput(): string | undefined;
    private _allocatedIps;
    get allocatedIps(): NsxtEdgegatewaySubnetAllocatedIpsList;
    putAllocatedIps(value: NsxtEdgegatewaySubnetAllocatedIps[] | cdktf.IResolvable): void;
    resetAllocatedIps(): void;
    get allocatedIpsInput(): cdktf.IResolvable | NsxtEdgegatewaySubnetAllocatedIps[] | undefined;
}
export declare class NsxtEdgegatewaySubnetList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewaySubnet[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewaySubnetOutputReference;
}
export interface NsxtEdgegatewaySubnetWithIpCount {
    /**
    * Number of IP addresses to allocate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#allocated_ip_count NsxtEdgegateway#allocated_ip_count}
    */
    readonly allocatedIpCount: number;
    /**
    * Gateway address for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#gateway NsxtEdgegateway#gateway}
    */
    readonly gateway: string;
    /**
    * Prefix length for a subnet (e.g. 24)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#prefix_length NsxtEdgegateway#prefix_length}
    */
    readonly prefixLength: number;
    /**
    * Primary IP address for the edge gateway - will be auto-assigned if not defined
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#primary_ip NsxtEdgegateway#primary_ip}
    */
    readonly primaryIp?: string;
}
export declare function nsxtEdgegatewaySubnetWithIpCountToTerraform(struct?: NsxtEdgegatewaySubnetWithIpCount | cdktf.IResolvable): any;
export declare function nsxtEdgegatewaySubnetWithIpCountToHclTerraform(struct?: NsxtEdgegatewaySubnetWithIpCount | cdktf.IResolvable): any;
export declare class NsxtEdgegatewaySubnetWithIpCountOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewaySubnetWithIpCount | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewaySubnetWithIpCount | cdktf.IResolvable | undefined);
    private _allocatedIpCount?;
    get allocatedIpCount(): number;
    set allocatedIpCount(value: number);
    get allocatedIpCountInput(): number | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): number;
    set prefixLength(value: number);
    get prefixLengthInput(): number | undefined;
    private _primaryIp?;
    get primaryIp(): string;
    set primaryIp(value: string);
    resetPrimaryIp(): void;
    get primaryIpInput(): string | undefined;
}
export declare class NsxtEdgegatewaySubnetWithIpCountList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewaySubnetWithIpCount[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewaySubnetWithIpCountOutputReference;
}
export interface NsxtEdgegatewaySubnetWithTotalIpCount {
    /**
    * Gateway address for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#gateway NsxtEdgegateway#gateway}
    */
    readonly gateway: string;
    /**
    * Prefix length for a subnet (e.g. 24)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#prefix_length NsxtEdgegateway#prefix_length}
    */
    readonly prefixLength: number;
    /**
    * Primary IP address for the edge gateway - will be auto-assigned if not defined
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#primary_ip NsxtEdgegateway#primary_ip}
    */
    readonly primaryIp?: string;
}
export declare function nsxtEdgegatewaySubnetWithTotalIpCountToTerraform(struct?: NsxtEdgegatewaySubnetWithTotalIpCount | cdktf.IResolvable): any;
export declare function nsxtEdgegatewaySubnetWithTotalIpCountToHclTerraform(struct?: NsxtEdgegatewaySubnetWithTotalIpCount | cdktf.IResolvable): any;
export declare class NsxtEdgegatewaySubnetWithTotalIpCountOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtEdgegatewaySubnetWithTotalIpCount | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtEdgegatewaySubnetWithTotalIpCount | cdktf.IResolvable | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): number;
    set prefixLength(value: number);
    get prefixLengthInput(): number | undefined;
    private _primaryIp?;
    get primaryIp(): string;
    set primaryIp(value: string);
    resetPrimaryIp(): void;
    get primaryIpInput(): string | undefined;
}
export declare class NsxtEdgegatewaySubnetWithTotalIpCountList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtEdgegatewaySubnetWithTotalIpCount[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtEdgegatewaySubnetWithTotalIpCountOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway vcd_nsxt_edgegateway}
*/
export declare class NsxtEdgegateway extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_edgegateway";
    /**
    * Generates CDKTF code for importing a NsxtEdgegateway resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtEdgegateway to import
    * @param importFromId The id of the existing NsxtEdgegateway that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtEdgegateway to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_edgegateway vcd_nsxt_edgegateway} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtEdgegatewayConfig
    */
    constructor(scope: Construct, id: string, config: NsxtEdgegatewayConfig);
    private _dedicateExternalNetwork?;
    get dedicateExternalNetwork(): boolean | cdktf.IResolvable;
    set dedicateExternalNetwork(value: boolean | cdktf.IResolvable);
    resetDedicateExternalNetwork(): void;
    get dedicateExternalNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeClusterId?;
    get edgeClusterId(): string;
    set edgeClusterId(value: string);
    resetEdgeClusterId(): void;
    get edgeClusterIdInput(): string | undefined;
    get externalNetworkAllocatedIpCount(): number;
    private _externalNetworkId?;
    get externalNetworkId(): string;
    set externalNetworkId(value: string);
    get externalNetworkIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _ownerId?;
    get ownerId(): string;
    set ownerId(value: string);
    resetOwnerId(): void;
    get ownerIdInput(): string | undefined;
    get primaryIp(): string;
    private _startingVdcId?;
    get startingVdcId(): string;
    set startingVdcId(value: string);
    resetStartingVdcId(): void;
    get startingVdcIdInput(): string | undefined;
    private _totalAllocatedIpCount?;
    get totalAllocatedIpCount(): number;
    set totalAllocatedIpCount(value: number);
    resetTotalAllocatedIpCount(): void;
    get totalAllocatedIpCountInput(): number | undefined;
    get unusedIpCount(): number;
    get useIpSpaces(): cdktf.IResolvable;
    get usedIpCount(): number;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _externalNetwork;
    get externalNetwork(): NsxtEdgegatewayExternalNetworkList;
    putExternalNetwork(value: NsxtEdgegatewayExternalNetwork[] | cdktf.IResolvable): void;
    resetExternalNetwork(): void;
    get externalNetworkInput(): cdktf.IResolvable | NsxtEdgegatewayExternalNetwork[] | undefined;
    private _subnet;
    get subnet(): NsxtEdgegatewaySubnetList;
    putSubnet(value: NsxtEdgegatewaySubnet[] | cdktf.IResolvable): void;
    resetSubnet(): void;
    get subnetInput(): cdktf.IResolvable | NsxtEdgegatewaySubnet[] | undefined;
    private _subnetWithIpCount;
    get subnetWithIpCount(): NsxtEdgegatewaySubnetWithIpCountList;
    putSubnetWithIpCount(value: NsxtEdgegatewaySubnetWithIpCount[] | cdktf.IResolvable): void;
    resetSubnetWithIpCount(): void;
    get subnetWithIpCountInput(): cdktf.IResolvable | NsxtEdgegatewaySubnetWithIpCount[] | undefined;
    private _subnetWithTotalIpCount;
    get subnetWithTotalIpCount(): NsxtEdgegatewaySubnetWithTotalIpCountList;
    putSubnetWithTotalIpCount(value: NsxtEdgegatewaySubnetWithTotalIpCount[] | cdktf.IResolvable): void;
    resetSubnetWithTotalIpCount(): void;
    get subnetWithTotalIpCountInput(): cdktf.IResolvable | NsxtEdgegatewaySubnetWithTotalIpCount[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
