import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtIpsecVpnTunnelConfig extends cdktf.TerraformMetaArguments {
    /**
    * One of 'PSK' (default), 'CERTIFICATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#authentication_mode NsxtIpsecVpnTunnel#authentication_mode}
    */
    readonly authenticationMode?: string;
    /**
    * Optional CA certificate ID to use for authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ca_certificate_id NsxtIpsecVpnTunnel#ca_certificate_id}
    */
    readonly caCertificateId?: string;
    /**
    * Optional certificate ID to use for authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#certificate_id NsxtIpsecVpnTunnel#certificate_id}
    */
    readonly certificateId?: string;
    /**
    * Description IP Sec VPN Tunnel
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#description NsxtIpsecVpnTunnel#description}
    */
    readonly description?: string;
    /**
    * Edge gateway name in which IP Sec VPN configuration is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#edge_gateway_id NsxtIpsecVpnTunnel#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Enables or disables this configuration (default true)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#enabled NsxtIpsecVpnTunnel#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#id NsxtIpsecVpnTunnel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IPv4 Address for the endpoint. This has to be a sub-allocated IP on the Edge Gateway.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#local_ip_address NsxtIpsecVpnTunnel#local_ip_address}
    */
    readonly localIpAddress: string;
    /**
    * Set of local networks in CIDR format. At least one value is required
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#local_networks NsxtIpsecVpnTunnel#local_networks}
    */
    readonly localNetworks: string[];
    /**
    * Sets whether logging for the tunnel is enabled or not. (default - false)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#logging NsxtIpsecVpnTunnel#logging}
    */
    readonly logging?: boolean | cdktf.IResolvable;
    /**
    * Name of IP Sec VPN Tunnel
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#name NsxtIpsecVpnTunnel#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#org NsxtIpsecVpnTunnel#org}
    */
    readonly org?: string;
    /**
    * Pre-Shared Key (PSK)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#pre_shared_key NsxtIpsecVpnTunnel#pre_shared_key}
    */
    readonly preSharedKey: string;
    /**
    * Custom remote ID of the peer site. 'remote_ip_address' is used by default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#remote_id NsxtIpsecVpnTunnel#remote_id}
    */
    readonly remoteId?: string;
    /**
    * Public IPv4 Address of the remote device terminating the VPN connection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#remote_ip_address NsxtIpsecVpnTunnel#remote_ip_address}
    */
    readonly remoteIpAddress: string;
    /**
    * Set of remote networks in CIDR format. Leaving it empty is interpreted as 0.0.0.0/0
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#remote_networks NsxtIpsecVpnTunnel#remote_networks}
    */
    readonly remoteNetworks?: string[];
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#vdc NsxtIpsecVpnTunnel#vdc}
    */
    readonly vdc?: string;
    /**
    * security_profile_customization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#security_profile_customization NsxtIpsecVpnTunnel#security_profile_customization}
    */
    readonly securityProfileCustomization?: NsxtIpsecVpnTunnelSecurityProfileCustomization;
}
export interface NsxtIpsecVpnTunnelSecurityProfileCustomization {
    /**
    * Value in seconds of dead probe detection interval. Minimum is 3 seconds and the maximum is 60 seconds
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#dpd_probe_internal NsxtIpsecVpnTunnel#dpd_probe_internal}
    */
    readonly dpdProbeInternal?: number;
    /**
    * Diffie-Hellman groups to be used if Perfect Forward Secrecy is enabled. One of GROUP2, GROUP5, GROUP14, GROUP15, GROUP16, GROUP19, GROUP20, GROUP21
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ike_dh_groups NsxtIpsecVpnTunnel#ike_dh_groups}
    */
    readonly ikeDhGroups: string[];
    /**
    * Secure hashing algorithms to use during the IKE negotiation. One of SHA1, SHA2_256, SHA2_384, SHA2_512
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ike_digest_algorithms NsxtIpsecVpnTunnel#ike_digest_algorithms}
    */
    readonly ikeDigestAlgorithms?: string[];
    /**
    * Encryption algorithms. One of SHA1, SHA2_256, SHA2_384, SHA2_512
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ike_encryption_algorithms NsxtIpsecVpnTunnel#ike_encryption_algorithms}
    */
    readonly ikeEncryptionAlgorithms: string[];
    /**
    * Security Association life time (in seconds). It is number of seconds before the IPsec tunnel needs to reestablish
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ike_sa_lifetime NsxtIpsecVpnTunnel#ike_sa_lifetime}
    */
    readonly ikeSaLifetime?: number;
    /**
    * IKE version one of IKE_V1, IKE_V2, IKE_FLEX
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#ike_version NsxtIpsecVpnTunnel#ike_version}
    */
    readonly ikeVersion: string;
    /**
    * Policy for handling defragmentation bit. One of COPY, CLEAR
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_df_policy NsxtIpsecVpnTunnel#tunnel_df_policy}
    */
    readonly tunnelDfPolicy?: string;
    /**
    * Diffie-Hellman groups to be used is PFS is enabled. One of GROUP2, GROUP5, GROUP14, GROUP15, GROUP16, GROUP19, GROUP20, GROUP21
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_dh_groups NsxtIpsecVpnTunnel#tunnel_dh_groups}
    */
    readonly tunnelDhGroups: string[];
    /**
    * Digest algorithms to be used for message digest. One of SHA1, SHA2_256, SHA2_384, SHA2_512
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_digest_algorithms NsxtIpsecVpnTunnel#tunnel_digest_algorithms}
    */
    readonly tunnelDigestAlgorithms?: string[];
    /**
    * Encryption algorithms to use in IPSec tunnel establishment. One of AES_128, AES_256, AES_GCM_128, AES_GCM_192, AES_GCM_256, NO_ENCRYPTION_AUTH_AES_GMAC_128, NO_ENCRYPTION_AUTH_AES_GMAC_192, NO_ENCRYPTION_AUTH_AES_GMAC_256, NO_ENCRYPTION
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_encryption_algorithms NsxtIpsecVpnTunnel#tunnel_encryption_algorithms}
    */
    readonly tunnelEncryptionAlgorithms: string[];
    /**
    * Perfect Forward Secrecy Enabled or Disabled. Default (enabled)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_pfs_enabled NsxtIpsecVpnTunnel#tunnel_pfs_enabled}
    */
    readonly tunnelPfsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Security Association life time (in seconds)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#tunnel_sa_lifetime NsxtIpsecVpnTunnel#tunnel_sa_lifetime}
    */
    readonly tunnelSaLifetime?: number;
}
export declare function nsxtIpsecVpnTunnelSecurityProfileCustomizationToTerraform(struct?: NsxtIpsecVpnTunnelSecurityProfileCustomizationOutputReference | NsxtIpsecVpnTunnelSecurityProfileCustomization): any;
export declare function nsxtIpsecVpnTunnelSecurityProfileCustomizationToHclTerraform(struct?: NsxtIpsecVpnTunnelSecurityProfileCustomizationOutputReference | NsxtIpsecVpnTunnelSecurityProfileCustomization): any;
export declare class NsxtIpsecVpnTunnelSecurityProfileCustomizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtIpsecVpnTunnelSecurityProfileCustomization | undefined;
    set internalValue(value: NsxtIpsecVpnTunnelSecurityProfileCustomization | undefined);
    private _dpdProbeInternal?;
    get dpdProbeInternal(): number;
    set dpdProbeInternal(value: number);
    resetDpdProbeInternal(): void;
    get dpdProbeInternalInput(): number | undefined;
    private _ikeDhGroups?;
    get ikeDhGroups(): string[];
    set ikeDhGroups(value: string[]);
    get ikeDhGroupsInput(): string[] | undefined;
    private _ikeDigestAlgorithms?;
    get ikeDigestAlgorithms(): string[];
    set ikeDigestAlgorithms(value: string[]);
    resetIkeDigestAlgorithms(): void;
    get ikeDigestAlgorithmsInput(): string[] | undefined;
    private _ikeEncryptionAlgorithms?;
    get ikeEncryptionAlgorithms(): string[];
    set ikeEncryptionAlgorithms(value: string[]);
    get ikeEncryptionAlgorithmsInput(): string[] | undefined;
    private _ikeSaLifetime?;
    get ikeSaLifetime(): number;
    set ikeSaLifetime(value: number);
    resetIkeSaLifetime(): void;
    get ikeSaLifetimeInput(): number | undefined;
    private _ikeVersion?;
    get ikeVersion(): string;
    set ikeVersion(value: string);
    get ikeVersionInput(): string | undefined;
    private _tunnelDfPolicy?;
    get tunnelDfPolicy(): string;
    set tunnelDfPolicy(value: string);
    resetTunnelDfPolicy(): void;
    get tunnelDfPolicyInput(): string | undefined;
    private _tunnelDhGroups?;
    get tunnelDhGroups(): string[];
    set tunnelDhGroups(value: string[]);
    get tunnelDhGroupsInput(): string[] | undefined;
    private _tunnelDigestAlgorithms?;
    get tunnelDigestAlgorithms(): string[];
    set tunnelDigestAlgorithms(value: string[]);
    resetTunnelDigestAlgorithms(): void;
    get tunnelDigestAlgorithmsInput(): string[] | undefined;
    private _tunnelEncryptionAlgorithms?;
    get tunnelEncryptionAlgorithms(): string[];
    set tunnelEncryptionAlgorithms(value: string[]);
    get tunnelEncryptionAlgorithmsInput(): string[] | undefined;
    private _tunnelPfsEnabled?;
    get tunnelPfsEnabled(): boolean | cdktf.IResolvable;
    set tunnelPfsEnabled(value: boolean | cdktf.IResolvable);
    resetTunnelPfsEnabled(): void;
    get tunnelPfsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _tunnelSaLifetime?;
    get tunnelSaLifetime(): number;
    set tunnelSaLifetime(value: number);
    resetTunnelSaLifetime(): void;
    get tunnelSaLifetimeInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel vcd_nsxt_ipsec_vpn_tunnel}
*/
export declare class NsxtIpsecVpnTunnel extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_ipsec_vpn_tunnel";
    /**
    * Generates CDKTF code for importing a NsxtIpsecVpnTunnel resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtIpsecVpnTunnel to import
    * @param importFromId The id of the existing NsxtIpsecVpnTunnel that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtIpsecVpnTunnel to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_ipsec_vpn_tunnel vcd_nsxt_ipsec_vpn_tunnel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtIpsecVpnTunnelConfig
    */
    constructor(scope: Construct, id: string, config: NsxtIpsecVpnTunnelConfig);
    private _authenticationMode?;
    get authenticationMode(): string;
    set authenticationMode(value: string);
    resetAuthenticationMode(): void;
    get authenticationModeInput(): string | undefined;
    private _caCertificateId?;
    get caCertificateId(): string;
    set caCertificateId(value: string);
    resetCaCertificateId(): void;
    get caCertificateIdInput(): string | undefined;
    private _certificateId?;
    get certificateId(): string;
    set certificateId(value: string);
    resetCertificateId(): void;
    get certificateIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get ikeFailReason(): string;
    get ikeServiceStatus(): string;
    private _localIpAddress?;
    get localIpAddress(): string;
    set localIpAddress(value: string);
    get localIpAddressInput(): string | undefined;
    private _localNetworks?;
    get localNetworks(): string[];
    set localNetworks(value: string[]);
    get localNetworksInput(): string[] | undefined;
    private _logging?;
    get logging(): boolean | cdktf.IResolvable;
    set logging(value: boolean | cdktf.IResolvable);
    resetLogging(): void;
    get loggingInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _preSharedKey?;
    get preSharedKey(): string;
    set preSharedKey(value: string);
    get preSharedKeyInput(): string | undefined;
    private _remoteId?;
    get remoteId(): string;
    set remoteId(value: string);
    resetRemoteId(): void;
    get remoteIdInput(): string | undefined;
    private _remoteIpAddress?;
    get remoteIpAddress(): string;
    set remoteIpAddress(value: string);
    get remoteIpAddressInput(): string | undefined;
    private _remoteNetworks?;
    get remoteNetworks(): string[];
    set remoteNetworks(value: string[]);
    resetRemoteNetworks(): void;
    get remoteNetworksInput(): string[] | undefined;
    get securityProfile(): string;
    get status(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _securityProfileCustomization;
    get securityProfileCustomization(): NsxtIpsecVpnTunnelSecurityProfileCustomizationOutputReference;
    putSecurityProfileCustomization(value: NsxtIpsecVpnTunnelSecurityProfileCustomization): void;
    resetSecurityProfileCustomization(): void;
    get securityProfileCustomizationInput(): NsxtIpsecVpnTunnelSecurityProfileCustomization | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
