import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtNatRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Application Port Profile to apply for this rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#app_port_profile_id NsxtNatRule#app_port_profile_id}
    */
    readonly appPortProfileId?: string;
    /**
    * Description of NAT rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#description NsxtNatRule#description}
    */
    readonly description?: string;
    /**
    * For DNAT only. Enter a port into which the DNAT rule is translating for the packets inbound to the virtual machines.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#dnat_external_port NsxtNatRule#dnat_external_port}
    */
    readonly dnatExternalPort?: string;
    /**
    * Edge gateway name in which NAT Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#edge_gateway_id NsxtNatRule#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Enables or disables this rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#enabled NsxtNatRule#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * IP address or CIDR of external network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#external_address NsxtNatRule#external_address}
    */
    readonly externalAddress?: string;
    /**
    * VCD 10.2.2+ Determines how the firewall matches the address during NATing if firewall stage is not skipped. One of 'MATCH_INTERNAL_ADDRESS', 'MATCH_EXTERNAL_ADDRESS', 'BYPASS'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#firewall_match NsxtNatRule#firewall_match}
    */
    readonly firewallMatch?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#id NsxtNatRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP address or CIDR of the virtual machines for which you are configuring NAT
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#internal_address NsxtNatRule#internal_address}
    */
    readonly internalAddress?: string;
    /**
    * Enable logging when this rule is applied
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#logging NsxtNatRule#logging}
    */
    readonly logging?: boolean | cdktf.IResolvable;
    /**
    * Name of NAT rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#name NsxtNatRule#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#org NsxtNatRule#org}
    */
    readonly org?: string;
    /**
    * VCD 10.2.2+ If an address has multiple NAT rules, the rule with the highest priority is applied. A lower value means a higher precedence for this rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#priority NsxtNatRule#priority}
    */
    readonly priority?: number;
    /**
    * Rule type - one of 'DNAT', 'NO_DNAT', 'SNAT', 'NO_SNAT', 'REFLEXIVE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#rule_type NsxtNatRule#rule_type}
    */
    readonly ruleType: string;
    /**
    * For SNAT only. If you want the rule to apply only for traffic to a specific domain, enter an IP address for this domain or an IP address range in CIDR format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#snat_destination_address NsxtNatRule#snat_destination_address}
    */
    readonly snatDestinationAddress?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#vdc NsxtNatRule#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule vcd_nsxt_nat_rule}
*/
export declare class NsxtNatRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_nat_rule";
    /**
    * Generates CDKTF code for importing a NsxtNatRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtNatRule to import
    * @param importFromId The id of the existing NsxtNatRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtNatRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_nat_rule vcd_nsxt_nat_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtNatRuleConfig
    */
    constructor(scope: Construct, id: string, config: NsxtNatRuleConfig);
    private _appPortProfileId?;
    get appPortProfileId(): string;
    set appPortProfileId(value: string);
    resetAppPortProfileId(): void;
    get appPortProfileIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dnatExternalPort?;
    get dnatExternalPort(): string;
    set dnatExternalPort(value: string);
    resetDnatExternalPort(): void;
    get dnatExternalPortInput(): string | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _externalAddress?;
    get externalAddress(): string;
    set externalAddress(value: string);
    resetExternalAddress(): void;
    get externalAddressInput(): string | undefined;
    private _firewallMatch?;
    get firewallMatch(): string;
    set firewallMatch(value: string);
    resetFirewallMatch(): void;
    get firewallMatchInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _internalAddress?;
    get internalAddress(): string;
    set internalAddress(value: string);
    resetInternalAddress(): void;
    get internalAddressInput(): string | undefined;
    private _logging?;
    get logging(): boolean | cdktf.IResolvable;
    set logging(value: boolean | cdktf.IResolvable);
    resetLogging(): void;
    get loggingInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    resetPriority(): void;
    get priorityInput(): number | undefined;
    private _ruleType?;
    get ruleType(): string;
    set ruleType(value: string);
    get ruleTypeInput(): string | undefined;
    private _snatDestinationAddress?;
    get snatDestinationAddress(): string;
    set snatDestinationAddress(value: string);
    resetSnatDestinationAddress(): void;
    get snatDestinationAddressInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
