import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtNetworkDhcpBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Binding type 'IPV4' or 'IPV6'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#binding_type NsxtNetworkDhcpBinding#binding_type}
    */
    readonly bindingType: string;
    /**
    * Description of DHCP binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#description NsxtNetworkDhcpBinding#description}
    */
    readonly description?: string;
    /**
    * The DNS server IPs to be assigned . 2 values maximum.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#dns_servers NsxtNetworkDhcpBinding#dns_servers}
    */
    readonly dnsServers?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#id NsxtNetworkDhcpBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IP address of the DHCP binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#ip_address NsxtNetworkDhcpBinding#ip_address}
    */
    readonly ipAddress: string;
    /**
    * Lease time in seconds. Minimum value is 60 seconds
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#lease_time NsxtNetworkDhcpBinding#lease_time}
    */
    readonly leaseTime: number;
    /**
    * MAC address of the DHCP binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#mac_address NsxtNetworkDhcpBinding#mac_address}
    */
    readonly macAddress: string;
    /**
    * Name of DHCP binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#name NsxtNetworkDhcpBinding#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#org NsxtNetworkDhcpBinding#org}
    */
    readonly org?: string;
    /**
    * Parent Org VDC network ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#org_network_id NsxtNetworkDhcpBinding#org_network_id}
    */
    readonly orgNetworkId: string;
    /**
    * dhcp_v4_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#dhcp_v4_config NsxtNetworkDhcpBinding#dhcp_v4_config}
    */
    readonly dhcpV4Config?: NsxtNetworkDhcpBindingDhcpV4Config;
    /**
    * dhcp_v6_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#dhcp_v6_config NsxtNetworkDhcpBinding#dhcp_v6_config}
    */
    readonly dhcpV6Config?: NsxtNetworkDhcpBindingDhcpV6Config;
}
export interface NsxtNetworkDhcpBindingDhcpV4Config {
    /**
    * IPv4 gateway address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#gateway_ip_address NsxtNetworkDhcpBinding#gateway_ip_address}
    */
    readonly gatewayIpAddress?: string;
    /**
    * Hostname for the DHCP client
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#hostname NsxtNetworkDhcpBinding#hostname}
    */
    readonly hostname?: string;
}
export declare function nsxtNetworkDhcpBindingDhcpV4ConfigToTerraform(struct?: NsxtNetworkDhcpBindingDhcpV4ConfigOutputReference | NsxtNetworkDhcpBindingDhcpV4Config): any;
export declare function nsxtNetworkDhcpBindingDhcpV4ConfigToHclTerraform(struct?: NsxtNetworkDhcpBindingDhcpV4ConfigOutputReference | NsxtNetworkDhcpBindingDhcpV4Config): any;
export declare class NsxtNetworkDhcpBindingDhcpV4ConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtNetworkDhcpBindingDhcpV4Config | undefined;
    set internalValue(value: NsxtNetworkDhcpBindingDhcpV4Config | undefined);
    private _gatewayIpAddress?;
    get gatewayIpAddress(): string;
    set gatewayIpAddress(value: string);
    resetGatewayIpAddress(): void;
    get gatewayIpAddressInput(): string | undefined;
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
}
export interface NsxtNetworkDhcpBindingDhcpV6Config {
    /**
    * Set of domain names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#domain_names NsxtNetworkDhcpBinding#domain_names}
    */
    readonly domainNames?: string[];
    /**
    * Set of SNTP servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#sntp_servers NsxtNetworkDhcpBinding#sntp_servers}
    */
    readonly sntpServers?: string[];
}
export declare function nsxtNetworkDhcpBindingDhcpV6ConfigToTerraform(struct?: NsxtNetworkDhcpBindingDhcpV6ConfigOutputReference | NsxtNetworkDhcpBindingDhcpV6Config): any;
export declare function nsxtNetworkDhcpBindingDhcpV6ConfigToHclTerraform(struct?: NsxtNetworkDhcpBindingDhcpV6ConfigOutputReference | NsxtNetworkDhcpBindingDhcpV6Config): any;
export declare class NsxtNetworkDhcpBindingDhcpV6ConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxtNetworkDhcpBindingDhcpV6Config | undefined;
    set internalValue(value: NsxtNetworkDhcpBindingDhcpV6Config | undefined);
    private _domainNames?;
    get domainNames(): string[];
    set domainNames(value: string[]);
    resetDomainNames(): void;
    get domainNamesInput(): string[] | undefined;
    private _sntpServers?;
    get sntpServers(): string[];
    set sntpServers(value: string[]);
    resetSntpServers(): void;
    get sntpServersInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding vcd_nsxt_network_dhcp_binding}
*/
export declare class NsxtNetworkDhcpBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_network_dhcp_binding";
    /**
    * Generates CDKTF code for importing a NsxtNetworkDhcpBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtNetworkDhcpBinding to import
    * @param importFromId The id of the existing NsxtNetworkDhcpBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtNetworkDhcpBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp_binding vcd_nsxt_network_dhcp_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtNetworkDhcpBindingConfig
    */
    constructor(scope: Construct, id: string, config: NsxtNetworkDhcpBindingConfig);
    private _bindingType?;
    get bindingType(): string;
    set bindingType(value: string);
    get bindingTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    resetDnsServers(): void;
    get dnsServersInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    get ipAddressInput(): string | undefined;
    private _leaseTime?;
    get leaseTime(): number;
    set leaseTime(value: number);
    get leaseTimeInput(): number | undefined;
    private _macAddress?;
    get macAddress(): string;
    set macAddress(value: string);
    get macAddressInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkId?;
    get orgNetworkId(): string;
    set orgNetworkId(value: string);
    get orgNetworkIdInput(): string | undefined;
    private _dhcpV4Config;
    get dhcpV4Config(): NsxtNetworkDhcpBindingDhcpV4ConfigOutputReference;
    putDhcpV4Config(value: NsxtNetworkDhcpBindingDhcpV4Config): void;
    resetDhcpV4Config(): void;
    get dhcpV4ConfigInput(): NsxtNetworkDhcpBindingDhcpV4Config | undefined;
    private _dhcpV6Config;
    get dhcpV6Config(): NsxtNetworkDhcpBindingDhcpV6ConfigOutputReference;
    putDhcpV6Config(value: NsxtNetworkDhcpBindingDhcpV6Config): void;
    resetDhcpV6Config(): void;
    get dhcpV6ConfigInput(): NsxtNetworkDhcpBindingDhcpV6Config | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
