import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtNetworkDhcpConfig extends cdktf.TerraformMetaArguments {
    /**
    * The DNS server IPs to be assigned by this DHCP service. 2 values maximum.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#dns_servers NsxtNetworkDhcp#dns_servers}
    */
    readonly dnsServers?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#id NsxtNetworkDhcp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Lease time in seconds
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#lease_time NsxtNetworkDhcp#lease_time}
    */
    readonly leaseTime?: number;
    /**
    * IP Address of DHCP server in network. Only applicable when mode=NETWORK
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#listener_ip_address NsxtNetworkDhcp#listener_ip_address}
    */
    readonly listenerIpAddress?: string;
    /**
    * DHCP mode. One of 'EDGE' (default), 'NETWORK', 'RELAY'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#mode NsxtNetworkDhcp#mode}
    */
    readonly mode?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#org NsxtNetworkDhcp#org}
    */
    readonly org?: string;
    /**
    * Parent Org VDC network ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#org_network_id NsxtNetworkDhcp#org_network_id}
    */
    readonly orgNetworkId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#vdc NsxtNetworkDhcp#vdc}
    */
    readonly vdc?: string;
    /**
    * pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#pool NsxtNetworkDhcp#pool}
    */
    readonly pool?: NsxtNetworkDhcpPool[] | cdktf.IResolvable;
}
export interface NsxtNetworkDhcpPool {
    /**
    * End address of DHCP pool IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#end_address NsxtNetworkDhcp#end_address}
    */
    readonly endAddress: string;
    /**
    * Start address of DHCP pool IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#start_address NsxtNetworkDhcp#start_address}
    */
    readonly startAddress: string;
}
export declare function nsxtNetworkDhcpPoolToTerraform(struct?: NsxtNetworkDhcpPool | cdktf.IResolvable): any;
export declare function nsxtNetworkDhcpPoolToHclTerraform(struct?: NsxtNetworkDhcpPool | cdktf.IResolvable): any;
export declare class NsxtNetworkDhcpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtNetworkDhcpPool | cdktf.IResolvable | undefined;
    set internalValue(value: NsxtNetworkDhcpPool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class NsxtNetworkDhcpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxtNetworkDhcpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtNetworkDhcpPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp vcd_nsxt_network_dhcp}
*/
export declare class NsxtNetworkDhcp extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_network_dhcp";
    /**
    * Generates CDKTF code for importing a NsxtNetworkDhcp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtNetworkDhcp to import
    * @param importFromId The id of the existing NsxtNetworkDhcp that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtNetworkDhcp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_dhcp vcd_nsxt_network_dhcp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtNetworkDhcpConfig
    */
    constructor(scope: Construct, id: string, config: NsxtNetworkDhcpConfig);
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    resetDnsServers(): void;
    get dnsServersInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _leaseTime?;
    get leaseTime(): number;
    set leaseTime(value: number);
    resetLeaseTime(): void;
    get leaseTimeInput(): number | undefined;
    private _listenerIpAddress?;
    get listenerIpAddress(): string;
    set listenerIpAddress(value: string);
    resetListenerIpAddress(): void;
    get listenerIpAddressInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkId?;
    get orgNetworkId(): string;
    set orgNetworkId(value: string);
    get orgNetworkIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _pool;
    get pool(): NsxtNetworkDhcpPoolList;
    putPool(value: NsxtNetworkDhcpPool[] | cdktf.IResolvable): void;
    resetPool(): void;
    get poolInput(): cdktf.IResolvable | NsxtNetworkDhcpPool[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
