import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtNetworkSegmentProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#id NsxtNetworkSegmentProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * NSX-T IP Discovery Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#ip_discovery_profile_id NsxtNetworkSegmentProfile#ip_discovery_profile_id}
    */
    readonly ipDiscoveryProfileId?: string;
    /**
    * NSX-T Mac Discovery Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#mac_discovery_profile_id NsxtNetworkSegmentProfile#mac_discovery_profile_id}
    */
    readonly macDiscoveryProfileId?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#org NsxtNetworkSegmentProfile#org}
    */
    readonly org?: string;
    /**
    * ID of the Organization Network that will have the segment profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#org_network_id NsxtNetworkSegmentProfile#org_network_id}
    */
    readonly orgNetworkId: string;
    /**
    * NSX-T QoS Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#qos_profile_id NsxtNetworkSegmentProfile#qos_profile_id}
    */
    readonly qosProfileId?: string;
    /**
    * Segment Profile Template ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#segment_profile_template_id NsxtNetworkSegmentProfile#segment_profile_template_id}
    */
    readonly segmentProfileTemplateId?: string;
    /**
    * NSX-T Segment Security Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#segment_security_profile_id NsxtNetworkSegmentProfile#segment_security_profile_id}
    */
    readonly segmentSecurityProfileId?: string;
    /**
    * NSX-T Spoof Guard Profile
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#spoof_guard_profile_id NsxtNetworkSegmentProfile#spoof_guard_profile_id}
    */
    readonly spoofGuardProfileId?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile vcd_nsxt_network_segment_profile}
*/
export declare class NsxtNetworkSegmentProfile extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_network_segment_profile";
    /**
    * Generates CDKTF code for importing a NsxtNetworkSegmentProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtNetworkSegmentProfile to import
    * @param importFromId The id of the existing NsxtNetworkSegmentProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtNetworkSegmentProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_network_segment_profile vcd_nsxt_network_segment_profile} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtNetworkSegmentProfileConfig
    */
    constructor(scope: Construct, id: string, config: NsxtNetworkSegmentProfileConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipDiscoveryProfileId?;
    get ipDiscoveryProfileId(): string;
    set ipDiscoveryProfileId(value: string);
    resetIpDiscoveryProfileId(): void;
    get ipDiscoveryProfileIdInput(): string | undefined;
    private _macDiscoveryProfileId?;
    get macDiscoveryProfileId(): string;
    set macDiscoveryProfileId(value: string);
    resetMacDiscoveryProfileId(): void;
    get macDiscoveryProfileIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkId?;
    get orgNetworkId(): string;
    set orgNetworkId(value: string);
    get orgNetworkIdInput(): string | undefined;
    private _qosProfileId?;
    get qosProfileId(): string;
    set qosProfileId(value: string);
    resetQosProfileId(): void;
    get qosProfileIdInput(): string | undefined;
    private _segmentProfileTemplateId?;
    get segmentProfileTemplateId(): string;
    set segmentProfileTemplateId(value: string);
    resetSegmentProfileTemplateId(): void;
    get segmentProfileTemplateIdInput(): string | undefined;
    get segmentProfileTemplateName(): string;
    private _segmentSecurityProfileId?;
    get segmentSecurityProfileId(): string;
    set segmentSecurityProfileId(value: string);
    resetSegmentSecurityProfileId(): void;
    get segmentSecurityProfileIdInput(): string | undefined;
    private _spoofGuardProfileId?;
    get spoofGuardProfileId(): string;
    set spoofGuardProfileId(value: string);
    resetSpoofGuardProfileId(): void;
    get spoofGuardProfileIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
