import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtRouteAdvertisementConfig extends cdktf.TerraformMetaArguments {
    /**
    * NSX-T Edge Gateway ID in which route advertisement is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#edge_gateway_id NsxtRouteAdvertisement#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Defines if route advertisement is active
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#enabled NsxtRouteAdvertisement#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#id NsxtRouteAdvertisement#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#org NsxtRouteAdvertisement#org}
    */
    readonly org?: string;
    /**
    * Set of subnets that will be advertised to Tier-0 gateway. Empty means none
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#subnets NsxtRouteAdvertisement#subnets}
    */
    readonly subnets?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement vcd_nsxt_route_advertisement}
*/
export declare class NsxtRouteAdvertisement extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_route_advertisement";
    /**
    * Generates CDKTF code for importing a NsxtRouteAdvertisement resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtRouteAdvertisement to import
    * @param importFromId The id of the existing NsxtRouteAdvertisement that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtRouteAdvertisement to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_route_advertisement vcd_nsxt_route_advertisement} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtRouteAdvertisementConfig
    */
    constructor(scope: Construct, id: string, config: NsxtRouteAdvertisementConfig);
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _subnets?;
    get subnets(): string[];
    set subnets(value: string[]);
    resetSubnets(): void;
    get subnetsInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
