import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxtSecurityGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Security Group description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#description NsxtSecurityGroup#description}
    */
    readonly description?: string;
    /**
    * Edge Gateway ID in which security group is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#edge_gateway_id NsxtSecurityGroup#edge_gateway_id}
    */
    readonly edgeGatewayId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#id NsxtSecurityGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Set of Org VDC network IDs attached to this security group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#member_org_network_ids NsxtSecurityGroup#member_org_network_ids}
    */
    readonly memberOrgNetworkIds?: string[];
    /**
    * Security Group name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#name NsxtSecurityGroup#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#org NsxtSecurityGroup#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#vdc NsxtSecurityGroup#vdc}
    */
    readonly vdc?: string;
}
export interface NsxtSecurityGroupMemberVms {
}
export declare function nsxtSecurityGroupMemberVmsToTerraform(struct?: NsxtSecurityGroupMemberVms): any;
export declare function nsxtSecurityGroupMemberVmsToHclTerraform(struct?: NsxtSecurityGroupMemberVms): any;
export declare class NsxtSecurityGroupMemberVmsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxtSecurityGroupMemberVms | undefined;
    set internalValue(value: NsxtSecurityGroupMemberVms | undefined);
    get vappId(): string;
    get vappName(): string;
    get vmId(): string;
    get vmName(): string;
}
export declare class NsxtSecurityGroupMemberVmsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxtSecurityGroupMemberVmsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group vcd_nsxt_security_group}
*/
export declare class NsxtSecurityGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxt_security_group";
    /**
    * Generates CDKTF code for importing a NsxtSecurityGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxtSecurityGroup to import
    * @param importFromId The id of the existing NsxtSecurityGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxtSecurityGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxt_security_group vcd_nsxt_security_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxtSecurityGroupConfig
    */
    constructor(scope: Construct, id: string, config: NsxtSecurityGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGatewayId?;
    get edgeGatewayId(): string;
    set edgeGatewayId(value: string);
    get edgeGatewayIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _memberOrgNetworkIds?;
    get memberOrgNetworkIds(): string[];
    set memberOrgNetworkIds(value: string[]);
    resetMemberOrgNetworkIds(): void;
    get memberOrgNetworkIdsInput(): string[] | undefined;
    private _memberVms;
    get memberVms(): NsxtSecurityGroupMemberVmsList;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get ownerId(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
