import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxvDhcpRelayConfig extends cdktf.TerraformMetaArguments {
    /**
    * A set of IP domain names of DHCP servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#domain_names NsxvDhcpRelay#domain_names}
    */
    readonly domainNames?: string[];
    /**
    * Edge gateway name for DHCP relay settings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#edge_gateway NsxvDhcpRelay#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#id NsxvDhcpRelay#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of IP address of DHCP servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#ip_addresses NsxvDhcpRelay#ip_addresses}
    */
    readonly ipAddresses?: string[];
    /**
    * A set of IP set names which consist DHCP servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#ip_sets NsxvDhcpRelay#ip_sets}
    */
    readonly ipSets?: string[];
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#org NsxvDhcpRelay#org}
    */
    readonly org?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#vdc NsxvDhcpRelay#vdc}
    */
    readonly vdc?: string;
    /**
    * relay_agent block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#relay_agent NsxvDhcpRelay#relay_agent}
    */
    readonly relayAgent: NsxvDhcpRelayRelayAgent[] | cdktf.IResolvable;
}
export interface NsxvDhcpRelayRelayAgent {
    /**
    * Optional gateway IP address of org network which is to be used for relaying DHCP message to specified servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#gateway_ip_address NsxvDhcpRelay#gateway_ip_address}
    */
    readonly gatewayIpAddress?: string;
    /**
    * Org network which is to be used for relaying DHCP message to specified servers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#network_name NsxvDhcpRelay#network_name}
    */
    readonly networkName: string;
}
export declare function nsxvDhcpRelayRelayAgentToTerraform(struct?: NsxvDhcpRelayRelayAgent | cdktf.IResolvable): any;
export declare function nsxvDhcpRelayRelayAgentToHclTerraform(struct?: NsxvDhcpRelayRelayAgent | cdktf.IResolvable): any;
export declare class NsxvDhcpRelayRelayAgentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxvDhcpRelayRelayAgent | cdktf.IResolvable | undefined;
    set internalValue(value: NsxvDhcpRelayRelayAgent | cdktf.IResolvable | undefined);
    private _gatewayIpAddress?;
    get gatewayIpAddress(): string;
    set gatewayIpAddress(value: string);
    resetGatewayIpAddress(): void;
    get gatewayIpAddressInput(): string | undefined;
    private _networkName?;
    get networkName(): string;
    set networkName(value: string);
    get networkNameInput(): string | undefined;
}
export declare class NsxvDhcpRelayRelayAgentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxvDhcpRelayRelayAgent[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxvDhcpRelayRelayAgentOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay vcd_nsxv_dhcp_relay}
*/
export declare class NsxvDhcpRelay extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxv_dhcp_relay";
    /**
    * Generates CDKTF code for importing a NsxvDhcpRelay resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxvDhcpRelay to import
    * @param importFromId The id of the existing NsxvDhcpRelay that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxvDhcpRelay to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dhcp_relay vcd_nsxv_dhcp_relay} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxvDhcpRelayConfig
    */
    constructor(scope: Construct, id: string, config: NsxvDhcpRelayConfig);
    private _domainNames?;
    get domainNames(): string[];
    set domainNames(value: string[]);
    resetDomainNames(): void;
    get domainNamesInput(): string[] | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ipAddresses?;
    get ipAddresses(): string[];
    set ipAddresses(value: string[]);
    resetIpAddresses(): void;
    get ipAddressesInput(): string[] | undefined;
    private _ipSets?;
    get ipSets(): string[];
    set ipSets(value: string[]);
    resetIpSets(): void;
    get ipSetsInput(): string[] | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _relayAgent;
    get relayAgent(): NsxvDhcpRelayRelayAgentList;
    putRelayAgent(value: NsxvDhcpRelayRelayAgent[] | cdktf.IResolvable): void;
    get relayAgentInput(): cdktf.IResolvable | NsxvDhcpRelayRelayAgent[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
