import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxvDnatConfig extends cdktf.TerraformMetaArguments {
    /**
    * NAT rule description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#description NsxvDnat#description}
    */
    readonly description?: string;
    /**
    * Edge gateway name in which NAT Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#edge_gateway NsxvDnat#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Whether the rule should be enabled. Default 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#enabled NsxvDnat#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * ICMP type. Only supported when protocol is ICMP. One of `any`, `address-mask-request`, `address-mask-reply`, `destination-unreachable`, `echo-request`, `echo-reply`, `parameter-problem`, `redirect`, `router-advertisement`, `router-solicitation`, `source-quench`, `time-exceeded`, `timestamp-request`, `timestamp-reply`. Default `any`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#icmp_type NsxvDnat#icmp_type}
    */
    readonly icmpType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#id NsxvDnat#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether logging should be enabled for this rule. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#logging_enabled NsxvDnat#logging_enabled}
    */
    readonly loggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Org or external network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#network_name NsxvDnat#network_name}
    */
    readonly networkName: string;
    /**
    * Network type. One of 'ext', 'org'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#network_type NsxvDnat#network_type}
    */
    readonly networkType: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#org NsxvDnat#org}
    */
    readonly org?: string;
    /**
    * Original address or address range. This is the the destination address for DNAT rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#original_address NsxvDnat#original_address}
    */
    readonly originalAddress: string;
    /**
    * Original port. This is the destination port for DNAT rules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#original_port NsxvDnat#original_port}
    */
    readonly originalPort?: string;
    /**
    * Protocol. Such as 'tcp', 'udp', 'icmp', 'any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#protocol NsxvDnat#protocol}
    */
    readonly protocol?: string;
    /**
    * Optional. Allows to set custom rule tag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#rule_tag NsxvDnat#rule_tag}
    */
    readonly ruleTag?: number;
    /**
    * Read only. Possible values 'user', 'internal_high'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#rule_type NsxvDnat#rule_type}
    */
    readonly ruleType?: string;
    /**
    * Translated address or address range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#translated_address NsxvDnat#translated_address}
    */
    readonly translatedAddress?: string;
    /**
    * Translated port
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#translated_port NsxvDnat#translated_port}
    */
    readonly translatedPort?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#vdc NsxvDnat#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat vcd_nsxv_dnat}
*/
export declare class NsxvDnat extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxv_dnat";
    /**
    * Generates CDKTF code for importing a NsxvDnat resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxvDnat to import
    * @param importFromId The id of the existing NsxvDnat that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxvDnat to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_dnat vcd_nsxv_dnat} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxvDnatConfig
    */
    constructor(scope: Construct, id: string, config: NsxvDnatConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _icmpType?;
    get icmpType(): string;
    set icmpType(value: string);
    resetIcmpType(): void;
    get icmpTypeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _loggingEnabled?;
    get loggingEnabled(): boolean | cdktf.IResolvable;
    set loggingEnabled(value: boolean | cdktf.IResolvable);
    resetLoggingEnabled(): void;
    get loggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _networkName?;
    get networkName(): string;
    set networkName(value: string);
    get networkNameInput(): string | undefined;
    private _networkType?;
    get networkType(): string;
    set networkType(value: string);
    get networkTypeInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _originalAddress?;
    get originalAddress(): string;
    set originalAddress(value: string);
    get originalAddressInput(): string | undefined;
    private _originalPort?;
    get originalPort(): string;
    set originalPort(value: string);
    resetOriginalPort(): void;
    get originalPortInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _ruleTag?;
    get ruleTag(): number;
    set ruleTag(value: number);
    resetRuleTag(): void;
    get ruleTagInput(): number | undefined;
    private _ruleType?;
    get ruleType(): string;
    set ruleType(value: string);
    resetRuleType(): void;
    get ruleTypeInput(): string | undefined;
    private _translatedAddress?;
    get translatedAddress(): string;
    set translatedAddress(value: string);
    resetTranslatedAddress(): void;
    get translatedAddressInput(): string | undefined;
    private _translatedPort?;
    get translatedPort(): string;
    set translatedPort(value: string);
    resetTranslatedPort(): void;
    get translatedPortInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
