import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxvFirewallRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * This firewall rule will be inserted above the referred one
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#above_rule_id NsxvFirewallRule#above_rule_id}
    */
    readonly aboveRuleId?: string;
    /**
    * 'accept' or 'deny'. Default 'accept'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#action NsxvFirewallRule#action}
    */
    readonly action?: string;
    /**
    * Edge gateway name in which Firewall Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#edge_gateway NsxvFirewallRule#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Whether the rule should be enabled. Default 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#enabled NsxvFirewallRule#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#id NsxvFirewallRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether logging should be enabled for this rule. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#logging_enabled NsxvFirewallRule#logging_enabled}
    */
    readonly loggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Firewall rule name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#name NsxvFirewallRule#name}
    */
    readonly name?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#org NsxvFirewallRule#org}
    */
    readonly org?: string;
    /**
    * Optional. Allows to set custom rule tag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#rule_tag NsxvFirewallRule#rule_tag}
    */
    readonly ruleTag?: number;
    /**
    * Read only. Possible values 'user', 'internal_high'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#rule_type NsxvFirewallRule#rule_type}
    */
    readonly ruleType?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#vdc NsxvFirewallRule#vdc}
    */
    readonly vdc?: string;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#destination NsxvFirewallRule#destination}
    */
    readonly destination: NsxvFirewallRuleDestination;
    /**
    * service block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#service NsxvFirewallRule#service}
    */
    readonly service: NsxvFirewallRuleService[] | cdktf.IResolvable;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#source NsxvFirewallRule#source}
    */
    readonly source: NsxvFirewallRuleSource;
}
export interface NsxvFirewallRuleDestination {
    /**
    * Rule is applied to traffic going to any destinations except for the excluded destination. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#exclude NsxvFirewallRule#exclude}
    */
    readonly exclude?: boolean | cdktf.IResolvable;
    /**
    * 'vse', 'internal', 'external' or network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#gateway_interfaces NsxvFirewallRule#gateway_interfaces}
    */
    readonly gatewayInterfaces?: string[];
    /**
    * IP address, CIDR, an IP range, or the keyword 'any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#ip_addresses NsxvFirewallRule#ip_addresses}
    */
    readonly ipAddresses?: string[];
    /**
    * Set of IP set names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#ip_sets NsxvFirewallRule#ip_sets}
    */
    readonly ipSets?: string[];
    /**
    * Set of org network names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#org_networks NsxvFirewallRule#org_networks}
    */
    readonly orgNetworks?: string[];
    /**
    * Set of VM IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#vm_ids NsxvFirewallRule#vm_ids}
    */
    readonly vmIds?: string[];
}
export declare function nsxvFirewallRuleDestinationToTerraform(struct?: NsxvFirewallRuleDestinationOutputReference | NsxvFirewallRuleDestination): any;
export declare function nsxvFirewallRuleDestinationToHclTerraform(struct?: NsxvFirewallRuleDestinationOutputReference | NsxvFirewallRuleDestination): any;
export declare class NsxvFirewallRuleDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxvFirewallRuleDestination | undefined;
    set internalValue(value: NsxvFirewallRuleDestination | undefined);
    private _exclude?;
    get exclude(): boolean | cdktf.IResolvable;
    set exclude(value: boolean | cdktf.IResolvable);
    resetExclude(): void;
    get excludeInput(): boolean | cdktf.IResolvable | undefined;
    private _gatewayInterfaces?;
    get gatewayInterfaces(): string[];
    set gatewayInterfaces(value: string[]);
    resetGatewayInterfaces(): void;
    get gatewayInterfacesInput(): string[] | undefined;
    private _ipAddresses?;
    get ipAddresses(): string[];
    set ipAddresses(value: string[]);
    resetIpAddresses(): void;
    get ipAddressesInput(): string[] | undefined;
    private _ipSets?;
    get ipSets(): string[];
    set ipSets(value: string[]);
    resetIpSets(): void;
    get ipSetsInput(): string[] | undefined;
    private _orgNetworks?;
    get orgNetworks(): string[];
    set orgNetworks(value: string[]);
    resetOrgNetworks(): void;
    get orgNetworksInput(): string[] | undefined;
    private _vmIds?;
    get vmIds(): string[];
    set vmIds(value: string[]);
    resetVmIds(): void;
    get vmIdsInput(): string[] | undefined;
}
export interface NsxvFirewallRuleService {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#port NsxvFirewallRule#port}
    */
    readonly port?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#protocol NsxvFirewallRule#protocol}
    */
    readonly protocol: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#source_port NsxvFirewallRule#source_port}
    */
    readonly sourcePort?: string;
}
export declare function nsxvFirewallRuleServiceToTerraform(struct?: NsxvFirewallRuleService | cdktf.IResolvable): any;
export declare function nsxvFirewallRuleServiceToHclTerraform(struct?: NsxvFirewallRuleService | cdktf.IResolvable): any;
export declare class NsxvFirewallRuleServiceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NsxvFirewallRuleService | cdktf.IResolvable | undefined;
    set internalValue(value: NsxvFirewallRuleService | cdktf.IResolvable | undefined);
    private _port?;
    get port(): string;
    set port(value: string);
    resetPort(): void;
    get portInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _sourcePort?;
    get sourcePort(): string;
    set sourcePort(value: string);
    resetSourcePort(): void;
    get sourcePortInput(): string | undefined;
}
export declare class NsxvFirewallRuleServiceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NsxvFirewallRuleService[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NsxvFirewallRuleServiceOutputReference;
}
export interface NsxvFirewallRuleSource {
    /**
    * Rule is applied to traffic coming from all sources except for the excluded source. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#exclude NsxvFirewallRule#exclude}
    */
    readonly exclude?: boolean | cdktf.IResolvable;
    /**
    * 'vse', 'internal', 'external' or network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#gateway_interfaces NsxvFirewallRule#gateway_interfaces}
    */
    readonly gatewayInterfaces?: string[];
    /**
    * IP address, CIDR, an IP range, or the keyword 'any'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#ip_addresses NsxvFirewallRule#ip_addresses}
    */
    readonly ipAddresses?: string[];
    /**
    * Set of IP set names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#ip_sets NsxvFirewallRule#ip_sets}
    */
    readonly ipSets?: string[];
    /**
    * Set of org network names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#org_networks NsxvFirewallRule#org_networks}
    */
    readonly orgNetworks?: string[];
    /**
    * Set of VM IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#vm_ids NsxvFirewallRule#vm_ids}
    */
    readonly vmIds?: string[];
}
export declare function nsxvFirewallRuleSourceToTerraform(struct?: NsxvFirewallRuleSourceOutputReference | NsxvFirewallRuleSource): any;
export declare function nsxvFirewallRuleSourceToHclTerraform(struct?: NsxvFirewallRuleSourceOutputReference | NsxvFirewallRuleSource): any;
export declare class NsxvFirewallRuleSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NsxvFirewallRuleSource | undefined;
    set internalValue(value: NsxvFirewallRuleSource | undefined);
    private _exclude?;
    get exclude(): boolean | cdktf.IResolvable;
    set exclude(value: boolean | cdktf.IResolvable);
    resetExclude(): void;
    get excludeInput(): boolean | cdktf.IResolvable | undefined;
    private _gatewayInterfaces?;
    get gatewayInterfaces(): string[];
    set gatewayInterfaces(value: string[]);
    resetGatewayInterfaces(): void;
    get gatewayInterfacesInput(): string[] | undefined;
    private _ipAddresses?;
    get ipAddresses(): string[];
    set ipAddresses(value: string[]);
    resetIpAddresses(): void;
    get ipAddressesInput(): string[] | undefined;
    private _ipSets?;
    get ipSets(): string[];
    set ipSets(value: string[]);
    resetIpSets(): void;
    get ipSetsInput(): string[] | undefined;
    private _orgNetworks?;
    get orgNetworks(): string[];
    set orgNetworks(value: string[]);
    resetOrgNetworks(): void;
    get orgNetworksInput(): string[] | undefined;
    private _vmIds?;
    get vmIds(): string[];
    set vmIds(value: string[]);
    resetVmIds(): void;
    get vmIdsInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule vcd_nsxv_firewall_rule}
*/
export declare class NsxvFirewallRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxv_firewall_rule";
    /**
    * Generates CDKTF code for importing a NsxvFirewallRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxvFirewallRule to import
    * @param importFromId The id of the existing NsxvFirewallRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxvFirewallRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_firewall_rule vcd_nsxv_firewall_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxvFirewallRuleConfig
    */
    constructor(scope: Construct, id: string, config: NsxvFirewallRuleConfig);
    private _aboveRuleId?;
    get aboveRuleId(): string;
    set aboveRuleId(value: string);
    resetAboveRuleId(): void;
    get aboveRuleIdInput(): string | undefined;
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _loggingEnabled?;
    get loggingEnabled(): boolean | cdktf.IResolvable;
    set loggingEnabled(value: boolean | cdktf.IResolvable);
    resetLoggingEnabled(): void;
    get loggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _ruleTag?;
    get ruleTag(): number;
    set ruleTag(value: number);
    resetRuleTag(): void;
    get ruleTagInput(): number | undefined;
    private _ruleType?;
    get ruleType(): string;
    set ruleType(value: string);
    resetRuleType(): void;
    get ruleTypeInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _destination;
    get destination(): NsxvFirewallRuleDestinationOutputReference;
    putDestination(value: NsxvFirewallRuleDestination): void;
    get destinationInput(): NsxvFirewallRuleDestination | undefined;
    private _service;
    get service(): NsxvFirewallRuleServiceList;
    putService(value: NsxvFirewallRuleService[] | cdktf.IResolvable): void;
    get serviceInput(): cdktf.IResolvable | NsxvFirewallRuleService[] | undefined;
    private _source;
    get source(): NsxvFirewallRuleSourceOutputReference;
    putSource(value: NsxvFirewallRuleSource): void;
    get sourceInput(): NsxvFirewallRuleSource | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
