import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NsxvSnatConfig extends cdktf.TerraformMetaArguments {
    /**
    * NAT rule description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#description NsxvSnat#description}
    */
    readonly description?: string;
    /**
    * Edge gateway name in which NAT Rule is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#edge_gateway NsxvSnat#edge_gateway}
    */
    readonly edgeGateway: string;
    /**
    * Whether the rule should be enabled. Default 'true'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#enabled NsxvSnat#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#id NsxvSnat#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether logging should be enabled for this rule. Default 'false'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#logging_enabled NsxvSnat#logging_enabled}
    */
    readonly loggingEnabled?: boolean | cdktf.IResolvable;
    /**
    * Org or external network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#network_name NsxvSnat#network_name}
    */
    readonly networkName: string;
    /**
    * Network type. One of 'ext', 'org'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#network_type NsxvSnat#network_type}
    */
    readonly networkType: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#org NsxvSnat#org}
    */
    readonly org?: string;
    /**
    * Original address or address range. This is the the source address for SNAT rules
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#original_address NsxvSnat#original_address}
    */
    readonly originalAddress: string;
    /**
    * Optional. Allows to set custom rule tag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#rule_tag NsxvSnat#rule_tag}
    */
    readonly ruleTag?: number;
    /**
    * Read only. Possible values 'user', 'internal_high'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#rule_type NsxvSnat#rule_type}
    */
    readonly ruleType?: string;
    /**
    * Translated address or address range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#translated_address NsxvSnat#translated_address}
    */
    readonly translatedAddress?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#vdc NsxvSnat#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat vcd_nsxv_snat}
*/
export declare class NsxvSnat extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_nsxv_snat";
    /**
    * Generates CDKTF code for importing a NsxvSnat resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NsxvSnat to import
    * @param importFromId The id of the existing NsxvSnat that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NsxvSnat to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/nsxv_snat vcd_nsxv_snat} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NsxvSnatConfig
    */
    constructor(scope: Construct, id: string, config: NsxvSnatConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeGateway?;
    get edgeGateway(): string;
    set edgeGateway(value: string);
    get edgeGatewayInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _loggingEnabled?;
    get loggingEnabled(): boolean | cdktf.IResolvable;
    set loggingEnabled(value: boolean | cdktf.IResolvable);
    resetLoggingEnabled(): void;
    get loggingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _networkName?;
    get networkName(): string;
    set networkName(value: string);
    get networkNameInput(): string | undefined;
    private _networkType?;
    get networkType(): string;
    set networkType(value: string);
    get networkTypeInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _originalAddress?;
    get originalAddress(): string;
    set originalAddress(value: string);
    get originalAddressInput(): string | undefined;
    private _ruleTag?;
    get ruleTag(): number;
    set ruleTag(value: number);
    resetRuleTag(): void;
    get ruleTagInput(): number | undefined;
    private _ruleType?;
    get ruleType(): string;
    set ruleType(value: string);
    resetRuleType(): void;
    get ruleTypeInput(): string | undefined;
    private _translatedAddress?;
    get translatedAddress(): string;
    set translatedAddress(value: string);
    resetTranslatedAddress(): void;
    get translatedAddressInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
