import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgLdapConfig extends cdktf.TerraformMetaArguments {
    /**
    * If ldap_mode is SYSTEM, specifies a LDAP attribute=value pair to use for OU (organizational unit)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#custom_user_ou OrgLdap#custom_user_ou}
    */
    readonly customUserOu?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#id OrgLdap#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Type of LDAP settings (one of NONE, SYSTEM, CUSTOM)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#ldap_mode OrgLdap#ldap_mode}
    */
    readonly ldapMode: string;
    /**
    * Organization ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#org_id OrgLdap#org_id}
    */
    readonly orgId: string;
    /**
    * custom_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#custom_settings OrgLdap#custom_settings}
    */
    readonly customSettings?: OrgLdapCustomSettings;
}
export interface OrgLdapCustomSettingsGroupAttributes {
    /**
    * LDAP group attribute used to identify a group member
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#group_back_link_identifier OrgLdap#group_back_link_identifier}
    */
    readonly groupBackLinkIdentifier?: string;
    /**
    * LDAP attribute that identifies a group as a member of another group. For example, dn
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#group_membership_identifier OrgLdap#group_membership_identifier}
    */
    readonly groupMembershipIdentifier: string;
    /**
    * LDAP attribute to use when getting the members of a group. For example, member
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#membership OrgLdap#membership}
    */
    readonly membership: string;
    /**
    * LDAP attribute to use for the group name. For example, cn
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#name OrgLdap#name}
    */
    readonly name: string;
    /**
    * LDAP objectClass of which imported groups are members. For example, group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#object_class OrgLdap#object_class}
    */
    readonly objectClass: string;
    /**
    * LDAP attribute to use as the unique identifier for a group. For example, objectGuid
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#unique_identifier OrgLdap#unique_identifier}
    */
    readonly uniqueIdentifier: string;
}
export declare function orgLdapCustomSettingsGroupAttributesToTerraform(struct?: OrgLdapCustomSettingsGroupAttributesOutputReference | OrgLdapCustomSettingsGroupAttributes): any;
export declare function orgLdapCustomSettingsGroupAttributesToHclTerraform(struct?: OrgLdapCustomSettingsGroupAttributesOutputReference | OrgLdapCustomSettingsGroupAttributes): any;
export declare class OrgLdapCustomSettingsGroupAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgLdapCustomSettingsGroupAttributes | undefined;
    set internalValue(value: OrgLdapCustomSettingsGroupAttributes | undefined);
    private _groupBackLinkIdentifier?;
    get groupBackLinkIdentifier(): string;
    set groupBackLinkIdentifier(value: string);
    resetGroupBackLinkIdentifier(): void;
    get groupBackLinkIdentifierInput(): string | undefined;
    private _groupMembershipIdentifier?;
    get groupMembershipIdentifier(): string;
    set groupMembershipIdentifier(value: string);
    get groupMembershipIdentifierInput(): string | undefined;
    private _membership?;
    get membership(): string;
    set membership(value: string);
    get membershipInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _objectClass?;
    get objectClass(): string;
    set objectClass(value: string);
    get objectClassInput(): string | undefined;
    private _uniqueIdentifier?;
    get uniqueIdentifier(): string;
    set uniqueIdentifier(value: string);
    get uniqueIdentifierInput(): string | undefined;
}
export interface OrgLdapCustomSettingsUserAttributes {
    /**
    * LDAP attribute to use for the user's full name. For example, displayName
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#display_name OrgLdap#display_name}
    */
    readonly displayName: string;
    /**
    * LDAP attribute to use for the user's email address. For example, mail
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#email OrgLdap#email}
    */
    readonly email: string;
    /**
    * LDAP attribute to use for the user's given name. For example, givenName
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#given_name OrgLdap#given_name}
    */
    readonly givenName: string;
    /**
    * LDAP attribute that returns the identifiers of all the groups of which the user is a member
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#group_back_link_identifier OrgLdap#group_back_link_identifier}
    */
    readonly groupBackLinkIdentifier?: string;
    /**
    * LDAP attribute that identifies a user as a member of a group. For example, dn
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#group_membership_identifier OrgLdap#group_membership_identifier}
    */
    readonly groupMembershipIdentifier: string;
    /**
    * LDAP objectClass of which imported users are members. For example, user or person
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#object_class OrgLdap#object_class}
    */
    readonly objectClass: string;
    /**
    * LDAP attribute to use for the user's surname. For example, sn
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#surname OrgLdap#surname}
    */
    readonly surname: string;
    /**
    * LDAP attribute to use for the user's telephone number. For example, telephoneNumber
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#telephone OrgLdap#telephone}
    */
    readonly telephone: string;
    /**
    * LDAP attribute to use as the unique identifier for a user. For example, objectGuid
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#unique_identifier OrgLdap#unique_identifier}
    */
    readonly uniqueIdentifier: string;
    /**
    * LDAP attribute to use when looking up a user name to import. For example, userPrincipalName or samAccountName
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#username OrgLdap#username}
    */
    readonly username: string;
}
export declare function orgLdapCustomSettingsUserAttributesToTerraform(struct?: OrgLdapCustomSettingsUserAttributesOutputReference | OrgLdapCustomSettingsUserAttributes): any;
export declare function orgLdapCustomSettingsUserAttributesToHclTerraform(struct?: OrgLdapCustomSettingsUserAttributesOutputReference | OrgLdapCustomSettingsUserAttributes): any;
export declare class OrgLdapCustomSettingsUserAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgLdapCustomSettingsUserAttributes | undefined;
    set internalValue(value: OrgLdapCustomSettingsUserAttributes | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _givenName?;
    get givenName(): string;
    set givenName(value: string);
    get givenNameInput(): string | undefined;
    private _groupBackLinkIdentifier?;
    get groupBackLinkIdentifier(): string;
    set groupBackLinkIdentifier(value: string);
    resetGroupBackLinkIdentifier(): void;
    get groupBackLinkIdentifierInput(): string | undefined;
    private _groupMembershipIdentifier?;
    get groupMembershipIdentifier(): string;
    set groupMembershipIdentifier(value: string);
    get groupMembershipIdentifierInput(): string | undefined;
    private _objectClass?;
    get objectClass(): string;
    set objectClass(value: string);
    get objectClassInput(): string | undefined;
    private _surname?;
    get surname(): string;
    set surname(value: string);
    get surnameInput(): string | undefined;
    private _telephone?;
    get telephone(): string;
    set telephone(value: string);
    get telephoneInput(): string | undefined;
    private _uniqueIdentifier?;
    get uniqueIdentifier(): string;
    set uniqueIdentifier(value: string);
    get uniqueIdentifierInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    get usernameInput(): string | undefined;
}
export interface OrgLdapCustomSettings {
    /**
    * authentication method: one of SIMPLE, MD5DIGEST, NTLM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#authentication_method OrgLdap#authentication_method}
    */
    readonly authenticationMethod: string;
    /**
    * LDAP search base
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#base_distinguished_name OrgLdap#base_distinguished_name}
    */
    readonly baseDistinguishedName?: string;
    /**
    * type of connector: one of OPEN_LDAP, ACTIVE_DIRECTORY
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#connector_type OrgLdap#connector_type}
    */
    readonly connectorType: string;
    /**
    * True if the LDAP service requires an SSL connection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#is_ssl OrgLdap#is_ssl}
    */
    readonly isSsl?: boolean | cdktf.IResolvable;
    /**
    * Password for the user identified by UserName. This value is never returned by GET. It is inspected on create and modify. On modify, the absence of this element indicates that the password should not be changed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#password OrgLdap#password}
    */
    readonly password?: string;
    /**
    * Port number for LDAP service
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#port OrgLdap#port}
    */
    readonly port: number;
    /**
    * host name or IP of the LDAP server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#server OrgLdap#server}
    */
    readonly server: string;
    /**
    * Username to use when logging in to LDAP, specified using LDAP attribute=value pairs (for example: cn="ldap-admin", c="example", dc="com")
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#username OrgLdap#username}
    */
    readonly username?: string;
    /**
    * group_attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#group_attributes OrgLdap#group_attributes}
    */
    readonly groupAttributes: OrgLdapCustomSettingsGroupAttributes;
    /**
    * user_attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#user_attributes OrgLdap#user_attributes}
    */
    readonly userAttributes: OrgLdapCustomSettingsUserAttributes;
}
export declare function orgLdapCustomSettingsToTerraform(struct?: OrgLdapCustomSettingsOutputReference | OrgLdapCustomSettings): any;
export declare function orgLdapCustomSettingsToHclTerraform(struct?: OrgLdapCustomSettingsOutputReference | OrgLdapCustomSettings): any;
export declare class OrgLdapCustomSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgLdapCustomSettings | undefined;
    set internalValue(value: OrgLdapCustomSettings | undefined);
    private _authenticationMethod?;
    get authenticationMethod(): string;
    set authenticationMethod(value: string);
    get authenticationMethodInput(): string | undefined;
    private _baseDistinguishedName?;
    get baseDistinguishedName(): string;
    set baseDistinguishedName(value: string);
    resetBaseDistinguishedName(): void;
    get baseDistinguishedNameInput(): string | undefined;
    private _connectorType?;
    get connectorType(): string;
    set connectorType(value: string);
    get connectorTypeInput(): string | undefined;
    private _isSsl?;
    get isSsl(): boolean | cdktf.IResolvable;
    set isSsl(value: boolean | cdktf.IResolvable);
    resetIsSsl(): void;
    get isSslInput(): boolean | cdktf.IResolvable | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _server?;
    get server(): string;
    set server(value: string);
    get serverInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
    private _groupAttributes;
    get groupAttributes(): OrgLdapCustomSettingsGroupAttributesOutputReference;
    putGroupAttributes(value: OrgLdapCustomSettingsGroupAttributes): void;
    get groupAttributesInput(): OrgLdapCustomSettingsGroupAttributes | undefined;
    private _userAttributes;
    get userAttributes(): OrgLdapCustomSettingsUserAttributesOutputReference;
    putUserAttributes(value: OrgLdapCustomSettingsUserAttributes): void;
    get userAttributesInput(): OrgLdapCustomSettingsUserAttributes | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap vcd_org_ldap}
*/
export declare class OrgLdap extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_ldap";
    /**
    * Generates CDKTF code for importing a OrgLdap resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgLdap to import
    * @param importFromId The id of the existing OrgLdap that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgLdap to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_ldap vcd_org_ldap} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgLdapConfig
    */
    constructor(scope: Construct, id: string, config: OrgLdapConfig);
    private _customUserOu?;
    get customUserOu(): string;
    set customUserOu(value: string);
    resetCustomUserOu(): void;
    get customUserOuInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ldapMode?;
    get ldapMode(): string;
    set ldapMode(value: string);
    get ldapModeInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _customSettings;
    get customSettings(): OrgLdapCustomSettingsOutputReference;
    putCustomSettings(value: OrgLdapCustomSettings): void;
    resetCustomSettings(): void;
    get customSettingsInput(): OrgLdapCustomSettings | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
