import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgSamlConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional email attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#email OrgSaml#email}
    */
    readonly email?: string;
    /**
    * Enable SAML authentication. When this option is set, authentication is deferred to the SAML identity provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#enabled OrgSaml#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Your service provider entity ID. Once you set this field, it cannot be changed back to empty.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#entity_id OrgSaml#entity_id}
    */
    readonly entityId?: string;
    /**
    * Optional first name attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#first_name OrgSaml#first_name}
    */
    readonly firstName?: string;
    /**
    * Optional full name attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#full_name OrgSaml#full_name}
    */
    readonly fullName?: string;
    /**
    * Optional group attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#group OrgSaml#group}
    */
    readonly group?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#id OrgSaml#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the file containing the metadata from the identity provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#identity_provider_metadata_file OrgSaml#identity_provider_metadata_file}
    */
    readonly identityProviderMetadataFile?: string;
    /**
    * The text of the metadata from the identity provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#identity_provider_metadata_text OrgSaml#identity_provider_metadata_text}
    */
    readonly identityProviderMetadataText?: string;
    /**
    * Organization ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#org_id OrgSaml#org_id}
    */
    readonly orgId: string;
    /**
    * Optional role attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#role OrgSaml#role}
    */
    readonly role?: string;
    /**
    * Optional surname attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#surname OrgSaml#surname}
    */
    readonly surname?: string;
    /**
    * Optional username attribute name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#user_name OrgSaml#user_name}
    */
    readonly userName?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml vcd_org_saml}
*/
export declare class OrgSaml extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_saml";
    /**
    * Generates CDKTF code for importing a OrgSaml resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgSaml to import
    * @param importFromId The id of the existing OrgSaml that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgSaml to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_saml vcd_org_saml} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgSamlConfig
    */
    constructor(scope: Construct, id: string, config: OrgSamlConfig);
    private _email?;
    get email(): string;
    set email(value: string);
    resetEmail(): void;
    get emailInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _entityId?;
    get entityId(): string;
    set entityId(value: string);
    resetEntityId(): void;
    get entityIdInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    resetFirstName(): void;
    get firstNameInput(): string | undefined;
    private _fullName?;
    get fullName(): string;
    set fullName(value: string);
    resetFullName(): void;
    get fullNameInput(): string | undefined;
    private _group?;
    get group(): string;
    set group(value: string);
    resetGroup(): void;
    get groupInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _identityProviderMetadataFile?;
    get identityProviderMetadataFile(): string;
    set identityProviderMetadataFile(value: string);
    resetIdentityProviderMetadataFile(): void;
    get identityProviderMetadataFileInput(): string | undefined;
    private _identityProviderMetadataText?;
    get identityProviderMetadataText(): string;
    set identityProviderMetadataText(value: string);
    resetIdentityProviderMetadataText(): void;
    get identityProviderMetadataTextInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    resetRole(): void;
    get roleInput(): string | undefined;
    private _surname?;
    get surname(): string;
    set surname(value: string);
    resetSurname(): void;
    get surnameInput(): string | undefined;
    private _userName?;
    get userName(): string;
    set userName(value: string);
    resetUserName(): void;
    get userNameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
