import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgUserConfig extends cdktf.TerraformMetaArguments {
    /**
    * Quota of vApps that this user can deploy. A value of 0 specifies an unlimited quota.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#deployed_vm_quota OrgUser#deployed_vm_quota}
    */
    readonly deployedVmQuota?: number;
    /**
    * The user's description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#description OrgUser#description}
    */
    readonly description?: string;
    /**
    * The user's email address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#email_address OrgUser#email_address}
    */
    readonly emailAddress?: string;
    /**
    * True if the user is enabled and can log in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#enabled OrgUser#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The user's full name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#full_name OrgUser#full_name}
    */
    readonly fullName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#id OrgUser#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The user's telephone
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#instant_messaging OrgUser#instant_messaging}
    */
    readonly instantMessaging?: string;
    /**
    * True if this user is imported from an external resource, like an LDAP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#is_external OrgUser#is_external}
    */
    readonly isExternal?: boolean | cdktf.IResolvable;
    /**
    * True if this user has a group role.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#is_group_role OrgUser#is_group_role}
    */
    readonly isGroupRole?: boolean | cdktf.IResolvable;
    /**
    * If the user account has been locked due to too many invalid login attempts, the value will change to true (only the system can lock the user). To unlock the user re-set this flag to false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#is_locked OrgUser#is_locked}
    */
    readonly isLocked?: boolean | cdktf.IResolvable;
    /**
    * User's name. Only lowercase letters allowed. Cannot be changed after creation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#name OrgUser#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#org OrgUser#org}
    */
    readonly org?: string;
    /**
    * The user's password. This value is never returned on read. Either "password" or "password_file" must be included on creation unless is_external is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#password OrgUser#password}
    */
    readonly password?: string;
    /**
    * Name of a file containing the user's password. Either "password_file" or "password" must be included on creation unless is_external is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#password_file OrgUser#password_file}
    */
    readonly passwordFile?: string;
    /**
    * Identity provider type for this this user. One of: 'INTEGRATED', 'SAML', 'OAUTH'. When empty, the default value 'INTEGRATED' is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#provider_type OrgUser#provider_type}
    */
    readonly providerType?: string;
    /**
    * Role within the organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#role OrgUser#role}
    */
    readonly role: string;
    /**
    * Quota of vApps that this user can store. A value of 0 specifies an unlimited quota.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#stored_vm_quota OrgUser#stored_vm_quota}
    */
    readonly storedVmQuota?: number;
    /**
    * Take ownership of user's objects on deletion.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#take_ownership OrgUser#take_ownership}
    */
    readonly takeOwnership?: boolean | cdktf.IResolvable;
    /**
    * The user's telephone
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#telephone OrgUser#telephone}
    */
    readonly telephone?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user vcd_org_user}
*/
export declare class OrgUser extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_user";
    /**
    * Generates CDKTF code for importing a OrgUser resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgUser to import
    * @param importFromId The id of the existing OrgUser that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgUser to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_user vcd_org_user} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgUserConfig
    */
    constructor(scope: Construct, id: string, config: OrgUserConfig);
    private _deployedVmQuota?;
    get deployedVmQuota(): number;
    set deployedVmQuota(value: number);
    resetDeployedVmQuota(): void;
    get deployedVmQuotaInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _emailAddress?;
    get emailAddress(): string;
    set emailAddress(value: string);
    resetEmailAddress(): void;
    get emailAddressInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fullName?;
    get fullName(): string;
    set fullName(value: string);
    resetFullName(): void;
    get fullNameInput(): string | undefined;
    get groupNames(): string[];
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instantMessaging?;
    get instantMessaging(): string;
    set instantMessaging(value: string);
    resetInstantMessaging(): void;
    get instantMessagingInput(): string | undefined;
    private _isExternal?;
    get isExternal(): boolean | cdktf.IResolvable;
    set isExternal(value: boolean | cdktf.IResolvable);
    resetIsExternal(): void;
    get isExternalInput(): boolean | cdktf.IResolvable | undefined;
    private _isGroupRole?;
    get isGroupRole(): boolean | cdktf.IResolvable;
    set isGroupRole(value: boolean | cdktf.IResolvable);
    resetIsGroupRole(): void;
    get isGroupRoleInput(): boolean | cdktf.IResolvable | undefined;
    private _isLocked?;
    get isLocked(): boolean | cdktf.IResolvable;
    set isLocked(value: boolean | cdktf.IResolvable);
    resetIsLocked(): void;
    get isLockedInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _passwordFile?;
    get passwordFile(): string;
    set passwordFile(value: string);
    resetPasswordFile(): void;
    get passwordFileInput(): string | undefined;
    private _providerType?;
    get providerType(): string;
    set providerType(value: string);
    resetProviderType(): void;
    get providerTypeInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _storedVmQuota?;
    get storedVmQuota(): number;
    set storedVmQuota(value: number);
    resetStoredVmQuota(): void;
    get storedVmQuotaInput(): number | undefined;
    private _takeOwnership?;
    get takeOwnership(): boolean | cdktf.IResolvable;
    set takeOwnership(value: boolean | cdktf.IResolvable);
    resetTakeOwnership(): void;
    get takeOwnershipInput(): boolean | cdktf.IResolvable | undefined;
    private _telephone?;
    get telephone(): string;
    set telephone(value: string);
    resetTelephone(): void;
    get telephoneInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
