import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgVdcNsxtNetworkProfileConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of NSX-T Edge Cluster (provider vApp networking services and DHCP capability for Isolated networks)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#edge_cluster_id OrgVdcNsxtNetworkProfile#edge_cluster_id}
    */
    readonly edgeClusterId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#id OrgVdcNsxtNetworkProfile#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#org OrgVdcNsxtNetworkProfile#org}
    */
    readonly org?: string;
    /**
    * Default NSX-T Segment Profile for vApp networks
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#vapp_networks_default_segment_profile_template_id OrgVdcNsxtNetworkProfile#vapp_networks_default_segment_profile_template_id}
    */
    readonly vappNetworksDefaultSegmentProfileTemplateId?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#vdc OrgVdcNsxtNetworkProfile#vdc}
    */
    readonly vdc?: string;
    /**
    * Default NSX-T Segment Profile for Org VDC networks
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#vdc_networks_default_segment_profile_template_id OrgVdcNsxtNetworkProfile#vdc_networks_default_segment_profile_template_id}
    */
    readonly vdcNetworksDefaultSegmentProfileTemplateId?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile vcd_org_vdc_nsxt_network_profile}
*/
export declare class OrgVdcNsxtNetworkProfile extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_vdc_nsxt_network_profile";
    /**
    * Generates CDKTF code for importing a OrgVdcNsxtNetworkProfile resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgVdcNsxtNetworkProfile to import
    * @param importFromId The id of the existing OrgVdcNsxtNetworkProfile that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgVdcNsxtNetworkProfile to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc_nsxt_network_profile vcd_org_vdc_nsxt_network_profile} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgVdcNsxtNetworkProfileConfig = {}
    */
    constructor(scope: Construct, id: string, config?: OrgVdcNsxtNetworkProfileConfig);
    private _edgeClusterId?;
    get edgeClusterId(): string;
    set edgeClusterId(value: string);
    resetEdgeClusterId(): void;
    get edgeClusterIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vappNetworksDefaultSegmentProfileTemplateId?;
    get vappNetworksDefaultSegmentProfileTemplateId(): string;
    set vappNetworksDefaultSegmentProfileTemplateId(value: string);
    resetVappNetworksDefaultSegmentProfileTemplateId(): void;
    get vappNetworksDefaultSegmentProfileTemplateIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _vdcNetworksDefaultSegmentProfileTemplateId?;
    get vdcNetworksDefaultSegmentProfileTemplateId(): string;
    set vdcNetworksDefaultSegmentProfileTemplateId(value: string);
    resetVdcNetworksDefaultSegmentProfileTemplateId(): void;
    get vdcNetworksDefaultSegmentProfileTemplateIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
