import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgVdcConfig extends cdktf.TerraformMetaArguments {
    /**
    * The allocation model used by this VDC; must be one of {AllocationVApp, AllocationPool, ReservationPool, Flex}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#allocation_model OrgVdc#allocation_model}
    */
    readonly allocationModel: string;
    /**
    * Set to false to disallow creation of the VDC if the AllocationModel is AllocationPool or ReservationPool and the ComputeCapacity you specified is greater than what the backing Provider VDC can supply. Default is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#allow_over_commit OrgVdc#allow_over_commit}
    */
    readonly allowOverCommit?: boolean | cdktf.IResolvable;
    /**
    * Percentage of allocated CPU resources guaranteed to vApps deployed in this VDC. For example, if this value is 0.75, then 75% of allocated resources are guaranteed. Required when AllocationModel is AllocationVApp or AllocationPool. If the element is empty, vCD sets a value
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#cpu_guaranteed OrgVdc#cpu_guaranteed}
    */
    readonly cpuGuaranteed?: number;
    /**
    * Specifies the clock frequency, in Megahertz, for any virtual CPU that is allocated to a VM. A VM with 2 vCPUs will consume twice as much of this value. Ignored for ReservationPool. Required when AllocationModel is AllocationVApp or AllocationPool, and may not be less than 256 MHz. Defaults to 1000 MHz if the element is empty or missing.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#cpu_speed OrgVdc#cpu_speed}
    */
    readonly cpuSpeed?: number;
    /**
    * ID of default Compute policy for this VDC, which can be a VM Sizing Policy, VM Placement Policy or vGPU Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#default_compute_policy_id OrgVdc#default_compute_policy_id}
    */
    readonly defaultComputePolicyId?: string;
    /**
    * ID of default VM Compute policy, which can be a VM Sizing Policy, VM Placement Policy or vGPU Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#default_vm_sizing_policy_id OrgVdc#default_vm_sizing_policy_id}
    */
    readonly defaultVmSizingPolicyId?: string;
    /**
    * When destroying use delete_force=True to remove a VDC and any objects it contains, regardless of their state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#delete_force OrgVdc#delete_force}
    */
    readonly deleteForce?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_recursive=True to remove the VDC and any objects it contains that are in a state that normally allows removal.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#delete_recursive OrgVdc#delete_recursive}
    */
    readonly deleteRecursive?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#description OrgVdc#description}
    */
    readonly description?: string;
    /**
    * ID of NSX-T Edge Cluster (provider vApp networking services and DHCP capability for Isolated networks)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#edge_cluster_id OrgVdc#edge_cluster_id}
    */
    readonly edgeClusterId?: string;
    /**
    * Set to true to indicate if the Flex VDC is to be elastic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#elasticity OrgVdc#elasticity}
    */
    readonly elasticity?: boolean | cdktf.IResolvable;
    /**
    * Request for fast provisioning. Request will be honored only if the underlying datas tore supports it. Fast provisioning can reduce the time it takes to create virtual machines by using vSphere linked clones. If you disable fast provisioning, all provisioning operations will result in full clones.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enable_fast_provisioning OrgVdc#enable_fast_provisioning}
    */
    readonly enableFastProvisioning?: boolean | cdktf.IResolvable;
    /**
    * Set to true to enable distributed firewall - Only applies to NSX-V VDCs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enable_nsxv_distributed_firewall OrgVdc#enable_nsxv_distributed_firewall}
    */
    readonly enableNsxvDistributedFirewall?: boolean | cdktf.IResolvable;
    /**
    * Boolean to request thin provisioning. Request will be honored only if the underlying datastore supports it. Thin provisioning saves storage space by committing it on demand. This allows over-allocation of storage.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enable_thin_provisioning OrgVdc#enable_thin_provisioning}
    */
    readonly enableThinProvisioning?: boolean | cdktf.IResolvable;
    /**
    * True if discovery of vCenter VMs is enabled for resource pools backing this VDC. If left unspecified, the actual behaviour depends on enablement at the organization level and at the system level.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enable_vm_discovery OrgVdc#enable_vm_discovery}
    */
    readonly enableVmDiscovery?: boolean | cdktf.IResolvable;
    /**
    * True if this VDC is enabled for use by the organization VDCs. Default is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enabled OrgVdc#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#id OrgVdc#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Set to true to indicate if the Flex VDC is to include memory overhead into its accounting for admission control.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#include_vm_memory_overhead OrgVdc#include_vm_memory_overhead}
    */
    readonly includeVmMemoryOverhead?: boolean | cdktf.IResolvable;
    /**
    * Percentage of allocated memory resources guaranteed to vApps deployed in this VDC. For example, if this value is 0.75, then 75% of allocated resources are guaranteed. Required when AllocationModel is AllocationVApp or AllocationPool. When Allocation model is AllocationPool minimum value is 0.2. If the element is empty, vCD sets a value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#memory_guaranteed OrgVdc#memory_guaranteed}
    */
    readonly memoryGuaranteed?: number;
    /**
    * Key and value pairs for Org VDC metadata
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#metadata OrgVdc#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#name OrgVdc#name}
    */
    readonly name: string;
    /**
    * The name of a network pool in the Provider VDC. Required if this VDC will contain routed or isolated networks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#network_pool_name OrgVdc#network_pool_name}
    */
    readonly networkPoolName?: string;
    /**
    * Maximum number of network objects that can be deployed in this VDC. Defaults to 0, which means no networks can be deployed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#network_quota OrgVdc#network_quota}
    */
    readonly networkQuota?: number;
    /**
    * Maximum number of virtual NICs allowed in this VDC. Defaults to 0, which specifies an unlimited number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#nic_quota OrgVdc#nic_quota}
    */
    readonly nicQuota?: number;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#org OrgVdc#org}
    */
    readonly org?: string;
    /**
    * A reference to the Provider VDC from which this organization VDC is provisioned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#provider_vdc_name OrgVdc#provider_vdc_name}
    */
    readonly providerVdcName: string;
    /**
    * Set of VM Placement Policy IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#vm_placement_policy_ids OrgVdc#vm_placement_policy_ids}
    */
    readonly vmPlacementPolicyIds?: string[];
    /**
    * The maximum number of VMs that can be created in this VDC. Includes deployed and undeployed VMs in vApps and vApp templates. Defaults to 0, which specifies an unlimited number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#vm_quota OrgVdc#vm_quota}
    */
    readonly vmQuota?: number;
    /**
    * Set of VM Sizing Policy IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#vm_sizing_policy_ids OrgVdc#vm_sizing_policy_ids}
    */
    readonly vmSizingPolicyIds?: string[];
    /**
    * Set of VM vGPU Policy IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#vm_vgpu_policy_ids OrgVdc#vm_vgpu_policy_ids}
    */
    readonly vmVgpuPolicyIds?: string[];
    /**
    * compute_capacity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#compute_capacity OrgVdc#compute_capacity}
    */
    readonly computeCapacity: OrgVdcComputeCapacity;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#metadata_entry OrgVdc#metadata_entry}
    */
    readonly metadataEntry?: OrgVdcMetadataEntry[] | cdktf.IResolvable;
    /**
    * storage_profile block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#storage_profile OrgVdc#storage_profile}
    */
    readonly storageProfile: OrgVdcStorageProfile[] | cdktf.IResolvable;
}
export interface OrgVdcComputeCapacityCpu {
    /**
    * Capacity that is committed to be available. Value in MB or MHz. Used with AllocationPool (Allocation pool) and ReservationPool (Reservation pool).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#allocated OrgVdc#allocated}
    */
    readonly allocated?: number;
    /**
    * Capacity limit relative to the value specified for Allocation. It must not be less than that value. If it is greater than that value, it implies over provisioning. A value of 0 specifies unlimited units. Value in MB or MHz. Used with AllocationVApp (Pay as you go).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#limit OrgVdc#limit}
    */
    readonly limit?: number;
}
export declare function orgVdcComputeCapacityCpuToTerraform(struct?: OrgVdcComputeCapacityCpuOutputReference | OrgVdcComputeCapacityCpu): any;
export declare function orgVdcComputeCapacityCpuToHclTerraform(struct?: OrgVdcComputeCapacityCpuOutputReference | OrgVdcComputeCapacityCpu): any;
export declare class OrgVdcComputeCapacityCpuOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcComputeCapacityCpu | undefined;
    set internalValue(value: OrgVdcComputeCapacityCpu | undefined);
    private _allocated?;
    get allocated(): number;
    set allocated(value: number);
    resetAllocated(): void;
    get allocatedInput(): number | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    resetLimit(): void;
    get limitInput(): number | undefined;
    get reserved(): number;
    get used(): number;
}
export interface OrgVdcComputeCapacityMemory {
    /**
    * Capacity that is committed to be available. Value in MB or MHz. Used with AllocationPool (Allocation pool) and ReservationPool (Reservation pool).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#allocated OrgVdc#allocated}
    */
    readonly allocated?: number;
    /**
    * Capacity limit relative to the value specified for Allocation. It must not be less than that value. If it is greater than that value, it implies over provisioning. A value of 0 specifies unlimited units. Value in MB or MHz. Used with AllocationVApp (Pay as you go).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#limit OrgVdc#limit}
    */
    readonly limit?: number;
}
export declare function orgVdcComputeCapacityMemoryToTerraform(struct?: OrgVdcComputeCapacityMemoryOutputReference | OrgVdcComputeCapacityMemory): any;
export declare function orgVdcComputeCapacityMemoryToHclTerraform(struct?: OrgVdcComputeCapacityMemoryOutputReference | OrgVdcComputeCapacityMemory): any;
export declare class OrgVdcComputeCapacityMemoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcComputeCapacityMemory | undefined;
    set internalValue(value: OrgVdcComputeCapacityMemory | undefined);
    private _allocated?;
    get allocated(): number;
    set allocated(value: number);
    resetAllocated(): void;
    get allocatedInput(): number | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    resetLimit(): void;
    get limitInput(): number | undefined;
    get reserved(): number;
    get used(): number;
}
export interface OrgVdcComputeCapacity {
    /**
    * cpu block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#cpu OrgVdc#cpu}
    */
    readonly cpu: OrgVdcComputeCapacityCpu;
    /**
    * memory block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#memory OrgVdc#memory}
    */
    readonly memory: OrgVdcComputeCapacityMemory;
}
export declare function orgVdcComputeCapacityToTerraform(struct?: OrgVdcComputeCapacityOutputReference | OrgVdcComputeCapacity): any;
export declare function orgVdcComputeCapacityToHclTerraform(struct?: OrgVdcComputeCapacityOutputReference | OrgVdcComputeCapacity): any;
export declare class OrgVdcComputeCapacityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcComputeCapacity | undefined;
    set internalValue(value: OrgVdcComputeCapacity | undefined);
    private _cpu;
    get cpu(): OrgVdcComputeCapacityCpuOutputReference;
    putCpu(value: OrgVdcComputeCapacityCpu): void;
    get cpuInput(): OrgVdcComputeCapacityCpu | undefined;
    private _memory;
    get memory(): OrgVdcComputeCapacityMemoryOutputReference;
    putMemory(value: OrgVdcComputeCapacityMemory): void;
    get memoryInput(): OrgVdcComputeCapacityMemory | undefined;
}
export interface OrgVdcMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#is_system OrgVdc#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#key OrgVdc#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#type OrgVdc#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#user_access OrgVdc#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#value OrgVdc#value}
    */
    readonly value?: string;
}
export declare function orgVdcMetadataEntryToTerraform(struct?: OrgVdcMetadataEntry | cdktf.IResolvable): any;
export declare function orgVdcMetadataEntryToHclTerraform(struct?: OrgVdcMetadataEntry | cdktf.IResolvable): any;
export declare class OrgVdcMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgVdcMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: OrgVdcMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class OrgVdcMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgVdcMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgVdcMetadataEntryOutputReference;
}
export interface OrgVdcStorageProfile {
    /**
    * True if this is default storage profile for this VDC. The default storage profile is used when an object that can specify a storage profile is created with no storage profile specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#default OrgVdc#default}
    */
    readonly default: boolean | cdktf.IResolvable;
    /**
    * True if this storage profile is enabled for use in the VDC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#enabled OrgVdc#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Maximum number of MB allocated for this storage profile. A value of 0 specifies unlimited MB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#limit OrgVdc#limit}
    */
    readonly limit: number;
    /**
    * Name of Provider VDC storage profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#name OrgVdc#name}
    */
    readonly name: string;
}
export declare function orgVdcStorageProfileToTerraform(struct?: OrgVdcStorageProfile | cdktf.IResolvable): any;
export declare function orgVdcStorageProfileToHclTerraform(struct?: OrgVdcStorageProfile | cdktf.IResolvable): any;
export declare class OrgVdcStorageProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgVdcStorageProfile | cdktf.IResolvable | undefined;
    set internalValue(value: OrgVdcStorageProfile | cdktf.IResolvable | undefined);
    private _default?;
    get default(): boolean | cdktf.IResolvable;
    set default(value: boolean | cdktf.IResolvable);
    get defaultInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get storageUsedInMb(): number;
}
export declare class OrgVdcStorageProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgVdcStorageProfile[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgVdcStorageProfileOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc vcd_org_vdc}
*/
export declare class OrgVdc extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_vdc";
    /**
    * Generates CDKTF code for importing a OrgVdc resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgVdc to import
    * @param importFromId The id of the existing OrgVdc that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgVdc to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org_vdc vcd_org_vdc} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgVdcConfig
    */
    constructor(scope: Construct, id: string, config: OrgVdcConfig);
    private _allocationModel?;
    get allocationModel(): string;
    set allocationModel(value: string);
    get allocationModelInput(): string | undefined;
    private _allowOverCommit?;
    get allowOverCommit(): boolean | cdktf.IResolvable;
    set allowOverCommit(value: boolean | cdktf.IResolvable);
    resetAllowOverCommit(): void;
    get allowOverCommitInput(): boolean | cdktf.IResolvable | undefined;
    private _cpuGuaranteed?;
    get cpuGuaranteed(): number;
    set cpuGuaranteed(value: number);
    resetCpuGuaranteed(): void;
    get cpuGuaranteedInput(): number | undefined;
    private _cpuSpeed?;
    get cpuSpeed(): number;
    set cpuSpeed(value: number);
    resetCpuSpeed(): void;
    get cpuSpeedInput(): number | undefined;
    private _defaultComputePolicyId?;
    get defaultComputePolicyId(): string;
    set defaultComputePolicyId(value: string);
    resetDefaultComputePolicyId(): void;
    get defaultComputePolicyIdInput(): string | undefined;
    private _defaultVmSizingPolicyId?;
    get defaultVmSizingPolicyId(): string;
    set defaultVmSizingPolicyId(value: string);
    resetDefaultVmSizingPolicyId(): void;
    get defaultVmSizingPolicyIdInput(): string | undefined;
    private _deleteForce?;
    get deleteForce(): boolean | cdktf.IResolvable;
    set deleteForce(value: boolean | cdktf.IResolvable);
    resetDeleteForce(): void;
    get deleteForceInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteRecursive?;
    get deleteRecursive(): boolean | cdktf.IResolvable;
    set deleteRecursive(value: boolean | cdktf.IResolvable);
    resetDeleteRecursive(): void;
    get deleteRecursiveInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _edgeClusterId?;
    get edgeClusterId(): string;
    set edgeClusterId(value: string);
    resetEdgeClusterId(): void;
    get edgeClusterIdInput(): string | undefined;
    private _elasticity?;
    get elasticity(): boolean | cdktf.IResolvable;
    set elasticity(value: boolean | cdktf.IResolvable);
    resetElasticity(): void;
    get elasticityInput(): boolean | cdktf.IResolvable | undefined;
    private _enableFastProvisioning?;
    get enableFastProvisioning(): boolean | cdktf.IResolvable;
    set enableFastProvisioning(value: boolean | cdktf.IResolvable);
    resetEnableFastProvisioning(): void;
    get enableFastProvisioningInput(): boolean | cdktf.IResolvable | undefined;
    private _enableNsxvDistributedFirewall?;
    get enableNsxvDistributedFirewall(): boolean | cdktf.IResolvable;
    set enableNsxvDistributedFirewall(value: boolean | cdktf.IResolvable);
    resetEnableNsxvDistributedFirewall(): void;
    get enableNsxvDistributedFirewallInput(): boolean | cdktf.IResolvable | undefined;
    private _enableThinProvisioning?;
    get enableThinProvisioning(): boolean | cdktf.IResolvable;
    set enableThinProvisioning(value: boolean | cdktf.IResolvable);
    resetEnableThinProvisioning(): void;
    get enableThinProvisioningInput(): boolean | cdktf.IResolvable | undefined;
    private _enableVmDiscovery?;
    get enableVmDiscovery(): boolean | cdktf.IResolvable;
    set enableVmDiscovery(value: boolean | cdktf.IResolvable);
    resetEnableVmDiscovery(): void;
    get enableVmDiscoveryInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _includeVmMemoryOverhead?;
    get includeVmMemoryOverhead(): boolean | cdktf.IResolvable;
    set includeVmMemoryOverhead(value: boolean | cdktf.IResolvable);
    resetIncludeVmMemoryOverhead(): void;
    get includeVmMemoryOverheadInput(): boolean | cdktf.IResolvable | undefined;
    private _memoryGuaranteed?;
    get memoryGuaranteed(): number;
    set memoryGuaranteed(value: number);
    resetMemoryGuaranteed(): void;
    get memoryGuaranteedInput(): number | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkPoolName?;
    get networkPoolName(): string;
    set networkPoolName(value: string);
    resetNetworkPoolName(): void;
    get networkPoolNameInput(): string | undefined;
    private _networkQuota?;
    get networkQuota(): number;
    set networkQuota(value: number);
    resetNetworkQuota(): void;
    get networkQuotaInput(): number | undefined;
    private _nicQuota?;
    get nicQuota(): number;
    set nicQuota(value: number);
    resetNicQuota(): void;
    get nicQuotaInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _providerVdcName?;
    get providerVdcName(): string;
    set providerVdcName(value: string);
    get providerVdcNameInput(): string | undefined;
    private _vmPlacementPolicyIds?;
    get vmPlacementPolicyIds(): string[];
    set vmPlacementPolicyIds(value: string[]);
    resetVmPlacementPolicyIds(): void;
    get vmPlacementPolicyIdsInput(): string[] | undefined;
    private _vmQuota?;
    get vmQuota(): number;
    set vmQuota(value: number);
    resetVmQuota(): void;
    get vmQuotaInput(): number | undefined;
    private _vmSizingPolicyIds?;
    get vmSizingPolicyIds(): string[];
    set vmSizingPolicyIds(value: string[]);
    resetVmSizingPolicyIds(): void;
    get vmSizingPolicyIdsInput(): string[] | undefined;
    private _vmVgpuPolicyIds?;
    get vmVgpuPolicyIds(): string[];
    set vmVgpuPolicyIds(value: string[]);
    resetVmVgpuPolicyIds(): void;
    get vmVgpuPolicyIdsInput(): string[] | undefined;
    private _computeCapacity;
    get computeCapacity(): OrgVdcComputeCapacityOutputReference;
    putComputeCapacity(value: OrgVdcComputeCapacity): void;
    get computeCapacityInput(): OrgVdcComputeCapacity | undefined;
    private _metadataEntry;
    get metadataEntry(): OrgVdcMetadataEntryList;
    putMetadataEntry(value: OrgVdcMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | OrgVdcMetadataEntry[] | undefined;
    private _storageProfile;
    get storageProfile(): OrgVdcStorageProfileList;
    putStorageProfile(value: OrgVdcStorageProfile[] | cdktf.IResolvable): void;
    get storageProfileInput(): cdktf.IResolvable | OrgVdcStorageProfile[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
