import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgConfig extends cdktf.TerraformMetaArguments {
    /**
    * True if this organization is allowed to share catalogs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#can_publish_catalogs Org#can_publish_catalogs}
    */
    readonly canPublishCatalogs?: boolean | cdktf.IResolvable;
    /**
    * True if this organization is allowed to publish external catalogs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#can_publish_external_catalogs Org#can_publish_external_catalogs}
    */
    readonly canPublishExternalCatalogs?: boolean | cdktf.IResolvable;
    /**
    * True if this organization is allowed to subscribe to external catalogs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#can_subscribe_external_catalogs Org#can_subscribe_external_catalogs}
    */
    readonly canSubscribeExternalCatalogs?: boolean | cdktf.IResolvable;
    /**
    * Specifies this organization's default for virtual machine boot delay after power on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#delay_after_power_on_seconds Org#delay_after_power_on_seconds}
    */
    readonly delayAfterPowerOnSeconds?: number;
    /**
    * When destroying use delete_force=True with delete_recursive=True to remove an org and any objects it contains, regardless of their state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#delete_force Org#delete_force}
    */
    readonly deleteForce?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_recursive=True to remove the org and any objects it contains that are in a state that normally allows removal.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#delete_recursive Org#delete_recursive}
    */
    readonly deleteRecursive?: boolean | cdktf.IResolvable;
    /**
    * Maximum number of virtual machines that can be deployed simultaneously by a member of this organization. (0 = unlimited)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#deployed_vm_quota Org#deployed_vm_quota}
    */
    readonly deployedVmQuota?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#description Org#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#full_name Org#full_name}
    */
    readonly fullName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#id Org#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * True if this organization is enabled (allows login and all other operations).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#is_enabled Org#is_enabled}
    */
    readonly isEnabled?: boolean | cdktf.IResolvable;
    /**
    * Key value map of metadata to assign to this organization. Key and value can be any string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#metadata Org#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#name Org#name}
    */
    readonly name: string;
    /**
    * Maximum number of virtual machines in vApps or vApp templates that can be stored in an undeployed state by a member of this organization. (0 = unlimited)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#stored_vm_quota Org#stored_vm_quota}
    */
    readonly storedVmQuota?: number;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#metadata_entry Org#metadata_entry}
    */
    readonly metadataEntry?: OrgMetadataEntry[] | cdktf.IResolvable;
    /**
    * vapp_lease block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#vapp_lease Org#vapp_lease}
    */
    readonly vappLease?: OrgVappLease;
    /**
    * vapp_template_lease block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#vapp_template_lease Org#vapp_template_lease}
    */
    readonly vappTemplateLease?: OrgVappTemplateLease;
}
export interface OrgMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#is_system Org#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#key Org#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#type Org#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#user_access Org#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#value Org#value}
    */
    readonly value?: string;
}
export declare function orgMetadataEntryToTerraform(struct?: OrgMetadataEntry | cdktf.IResolvable): any;
export declare function orgMetadataEntryToHclTerraform(struct?: OrgMetadataEntry | cdktf.IResolvable): any;
export declare class OrgMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: OrgMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class OrgMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgMetadataEntryOutputReference;
}
export interface OrgVappLease {
    /**
    * If true, storage for a vApp is deleted when the vApp's lease expires. If false, the storage is flagged for deletion, but not deleted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#delete_on_storage_lease_expiration Org#delete_on_storage_lease_expiration}
    */
    readonly deleteOnStorageLeaseExpiration: boolean | cdktf.IResolvable;
    /**
    * How long vApps can run before they are automatically stopped (in seconds). 0 means never expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#maximum_runtime_lease_in_sec Org#maximum_runtime_lease_in_sec}
    */
    readonly maximumRuntimeLeaseInSec: number;
    /**
    * How long stopped vApps are available before being automatically cleaned up (in seconds). 0 means never expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#maximum_storage_lease_in_sec Org#maximum_storage_lease_in_sec}
    */
    readonly maximumStorageLeaseInSec: number;
    /**
    * When true, vApps are powered off when the runtime lease expires. When false, vApps are suspended when the runtime lease expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#power_off_on_runtime_lease_expiration Org#power_off_on_runtime_lease_expiration}
    */
    readonly powerOffOnRuntimeLeaseExpiration: boolean | cdktf.IResolvable;
}
export declare function orgVappLeaseToTerraform(struct?: OrgVappLeaseOutputReference | OrgVappLease): any;
export declare function orgVappLeaseToHclTerraform(struct?: OrgVappLeaseOutputReference | OrgVappLease): any;
export declare class OrgVappLeaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVappLease | undefined;
    set internalValue(value: OrgVappLease | undefined);
    private _deleteOnStorageLeaseExpiration?;
    get deleteOnStorageLeaseExpiration(): boolean | cdktf.IResolvable;
    set deleteOnStorageLeaseExpiration(value: boolean | cdktf.IResolvable);
    get deleteOnStorageLeaseExpirationInput(): boolean | cdktf.IResolvable | undefined;
    private _maximumRuntimeLeaseInSec?;
    get maximumRuntimeLeaseInSec(): number;
    set maximumRuntimeLeaseInSec(value: number);
    get maximumRuntimeLeaseInSecInput(): number | undefined;
    private _maximumStorageLeaseInSec?;
    get maximumStorageLeaseInSec(): number;
    set maximumStorageLeaseInSec(value: number);
    get maximumStorageLeaseInSecInput(): number | undefined;
    private _powerOffOnRuntimeLeaseExpiration?;
    get powerOffOnRuntimeLeaseExpiration(): boolean | cdktf.IResolvable;
    set powerOffOnRuntimeLeaseExpiration(value: boolean | cdktf.IResolvable);
    get powerOffOnRuntimeLeaseExpirationInput(): boolean | cdktf.IResolvable | undefined;
}
export interface OrgVappTemplateLease {
    /**
    * If true, storage for a vAppTemplate is deleted when the vAppTemplate lease expires. If false, the storage is flagged for deletion, but not deleted
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#delete_on_storage_lease_expiration Org#delete_on_storage_lease_expiration}
    */
    readonly deleteOnStorageLeaseExpiration: boolean | cdktf.IResolvable;
    /**
    * How long vApp templates are available before being automatically cleaned up (in seconds). 0 means never expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#maximum_storage_lease_in_sec Org#maximum_storage_lease_in_sec}
    */
    readonly maximumStorageLeaseInSec: number;
}
export declare function orgVappTemplateLeaseToTerraform(struct?: OrgVappTemplateLeaseOutputReference | OrgVappTemplateLease): any;
export declare function orgVappTemplateLeaseToHclTerraform(struct?: OrgVappTemplateLeaseOutputReference | OrgVappTemplateLease): any;
export declare class OrgVappTemplateLeaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVappTemplateLease | undefined;
    set internalValue(value: OrgVappTemplateLease | undefined);
    private _deleteOnStorageLeaseExpiration?;
    get deleteOnStorageLeaseExpiration(): boolean | cdktf.IResolvable;
    set deleteOnStorageLeaseExpiration(value: boolean | cdktf.IResolvable);
    get deleteOnStorageLeaseExpirationInput(): boolean | cdktf.IResolvable | undefined;
    private _maximumStorageLeaseInSec?;
    get maximumStorageLeaseInSec(): number;
    set maximumStorageLeaseInSec(value: number);
    get maximumStorageLeaseInSecInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org vcd_org}
*/
export declare class Org extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org";
    /**
    * Generates CDKTF code for importing a Org resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Org to import
    * @param importFromId The id of the existing Org that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Org to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/org vcd_org} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgConfig
    */
    constructor(scope: Construct, id: string, config: OrgConfig);
    private _canPublishCatalogs?;
    get canPublishCatalogs(): boolean | cdktf.IResolvable;
    set canPublishCatalogs(value: boolean | cdktf.IResolvable);
    resetCanPublishCatalogs(): void;
    get canPublishCatalogsInput(): boolean | cdktf.IResolvable | undefined;
    private _canPublishExternalCatalogs?;
    get canPublishExternalCatalogs(): boolean | cdktf.IResolvable;
    set canPublishExternalCatalogs(value: boolean | cdktf.IResolvable);
    resetCanPublishExternalCatalogs(): void;
    get canPublishExternalCatalogsInput(): boolean | cdktf.IResolvable | undefined;
    private _canSubscribeExternalCatalogs?;
    get canSubscribeExternalCatalogs(): boolean | cdktf.IResolvable;
    set canSubscribeExternalCatalogs(value: boolean | cdktf.IResolvable);
    resetCanSubscribeExternalCatalogs(): void;
    get canSubscribeExternalCatalogsInput(): boolean | cdktf.IResolvable | undefined;
    private _delayAfterPowerOnSeconds?;
    get delayAfterPowerOnSeconds(): number;
    set delayAfterPowerOnSeconds(value: number);
    resetDelayAfterPowerOnSeconds(): void;
    get delayAfterPowerOnSecondsInput(): number | undefined;
    private _deleteForce?;
    get deleteForce(): boolean | cdktf.IResolvable;
    set deleteForce(value: boolean | cdktf.IResolvable);
    resetDeleteForce(): void;
    get deleteForceInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteRecursive?;
    get deleteRecursive(): boolean | cdktf.IResolvable;
    set deleteRecursive(value: boolean | cdktf.IResolvable);
    resetDeleteRecursive(): void;
    get deleteRecursiveInput(): boolean | cdktf.IResolvable | undefined;
    private _deployedVmQuota?;
    get deployedVmQuota(): number;
    set deployedVmQuota(value: number);
    resetDeployedVmQuota(): void;
    get deployedVmQuotaInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _fullName?;
    get fullName(): string;
    set fullName(value: string);
    get fullNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isEnabled?;
    get isEnabled(): boolean | cdktf.IResolvable;
    set isEnabled(value: boolean | cdktf.IResolvable);
    resetIsEnabled(): void;
    get isEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get listOfCatalogs(): string[];
    get listOfVdcs(): string[];
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numberOfCatalogs(): number;
    get numberOfVdcs(): number;
    private _storedVmQuota?;
    get storedVmQuota(): number;
    set storedVmQuota(value: number);
    resetStoredVmQuota(): void;
    get storedVmQuotaInput(): number | undefined;
    private _metadataEntry;
    get metadataEntry(): OrgMetadataEntryList;
    putMetadataEntry(value: OrgMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | OrgMetadataEntry[] | undefined;
    private _vappLease;
    get vappLease(): OrgVappLeaseOutputReference;
    putVappLease(value: OrgVappLease): void;
    resetVappLease(): void;
    get vappLeaseInput(): OrgVappLease | undefined;
    private _vappTemplateLease;
    get vappTemplateLease(): OrgVappTemplateLeaseOutputReference;
    putVappTemplateLease(value: OrgVappTemplateLease): void;
    resetVappTemplateLease(): void;
    get vappTemplateLeaseInput(): OrgVappTemplateLease | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
