import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ProviderVdcConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional description of the Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#description ProviderVdc#description}
    */
    readonly description?: string;
    /**
    * The highest virtual hardware version supported by this Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#highest_supported_hardware_version ProviderVdc#highest_supported_hardware_version}
    */
    readonly highestSupportedHardwareVersion: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#id ProviderVdc#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * True if this Provider VDC is enabled and can provide resources to organization VDCs. A Provider VDC is always enabled on creation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#is_enabled ProviderVdc#is_enabled}
    */
    readonly isEnabled?: boolean | cdktf.IResolvable;
    /**
    * Name of the Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#name ProviderVdc#name}
    */
    readonly name: string;
    /**
    * Set IDs of the network pools used by this Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#network_pool_ids ProviderVdc#network_pool_ids}
    */
    readonly networkPoolIds?: string[];
    /**
    * ID of the registered NSX-T Manager that backs networking operations for this Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#nsxt_manager_id ProviderVdc#nsxt_manager_id}
    */
    readonly nsxtManagerId?: string;
    /**
    * Set of IDs of the resource pools backing this provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#resource_pool_ids ProviderVdc#resource_pool_ids}
    */
    readonly resourcePoolIds: string[];
    /**
    * Set of storage profile names used to create this Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#storage_profile_names ProviderVdc#storage_profile_names}
    */
    readonly storageProfileNames: string[];
    /**
    * ID of the vCenter server that provides the resource pools and datastores
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#vcenter_id ProviderVdc#vcenter_id}
    */
    readonly vcenterId: string;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#metadata_entry ProviderVdc#metadata_entry}
    */
    readonly metadataEntry?: ProviderVdcMetadataEntry[] | cdktf.IResolvable;
}
export interface ProviderVdcComputeCapacityCpu {
}
export declare function providerVdcComputeCapacityCpuToTerraform(struct?: ProviderVdcComputeCapacityCpu): any;
export declare function providerVdcComputeCapacityCpuToHclTerraform(struct?: ProviderVdcComputeCapacityCpu): any;
export declare class ProviderVdcComputeCapacityCpuOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ProviderVdcComputeCapacityCpu | undefined;
    set internalValue(value: ProviderVdcComputeCapacityCpu | undefined);
    get allocation(): number;
    get overhead(): number;
    get reserved(): number;
    get total(): number;
    get units(): string;
    get used(): number;
}
export declare class ProviderVdcComputeCapacityCpuList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ProviderVdcComputeCapacityCpuOutputReference;
}
export interface ProviderVdcComputeCapacityMemory {
}
export declare function providerVdcComputeCapacityMemoryToTerraform(struct?: ProviderVdcComputeCapacityMemory): any;
export declare function providerVdcComputeCapacityMemoryToHclTerraform(struct?: ProviderVdcComputeCapacityMemory): any;
export declare class ProviderVdcComputeCapacityMemoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ProviderVdcComputeCapacityMemory | undefined;
    set internalValue(value: ProviderVdcComputeCapacityMemory | undefined);
    get allocation(): number;
    get overhead(): number;
    get reserved(): number;
    get total(): number;
    get units(): string;
    get used(): number;
}
export declare class ProviderVdcComputeCapacityMemoryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ProviderVdcComputeCapacityMemoryOutputReference;
}
export interface ProviderVdcComputeCapacity {
}
export declare function providerVdcComputeCapacityToTerraform(struct?: ProviderVdcComputeCapacity): any;
export declare function providerVdcComputeCapacityToHclTerraform(struct?: ProviderVdcComputeCapacity): any;
export declare class ProviderVdcComputeCapacityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ProviderVdcComputeCapacity | undefined;
    set internalValue(value: ProviderVdcComputeCapacity | undefined);
    private _cpu;
    get cpu(): ProviderVdcComputeCapacityCpuList;
    get isElastic(): cdktf.IResolvable;
    get isHa(): cdktf.IResolvable;
    private _memory;
    get memory(): ProviderVdcComputeCapacityMemoryList;
}
export declare class ProviderVdcComputeCapacityList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ProviderVdcComputeCapacityOutputReference;
}
export interface ProviderVdcMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL. Defaults to false
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#is_system ProviderVdc#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#key ProviderVdc#key}
    */
    readonly key: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'. Defaults to 'MetadataStringValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#type ProviderVdc#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'. Defaults to 'READWRITE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#user_access ProviderVdc#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#value ProviderVdc#value}
    */
    readonly value: string;
}
export declare function providerVdcMetadataEntryToTerraform(struct?: ProviderVdcMetadataEntry | cdktf.IResolvable): any;
export declare function providerVdcMetadataEntryToHclTerraform(struct?: ProviderVdcMetadataEntry | cdktf.IResolvable): any;
export declare class ProviderVdcMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ProviderVdcMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: ProviderVdcMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ProviderVdcMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ProviderVdcMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ProviderVdcMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc vcd_provider_vdc}
*/
export declare class ProviderVdc extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_provider_vdc";
    /**
    * Generates CDKTF code for importing a ProviderVdc resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ProviderVdc to import
    * @param importFromId The id of the existing ProviderVdc that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ProviderVdc to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/provider_vdc vcd_provider_vdc} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ProviderVdcConfig
    */
    constructor(scope: Construct, id: string, config: ProviderVdcConfig);
    get capabilities(): string[];
    private _computeCapacity;
    get computeCapacity(): ProviderVdcComputeCapacityList;
    get computeProviderScope(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get externalNetworkIds(): string[];
    private _highestSupportedHardwareVersion?;
    get highestSupportedHardwareVersion(): string;
    set highestSupportedHardwareVersion(value: string);
    get highestSupportedHardwareVersionInput(): string | undefined;
    get hostIds(): string[];
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isEnabled?;
    get isEnabled(): boolean | cdktf.IResolvable;
    set isEnabled(value: boolean | cdktf.IResolvable);
    resetIsEnabled(): void;
    get isEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkPoolIds?;
    get networkPoolIds(): string[];
    set networkPoolIds(value: string[]);
    resetNetworkPoolIds(): void;
    get networkPoolIdsInput(): string[] | undefined;
    private _nsxtManagerId?;
    get nsxtManagerId(): string;
    set nsxtManagerId(value: string);
    resetNsxtManagerId(): void;
    get nsxtManagerIdInput(): string | undefined;
    private _resourcePoolIds?;
    get resourcePoolIds(): string[];
    set resourcePoolIds(value: string[]);
    get resourcePoolIdsInput(): string[] | undefined;
    get status(): number;
    get storageContainerIds(): string[];
    get storageProfileIds(): string[];
    private _storageProfileNames?;
    get storageProfileNames(): string[];
    set storageProfileNames(value: string[]);
    get storageProfileNamesInput(): string[] | undefined;
    get universalNetworkPoolId(): string;
    private _vcenterId?;
    get vcenterId(): string;
    set vcenterId(value: string);
    get vcenterIdInput(): string | undefined;
    private _metadataEntry;
    get metadataEntry(): ProviderVdcMetadataEntryList;
    putMetadataEntry(value: ProviderVdcMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | ProviderVdcMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
