import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VcdProviderConfig {
    /**
    * Set this to true if you understand the security risks of using API token files and would like to suppress the warnings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#allow_api_token_file VcdProvider#allow_api_token_file}
    */
    readonly allowApiTokenFile?: boolean | cdktf.IResolvable;
    /**
    * Set this to true if you understand the security risks of using Service Account token files and would like to suppress the warnings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#allow_service_account_token_file VcdProvider#allow_service_account_token_file}
    */
    readonly allowServiceAccountTokenFile?: boolean | cdktf.IResolvable;
    /**
    * If set, VCDClient will permit unverifiable SSL certificates.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#allow_unverified_ssl VcdProvider#allow_unverified_ssl}
    */
    readonly allowUnverifiedSsl?: boolean | cdktf.IResolvable;
    /**
    * The API token used instead of username/password for VCD API operations. (Requires VCD 10.3.1+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#api_token VcdProvider#api_token}
    */
    readonly apiToken?: string;
    /**
    * The API token file instead of username/password for VCD API operations. (Requires VCD 10.3.1+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#api_token_file VcdProvider#api_token_file}
    */
    readonly apiTokenFile?: string;
    /**
    * 'integrated', 'saml_adfs', 'token', 'api_token', 'api_token_file' and 'service_account_token_file' are supported. 'integrated' is default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#auth_type VcdProvider#auth_type}
    */
    readonly authType?: string;
    /**
    * Defines the import separation string to be used with 'terraform import'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#import_separator VcdProvider#import_separator}
    */
    readonly importSeparator?: string;
    /**
    * If set, it will enable logging of API requests and responses
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#logging VcdProvider#logging}
    */
    readonly logging?: boolean | cdktf.IResolvable;
    /**
    * Defines the full name of the logging file for API calls (requires 'logging')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#logging_file VcdProvider#logging_file}
    */
    readonly loggingFile?: string;
    /**
    * Max num seconds to wait for successful response when operating on resources within vCloud (defaults to 60)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#max_retry_timeout VcdProvider#max_retry_timeout}
    */
    readonly maxRetryTimeout?: number;
    /**
    * The VCD Org for API operations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#org VcdProvider#org}
    */
    readonly org: string;
    /**
    * The user password for VCD API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#password VcdProvider#password}
    */
    readonly password?: string;
    /**
    * Allows to specify custom Relaying Party Trust Identifier for auth_type=saml_adfs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#saml_adfs_rpt_id VcdProvider#saml_adfs_rpt_id}
    */
    readonly samlAdfsRptId?: string;
    /**
    * The Service Account API token file instead of username/password for VCD API operations. (Requires VCD 10.4.0+)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#service_account_token_file VcdProvider#service_account_token_file}
    */
    readonly serviceAccountTokenFile?: string;
    /**
    * The VCD Org for user authentication
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#sysorg VcdProvider#sysorg}
    */
    readonly sysorg?: string;
    /**
    * The token used instead of username/password for VCD API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#token VcdProvider#token}
    */
    readonly token?: string;
    /**
    * The VCD url for VCD API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#url VcdProvider#url}
    */
    readonly url: string;
    /**
    * The user name for VCD API operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#user VcdProvider#user}
    */
    readonly user?: string;
    /**
    * The VDC for API operations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#vdc VcdProvider#vdc}
    */
    readonly vdc?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#alias VcdProvider#alias}
    */
    readonly alias?: string;
    /**
    * ignore_metadata_changes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#ignore_metadata_changes VcdProvider#ignore_metadata_changes}
    */
    readonly ignoreMetadataChanges?: VcdProviderIgnoreMetadataChanges[] | cdktf.IResolvable;
}
export interface VcdProviderIgnoreMetadataChanges {
    /**
    * One of 'error', 'warn' or 'none'. Configures whether a conflict between this ignored metadata block and the metadata entries set in Terraform should fail, warn or do nothing. Defaults to 'error'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#conflict_action VcdProvider#conflict_action}
    */
    readonly conflictAction?: string;
    /**
    * Regular expression of the metadata entry keys to ignore. Either `key_regex` or `value_regex` is required
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#key_regex VcdProvider#key_regex}
    */
    readonly keyRegex?: string;
    /**
    * Ignores metadata from the specific entity in VCD named like this argument
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#resource_name VcdProvider#resource_name}
    */
    readonly resourceName?: string;
    /**
    * Ignores metadata from the specific resource type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#resource_type VcdProvider#resource_type}
    */
    readonly resourceType?: string;
    /**
    * Regular expression of the metadata entry values to ignore. Either `key_regex` or `value_regex` is required
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#value_regex VcdProvider#value_regex}
    */
    readonly valueRegex?: string;
}
export declare function vcdProviderIgnoreMetadataChangesToTerraform(struct?: VcdProviderIgnoreMetadataChanges | cdktf.IResolvable): any;
export declare function vcdProviderIgnoreMetadataChangesToHclTerraform(struct?: VcdProviderIgnoreMetadataChanges | cdktf.IResolvable): any;
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs vcd}
*/
export declare class VcdProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "vcd";
    /**
    * Generates CDKTF code for importing a VcdProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VcdProvider to import
    * @param importFromId The id of the existing VcdProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VcdProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs vcd} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VcdProviderConfig
    */
    constructor(scope: Construct, id: string, config: VcdProviderConfig);
    private _allowApiTokenFile?;
    get allowApiTokenFile(): boolean | cdktf.IResolvable | undefined;
    set allowApiTokenFile(value: boolean | cdktf.IResolvable | undefined);
    resetAllowApiTokenFile(): void;
    get allowApiTokenFileInput(): boolean | cdktf.IResolvable | undefined;
    private _allowServiceAccountTokenFile?;
    get allowServiceAccountTokenFile(): boolean | cdktf.IResolvable | undefined;
    set allowServiceAccountTokenFile(value: boolean | cdktf.IResolvable | undefined);
    resetAllowServiceAccountTokenFile(): void;
    get allowServiceAccountTokenFileInput(): boolean | cdktf.IResolvable | undefined;
    private _allowUnverifiedSsl?;
    get allowUnverifiedSsl(): boolean | cdktf.IResolvable | undefined;
    set allowUnverifiedSsl(value: boolean | cdktf.IResolvable | undefined);
    resetAllowUnverifiedSsl(): void;
    get allowUnverifiedSslInput(): boolean | cdktf.IResolvable | undefined;
    private _apiToken?;
    get apiToken(): string | undefined;
    set apiToken(value: string | undefined);
    resetApiToken(): void;
    get apiTokenInput(): string | undefined;
    private _apiTokenFile?;
    get apiTokenFile(): string | undefined;
    set apiTokenFile(value: string | undefined);
    resetApiTokenFile(): void;
    get apiTokenFileInput(): string | undefined;
    private _authType?;
    get authType(): string | undefined;
    set authType(value: string | undefined);
    resetAuthType(): void;
    get authTypeInput(): string | undefined;
    private _importSeparator?;
    get importSeparator(): string | undefined;
    set importSeparator(value: string | undefined);
    resetImportSeparator(): void;
    get importSeparatorInput(): string | undefined;
    private _logging?;
    get logging(): boolean | cdktf.IResolvable | undefined;
    set logging(value: boolean | cdktf.IResolvable | undefined);
    resetLogging(): void;
    get loggingInput(): boolean | cdktf.IResolvable | undefined;
    private _loggingFile?;
    get loggingFile(): string | undefined;
    set loggingFile(value: string | undefined);
    resetLoggingFile(): void;
    get loggingFileInput(): string | undefined;
    private _maxRetryTimeout?;
    get maxRetryTimeout(): number | undefined;
    set maxRetryTimeout(value: number | undefined);
    resetMaxRetryTimeout(): void;
    get maxRetryTimeoutInput(): number | undefined;
    private _org?;
    get org(): string | undefined;
    set org(value: string | undefined);
    get orgInput(): string | undefined;
    private _password?;
    get password(): string | undefined;
    set password(value: string | undefined);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _samlAdfsRptId?;
    get samlAdfsRptId(): string | undefined;
    set samlAdfsRptId(value: string | undefined);
    resetSamlAdfsRptId(): void;
    get samlAdfsRptIdInput(): string | undefined;
    private _serviceAccountTokenFile?;
    get serviceAccountTokenFile(): string | undefined;
    set serviceAccountTokenFile(value: string | undefined);
    resetServiceAccountTokenFile(): void;
    get serviceAccountTokenFileInput(): string | undefined;
    private _sysorg?;
    get sysorg(): string | undefined;
    set sysorg(value: string | undefined);
    resetSysorg(): void;
    get sysorgInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _url?;
    get url(): string | undefined;
    set url(value: string | undefined);
    get urlInput(): string | undefined;
    private _user?;
    get user(): string | undefined;
    set user(value: string | undefined);
    resetUser(): void;
    get userInput(): string | undefined;
    private _vdc?;
    get vdc(): string | undefined;
    set vdc(value: string | undefined);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _ignoreMetadataChanges?;
    get ignoreMetadataChanges(): VcdProviderIgnoreMetadataChanges[] | cdktf.IResolvable | undefined;
    set ignoreMetadataChanges(value: VcdProviderIgnoreMetadataChanges[] | cdktf.IResolvable | undefined);
    resetIgnoreMetadataChanges(): void;
    get ignoreMetadataChangesInput(): cdktf.IResolvable | VcdProviderIgnoreMetadataChanges[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
