import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RdeInterfaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#id RdeInterface#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Runtime Defined Entity Interface
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#name RdeInterface#name}
    */
    readonly name: string;
    /**
    * A unique namespace associated with the Runtime Defined Entity Interface. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#nss RdeInterface#nss}
    */
    readonly nss: string;
    /**
    * The vendor name. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#vendor RdeInterface#vendor}
    */
    readonly vendor: string;
    /**
    * The Runtime Defined Entity Interface's version. The version must follow semantic versioning rules. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#version RdeInterface#version}
    */
    readonly version: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface vcd_rde_interface}
*/
export declare class RdeInterface extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rde_interface";
    /**
    * Generates CDKTF code for importing a RdeInterface resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RdeInterface to import
    * @param importFromId The id of the existing RdeInterface that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RdeInterface to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_interface vcd_rde_interface} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RdeInterfaceConfig
    */
    constructor(scope: Construct, id: string, config: RdeInterfaceConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nss?;
    get nss(): string;
    set nss(value: string);
    get nssInput(): string | undefined;
    get readonly(): cdktf.IResolvable;
    private _vendor?;
    get vendor(): string;
    set vendor(value: string);
    get vendorInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
