import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RdeTypeConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the Runtime Defined Entity Type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#description RdeType#description}
    */
    readonly description?: string;
    /**
    * An external entity's ID that this definition may apply to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#external_id RdeType#external_id}
    */
    readonly externalId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#id RdeType#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * To be used when creating a new version of a Runtime Defined Entity Type. Specifies the version of the type that will be the template for the authorization configuration of the new version.The Type ACLs and the access requirements of the Type Behaviors of the new version will be copied from those of the inherited version.If not set, then the new type version will not inherit another version and will have the default authorization settings, just like the first version of a new type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#inherited_version RdeType#inherited_version}
    */
    readonly inheritedVersion?: string;
    /**
    * Set of Defined Interface URNs that this Runtime Defined Entity Type is referenced by
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#interface_ids RdeType#interface_ids}
    */
    readonly interfaceIds?: string[];
    /**
    * The name of the Runtime Defined Entity Type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#name RdeType#name}
    */
    readonly name: string;
    /**
    * A unique namespace associated with the Runtime Defined Entity Type. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#nss RdeType#nss}
    */
    readonly nss: string;
    /**
    * The JSON-Schema valid definition of the Runtime Defined Entity Type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#schema RdeType#schema}
    */
    readonly schema?: string;
    /**
    * URL that should point to a JSON-Schema valid definition file of the Runtime Defined Entity Type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#schema_url RdeType#schema_url}
    */
    readonly schemaUrl?: string;
    /**
    * The vendor name for the Runtime Defined Entity Type. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#vendor RdeType#vendor}
    */
    readonly vendor: string;
    /**
    * The version of the Runtime Defined Entity Type. The version string must follow semantic versioning rules. Combination of `vendor`, `nss` and `version` must be unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#version RdeType#version}
    */
    readonly version: string;
    /**
    * hook block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#hook RdeType#hook}
    */
    readonly hook?: RdeTypeHook[] | cdktf.IResolvable;
}
export interface RdeTypeHook {
    /**
    * Existing Behavior that will be automatically invoked when the RDE of this RDE Type triggers the event
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#behavior_id RdeType#behavior_id}
    */
    readonly behaviorId: string;
    /**
    * Event that will invoke the Behavior, one of PostCreate, PostUpdate, PreDelete, PostDelete
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#event RdeType#event}
    */
    readonly event: string;
}
export declare function rdeTypeHookToTerraform(struct?: RdeTypeHook | cdktf.IResolvable): any;
export declare function rdeTypeHookToHclTerraform(struct?: RdeTypeHook | cdktf.IResolvable): any;
export declare class RdeTypeHookOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RdeTypeHook | cdktf.IResolvable | undefined;
    set internalValue(value: RdeTypeHook | cdktf.IResolvable | undefined);
    private _behaviorId?;
    get behaviorId(): string;
    set behaviorId(value: string);
    get behaviorIdInput(): string | undefined;
    private _event?;
    get event(): string;
    set event(value: string);
    get eventInput(): string | undefined;
}
export declare class RdeTypeHookList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RdeTypeHook[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RdeTypeHookOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type vcd_rde_type}
*/
export declare class RdeType extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rde_type";
    /**
    * Generates CDKTF code for importing a RdeType resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RdeType to import
    * @param importFromId The id of the existing RdeType that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RdeType to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde_type vcd_rde_type} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RdeTypeConfig
    */
    constructor(scope: Construct, id: string, config: RdeTypeConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _externalId?;
    get externalId(): string;
    set externalId(value: string);
    resetExternalId(): void;
    get externalIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inheritedVersion?;
    get inheritedVersion(): string;
    set inheritedVersion(value: string);
    resetInheritedVersion(): void;
    get inheritedVersionInput(): string | undefined;
    private _interfaceIds?;
    get interfaceIds(): string[];
    set interfaceIds(value: string[]);
    resetInterfaceIds(): void;
    get interfaceIdsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nss?;
    get nss(): string;
    set nss(value: string);
    get nssInput(): string | undefined;
    get readonly(): cdktf.IResolvable;
    private _schema?;
    get schema(): string;
    set schema(value: string);
    resetSchema(): void;
    get schemaInput(): string | undefined;
    private _schemaUrl?;
    get schemaUrl(): string;
    set schemaUrl(value: string);
    resetSchemaUrl(): void;
    get schemaUrlInput(): string | undefined;
    private _vendor?;
    get vendor(): string;
    set vendor(value: string);
    get vendorInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    private _hook;
    get hook(): RdeTypeHookList;
    putHook(value: RdeTypeHook[] | cdktf.IResolvable): void;
    resetHook(): void;
    get hookInput(): cdktf.IResolvable | RdeTypeHook[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
