import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RdeConfig extends cdktf.TerraformMetaArguments {
    /**
    * An external entity's ID that this Runtime Defined Entity may have a relation to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#external_id Rde#external_id}
    */
    readonly externalId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#id Rde#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A JSON representation of the Runtime Defined Entity that is defined by the user and is used to initialize/override its contents
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#input_entity Rde#input_entity}
    */
    readonly inputEntity?: string;
    /**
    * URL that should point to a JSON representation of the Runtime Defined Entity and is used to initialize/override its contents
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#input_entity_url Rde#input_entity_url}
    */
    readonly inputEntityUrl?: string;
    /**
    * The name of the Runtime Defined Entity. It can be non-unique
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#name Rde#name}
    */
    readonly name: string;
    /**
    * The name of organization that will own this Runtime Defined Entity, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#org Rde#org}
    */
    readonly org?: string;
    /**
    * The Runtime Defined Entity Type ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#rde_type_id Rde#rde_type_id}
    */
    readonly rdeTypeId: string;
    /**
    * If `true`, the Runtime Defined Entity will be resolved by this provider. If `false`, it won't beresolved and must be done either by an external component action or by an update. The Runtime Defined Entity can't bedeleted until the entity is resolved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#resolve Rde#resolve}
    */
    readonly resolve: boolean | cdktf.IResolvable;
    /**
    * If `true`, the Runtime Defined Entity will be resolved before it gets deleted, to ensure forced deletion.Destroy will fail if it is not resolved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#resolve_on_removal Rde#resolve_on_removal}
    */
    readonly resolveOnRemoval?: boolean | cdktf.IResolvable;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#metadata_entry Rde#metadata_entry}
    */
    readonly metadataEntry?: RdeMetadataEntry[] | cdktf.IResolvable;
}
export interface RdeMetadataEntry {
    /**
    * Only meaningful for providers. Allows them to share entries with their tenants. Currently, accepted values are: `TENANT`, `PROVIDER`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#domain Rde#domain}
    */
    readonly domain?: string;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#key Rde#key}
    */
    readonly key: string;
    /**
    * Namespace of the metadata entry
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#namespace Rde#namespace}
    */
    readonly namespace?: string;
    /**
    * Persistent metadata entries can be copied over on some entity operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#persistent Rde#persistent}
    */
    readonly persistent?: boolean | cdktf.IResolvable;
    /**
    * True if the metadata entry is read only
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#readonly Rde#readonly}
    */
    readonly readonly?: boolean | cdktf.IResolvable;
    /**
    * Type of this metadata entry. One of: 'StringEntry', 'NumberEntry', 'BoolEntry'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#type Rde#type}
    */
    readonly type?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#value Rde#value}
    */
    readonly value: string;
}
export declare function rdeMetadataEntryToTerraform(struct?: RdeMetadataEntry | cdktf.IResolvable): any;
export declare function rdeMetadataEntryToHclTerraform(struct?: RdeMetadataEntry | cdktf.IResolvable): any;
export declare class RdeMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RdeMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: RdeMetadataEntry | cdktf.IResolvable | undefined);
    private _domain?;
    get domain(): string;
    set domain(value: string);
    resetDomain(): void;
    get domainInput(): string | undefined;
    get id(): string;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _persistent?;
    get persistent(): boolean | cdktf.IResolvable;
    set persistent(value: boolean | cdktf.IResolvable);
    resetPersistent(): void;
    get persistentInput(): boolean | cdktf.IResolvable | undefined;
    private _readonly?;
    get readonly(): boolean | cdktf.IResolvable;
    set readonly(value: boolean | cdktf.IResolvable);
    resetReadonly(): void;
    get readonlyInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class RdeMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RdeMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RdeMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde vcd_rde}
*/
export declare class Rde extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rde";
    /**
    * Generates CDKTF code for importing a Rde resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Rde to import
    * @param importFromId The id of the existing Rde that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Rde to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rde vcd_rde} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RdeConfig
    */
    constructor(scope: Construct, id: string, config: RdeConfig);
    get computedEntity(): string;
    get entityInSync(): cdktf.IResolvable;
    private _externalId?;
    get externalId(): string;
    set externalId(value: string);
    resetExternalId(): void;
    get externalIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inputEntity?;
    get inputEntity(): string;
    set inputEntity(value: string);
    resetInputEntity(): void;
    get inputEntityInput(): string | undefined;
    private _inputEntityUrl?;
    get inputEntityUrl(): string;
    set inputEntityUrl(value: string);
    resetInputEntityUrl(): void;
    get inputEntityUrlInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get orgId(): string;
    get ownerUserId(): string;
    private _rdeTypeId?;
    get rdeTypeId(): string;
    set rdeTypeId(value: string);
    get rdeTypeIdInput(): string | undefined;
    private _resolve?;
    get resolve(): boolean | cdktf.IResolvable;
    set resolve(value: boolean | cdktf.IResolvable);
    get resolveInput(): boolean | cdktf.IResolvable | undefined;
    private _resolveOnRemoval?;
    get resolveOnRemoval(): boolean | cdktf.IResolvable;
    set resolveOnRemoval(value: boolean | cdktf.IResolvable);
    resetResolveOnRemoval(): void;
    get resolveOnRemovalInput(): boolean | cdktf.IResolvable | undefined;
    get state(): string;
    private _metadataEntry;
    get metadataEntry(): RdeMetadataEntryList;
    putMetadataEntry(value: RdeMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | RdeMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
