import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RightsBundleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Rights bundle description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#description RightsBundle#description}
    */
    readonly description: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#id RightsBundle#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of rights bundle.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#name RightsBundle#name}
    */
    readonly name: string;
    /**
    * When true, publishes the rights bundle to all tenants
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#publish_to_all_tenants RightsBundle#publish_to_all_tenants}
    */
    readonly publishToAllTenants: boolean | cdktf.IResolvable;
    /**
    * Set of rights assigned to this rights bundle
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#rights RightsBundle#rights}
    */
    readonly rights?: string[];
    /**
    * Set of tenants to which this rights bundle is published
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#tenants RightsBundle#tenants}
    */
    readonly tenants?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle vcd_rights_bundle}
*/
export declare class RightsBundle extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rights_bundle";
    /**
    * Generates CDKTF code for importing a RightsBundle resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RightsBundle to import
    * @param importFromId The id of the existing RightsBundle that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RightsBundle to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/rights_bundle vcd_rights_bundle} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RightsBundleConfig
    */
    constructor(scope: Construct, id: string, config: RightsBundleConfig);
    get bundleKey(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _publishToAllTenants?;
    get publishToAllTenants(): boolean | cdktf.IResolvable;
    set publishToAllTenants(value: boolean | cdktf.IResolvable);
    get publishToAllTenantsInput(): boolean | cdktf.IResolvable | undefined;
    get readOnly(): cdktf.IResolvable;
    private _rights?;
    get rights(): string[];
    set rights(value: string[]);
    resetRights(): void;
    get rightsInput(): string[] | undefined;
    private _tenants?;
    get tenants(): string[];
    set tenants(value: string[]);
    resetTenants(): void;
    get tenantsInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
