import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SubscribedCatalogConfig extends cdktf.TerraformMetaArguments {
    /**
    * When true, the subscribed catalog will attempt canceling failed tasks
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#cancel_failed_tasks SubscribedCatalog#cancel_failed_tasks}
    */
    readonly cancelFailedTasks?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_force=True with delete_recursive=True to remove a catalog and any objects it contains, regardless of their state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#delete_force SubscribedCatalog#delete_force}
    */
    readonly deleteForce?: boolean | cdktf.IResolvable;
    /**
    * When destroying use delete_recursive=True to remove the catalog and any objects it contains that are in a state that normally allows removal.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#delete_recursive SubscribedCatalog#delete_recursive}
    */
    readonly deleteRecursive?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#id SubscribedCatalog#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * If true, subscription to a catalog creates a local copy of all items. Defaults to false, which does not create a local copy of catalog items unless a sync operation is performed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#make_local_copy SubscribedCatalog#make_local_copy}
    */
    readonly makeLocalCopy?: boolean | cdktf.IResolvable;
    /**
    * The name of the catalog
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#name SubscribedCatalog#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#org SubscribedCatalog#org}
    */
    readonly org?: string;
    /**
    * Optional storage profile ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#storage_profile_id SubscribedCatalog#storage_profile_id}
    */
    readonly storageProfileId?: string;
    /**
    * If true, saves list of tasks to file for later update
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#store_tasks SubscribedCatalog#store_tasks}
    */
    readonly storeTasks?: boolean | cdktf.IResolvable;
    /**
    * An optional password to access the catalog. Only ASCII characters are allowed in a valid password. Passing in six asterisks '******' indicates to keep current password. Passing in null or empty string indicates to remove password.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#subscription_password SubscribedCatalog#subscription_password}
    */
    readonly subscriptionPassword?: string;
    /**
    * The URL to subscribe to the external catalog.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#subscription_url SubscribedCatalog#subscription_url}
    */
    readonly subscriptionUrl: string;
    /**
    * If true, synchronise this catalog and all items
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_all SubscribedCatalog#sync_all}
    */
    readonly syncAll?: boolean | cdktf.IResolvable;
    /**
    * If true, synchronises all media items
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_all_media_items SubscribedCatalog#sync_all_media_items}
    */
    readonly syncAllMediaItems?: boolean | cdktf.IResolvable;
    /**
    * If true, synchronises all vApp templates
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_all_vapp_templates SubscribedCatalog#sync_all_vapp_templates}
    */
    readonly syncAllVappTemplates?: boolean | cdktf.IResolvable;
    /**
    * If true, synchronise this catalog. This operation fetches the list of items. If `make_local_copy` is set, it also fetches the items data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_catalog SubscribedCatalog#sync_catalog}
    */
    readonly syncCatalog?: boolean | cdktf.IResolvable;
    /**
    * Synchronises media items from this list of names.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_media_items SubscribedCatalog#sync_media_items}
    */
    readonly syncMediaItems?: string[];
    /**
    * Boolean value that shows if sync should be performed on every refresh.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_on_refresh SubscribedCatalog#sync_on_refresh}
    */
    readonly syncOnRefresh?: boolean | cdktf.IResolvable;
    /**
    * Synchronises vApp templates from this list of names.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#sync_vapp_templates SubscribedCatalog#sync_vapp_templates}
    */
    readonly syncVappTemplates?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog vcd_subscribed_catalog}
*/
export declare class SubscribedCatalog extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_subscribed_catalog";
    /**
    * Generates CDKTF code for importing a SubscribedCatalog resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SubscribedCatalog to import
    * @param importFromId The id of the existing SubscribedCatalog that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SubscribedCatalog to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/subscribed_catalog vcd_subscribed_catalog} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SubscribedCatalogConfig
    */
    constructor(scope: Construct, id: string, config: SubscribedCatalogConfig);
    private _cancelFailedTasks?;
    get cancelFailedTasks(): boolean | cdktf.IResolvable;
    set cancelFailedTasks(value: boolean | cdktf.IResolvable);
    resetCancelFailedTasks(): void;
    get cancelFailedTasksInput(): boolean | cdktf.IResolvable | undefined;
    get catalogVersion(): number;
    get created(): string;
    private _deleteForce?;
    get deleteForce(): boolean | cdktf.IResolvable;
    set deleteForce(value: boolean | cdktf.IResolvable);
    resetDeleteForce(): void;
    get deleteForceInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteRecursive?;
    get deleteRecursive(): boolean | cdktf.IResolvable;
    set deleteRecursive(value: boolean | cdktf.IResolvable);
    resetDeleteRecursive(): void;
    get deleteRecursiveInput(): boolean | cdktf.IResolvable | undefined;
    get description(): string;
    get failedTasks(): string[];
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get isLocal(): cdktf.IResolvable;
    get isPublished(): cdktf.IResolvable;
    get isShared(): cdktf.IResolvable;
    private _makeLocalCopy?;
    get makeLocalCopy(): boolean | cdktf.IResolvable;
    set makeLocalCopy(value: boolean | cdktf.IResolvable);
    resetMakeLocalCopy(): void;
    get makeLocalCopyInput(): boolean | cdktf.IResolvable | undefined;
    get mediaItemList(): string[];
    private _metadata;
    get metadata(): cdktf.StringMap;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numberOfMedia(): number;
    get numberOfVappTemplates(): number;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get ownerName(): string;
    get publishSubscriptionType(): string;
    get runningTasks(): string[];
    private _storageProfileId?;
    get storageProfileId(): string;
    set storageProfileId(value: string);
    resetStorageProfileId(): void;
    get storageProfileIdInput(): string | undefined;
    private _storeTasks?;
    get storeTasks(): boolean | cdktf.IResolvable;
    set storeTasks(value: boolean | cdktf.IResolvable);
    resetStoreTasks(): void;
    get storeTasksInput(): boolean | cdktf.IResolvable | undefined;
    private _subscriptionPassword?;
    get subscriptionPassword(): string;
    set subscriptionPassword(value: string);
    resetSubscriptionPassword(): void;
    get subscriptionPasswordInput(): string | undefined;
    private _subscriptionUrl?;
    get subscriptionUrl(): string;
    set subscriptionUrl(value: string);
    get subscriptionUrlInput(): string | undefined;
    private _syncAll?;
    get syncAll(): boolean | cdktf.IResolvable;
    set syncAll(value: boolean | cdktf.IResolvable);
    resetSyncAll(): void;
    get syncAllInput(): boolean | cdktf.IResolvable | undefined;
    private _syncAllMediaItems?;
    get syncAllMediaItems(): boolean | cdktf.IResolvable;
    set syncAllMediaItems(value: boolean | cdktf.IResolvable);
    resetSyncAllMediaItems(): void;
    get syncAllMediaItemsInput(): boolean | cdktf.IResolvable | undefined;
    private _syncAllVappTemplates?;
    get syncAllVappTemplates(): boolean | cdktf.IResolvable;
    set syncAllVappTemplates(value: boolean | cdktf.IResolvable);
    resetSyncAllVappTemplates(): void;
    get syncAllVappTemplatesInput(): boolean | cdktf.IResolvable | undefined;
    private _syncCatalog?;
    get syncCatalog(): boolean | cdktf.IResolvable;
    set syncCatalog(value: boolean | cdktf.IResolvable);
    resetSyncCatalog(): void;
    get syncCatalogInput(): boolean | cdktf.IResolvable | undefined;
    private _syncMediaItems?;
    get syncMediaItems(): string[];
    set syncMediaItems(value: string[]);
    resetSyncMediaItems(): void;
    get syncMediaItemsInput(): string[] | undefined;
    private _syncOnRefresh?;
    get syncOnRefresh(): boolean | cdktf.IResolvable;
    set syncOnRefresh(value: boolean | cdktf.IResolvable);
    resetSyncOnRefresh(): void;
    get syncOnRefreshInput(): boolean | cdktf.IResolvable | undefined;
    private _syncVappTemplates?;
    get syncVappTemplates(): string[];
    set syncVappTemplates(value: string[]);
    resetSyncVappTemplates(): void;
    get syncVappTemplatesInput(): string[] | undefined;
    get tasksFileName(): string;
    get vappTemplateList(): string[];
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
