import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface UiPluginConfig extends cdktf.TerraformMetaArguments {
    /**
    * true to make the UI Plugin enabled. 'false' to make it disabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#enabled UiPlugin#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#id UiPlugin#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Absolute or relative path to the ZIP file containing the UI Plugin
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#plugin_path UiPlugin#plugin_path}
    */
    readonly pluginPath?: string;
    /**
    * This value is calculated automatically on create by reading the UI Plugin ZIP file contents. You can updateit to `true` to make it provider scoped or `false` otherwise
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#provider_scoped UiPlugin#provider_scoped}
    */
    readonly providerScoped?: boolean | cdktf.IResolvable;
    /**
    * Set of organization IDs to which this UI Plugin must be published
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#tenant_ids UiPlugin#tenant_ids}
    */
    readonly tenantIds?: string[];
    /**
    * This value is calculated automatically on create by reading the UI Plugin ZIP file contents. You can updateit to `true` to make it tenant scoped or `false` otherwise
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#tenant_scoped UiPlugin#tenant_scoped}
    */
    readonly tenantScoped?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin vcd_ui_plugin}
*/
export declare class UiPlugin extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_ui_plugin";
    /**
    * Generates CDKTF code for importing a UiPlugin resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the UiPlugin to import
    * @param importFromId The id of the existing UiPlugin that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the UiPlugin to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/ui_plugin vcd_ui_plugin} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options UiPluginConfig
    */
    constructor(scope: Construct, id: string, config: UiPluginConfig);
    get description(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get license(): string;
    get link(): string;
    get name(): string;
    private _pluginPath?;
    get pluginPath(): string;
    set pluginPath(value: string);
    resetPluginPath(): void;
    get pluginPathInput(): string | undefined;
    private _providerScoped?;
    get providerScoped(): boolean | cdktf.IResolvable;
    set providerScoped(value: boolean | cdktf.IResolvable);
    resetProviderScoped(): void;
    get providerScopedInput(): boolean | cdktf.IResolvable | undefined;
    get status(): string;
    private _tenantIds?;
    get tenantIds(): string[];
    set tenantIds(value: string[]);
    resetTenantIds(): void;
    get tenantIdsInput(): string[] | undefined;
    private _tenantScoped?;
    get tenantScoped(): boolean | cdktf.IResolvable;
    set tenantScoped(value: boolean | cdktf.IResolvable);
    resetTenantScoped(): void;
    get tenantScopedInput(): boolean | cdktf.IResolvable | undefined;
    get vendor(): string;
    get version(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
