import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappAccessControlConfig extends cdktf.TerraformMetaArguments {
    /**
    * Access level when the vApp is shared with everyone (one of ReadOnly, Change, FullControl). Required when shared_with_everyone is set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#everyone_access_level VappAccessControl#everyone_access_level}
    */
    readonly everyoneAccessLevel?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#id VappAccessControl#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#org VappAccessControl#org}
    */
    readonly org?: string;
    /**
    * Whether the vApp is shared with everyone
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#shared_with_everyone VappAccessControl#shared_with_everyone}
    */
    readonly sharedWithEveryone: boolean | cdktf.IResolvable;
    /**
    * vApp identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#vapp_id VappAccessControl#vapp_id}
    */
    readonly vappId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#vdc VappAccessControl#vdc}
    */
    readonly vdc?: string;
    /**
    * shared_with block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#shared_with VappAccessControl#shared_with}
    */
    readonly sharedWith?: VappAccessControlSharedWith[] | cdktf.IResolvable;
}
export interface VappAccessControlSharedWith {
    /**
    * The access level for the user or group to which we are sharing. (One of ReadOnly, Change, FullControl)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#access_level VappAccessControl#access_level}
    */
    readonly accessLevel: string;
    /**
    * ID of the group to which we are sharing. Required if user_id is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#group_id VappAccessControl#group_id}
    */
    readonly groupId?: string;
    /**
    * ID of the user to which we are sharing. Required if group_id is not set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#user_id VappAccessControl#user_id}
    */
    readonly userId?: string;
}
export declare function vappAccessControlSharedWithToTerraform(struct?: VappAccessControlSharedWith | cdktf.IResolvable): any;
export declare function vappAccessControlSharedWithToHclTerraform(struct?: VappAccessControlSharedWith | cdktf.IResolvable): any;
export declare class VappAccessControlSharedWithOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappAccessControlSharedWith | cdktf.IResolvable | undefined;
    set internalValue(value: VappAccessControlSharedWith | cdktf.IResolvable | undefined);
    private _accessLevel?;
    get accessLevel(): string;
    set accessLevel(value: string);
    get accessLevelInput(): string | undefined;
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    resetGroupId(): void;
    get groupIdInput(): string | undefined;
    get subjectName(): string;
    private _userId?;
    get userId(): string;
    set userId(value: string);
    resetUserId(): void;
    get userIdInput(): string | undefined;
}
export declare class VappAccessControlSharedWithList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappAccessControlSharedWith[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappAccessControlSharedWithOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control vcd_vapp_access_control}
*/
export declare class VappAccessControl extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_access_control";
    /**
    * Generates CDKTF code for importing a VappAccessControl resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappAccessControl to import
    * @param importFromId The id of the existing VappAccessControl that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappAccessControl to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_access_control vcd_vapp_access_control} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappAccessControlConfig
    */
    constructor(scope: Construct, id: string, config: VappAccessControlConfig);
    private _everyoneAccessLevel?;
    get everyoneAccessLevel(): string;
    set everyoneAccessLevel(value: string);
    resetEveryoneAccessLevel(): void;
    get everyoneAccessLevelInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _sharedWithEveryone?;
    get sharedWithEveryone(): boolean | cdktf.IResolvable;
    set sharedWithEveryone(value: boolean | cdktf.IResolvable);
    get sharedWithEveryoneInput(): boolean | cdktf.IResolvable | undefined;
    private _vappId?;
    get vappId(): string;
    set vappId(value: string);
    get vappIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _sharedWith;
    get sharedWith(): VappAccessControlSharedWithList;
    putSharedWith(value: VappAccessControlSharedWith[] | cdktf.IResolvable): void;
    resetSharedWith(): void;
    get sharedWithInput(): cdktf.IResolvable | VappAccessControlSharedWith[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
