import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappFirewallRulesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Specifies what to do should none of the rules match. Either `allow` or `drop`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#default_action VappFirewallRules#default_action}
    */
    readonly defaultAction: string;
    /**
    * Enable or disable firewall service. Default is `true`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#enabled VappFirewallRules#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#id VappFirewallRules#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Flag to enable logging for default action. Default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#log_default_action VappFirewallRules#log_default_action}
    */
    readonly logDefaultAction?: boolean | cdktf.IResolvable;
    /**
    * vApp network identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#network_id VappFirewallRules#network_id}
    */
    readonly networkId: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#org VappFirewallRules#org}
    */
    readonly org?: string;
    /**
    * vApp identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#vapp_id VappFirewallRules#vapp_id}
    */
    readonly vappId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#vdc VappFirewallRules#vdc}
    */
    readonly vdc?: string;
    /**
    * rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#rule VappFirewallRules#rule}
    */
    readonly rule?: VappFirewallRulesRule[] | cdktf.IResolvable;
}
export interface VappFirewallRulesRule {
    /**
    * Destination IP address to which the rule applies. A value of `Any` matches any IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#destination_ip VappFirewallRules#destination_ip}
    */
    readonly destinationIp?: string;
    /**
    * Destination port to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#destination_port VappFirewallRules#destination_port}
    */
    readonly destinationPort?: string;
    /**
    * Destination VM identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#destination_vm_id VappFirewallRules#destination_vm_id}
    */
    readonly destinationVmId?: string;
    /**
    * The value can be one of: `assigned` - assigned internal IP will be automatically chosen. `NAT`: NATed external IP will be automatically chosen.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#destination_vm_ip_type VappFirewallRules#destination_vm_ip_type}
    */
    readonly destinationVmIpType?: string;
    /**
    * Destination VM NIC ID to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#destination_vm_nic_id VappFirewallRules#destination_vm_nic_id}
    */
    readonly destinationVmNicId?: number;
    /**
    * 'true' value will enable rule logging. Default is false
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#enable_logging VappFirewallRules#enable_logging}
    */
    readonly enableLogging?: boolean | cdktf.IResolvable;
    /**
    * 'true' value will enable firewall rule
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#enabled VappFirewallRules#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Rule name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#name VappFirewallRules#name}
    */
    readonly name?: string;
    /**
    * One of: `drop` (drop packets that match the rule), `allow` (allow packets that match the rule to pass through the firewall)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#policy VappFirewallRules#policy}
    */
    readonly policy?: string;
    /**
    * Specify the protocols to which the rule should be applied. One of: `any`, `icmp`, `tcp`, `udp`, `tcp&udp`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#protocol VappFirewallRules#protocol}
    */
    readonly protocol?: string;
    /**
    * Source IP address to which the rule applies. A value of `Any` matches any IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#source_ip VappFirewallRules#source_ip}
    */
    readonly sourceIp?: string;
    /**
    * Source port to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#source_port VappFirewallRules#source_port}
    */
    readonly sourcePort?: string;
    /**
    * Source VM identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#source_vm_id VappFirewallRules#source_vm_id}
    */
    readonly sourceVmId?: string;
    /**
    * The value can be one of: `assigned` - assigned internal IP will be automatically chosen. `NAT`: NATed external IP will be automatically chosen.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#source_vm_ip_type VappFirewallRules#source_vm_ip_type}
    */
    readonly sourceVmIpType?: string;
    /**
    * Source VM NIC ID to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#source_vm_nic_id VappFirewallRules#source_vm_nic_id}
    */
    readonly sourceVmNicId?: number;
}
export declare function vappFirewallRulesRuleToTerraform(struct?: VappFirewallRulesRule | cdktf.IResolvable): any;
export declare function vappFirewallRulesRuleToHclTerraform(struct?: VappFirewallRulesRule | cdktf.IResolvable): any;
export declare class VappFirewallRulesRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappFirewallRulesRule | cdktf.IResolvable | undefined;
    set internalValue(value: VappFirewallRulesRule | cdktf.IResolvable | undefined);
    private _destinationIp?;
    get destinationIp(): string;
    set destinationIp(value: string);
    resetDestinationIp(): void;
    get destinationIpInput(): string | undefined;
    private _destinationPort?;
    get destinationPort(): string;
    set destinationPort(value: string);
    resetDestinationPort(): void;
    get destinationPortInput(): string | undefined;
    private _destinationVmId?;
    get destinationVmId(): string;
    set destinationVmId(value: string);
    resetDestinationVmId(): void;
    get destinationVmIdInput(): string | undefined;
    private _destinationVmIpType?;
    get destinationVmIpType(): string;
    set destinationVmIpType(value: string);
    resetDestinationVmIpType(): void;
    get destinationVmIpTypeInput(): string | undefined;
    private _destinationVmNicId?;
    get destinationVmNicId(): number;
    set destinationVmNicId(value: number);
    resetDestinationVmNicId(): void;
    get destinationVmNicIdInput(): number | undefined;
    private _enableLogging?;
    get enableLogging(): boolean | cdktf.IResolvable;
    set enableLogging(value: boolean | cdktf.IResolvable);
    resetEnableLogging(): void;
    get enableLoggingInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    resetPolicy(): void;
    get policyInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _sourceIp?;
    get sourceIp(): string;
    set sourceIp(value: string);
    resetSourceIp(): void;
    get sourceIpInput(): string | undefined;
    private _sourcePort?;
    get sourcePort(): string;
    set sourcePort(value: string);
    resetSourcePort(): void;
    get sourcePortInput(): string | undefined;
    private _sourceVmId?;
    get sourceVmId(): string;
    set sourceVmId(value: string);
    resetSourceVmId(): void;
    get sourceVmIdInput(): string | undefined;
    private _sourceVmIpType?;
    get sourceVmIpType(): string;
    set sourceVmIpType(value: string);
    resetSourceVmIpType(): void;
    get sourceVmIpTypeInput(): string | undefined;
    private _sourceVmNicId?;
    get sourceVmNicId(): number;
    set sourceVmNicId(value: number);
    resetSourceVmNicId(): void;
    get sourceVmNicIdInput(): number | undefined;
}
export declare class VappFirewallRulesRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappFirewallRulesRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappFirewallRulesRuleOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules vcd_vapp_firewall_rules}
*/
export declare class VappFirewallRules extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_firewall_rules";
    /**
    * Generates CDKTF code for importing a VappFirewallRules resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappFirewallRules to import
    * @param importFromId The id of the existing VappFirewallRules that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappFirewallRules to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_firewall_rules vcd_vapp_firewall_rules} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappFirewallRulesConfig
    */
    constructor(scope: Construct, id: string, config: VappFirewallRulesConfig);
    private _defaultAction?;
    get defaultAction(): string;
    set defaultAction(value: string);
    get defaultActionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _logDefaultAction?;
    get logDefaultAction(): boolean | cdktf.IResolvable;
    set logDefaultAction(value: boolean | cdktf.IResolvable);
    resetLogDefaultAction(): void;
    get logDefaultActionInput(): boolean | cdktf.IResolvable | undefined;
    private _networkId?;
    get networkId(): string;
    set networkId(value: string);
    get networkIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vappId?;
    get vappId(): string;
    set vappId(value: string);
    get vappIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _rule;
    get rule(): VappFirewallRulesRuleList;
    putRule(value: VappFirewallRulesRule[] | cdktf.IResolvable): void;
    resetRule(): void;
    get ruleInput(): cdktf.IResolvable | VappFirewallRulesRule[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
