import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappNatRulesConfig extends cdktf.TerraformMetaArguments {
    /**
    * When enabled translates a virtual machine's private, internal IP address to a public IP address for outbound traffic.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#enable_ip_masquerade VappNatRules#enable_ip_masquerade}
    */
    readonly enableIpMasquerade?: boolean | cdktf.IResolvable;
    /**
    * Enable or disable NAT service. Default is `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#enabled VappNatRules#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#id VappNatRules#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * One of: `ipTranslation` (use IP translation), `portForwarding` (use port forwarding).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#nat_type VappNatRules#nat_type}
    */
    readonly natType: string;
    /**
    * vApp network identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#network_id VappNatRules#network_id}
    */
    readonly networkId: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#org VappNatRules#org}
    */
    readonly org?: string;
    /**
    * vApp identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#vapp_id VappNatRules#vapp_id}
    */
    readonly vappId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#vdc VappNatRules#vdc}
    */
    readonly vdc?: string;
    /**
    * rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#rule VappNatRules#rule}
    */
    readonly rule?: VappNatRulesRule[] | cdktf.IResolvable;
}
export interface VappNatRulesRule {
    /**
    * External IP address to forward to or External IP address to map to VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#external_ip VappNatRules#external_ip}
    */
    readonly externalIp?: string;
    /**
    * External port to forward.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#external_port VappNatRules#external_port}
    */
    readonly externalPort?: number;
    /**
    * Internal port to forward.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#forward_to_port VappNatRules#forward_to_port}
    */
    readonly forwardToPort?: number;
    /**
    * Mapping mode. One of: `automatic`, `manual`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#mapping_mode VappNatRules#mapping_mode}
    */
    readonly mappingMode?: string;
    /**
    * Protocol to forward. One of: `TCP` (forward TCP packets), `UDP` (forward UDP packets), `TCP_UDP` (forward TCP and UDP packets).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#protocol VappNatRules#protocol}
    */
    readonly protocol?: string;
    /**
    * VM to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#vm_id VappNatRules#vm_id}
    */
    readonly vmId: string;
    /**
    * VM NIC ID to which this rule applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#vm_nic_id VappNatRules#vm_nic_id}
    */
    readonly vmNicId: number;
}
export declare function vappNatRulesRuleToTerraform(struct?: VappNatRulesRule | cdktf.IResolvable): any;
export declare function vappNatRulesRuleToHclTerraform(struct?: VappNatRulesRule | cdktf.IResolvable): any;
export declare class VappNatRulesRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappNatRulesRule | cdktf.IResolvable | undefined;
    set internalValue(value: VappNatRulesRule | cdktf.IResolvable | undefined);
    private _externalIp?;
    get externalIp(): string;
    set externalIp(value: string);
    resetExternalIp(): void;
    get externalIpInput(): string | undefined;
    private _externalPort?;
    get externalPort(): number;
    set externalPort(value: number);
    resetExternalPort(): void;
    get externalPortInput(): number | undefined;
    private _forwardToPort?;
    get forwardToPort(): number;
    set forwardToPort(value: number);
    resetForwardToPort(): void;
    get forwardToPortInput(): number | undefined;
    get id(): string;
    private _mappingMode?;
    get mappingMode(): string;
    set mappingMode(value: string);
    resetMappingMode(): void;
    get mappingModeInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _vmId?;
    get vmId(): string;
    set vmId(value: string);
    get vmIdInput(): string | undefined;
    private _vmNicId?;
    get vmNicId(): number;
    set vmNicId(value: number);
    get vmNicIdInput(): number | undefined;
}
export declare class VappNatRulesRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappNatRulesRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappNatRulesRuleOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules vcd_vapp_nat_rules}
*/
export declare class VappNatRules extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_nat_rules";
    /**
    * Generates CDKTF code for importing a VappNatRules resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappNatRules to import
    * @param importFromId The id of the existing VappNatRules that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappNatRules to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_nat_rules vcd_vapp_nat_rules} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappNatRulesConfig
    */
    constructor(scope: Construct, id: string, config: VappNatRulesConfig);
    private _enableIpMasquerade?;
    get enableIpMasquerade(): boolean | cdktf.IResolvable;
    set enableIpMasquerade(value: boolean | cdktf.IResolvable);
    resetEnableIpMasquerade(): void;
    get enableIpMasqueradeInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _natType?;
    get natType(): string;
    set natType(value: string);
    get natTypeInput(): string | undefined;
    private _networkId?;
    get networkId(): string;
    set networkId(value: string);
    get networkIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vappId?;
    get vappId(): string;
    set vappId(value: string);
    get vappIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _rule;
    get rule(): VappNatRulesRuleList;
    putRule(value: VappNatRulesRule[] | cdktf.IResolvable): void;
    resetRule(): void;
    get ruleInput(): cdktf.IResolvable | VappNatRulesRule[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
