import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappNetworkConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional description for the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#description VappNetwork#description}
    */
    readonly description?: string;
    /**
    * Primary DNS server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#dns1 VappNetwork#dns1}
    */
    readonly dns1?: string;
    /**
    * Secondary DNS server
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#dns2 VappNetwork#dns2}
    */
    readonly dns2?: string;
    /**
    * DNS suffix
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#dns_suffix VappNetwork#dns_suffix}
    */
    readonly dnsSuffix?: string;
    /**
    * Gateway of the network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#gateway VappNetwork#gateway}
    */
    readonly gateway: string;
    /**
    * True if Network allows guest VLAN tagging
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#guest_vlan_allowed VappNetwork#guest_vlan_allowed}
    */
    readonly guestVlanAllowed?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#id VappNetwork#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * vApp network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#name VappNetwork#name}
    */
    readonly name: string;
    /**
    * Netmask address for a subnet.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#netmask VappNetwork#netmask}
    */
    readonly netmask?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#org VappNetwork#org}
    */
    readonly org?: string;
    /**
    * org network name to which vapp network is connected
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#org_network_name VappNetwork#org_network_name}
    */
    readonly orgNetworkName?: string;
    /**
    * Prefix length for a subnet
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#prefix_length VappNetwork#prefix_length}
    */
    readonly prefixLength?: string;
    /**
    * Specifies whether the vApp should be rebooted when the vApp network is removed. Default is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#reboot_vapp_on_removal VappNetwork#reboot_vapp_on_removal}
    */
    readonly rebootVappOnRemoval?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether the network resources such as IP/MAC of router will be retained across deployments. Default is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#retain_ip_mac_enabled VappNetwork#retain_ip_mac_enabled}
    */
    readonly retainIpMacEnabled?: boolean | cdktf.IResolvable;
    /**
    * vApp to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#vapp_name VappNetwork#vapp_name}
    */
    readonly vappName: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#vdc VappNetwork#vdc}
    */
    readonly vdc?: string;
    /**
    * dhcp_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#dhcp_pool VappNetwork#dhcp_pool}
    */
    readonly dhcpPool?: VappNetworkDhcpPool[] | cdktf.IResolvable;
    /**
    * static_ip_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#static_ip_pool VappNetwork#static_ip_pool}
    */
    readonly staticIpPool?: VappNetworkStaticIpPool[] | cdktf.IResolvable;
}
export interface VappNetworkDhcpPool {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#default_lease_time VappNetwork#default_lease_time}
    */
    readonly defaultLeaseTime?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#enabled VappNetwork#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#end_address VappNetwork#end_address}
    */
    readonly endAddress?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#max_lease_time VappNetwork#max_lease_time}
    */
    readonly maxLeaseTime?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#start_address VappNetwork#start_address}
    */
    readonly startAddress: string;
}
export declare function vappNetworkDhcpPoolToTerraform(struct?: VappNetworkDhcpPool | cdktf.IResolvable): any;
export declare function vappNetworkDhcpPoolToHclTerraform(struct?: VappNetworkDhcpPool | cdktf.IResolvable): any;
export declare class VappNetworkDhcpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappNetworkDhcpPool | cdktf.IResolvable | undefined;
    set internalValue(value: VappNetworkDhcpPool | cdktf.IResolvable | undefined);
    private _defaultLeaseTime?;
    get defaultLeaseTime(): number;
    set defaultLeaseTime(value: number);
    resetDefaultLeaseTime(): void;
    get defaultLeaseTimeInput(): number | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    resetEndAddress(): void;
    get endAddressInput(): string | undefined;
    private _maxLeaseTime?;
    get maxLeaseTime(): number;
    set maxLeaseTime(value: number);
    resetMaxLeaseTime(): void;
    get maxLeaseTimeInput(): number | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class VappNetworkDhcpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappNetworkDhcpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappNetworkDhcpPoolOutputReference;
}
export interface VappNetworkStaticIpPool {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#end_address VappNetwork#end_address}
    */
    readonly endAddress: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#start_address VappNetwork#start_address}
    */
    readonly startAddress: string;
}
export declare function vappNetworkStaticIpPoolToTerraform(struct?: VappNetworkStaticIpPool | cdktf.IResolvable): any;
export declare function vappNetworkStaticIpPoolToHclTerraform(struct?: VappNetworkStaticIpPool | cdktf.IResolvable): any;
export declare class VappNetworkStaticIpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappNetworkStaticIpPool | cdktf.IResolvable | undefined;
    set internalValue(value: VappNetworkStaticIpPool | cdktf.IResolvable | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export declare class VappNetworkStaticIpPoolList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappNetworkStaticIpPool[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappNetworkStaticIpPoolOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network vcd_vapp_network}
*/
export declare class VappNetwork extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_network";
    /**
    * Generates CDKTF code for importing a VappNetwork resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappNetwork to import
    * @param importFromId The id of the existing VappNetwork that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappNetwork to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_network vcd_vapp_network} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappNetworkConfig
    */
    constructor(scope: Construct, id: string, config: VappNetworkConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dns1?;
    get dns1(): string;
    set dns1(value: string);
    resetDns1(): void;
    get dns1Input(): string | undefined;
    private _dns2?;
    get dns2(): string;
    set dns2(value: string);
    resetDns2(): void;
    get dns2Input(): string | undefined;
    private _dnsSuffix?;
    get dnsSuffix(): string;
    set dnsSuffix(value: string);
    resetDnsSuffix(): void;
    get dnsSuffixInput(): string | undefined;
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _guestVlanAllowed?;
    get guestVlanAllowed(): boolean | cdktf.IResolvable;
    set guestVlanAllowed(value: boolean | cdktf.IResolvable);
    resetGuestVlanAllowed(): void;
    get guestVlanAllowedInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    resetNetmask(): void;
    get netmaskInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkName?;
    get orgNetworkName(): string;
    set orgNetworkName(value: string);
    resetOrgNetworkName(): void;
    get orgNetworkNameInput(): string | undefined;
    private _prefixLength?;
    get prefixLength(): string;
    set prefixLength(value: string);
    resetPrefixLength(): void;
    get prefixLengthInput(): string | undefined;
    private _rebootVappOnRemoval?;
    get rebootVappOnRemoval(): boolean | cdktf.IResolvable;
    set rebootVappOnRemoval(value: boolean | cdktf.IResolvable);
    resetRebootVappOnRemoval(): void;
    get rebootVappOnRemovalInput(): boolean | cdktf.IResolvable | undefined;
    private _retainIpMacEnabled?;
    get retainIpMacEnabled(): boolean | cdktf.IResolvable;
    set retainIpMacEnabled(value: boolean | cdktf.IResolvable);
    resetRetainIpMacEnabled(): void;
    get retainIpMacEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    get vappNameInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _dhcpPool;
    get dhcpPool(): VappNetworkDhcpPoolList;
    putDhcpPool(value: VappNetworkDhcpPool[] | cdktf.IResolvable): void;
    resetDhcpPool(): void;
    get dhcpPoolInput(): cdktf.IResolvable | VappNetworkDhcpPool[] | undefined;
    private _staticIpPool;
    get staticIpPool(): VappNetworkStaticIpPoolList;
    putStaticIpPool(value: VappNetworkStaticIpPool[] | cdktf.IResolvable): void;
    resetStaticIpPool(): void;
    get staticIpPoolInput(): cdktf.IResolvable | VappNetworkStaticIpPool[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
