import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappOrgNetworkConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#id VappOrgNetwork#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Fencing allows identical virtual machines in different vApp networks connect to organization VDC networks that are accessed in this vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#is_fenced VappOrgNetwork#is_fenced}
    */
    readonly isFenced?: boolean | cdktf.IResolvable;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#org VappOrgNetwork#org}
    */
    readonly org?: string;
    /**
    * Organization network name to which vApp network is connected to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#org_network_name VappOrgNetwork#org_network_name}
    */
    readonly orgNetworkName: string;
    /**
    * Specifies whether the vApp should be rebooted when the vApp network is removed. Default is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#reboot_vapp_on_removal VappOrgNetwork#reboot_vapp_on_removal}
    */
    readonly rebootVappOnRemoval?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether the network resources such as IP/MAC of router will be retained across deployments. Default is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#retain_ip_mac_enabled VappOrgNetwork#retain_ip_mac_enabled}
    */
    readonly retainIpMacEnabled?: boolean | cdktf.IResolvable;
    /**
    * vApp network name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#vapp_name VappOrgNetwork#vapp_name}
    */
    readonly vappName: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#vdc VappOrgNetwork#vdc}
    */
    readonly vdc?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network vcd_vapp_org_network}
*/
export declare class VappOrgNetwork extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_org_network";
    /**
    * Generates CDKTF code for importing a VappOrgNetwork resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappOrgNetwork to import
    * @param importFromId The id of the existing VappOrgNetwork that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappOrgNetwork to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_org_network vcd_vapp_org_network} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappOrgNetworkConfig
    */
    constructor(scope: Construct, id: string, config: VappOrgNetworkConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isFenced?;
    get isFenced(): boolean | cdktf.IResolvable;
    set isFenced(value: boolean | cdktf.IResolvable);
    resetIsFenced(): void;
    get isFencedInput(): boolean | cdktf.IResolvable | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _orgNetworkName?;
    get orgNetworkName(): string;
    set orgNetworkName(value: string);
    get orgNetworkNameInput(): string | undefined;
    private _rebootVappOnRemoval?;
    get rebootVappOnRemoval(): boolean | cdktf.IResolvable;
    set rebootVappOnRemoval(value: boolean | cdktf.IResolvable);
    resetRebootVappOnRemoval(): void;
    get rebootVappOnRemovalInput(): boolean | cdktf.IResolvable | undefined;
    private _retainIpMacEnabled?;
    get retainIpMacEnabled(): boolean | cdktf.IResolvable;
    set retainIpMacEnabled(value: boolean | cdktf.IResolvable);
    resetRetainIpMacEnabled(): void;
    get retainIpMacEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    get vappNameInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
