import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappStaticRoutingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Enable or disable static Routing. Default is `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#enabled VappStaticRouting#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#id VappStaticRouting#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * vApp network identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#network_id VappStaticRouting#network_id}
    */
    readonly networkId: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#org VappStaticRouting#org}
    */
    readonly org?: string;
    /**
    * vApp identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#vapp_id VappStaticRouting#vapp_id}
    */
    readonly vappId: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#vdc VappStaticRouting#vdc}
    */
    readonly vdc?: string;
    /**
    * rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#rule VappStaticRouting#rule}
    */
    readonly rule?: VappStaticRoutingRule[] | cdktf.IResolvable;
}
export interface VappStaticRoutingRule {
    /**
    * Name for the static route.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#name VappStaticRouting#name}
    */
    readonly name: string;
    /**
    * network specification in CIDR.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#network_cidr VappStaticRouting#network_cidr}
    */
    readonly networkCidr: string;
    /**
    * IP Address of Next Hop router/gateway.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#next_hop_ip VappStaticRouting#next_hop_ip}
    */
    readonly nextHopIp: string;
}
export declare function vappStaticRoutingRuleToTerraform(struct?: VappStaticRoutingRule | cdktf.IResolvable): any;
export declare function vappStaticRoutingRuleToHclTerraform(struct?: VappStaticRoutingRule | cdktf.IResolvable): any;
export declare class VappStaticRoutingRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappStaticRoutingRule | cdktf.IResolvable | undefined;
    set internalValue(value: VappStaticRoutingRule | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkCidr?;
    get networkCidr(): string;
    set networkCidr(value: string);
    get networkCidrInput(): string | undefined;
    private _nextHopIp?;
    get nextHopIp(): string;
    set nextHopIp(value: string);
    get nextHopIpInput(): string | undefined;
}
export declare class VappStaticRoutingRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappStaticRoutingRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappStaticRoutingRuleOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing vcd_vapp_static_routing}
*/
export declare class VappStaticRouting extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_static_routing";
    /**
    * Generates CDKTF code for importing a VappStaticRouting resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappStaticRouting to import
    * @param importFromId The id of the existing VappStaticRouting that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappStaticRouting to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_static_routing vcd_vapp_static_routing} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappStaticRoutingConfig
    */
    constructor(scope: Construct, id: string, config: VappStaticRoutingConfig);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _networkId?;
    get networkId(): string;
    set networkId(value: string);
    get networkIdInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _vappId?;
    get vappId(): string;
    set vappId(value: string);
    get vappIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _rule;
    get rule(): VappStaticRoutingRuleList;
    putRule(value: VappStaticRoutingRule[] | cdktf.IResolvable): void;
    resetRule(): void;
    get ruleInput(): cdktf.IResolvable | VappStaticRoutingRule[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
