import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappVmConfig extends cdktf.TerraformMetaArguments {
    /**
    * Automatically accept EULA if OVA has it
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#accept_all_eulas VappVm#accept_all_eulas}
    */
    readonly acceptAllEulas?: boolean | cdktf.IResolvable;
    /**
    * Media name to add as boot image.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_image VappVm#boot_image}
    */
    readonly bootImage?: string;
    /**
    * The URN of the media to use as boot image.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_image_id VappVm#boot_image_id}
    */
    readonly bootImageId?: string;
    /**
    * The catalog name in which to find the given vApp Template or media for boot_image
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#catalog_name VappVm#catalog_name}
    */
    readonly catalogName?: string;
    /**
    * Computer name to assign to this virtual machine
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#computer_name VappVm#computer_name}
    */
    readonly computerName?: string;
    /**
    * Consolidates disks during creation and allows to change disk size using 'override_template_disk' in fast provisioned VDCs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#consolidate_disks_on_create VappVm#consolidate_disks_on_create}
    */
    readonly consolidateDisksOnCreate?: boolean | cdktf.IResolvable;
    /**
    * Source VM that should be copied from
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#copy_from_vm_id VappVm#copy_from_vm_id}
    */
    readonly copyFromVmId?: string;
    /**
    * The number of cores per socket
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_cores VappVm#cpu_cores}
    */
    readonly cpuCores?: number;
    /**
    * True if the virtual machine supports addition of virtual CPUs while powered on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_hot_add_enabled VappVm#cpu_hot_add_enabled}
    */
    readonly cpuHotAddEnabled?: boolean | cdktf.IResolvable;
    /**
    * The limit for how much of CPU can be consumed on the underlying virtualization infrastructure. This is only valid when the resource allocation is not unlimited.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_limit VappVm#cpu_limit}
    */
    readonly cpuLimit?: number;
    /**
    * Pre-determined relative priorities according to which the non-reserved portion of this resource is made available to the virtualized workload
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_priority VappVm#cpu_priority}
    */
    readonly cpuPriority?: string;
    /**
    * The amount of MHz reservation on the underlying virtualization infrastructure
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_reservation VappVm#cpu_reservation}
    */
    readonly cpuReservation?: number;
    /**
    * Custom priority for the resource. This is a read-only, unless the `cpu_priority` is CUSTOM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpu_shares VappVm#cpu_shares}
    */
    readonly cpuShares?: number;
    /**
    * The number of virtual CPUs to allocate to the VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#cpus VappVm#cpus}
    */
    readonly cpus?: number;
    /**
    * The VM description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#description VappVm#description}
    */
    readonly description?: string;
    /**
    * Expose hardware-assisted CPU virtualization to guest OS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#expose_hardware_virtualization VappVm#expose_hardware_virtualization}
    */
    readonly exposeHardwareVirtualization?: boolean | cdktf.IResolvable;
    /**
    * Firmware of the VM. Can be either EFI or BIOS, availabilitydepending on the os_type argument. If unset, is set to 'bios' by default. Changing the value when `power_on` is set to true, will cause a reboot of the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#firmware VappVm#firmware}
    */
    readonly firmware?: string;
    /**
    * Key/value settings for guest properties
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#guest_properties VappVm#guest_properties}
    */
    readonly guestProperties?: {
        [key: string]: string;
    };
    /**
    * Virtual Hardware Version (e.g.`vmx-14`, `vmx-13`, `vmx-12`, etc.)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#hardware_version VappVm#hardware_version}
    */
    readonly hardwareVersion?: string;
    /**
    * VM Hyper Reference
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#href VappVm#href}
    */
    readonly href?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#id VappVm#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The amount of RAM (in MB) to allocate to the VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory VappVm#memory}
    */
    readonly memory?: number;
    /**
    * True if the virtual machine supports addition of memory while powered on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory_hot_add_enabled VappVm#memory_hot_add_enabled}
    */
    readonly memoryHotAddEnabled?: boolean | cdktf.IResolvable;
    /**
    * The limit for how much of memory can be consumed on the underlying virtualization infrastructure. This is only valid when the resource allocation is not unlimited.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory_limit VappVm#memory_limit}
    */
    readonly memoryLimit?: number;
    /**
    * Pre-determined relative priorities according to which the non-reserved portion of this resource is made available to the virtualized workload
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory_priority VappVm#memory_priority}
    */
    readonly memoryPriority?: string;
    /**
    * The amount of RAM (in MB) reservation on the underlying virtualization infrastructure
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory_reservation VappVm#memory_reservation}
    */
    readonly memoryReservation?: number;
    /**
    * Custom priority for the resource. This is a read-only, unless the `memory_priority` is CUSTOM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#memory_shares VappVm#memory_shares}
    */
    readonly memoryShares?: number;
    /**
    * Key value map of metadata to assign to this VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#metadata VappVm#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * A name for the VM, unique within the vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#name VappVm#name}
    */
    readonly name: string;
    /**
    * Optional number of seconds to try and wait for DHCP IP (valid for 'network' block only)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#network_dhcp_wait_seconds VappVm#network_dhcp_wait_seconds}
    */
    readonly networkDhcpWaitSeconds?: number;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#org VappVm#org}
    */
    readonly org?: string;
    /**
    * Operating System type. Possible values can be found in documentation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#os_type VappVm#os_type}
    */
    readonly osType?: string;
    /**
    * VM placement policy ID. Has to be assigned to Org VDC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#placement_policy_id VappVm#placement_policy_id}
    */
    readonly placementPolicyId?: string;
    /**
    * A boolean value stating if this VM should be powered on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#power_on VappVm#power_on}
    */
    readonly powerOn?: boolean | cdktf.IResolvable;
    /**
    * True if the update of resource should fail when virtual machine power off needed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#prevent_update_power_off VappVm#prevent_update_power_off}
    */
    readonly preventUpdatePowerOff?: boolean | cdktf.IResolvable;
    /**
    * Security tags to assign to this VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#security_tags VappVm#security_tags}
    */
    readonly securityTags?: string[];
    /**
    * VM sizing policy ID. Has to be assigned to Org VDC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#sizing_policy_id VappVm#sizing_policy_id}
    */
    readonly sizingPolicyId?: string;
    /**
    * Storage profile to override the default one
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#storage_profile VappVm#storage_profile}
    */
    readonly storageProfile?: string;
    /**
    * The name of the vApp Template to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#template_name VappVm#template_name}
    */
    readonly templateName?: string;
    /**
    * The vApp this VM belongs to - Required, unless it is a standalone VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#vapp_name VappVm#vapp_name}
    */
    readonly vappName: string;
    /**
    * The URN of the vApp Template to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#vapp_template_id VappVm#vapp_template_id}
    */
    readonly vappTemplateId?: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#vdc VappVm#vdc}
    */
    readonly vdc?: string;
    /**
    * The name of the VM in vApp Template to use. In cases when vApp template has more than one VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#vm_name_in_template VappVm#vm_name_in_template}
    */
    readonly vmNameInTemplate?: string;
    /**
    * boot_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_options VappVm#boot_options}
    */
    readonly bootOptions?: VappVmBootOptions;
    /**
    * customization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#customization VappVm#customization}
    */
    readonly customization?: VappVmCustomization;
    /**
    * disk block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#disk VappVm#disk}
    */
    readonly disk?: VappVmDisk[] | cdktf.IResolvable;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#metadata_entry VappVm#metadata_entry}
    */
    readonly metadataEntry?: VappVmMetadataEntry[] | cdktf.IResolvable;
    /**
    * network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#network VappVm#network}
    */
    readonly network?: VappVmNetwork[] | cdktf.IResolvable;
    /**
    * override_template_disk block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#override_template_disk VappVm#override_template_disk}
    */
    readonly overrideTemplateDisk?: VappVmOverrideTemplateDisk[] | cdktf.IResolvable;
}
export interface VappVmInternalDisk {
}
export declare function vappVmInternalDiskToTerraform(struct?: VappVmInternalDisk): any;
export declare function vappVmInternalDiskToHclTerraform(struct?: VappVmInternalDisk): any;
export declare class VappVmInternalDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappVmInternalDisk | undefined;
    set internalValue(value: VappVmInternalDisk | undefined);
    get busNumber(): number;
    get busType(): string;
    get diskId(): string;
    get iops(): number;
    get sizeInMb(): number;
    get storageProfile(): string;
    get thinProvisioned(): cdktf.IResolvable;
    get unitNumber(): number;
}
export declare class VappVmInternalDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappVmInternalDiskOutputReference;
}
export interface VappVmBootOptions {
    /**
    * Number of milliseconds to wait between powering-on and booting the VM
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_delay VappVm#boot_delay}
    */
    readonly bootDelay?: number;
    /**
    * Delay in milliseconds before a boot retry. Only works if 'boot_retry_enabled' is set to true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_retry_delay VappVm#boot_retry_delay}
    */
    readonly bootRetryDelay?: number;
    /**
    * If set to true, a VM that fails to boot will try again after the 'boot_retry_delay' time period has expired
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#boot_retry_enabled VappVm#boot_retry_enabled}
    */
    readonly bootRetryEnabled?: boolean | cdktf.IResolvable;
    /**
    * If set to true, enables EFI Secure Boot for the VM. Can only be changed when the VM is powered off.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#efi_secure_boot VappVm#efi_secure_boot}
    */
    readonly efiSecureBoot?: boolean | cdktf.IResolvable;
    /**
    * If set to true, the VM will enter BIOS setup on next boot. If a VM is powered on, the field will be set to `false` by VCD and Terraform will return a non-empty plan
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#enter_bios_setup_on_next_boot VappVm#enter_bios_setup_on_next_boot}
    */
    readonly enterBiosSetupOnNextBoot?: boolean | cdktf.IResolvable;
}
export declare function vappVmBootOptionsToTerraform(struct?: VappVmBootOptionsOutputReference | VappVmBootOptions): any;
export declare function vappVmBootOptionsToHclTerraform(struct?: VappVmBootOptionsOutputReference | VappVmBootOptions): any;
export declare class VappVmBootOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VappVmBootOptions | undefined;
    set internalValue(value: VappVmBootOptions | undefined);
    private _bootDelay?;
    get bootDelay(): number;
    set bootDelay(value: number);
    resetBootDelay(): void;
    get bootDelayInput(): number | undefined;
    private _bootRetryDelay?;
    get bootRetryDelay(): number;
    set bootRetryDelay(value: number);
    resetBootRetryDelay(): void;
    get bootRetryDelayInput(): number | undefined;
    private _bootRetryEnabled?;
    get bootRetryEnabled(): boolean | cdktf.IResolvable;
    set bootRetryEnabled(value: boolean | cdktf.IResolvable);
    resetBootRetryEnabled(): void;
    get bootRetryEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _efiSecureBoot?;
    get efiSecureBoot(): boolean | cdktf.IResolvable;
    set efiSecureBoot(value: boolean | cdktf.IResolvable);
    resetEfiSecureBoot(): void;
    get efiSecureBootInput(): boolean | cdktf.IResolvable | undefined;
    private _enterBiosSetupOnNextBoot?;
    get enterBiosSetupOnNextBoot(): boolean | cdktf.IResolvable;
    set enterBiosSetupOnNextBoot(value: boolean | cdktf.IResolvable);
    resetEnterBiosSetupOnNextBoot(): void;
    get enterBiosSetupOnNextBootInput(): boolean | cdktf.IResolvable | undefined;
}
export interface VappVmCustomization {
    /**
    * Manually specify admin password
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#admin_password VappVm#admin_password}
    */
    readonly adminPassword?: string;
    /**
    * Allow local administrator password
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#allow_local_admin_password VappVm#allow_local_admin_password}
    */
    readonly allowLocalAdminPassword?: boolean | cdktf.IResolvable;
    /**
    * Auto generate password
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#auto_generate_password VappVm#auto_generate_password}
    */
    readonly autoGeneratePassword?: boolean | cdktf.IResolvable;
    /**
    * 'true' value will change SID. Applicable only for Windows VMs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#change_sid VappVm#change_sid}
    */
    readonly changeSid?: boolean | cdktf.IResolvable;
    /**
    * 'true' value will enable guest customization. It may occur on first boot or when 'force' is used
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#enabled VappVm#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * 'true' value will cause the VM to reboot on every 'apply' operation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#force VappVm#force}
    */
    readonly force?: boolean | cdktf.IResolvable;
    /**
    * Script to run on initial boot or with customization.force=true set
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#initscript VappVm#initscript}
    */
    readonly initscript?: string;
    /**
    * Enable this VM to join a domain
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_domain VappVm#join_domain}
    */
    readonly joinDomain?: boolean | cdktf.IResolvable;
    /**
    * Account organizational unit for domain name join
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_domain_account_ou VappVm#join_domain_account_ou}
    */
    readonly joinDomainAccountOu?: string;
    /**
    * Custom domain name for join
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_domain_name VappVm#join_domain_name}
    */
    readonly joinDomainName?: string;
    /**
    * Password for custom domain name join
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_domain_password VappVm#join_domain_password}
    */
    readonly joinDomainPassword?: string;
    /**
    * Username for custom domain name join
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_domain_user VappVm#join_domain_user}
    */
    readonly joinDomainUser?: string;
    /**
    * Use organization's domain for joining
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#join_org_domain VappVm#join_org_domain}
    */
    readonly joinOrgDomain?: boolean | cdktf.IResolvable;
    /**
    * Require Administrator to change password on first login
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#must_change_password_on_first_login VappVm#must_change_password_on_first_login}
    */
    readonly mustChangePasswordOnFirstLogin?: boolean | cdktf.IResolvable;
    /**
    * Number of times to log on automatically. '0' - disabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#number_of_auto_logons VappVm#number_of_auto_logons}
    */
    readonly numberOfAutoLogons?: number;
}
export declare function vappVmCustomizationToTerraform(struct?: VappVmCustomizationOutputReference | VappVmCustomization): any;
export declare function vappVmCustomizationToHclTerraform(struct?: VappVmCustomizationOutputReference | VappVmCustomization): any;
export declare class VappVmCustomizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VappVmCustomization | undefined;
    set internalValue(value: VappVmCustomization | undefined);
    private _adminPassword?;
    get adminPassword(): string;
    set adminPassword(value: string);
    resetAdminPassword(): void;
    get adminPasswordInput(): string | undefined;
    private _allowLocalAdminPassword?;
    get allowLocalAdminPassword(): boolean | cdktf.IResolvable;
    set allowLocalAdminPassword(value: boolean | cdktf.IResolvable);
    resetAllowLocalAdminPassword(): void;
    get allowLocalAdminPasswordInput(): boolean | cdktf.IResolvable | undefined;
    private _autoGeneratePassword?;
    get autoGeneratePassword(): boolean | cdktf.IResolvable;
    set autoGeneratePassword(value: boolean | cdktf.IResolvable);
    resetAutoGeneratePassword(): void;
    get autoGeneratePasswordInput(): boolean | cdktf.IResolvable | undefined;
    private _changeSid?;
    get changeSid(): boolean | cdktf.IResolvable;
    set changeSid(value: boolean | cdktf.IResolvable);
    resetChangeSid(): void;
    get changeSidInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _force?;
    get force(): boolean | cdktf.IResolvable;
    set force(value: boolean | cdktf.IResolvable);
    resetForce(): void;
    get forceInput(): boolean | cdktf.IResolvable | undefined;
    private _initscript?;
    get initscript(): string;
    set initscript(value: string);
    resetInitscript(): void;
    get initscriptInput(): string | undefined;
    private _joinDomain?;
    get joinDomain(): boolean | cdktf.IResolvable;
    set joinDomain(value: boolean | cdktf.IResolvable);
    resetJoinDomain(): void;
    get joinDomainInput(): boolean | cdktf.IResolvable | undefined;
    private _joinDomainAccountOu?;
    get joinDomainAccountOu(): string;
    set joinDomainAccountOu(value: string);
    resetJoinDomainAccountOu(): void;
    get joinDomainAccountOuInput(): string | undefined;
    private _joinDomainName?;
    get joinDomainName(): string;
    set joinDomainName(value: string);
    resetJoinDomainName(): void;
    get joinDomainNameInput(): string | undefined;
    private _joinDomainPassword?;
    get joinDomainPassword(): string;
    set joinDomainPassword(value: string);
    resetJoinDomainPassword(): void;
    get joinDomainPasswordInput(): string | undefined;
    private _joinDomainUser?;
    get joinDomainUser(): string;
    set joinDomainUser(value: string);
    resetJoinDomainUser(): void;
    get joinDomainUserInput(): string | undefined;
    private _joinOrgDomain?;
    get joinOrgDomain(): boolean | cdktf.IResolvable;
    set joinOrgDomain(value: boolean | cdktf.IResolvable);
    resetJoinOrgDomain(): void;
    get joinOrgDomainInput(): boolean | cdktf.IResolvable | undefined;
    private _mustChangePasswordOnFirstLogin?;
    get mustChangePasswordOnFirstLogin(): boolean | cdktf.IResolvable;
    set mustChangePasswordOnFirstLogin(value: boolean | cdktf.IResolvable);
    resetMustChangePasswordOnFirstLogin(): void;
    get mustChangePasswordOnFirstLoginInput(): boolean | cdktf.IResolvable | undefined;
    private _numberOfAutoLogons?;
    get numberOfAutoLogons(): number;
    set numberOfAutoLogons(value: number);
    resetNumberOfAutoLogons(): void;
    get numberOfAutoLogonsInput(): number | undefined;
}
export interface VappVmDisk {
    /**
    * Bus number on which to place the disk controller
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#bus_number VappVm#bus_number}
    */
    readonly busNumber: string;
    /**
    * Independent disk name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#name VappVm#name}
    */
    readonly name: string;
    /**
    * Unit number (slot) on the bus specified by BusNumber
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#unit_number VappVm#unit_number}
    */
    readonly unitNumber: string;
}
export declare function vappVmDiskToTerraform(struct?: VappVmDisk | cdktf.IResolvable): any;
export declare function vappVmDiskToHclTerraform(struct?: VappVmDisk | cdktf.IResolvable): any;
export declare class VappVmDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappVmDisk | cdktf.IResolvable | undefined;
    set internalValue(value: VappVmDisk | cdktf.IResolvable | undefined);
    private _busNumber?;
    get busNumber(): string;
    set busNumber(value: string);
    get busNumberInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get sizeInMb(): number;
    private _unitNumber?;
    get unitNumber(): string;
    set unitNumber(value: string);
    get unitNumberInput(): string | undefined;
}
export declare class VappVmDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappVmDisk[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappVmDiskOutputReference;
}
export interface VappVmMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#is_system VappVm#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#key VappVm#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#type VappVm#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#user_access VappVm#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#value VappVm#value}
    */
    readonly value?: string;
}
export declare function vappVmMetadataEntryToTerraform(struct?: VappVmMetadataEntry | cdktf.IResolvable): any;
export declare function vappVmMetadataEntryToHclTerraform(struct?: VappVmMetadataEntry | cdktf.IResolvable): any;
export declare class VappVmMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappVmMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: VappVmMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class VappVmMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappVmMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappVmMetadataEntryOutputReference;
}
export interface VappVmNetwork {
    /**
    * Network card adapter type. (e.g. 'E1000', 'E1000E', 'SRIOVETHERNETCARD', 'VMXNET3', 'PCNet32')
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#adapter_type VappVm#adapter_type}
    */
    readonly adapterType?: string;
    /**
    * It defines if NIC is connected or not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#connected VappVm#connected}
    */
    readonly connected?: boolean | cdktf.IResolvable;
    /**
    * IP of the VM. Settings depend on `ip_allocation_mode`. Omitted or empty for DHCP, POOL, NONE. Required for MANUAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#ip VappVm#ip}
    */
    readonly ip?: string;
    /**
    * IP address allocation mode. One of POOL, DHCP, MANUAL, NONE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#ip_allocation_mode VappVm#ip_allocation_mode}
    */
    readonly ipAllocationMode?: string;
    /**
    * Set to true if network interface should be primary. First network card in the list will be primary by default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#is_primary VappVm#is_primary}
    */
    readonly isPrimary?: boolean | cdktf.IResolvable;
    /**
    * Mac address of network interface
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#mac VappVm#mac}
    */
    readonly mac?: string;
    /**
    * Name of the network this VM should connect to. Always required except for `type` `NONE`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#name VappVm#name}
    */
    readonly name?: string;
    /**
    * Network type to use: 'vapp', 'org' or 'none'. Use 'vapp' for vApp network, 'org' to attach Org VDC network. 'none' for empty NIC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#type VappVm#type}
    */
    readonly type: string;
}
export declare function vappVmNetworkToTerraform(struct?: VappVmNetwork | cdktf.IResolvable): any;
export declare function vappVmNetworkToHclTerraform(struct?: VappVmNetwork | cdktf.IResolvable): any;
export declare class VappVmNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappVmNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: VappVmNetwork | cdktf.IResolvable | undefined);
    private _adapterType?;
    get adapterType(): string;
    set adapterType(value: string);
    resetAdapterType(): void;
    get adapterTypeInput(): string | undefined;
    private _connected?;
    get connected(): boolean | cdktf.IResolvable;
    set connected(value: boolean | cdktf.IResolvable);
    resetConnected(): void;
    get connectedInput(): boolean | cdktf.IResolvable | undefined;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _ipAllocationMode?;
    get ipAllocationMode(): string;
    set ipAllocationMode(value: string);
    resetIpAllocationMode(): void;
    get ipAllocationModeInput(): string | undefined;
    private _isPrimary?;
    get isPrimary(): boolean | cdktf.IResolvable;
    set isPrimary(value: boolean | cdktf.IResolvable);
    resetIsPrimary(): void;
    get isPrimaryInput(): boolean | cdktf.IResolvable | undefined;
    private _mac?;
    get mac(): string;
    set mac(value: string);
    resetMac(): void;
    get macInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export declare class VappVmNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappVmNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappVmNetworkOutputReference;
}
export interface VappVmOverrideTemplateDisk {
    /**
    * The number of the SCSI or IDE controller itself.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#bus_number VappVm#bus_number}
    */
    readonly busNumber: number;
    /**
    * The type of disk controller. Possible values: ide, parallel( LSI Logic Parallel SCSI), sas(LSI Logic SAS (SCSI)), paravirtual(Paravirtual (SCSI)), sata, nvme
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#bus_type VappVm#bus_type}
    */
    readonly busType: string;
    /**
    * Specifies the IOPS for the disk. Default is 0.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#iops VappVm#iops}
    */
    readonly iops?: number;
    /**
    * The size of the disk in MB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#size_in_mb VappVm#size_in_mb}
    */
    readonly sizeInMb: number;
    /**
    * Storage profile to override the VM default one
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#storage_profile VappVm#storage_profile}
    */
    readonly storageProfile?: string;
    /**
    * The device number on the SCSI or IDE controller of the disk.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#unit_number VappVm#unit_number}
    */
    readonly unitNumber: number;
}
export declare function vappVmOverrideTemplateDiskToTerraform(struct?: VappVmOverrideTemplateDisk | cdktf.IResolvable): any;
export declare function vappVmOverrideTemplateDiskToHclTerraform(struct?: VappVmOverrideTemplateDisk | cdktf.IResolvable): any;
export declare class VappVmOverrideTemplateDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappVmOverrideTemplateDisk | cdktf.IResolvable | undefined;
    set internalValue(value: VappVmOverrideTemplateDisk | cdktf.IResolvable | undefined);
    private _busNumber?;
    get busNumber(): number;
    set busNumber(value: number);
    get busNumberInput(): number | undefined;
    private _busType?;
    get busType(): string;
    set busType(value: string);
    get busTypeInput(): string | undefined;
    private _iops?;
    get iops(): number;
    set iops(value: number);
    resetIops(): void;
    get iopsInput(): number | undefined;
    private _sizeInMb?;
    get sizeInMb(): number;
    set sizeInMb(value: number);
    get sizeInMbInput(): number | undefined;
    private _storageProfile?;
    get storageProfile(): string;
    set storageProfile(value: string);
    resetStorageProfile(): void;
    get storageProfileInput(): string | undefined;
    private _unitNumber?;
    get unitNumber(): number;
    set unitNumber(value: number);
    get unitNumberInput(): number | undefined;
}
export declare class VappVmOverrideTemplateDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappVmOverrideTemplateDisk[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappVmOverrideTemplateDiskOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm vcd_vapp_vm}
*/
export declare class VappVm extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp_vm";
    /**
    * Generates CDKTF code for importing a VappVm resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VappVm to import
    * @param importFromId The id of the existing VappVm that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VappVm to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp_vm vcd_vapp_vm} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappVmConfig
    */
    constructor(scope: Construct, id: string, config: VappVmConfig);
    private _acceptAllEulas?;
    get acceptAllEulas(): boolean | cdktf.IResolvable;
    set acceptAllEulas(value: boolean | cdktf.IResolvable);
    resetAcceptAllEulas(): void;
    get acceptAllEulasInput(): boolean | cdktf.IResolvable | undefined;
    private _bootImage?;
    get bootImage(): string;
    set bootImage(value: string);
    resetBootImage(): void;
    get bootImageInput(): string | undefined;
    private _bootImageId?;
    get bootImageId(): string;
    set bootImageId(value: string);
    resetBootImageId(): void;
    get bootImageIdInput(): string | undefined;
    private _catalogName?;
    get catalogName(): string;
    set catalogName(value: string);
    resetCatalogName(): void;
    get catalogNameInput(): string | undefined;
    private _computerName?;
    get computerName(): string;
    set computerName(value: string);
    resetComputerName(): void;
    get computerNameInput(): string | undefined;
    private _consolidateDisksOnCreate?;
    get consolidateDisksOnCreate(): boolean | cdktf.IResolvable;
    set consolidateDisksOnCreate(value: boolean | cdktf.IResolvable);
    resetConsolidateDisksOnCreate(): void;
    get consolidateDisksOnCreateInput(): boolean | cdktf.IResolvable | undefined;
    private _copyFromVmId?;
    get copyFromVmId(): string;
    set copyFromVmId(value: string);
    resetCopyFromVmId(): void;
    get copyFromVmIdInput(): string | undefined;
    private _cpuCores?;
    get cpuCores(): number;
    set cpuCores(value: number);
    resetCpuCores(): void;
    get cpuCoresInput(): number | undefined;
    private _cpuHotAddEnabled?;
    get cpuHotAddEnabled(): boolean | cdktf.IResolvable;
    set cpuHotAddEnabled(value: boolean | cdktf.IResolvable);
    resetCpuHotAddEnabled(): void;
    get cpuHotAddEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _cpuLimit?;
    get cpuLimit(): number;
    set cpuLimit(value: number);
    resetCpuLimit(): void;
    get cpuLimitInput(): number | undefined;
    private _cpuPriority?;
    get cpuPriority(): string;
    set cpuPriority(value: string);
    resetCpuPriority(): void;
    get cpuPriorityInput(): string | undefined;
    private _cpuReservation?;
    get cpuReservation(): number;
    set cpuReservation(value: number);
    resetCpuReservation(): void;
    get cpuReservationInput(): number | undefined;
    private _cpuShares?;
    get cpuShares(): number;
    set cpuShares(value: number);
    resetCpuShares(): void;
    get cpuSharesInput(): number | undefined;
    private _cpus?;
    get cpus(): number;
    set cpus(value: number);
    resetCpus(): void;
    get cpusInput(): number | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _exposeHardwareVirtualization?;
    get exposeHardwareVirtualization(): boolean | cdktf.IResolvable;
    set exposeHardwareVirtualization(value: boolean | cdktf.IResolvable);
    resetExposeHardwareVirtualization(): void;
    get exposeHardwareVirtualizationInput(): boolean | cdktf.IResolvable | undefined;
    private _firmware?;
    get firmware(): string;
    set firmware(value: string);
    resetFirmware(): void;
    get firmwareInput(): string | undefined;
    private _guestProperties?;
    get guestProperties(): {
        [key: string]: string;
    };
    set guestProperties(value: {
        [key: string]: string;
    });
    resetGuestProperties(): void;
    get guestPropertiesInput(): {
        [key: string]: string;
    } | undefined;
    private _hardwareVersion?;
    get hardwareVersion(): string;
    set hardwareVersion(value: string);
    resetHardwareVersion(): void;
    get hardwareVersionInput(): string | undefined;
    private _href?;
    get href(): string;
    set href(value: string);
    resetHref(): void;
    get hrefInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inheritedMetadata;
    get inheritedMetadata(): cdktf.StringMap;
    private _internalDisk;
    get internalDisk(): VappVmInternalDiskList;
    private _memory?;
    get memory(): number;
    set memory(value: number);
    resetMemory(): void;
    get memoryInput(): number | undefined;
    private _memoryHotAddEnabled?;
    get memoryHotAddEnabled(): boolean | cdktf.IResolvable;
    set memoryHotAddEnabled(value: boolean | cdktf.IResolvable);
    resetMemoryHotAddEnabled(): void;
    get memoryHotAddEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _memoryLimit?;
    get memoryLimit(): number;
    set memoryLimit(value: number);
    resetMemoryLimit(): void;
    get memoryLimitInput(): number | undefined;
    private _memoryPriority?;
    get memoryPriority(): string;
    set memoryPriority(value: string);
    resetMemoryPriority(): void;
    get memoryPriorityInput(): string | undefined;
    private _memoryReservation?;
    get memoryReservation(): number;
    set memoryReservation(value: number);
    resetMemoryReservation(): void;
    get memoryReservationInput(): number | undefined;
    private _memoryShares?;
    get memoryShares(): number;
    set memoryShares(value: number);
    resetMemoryShares(): void;
    get memorySharesInput(): number | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkDhcpWaitSeconds?;
    get networkDhcpWaitSeconds(): number;
    set networkDhcpWaitSeconds(value: number);
    resetNetworkDhcpWaitSeconds(): void;
    get networkDhcpWaitSecondsInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _osType?;
    get osType(): string;
    set osType(value: string);
    resetOsType(): void;
    get osTypeInput(): string | undefined;
    private _placementPolicyId?;
    get placementPolicyId(): string;
    set placementPolicyId(value: string);
    resetPlacementPolicyId(): void;
    get placementPolicyIdInput(): string | undefined;
    private _powerOn?;
    get powerOn(): boolean | cdktf.IResolvable;
    set powerOn(value: boolean | cdktf.IResolvable);
    resetPowerOn(): void;
    get powerOnInput(): boolean | cdktf.IResolvable | undefined;
    private _preventUpdatePowerOff?;
    get preventUpdatePowerOff(): boolean | cdktf.IResolvable;
    set preventUpdatePowerOff(value: boolean | cdktf.IResolvable);
    resetPreventUpdatePowerOff(): void;
    get preventUpdatePowerOffInput(): boolean | cdktf.IResolvable | undefined;
    private _securityTags?;
    get securityTags(): string[];
    set securityTags(value: string[]);
    resetSecurityTags(): void;
    get securityTagsInput(): string[] | undefined;
    private _sizingPolicyId?;
    get sizingPolicyId(): string;
    set sizingPolicyId(value: string);
    resetSizingPolicyId(): void;
    get sizingPolicyIdInput(): string | undefined;
    get status(): number;
    get statusText(): string;
    private _storageProfile?;
    get storageProfile(): string;
    set storageProfile(value: string);
    resetStorageProfile(): void;
    get storageProfileInput(): string | undefined;
    private _templateName?;
    get templateName(): string;
    set templateName(value: string);
    resetTemplateName(): void;
    get templateNameInput(): string | undefined;
    get vappId(): string;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    get vappNameInput(): string | undefined;
    private _vappTemplateId?;
    get vappTemplateId(): string;
    set vappTemplateId(value: string);
    resetVappTemplateId(): void;
    get vappTemplateIdInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _vmNameInTemplate?;
    get vmNameInTemplate(): string;
    set vmNameInTemplate(value: string);
    resetVmNameInTemplate(): void;
    get vmNameInTemplateInput(): string | undefined;
    get vmType(): string;
    private _bootOptions;
    get bootOptions(): VappVmBootOptionsOutputReference;
    putBootOptions(value: VappVmBootOptions): void;
    resetBootOptions(): void;
    get bootOptionsInput(): VappVmBootOptions | undefined;
    private _customization;
    get customization(): VappVmCustomizationOutputReference;
    putCustomization(value: VappVmCustomization): void;
    resetCustomization(): void;
    get customizationInput(): VappVmCustomization | undefined;
    private _disk;
    get disk(): VappVmDiskList;
    putDisk(value: VappVmDisk[] | cdktf.IResolvable): void;
    resetDisk(): void;
    get diskInput(): cdktf.IResolvable | VappVmDisk[] | undefined;
    private _metadataEntry;
    get metadataEntry(): VappVmMetadataEntryList;
    putMetadataEntry(value: VappVmMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | VappVmMetadataEntry[] | undefined;
    private _network;
    get network(): VappVmNetworkList;
    putNetwork(value: VappVmNetwork[] | cdktf.IResolvable): void;
    resetNetwork(): void;
    get networkInput(): cdktf.IResolvable | VappVmNetwork[] | undefined;
    private _overrideTemplateDisk;
    get overrideTemplateDisk(): VappVmOverrideTemplateDiskList;
    putOverrideTemplateDisk(value: VappVmOverrideTemplateDisk[] | cdktf.IResolvable): void;
    resetOverrideTemplateDisk(): void;
    get overrideTemplateDiskInput(): cdktf.IResolvable | VappVmOverrideTemplateDisk[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
