import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VappConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional description of the vApp
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#description Vapp#description}
    */
    readonly description?: string;
    /**
    * Key/value settings for guest properties. Will be picked up by new VMs when created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#guest_properties Vapp#guest_properties}
    */
    readonly guestProperties?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#id Vapp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key value map of metadata to assign to this vApp. Key and value can be any string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#metadata Vapp#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * A name for the vApp, unique withing the VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#name Vapp#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#org Vapp#org}
    */
    readonly org?: string;
    /**
    * A boolean value stating if this vApp should be powered on
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#power_on Vapp#power_on}
    */
    readonly powerOn?: boolean | cdktf.IResolvable;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#vdc Vapp#vdc}
    */
    readonly vdc?: string;
    /**
    * lease block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#lease Vapp#lease}
    */
    readonly lease?: VappLease;
    /**
    * metadata_entry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#metadata_entry Vapp#metadata_entry}
    */
    readonly metadataEntry?: VappMetadataEntry[] | cdktf.IResolvable;
}
export interface VappLease {
    /**
    * How long any of the VMs in the vApp can run before the vApp is automatically powered off or suspended. 0 means never expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#runtime_lease_in_sec Vapp#runtime_lease_in_sec}
    */
    readonly runtimeLeaseInSec: number;
    /**
    * How long the vApp is available before being automatically deleted or marked as expired. 0 means never expires
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#storage_lease_in_sec Vapp#storage_lease_in_sec}
    */
    readonly storageLeaseInSec: number;
}
export declare function vappLeaseToTerraform(struct?: VappLeaseOutputReference | VappLease): any;
export declare function vappLeaseToHclTerraform(struct?: VappLeaseOutputReference | VappLease): any;
export declare class VappLeaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VappLease | undefined;
    set internalValue(value: VappLease | undefined);
    private _runtimeLeaseInSec?;
    get runtimeLeaseInSec(): number;
    set runtimeLeaseInSec(value: number);
    get runtimeLeaseInSecInput(): number | undefined;
    private _storageLeaseInSec?;
    get storageLeaseInSec(): number;
    set storageLeaseInSec(value: number);
    get storageLeaseInSecInput(): number | undefined;
}
export interface VappMetadataEntry {
    /**
    * Domain for this metadata entry. true, if it belongs to SYSTEM. false, if it belongs to GENERAL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#is_system Vapp#is_system}
    */
    readonly isSystem?: boolean | cdktf.IResolvable;
    /**
    * Key of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#key Vapp#key}
    */
    readonly key?: string;
    /**
    * Type of this metadata entry. One of: 'MetadataStringValue', 'MetadataNumberValue', 'MetadataBooleanValue', 'MetadataDateTimeValue'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#type Vapp#type}
    */
    readonly type?: string;
    /**
    * User access level for this metadata entry. One of: 'READWRITE', 'READONLY', 'PRIVATE'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#user_access Vapp#user_access}
    */
    readonly userAccess?: string;
    /**
    * Value of this metadata entry. Required if the metadata entry is not empty
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#value Vapp#value}
    */
    readonly value?: string;
}
export declare function vappMetadataEntryToTerraform(struct?: VappMetadataEntry | cdktf.IResolvable): any;
export declare function vappMetadataEntryToHclTerraform(struct?: VappMetadataEntry | cdktf.IResolvable): any;
export declare class VappMetadataEntryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VappMetadataEntry | cdktf.IResolvable | undefined;
    set internalValue(value: VappMetadataEntry | cdktf.IResolvable | undefined);
    private _isSystem?;
    get isSystem(): boolean | cdktf.IResolvable;
    set isSystem(value: boolean | cdktf.IResolvable);
    resetIsSystem(): void;
    get isSystemInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _userAccess?;
    get userAccess(): string;
    set userAccess(value: string);
    resetUserAccess(): void;
    get userAccessInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class VappMetadataEntryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VappMetadataEntry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VappMetadataEntryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp vcd_vapp}
*/
export declare class Vapp extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vapp";
    /**
    * Generates CDKTF code for importing a Vapp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Vapp to import
    * @param importFromId The id of the existing Vapp that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Vapp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vapp vcd_vapp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VappConfig
    */
    constructor(scope: Construct, id: string, config: VappConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _guestProperties?;
    get guestProperties(): {
        [key: string]: string;
    };
    set guestProperties(value: {
        [key: string]: string;
    });
    resetGuestProperties(): void;
    get guestPropertiesInput(): {
        [key: string]: string;
    } | undefined;
    get href(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inheritedMetadata;
    get inheritedMetadata(): cdktf.StringMap;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _powerOn?;
    get powerOn(): boolean | cdktf.IResolvable;
    set powerOn(value: boolean | cdktf.IResolvable);
    resetPowerOn(): void;
    get powerOnInput(): boolean | cdktf.IResolvable | undefined;
    get status(): number;
    get statusText(): string;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _lease;
    get lease(): VappLeaseOutputReference;
    putLease(value: VappLease): void;
    resetLease(): void;
    get leaseInput(): VappLease | undefined;
    private _metadataEntry;
    get metadataEntry(): VappMetadataEntryList;
    putMetadataEntry(value: VappMetadataEntry[] | cdktf.IResolvable): void;
    resetMetadataEntry(): void;
    get metadataEntryInput(): cdktf.IResolvable | VappMetadataEntry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
