import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VdcGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Default Policy Status
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#default_policy_status VdcGroup#default_policy_status}
    */
    readonly defaultPolicyStatus?: boolean | cdktf.IResolvable;
    /**
    * VDC group description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#description VdcGroup#description}
    */
    readonly description?: string;
    /**
    * Distributed firewall status
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#dfw_enabled VdcGroup#dfw_enabled}
    */
    readonly dfwEnabled?: boolean | cdktf.IResolvable;
    /**
    * Forces deletion of VDC Group during destroy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#force_delete VdcGroup#force_delete}
    */
    readonly forceDelete?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#id VdcGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of VDC group
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#name VdcGroup#name}
    */
    readonly name: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#org VdcGroup#org}
    */
    readonly org?: string;
    /**
    * Participating VDC IDs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#participating_vdc_ids VdcGroup#participating_vdc_ids}
    */
    readonly participatingVdcIds: string[];
    /**
    * A flag to remove default firewall rule when DFW and Default Policy are both enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#remove_default_firewall_rule VdcGroup#remove_default_firewall_rule}
    */
    readonly removeDefaultFirewallRule?: boolean | cdktf.IResolvable;
    /**
    * Starting VDC ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#starting_vdc_id VdcGroup#starting_vdc_id}
    */
    readonly startingVdcId: string;
}
export interface VdcGroupParticipatingOrgVdcs {
}
export declare function vdcGroupParticipatingOrgVdcsToTerraform(struct?: VdcGroupParticipatingOrgVdcs): any;
export declare function vdcGroupParticipatingOrgVdcsToHclTerraform(struct?: VdcGroupParticipatingOrgVdcs): any;
export declare class VdcGroupParticipatingOrgVdcsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VdcGroupParticipatingOrgVdcs | undefined;
    set internalValue(value: VdcGroupParticipatingOrgVdcs | undefined);
    get faultDomainTag(): string;
    get isRemoteOrg(): cdktf.IResolvable;
    get networkProviderScope(): string;
    get orgId(): string;
    get orgName(): string;
    get siteId(): string;
    get siteName(): string;
    get status(): string;
    get vdcId(): string;
    get vdcName(): string;
}
export declare class VdcGroupParticipatingOrgVdcsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VdcGroupParticipatingOrgVdcsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group vcd_vdc_group}
*/
export declare class VdcGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vdc_group";
    /**
    * Generates CDKTF code for importing a VdcGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VdcGroup to import
    * @param importFromId The id of the existing VdcGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VdcGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vdc_group vcd_vdc_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VdcGroupConfig
    */
    constructor(scope: Construct, id: string, config: VdcGroupConfig);
    private _defaultPolicyStatus?;
    get defaultPolicyStatus(): boolean | cdktf.IResolvable;
    set defaultPolicyStatus(value: boolean | cdktf.IResolvable);
    resetDefaultPolicyStatus(): void;
    get defaultPolicyStatusInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dfwEnabled?;
    get dfwEnabled(): boolean | cdktf.IResolvable;
    set dfwEnabled(value: boolean | cdktf.IResolvable);
    resetDfwEnabled(): void;
    get dfwEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get errorMessage(): string;
    private _forceDelete?;
    get forceDelete(): boolean | cdktf.IResolvable;
    set forceDelete(value: boolean | cdktf.IResolvable);
    resetForceDelete(): void;
    get forceDeleteInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get localEgress(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get networkPoolId(): string;
    get networkPoolUniversalId(): string;
    get networkProviderType(): string;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _participatingOrgVdcs;
    get participatingOrgVdcs(): VdcGroupParticipatingOrgVdcsList;
    private _participatingVdcIds?;
    get participatingVdcIds(): string[];
    set participatingVdcIds(value: string[]);
    get participatingVdcIdsInput(): string[] | undefined;
    private _removeDefaultFirewallRule?;
    get removeDefaultFirewallRule(): boolean | cdktf.IResolvable;
    set removeDefaultFirewallRule(value: boolean | cdktf.IResolvable);
    resetRemoveDefaultFirewallRule(): void;
    get removeDefaultFirewallRuleInput(): boolean | cdktf.IResolvable | undefined;
    private _startingVdcId?;
    get startingVdcId(): string;
    set startingVdcId(value: string);
    get startingVdcIdInput(): string | undefined;
    get status(): string;
    get type(): string;
    get universalNetworkingEnabled(): cdktf.IResolvable;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
