import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmInternalDiskAConfig extends cdktf.TerraformMetaArguments {
    /**
    * Powers off VM when changing any attribute of an IDE disk or unit/bus number of other disk types, after the change is complete VM is powered back on. Without this setting enabled, such changes on a powered-on VM would fail.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#allow_vm_reboot VmInternalDiskA#allow_vm_reboot}
    */
    readonly allowVmReboot?: boolean | cdktf.IResolvable;
    /**
    * The number of the SCSI or IDE controller itself.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#bus_number VmInternalDiskA#bus_number}
    */
    readonly busNumber: number;
    /**
    * The type of disk controller. Possible values: ide, parallel( LSI Logic Parallel SCSI), sas(LSI Logic SAS (SCSI)), paravirtual(Paravirtual (SCSI)), sata, nvme
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#bus_type VmInternalDiskA#bus_type}
    */
    readonly busType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#id VmInternalDiskA#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Specifies the IOPS for the disk.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#iops VmInternalDiskA#iops}
    */
    readonly iops?: number;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#org VmInternalDiskA#org}
    */
    readonly org?: string;
    /**
    * The size of the disk in MB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#size_in_mb VmInternalDiskA#size_in_mb}
    */
    readonly sizeInMb: number;
    /**
    * Storage profile to override the VM default one
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#storage_profile VmInternalDiskA#storage_profile}
    */
    readonly storageProfile?: string;
    /**
    * The device number on the SCSI or IDE controller of the disk.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#unit_number VmInternalDiskA#unit_number}
    */
    readonly unitNumber: number;
    /**
    * The vApp this VM internal disk belongs to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#vapp_name VmInternalDiskA#vapp_name}
    */
    readonly vappName: string;
    /**
    * The name of VDC to use, optional if defined at provider level
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#vdc VmInternalDiskA#vdc}
    */
    readonly vdc?: string;
    /**
    * VM in vApp in which internal disk is created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#vm_name VmInternalDiskA#vm_name}
    */
    readonly vmName: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk vcd_vm_internal_disk}
*/
export declare class VmInternalDiskA extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vm_internal_disk";
    /**
    * Generates CDKTF code for importing a VmInternalDiskA resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmInternalDiskA to import
    * @param importFromId The id of the existing VmInternalDiskA that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmInternalDiskA to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_internal_disk vcd_vm_internal_disk} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmInternalDiskAConfig
    */
    constructor(scope: Construct, id: string, config: VmInternalDiskAConfig);
    private _allowVmReboot?;
    get allowVmReboot(): boolean | cdktf.IResolvable;
    set allowVmReboot(value: boolean | cdktf.IResolvable);
    resetAllowVmReboot(): void;
    get allowVmRebootInput(): boolean | cdktf.IResolvable | undefined;
    private _busNumber?;
    get busNumber(): number;
    set busNumber(value: number);
    get busNumberInput(): number | undefined;
    private _busType?;
    get busType(): string;
    set busType(value: string);
    get busTypeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _iops?;
    get iops(): number;
    set iops(value: number);
    resetIops(): void;
    get iopsInput(): number | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _sizeInMb?;
    get sizeInMb(): number;
    set sizeInMb(value: number);
    get sizeInMbInput(): number | undefined;
    private _storageProfile?;
    get storageProfile(): string;
    set storageProfile(value: string);
    resetStorageProfile(): void;
    get storageProfileInput(): string | undefined;
    get thinProvisioned(): cdktf.IResolvable;
    private _unitNumber?;
    get unitNumber(): number;
    set unitNumber(value: number);
    get unitNumberInput(): number | undefined;
    private _vappName?;
    get vappName(): string;
    set vappName(value: string);
    get vappNameInput(): string | undefined;
    private _vdc?;
    get vdc(): string;
    set vdc(value: string);
    resetVdc(): void;
    get vdcInput(): string | undefined;
    private _vmName?;
    get vmName(): string;
    set vmName(value: string);
    get vmNameInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
