import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmPlacementPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the VM Placement Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#description VmPlacementPolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#id VmPlacementPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * IDs of one or more Logical VM Groups to define this VM Placement Policy. There is an AND relationship among all the entries set in this attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#logical_vm_group_ids VmPlacementPolicy#logical_vm_group_ids}
    */
    readonly logicalVmGroupIds?: string[];
    /**
    * Name of the VM Placement Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#name VmPlacementPolicy#name}
    */
    readonly name: string;
    /**
    * ID of the Provider VDC to which the VM Placement Policy belongs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#provider_vdc_id VmPlacementPolicy#provider_vdc_id}
    */
    readonly providerVdcId: string;
    /**
    * IDs of the collection of VMs with similar host requirements
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#vm_group_ids VmPlacementPolicy#vm_group_ids}
    */
    readonly vmGroupIds?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy vcd_vm_placement_policy}
*/
export declare class VmPlacementPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vm_placement_policy";
    /**
    * Generates CDKTF code for importing a VmPlacementPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmPlacementPolicy to import
    * @param importFromId The id of the existing VmPlacementPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmPlacementPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_placement_policy vcd_vm_placement_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmPlacementPolicyConfig
    */
    constructor(scope: Construct, id: string, config: VmPlacementPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _logicalVmGroupIds?;
    get logicalVmGroupIds(): string[];
    set logicalVmGroupIds(value: string[]);
    resetLogicalVmGroupIds(): void;
    get logicalVmGroupIdsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _providerVdcId?;
    get providerVdcId(): string;
    set providerVdcId(value: string);
    get providerVdcIdInput(): string | undefined;
    private _vmGroupIds?;
    get vmGroupIds(): string[];
    set vmGroupIds(value: string[]);
    resetVmGroupIds(): void;
    get vmGroupIdsInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
