import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmSizingPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#description VmSizingPolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#id VmSizingPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#name VmSizingPolicy#name}
    */
    readonly name: string;
    /**
    * The name of organization to use - Deprecated and unneeded: will be ignored if used
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#org VmSizingPolicy#org}
    */
    readonly org?: string;
    /**
    * cpu block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#cpu VmSizingPolicy#cpu}
    */
    readonly cpu?: VmSizingPolicyCpu;
    /**
    * memory block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#memory VmSizingPolicy#memory}
    */
    readonly memory?: VmSizingPolicyMemory;
}
export interface VmSizingPolicyCpu {
    /**
    * The number of cores per socket for a VM. This is a VM hardware configuration. The number of vCPUs that is defined in the VM sizing policy must be divisible by the number of cores per socket. If the number of vCPUs is not divisible by the number of cores per socket, the number of cores per socket becomes invalid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#cores_per_socket VmSizingPolicy#cores_per_socket}
    */
    readonly coresPerSocket?: string;
    /**
    * Defines the number of vCPUs configured for a VM. This is a VM hardware configuration. When a tenant assigns the VM sizing policy to a VM, this count becomes the configured number of vCPUs for the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#count VmSizingPolicy#count}
    */
    readonly count?: string;
    /**
    * Defines the CPU limit in MHz for a VM. If not defined in the VDC compute policy, CPU limit is equal to the vCPU speed multiplied by the number of vCPUs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#limit_in_mhz VmSizingPolicy#limit_in_mhz}
    */
    readonly limitInMhz?: string;
    /**
    * Defines how much of the CPU resources of a VM are reserved. The allocated CPU for a VM equals the number of vCPUs times the vCPU speed in MHz. The value of the attribute ranges between 0 and one. Value of 0 CPU reservation guarantee defines no CPU reservation. Value of 1 defines 100% of CPU reserved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#reservation_guarantee VmSizingPolicy#reservation_guarantee}
    */
    readonly reservationGuarantee?: string;
    /**
    * Defines the number of CPU shares for a VM. Shares specify the relative importance of a VM within a virtual data center. If a VM has twice as many shares of CPU as another VM, it is entitled to consume twice as much CPU when these two virtual machines are competing for resources. If not defined in the VDC compute policy, normal shares are applied to the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#shares VmSizingPolicy#shares}
    */
    readonly shares?: string;
    /**
    * Defines the vCPU speed of a core in MHz.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#speed_in_mhz VmSizingPolicy#speed_in_mhz}
    */
    readonly speedInMhz?: string;
}
export declare function vmSizingPolicyCpuToTerraform(struct?: VmSizingPolicyCpuOutputReference | VmSizingPolicyCpu): any;
export declare function vmSizingPolicyCpuToHclTerraform(struct?: VmSizingPolicyCpuOutputReference | VmSizingPolicyCpu): any;
export declare class VmSizingPolicyCpuOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmSizingPolicyCpu | undefined;
    set internalValue(value: VmSizingPolicyCpu | undefined);
    private _coresPerSocket?;
    get coresPerSocket(): string;
    set coresPerSocket(value: string);
    resetCoresPerSocket(): void;
    get coresPerSocketInput(): string | undefined;
    private _count?;
    get count(): string;
    set count(value: string);
    resetCount(): void;
    get countInput(): string | undefined;
    private _limitInMhz?;
    get limitInMhz(): string;
    set limitInMhz(value: string);
    resetLimitInMhz(): void;
    get limitInMhzInput(): string | undefined;
    private _reservationGuarantee?;
    get reservationGuarantee(): string;
    set reservationGuarantee(value: string);
    resetReservationGuarantee(): void;
    get reservationGuaranteeInput(): string | undefined;
    private _shares?;
    get shares(): string;
    set shares(value: string);
    resetShares(): void;
    get sharesInput(): string | undefined;
    private _speedInMhz?;
    get speedInMhz(): string;
    set speedInMhz(value: string);
    resetSpeedInMhz(): void;
    get speedInMhzInput(): string | undefined;
}
export interface VmSizingPolicyMemory {
    /**
    * Defines the memory limit in MB for a VM. If not defined in the VM sizing policy, memory limit is equal to the allocated memory for the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#limit_in_mb VmSizingPolicy#limit_in_mb}
    */
    readonly limitInMb?: string;
    /**
    * Defines the reserved amount of memory that is configured for a VM. The value of the attribute ranges between 0 and one. Value of 0 memory reservation guarantee defines no memory reservation. Value of 1 defines 100% of memory reserved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#reservation_guarantee VmSizingPolicy#reservation_guarantee}
    */
    readonly reservationGuarantee?: string;
    /**
    * Defines the number of memory shares for a VM. Shares specify the relative importance of a VM within a virtual data center. If a VM has twice as many shares of memory as another VM, it is entitled to consume twice as much memory when these two virtual machines are competing for resources. If not defined in the VDC compute policy, normal shares are applied to the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#shares VmSizingPolicy#shares}
    */
    readonly shares?: string;
    /**
    * Defines the memory configured for a VM in MB. This is a VM hardware configuration. When a tenant assigns the VM sizing policy to a VM, the VM receives the amount of memory defined by this attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#size_in_mb VmSizingPolicy#size_in_mb}
    */
    readonly sizeInMb?: string;
}
export declare function vmSizingPolicyMemoryToTerraform(struct?: VmSizingPolicyMemoryOutputReference | VmSizingPolicyMemory): any;
export declare function vmSizingPolicyMemoryToHclTerraform(struct?: VmSizingPolicyMemoryOutputReference | VmSizingPolicyMemory): any;
export declare class VmSizingPolicyMemoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmSizingPolicyMemory | undefined;
    set internalValue(value: VmSizingPolicyMemory | undefined);
    private _limitInMb?;
    get limitInMb(): string;
    set limitInMb(value: string);
    resetLimitInMb(): void;
    get limitInMbInput(): string | undefined;
    private _reservationGuarantee?;
    get reservationGuarantee(): string;
    set reservationGuarantee(value: string);
    resetReservationGuarantee(): void;
    get reservationGuaranteeInput(): string | undefined;
    private _shares?;
    get shares(): string;
    set shares(value: string);
    resetShares(): void;
    get sharesInput(): string | undefined;
    private _sizeInMb?;
    get sizeInMb(): string;
    set sizeInMb(value: string);
    resetSizeInMb(): void;
    get sizeInMbInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy vcd_vm_sizing_policy}
*/
export declare class VmSizingPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vm_sizing_policy";
    /**
    * Generates CDKTF code for importing a VmSizingPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmSizingPolicy to import
    * @param importFromId The id of the existing VmSizingPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmSizingPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_sizing_policy vcd_vm_sizing_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmSizingPolicyConfig
    */
    constructor(scope: Construct, id: string, config: VmSizingPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    private _cpu;
    get cpu(): VmSizingPolicyCpuOutputReference;
    putCpu(value: VmSizingPolicyCpu): void;
    resetCpu(): void;
    get cpuInput(): VmSizingPolicyCpu | undefined;
    private _memory;
    get memory(): VmSizingPolicyMemoryOutputReference;
    putMemory(value: VmSizingPolicyMemory): void;
    resetMemory(): void;
    get memoryInput(): VmSizingPolicyMemory | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
