import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmVgpuPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the vGPU policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#description VmVgpuPolicy#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#id VmVgpuPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique name of the vGPU policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#name VmVgpuPolicy#name}
    */
    readonly name: string;
    /**
    * cpu block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#cpu VmVgpuPolicy#cpu}
    */
    readonly cpu?: VmVgpuPolicyCpu;
    /**
    * memory block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#memory VmVgpuPolicy#memory}
    */
    readonly memory?: VmVgpuPolicyMemory;
    /**
    * provider_vdc_scope block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#provider_vdc_scope VmVgpuPolicy#provider_vdc_scope}
    */
    readonly providerVdcScope?: VmVgpuPolicyProviderVdcScope[] | cdktf.IResolvable;
    /**
    * vgpu_profile block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#vgpu_profile VmVgpuPolicy#vgpu_profile}
    */
    readonly vgpuProfile: VmVgpuPolicyVgpuProfile;
}
export interface VmVgpuPolicyCpu {
    /**
    * The number of cores per socket for a VM. This is a VM hardware configuration. The number of vCPUs that is defined in the VM sizing policy must be divisible by the number of cores per socket. If the number of vCPUs is not divisible by the number of cores per socket, the number of cores per socket becomes invalid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#cores_per_socket VmVgpuPolicy#cores_per_socket}
    */
    readonly coresPerSocket?: string;
    /**
    * Defines the number of vCPUs configured for a VM. This is a VM hardware configuration. When a tenant assigns the VM sizing policy to a VM, this count becomes the configured number of vCPUs for the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#count VmVgpuPolicy#count}
    */
    readonly count?: string;
    /**
    * Defines the CPU limit in MHz for a VM. If not defined in the VDC compute policy, CPU limit is equal to the vCPU speed multiplied by the number of vCPUs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#limit_in_mhz VmVgpuPolicy#limit_in_mhz}
    */
    readonly limitInMhz?: string;
    /**
    * Defines how much of the CPU resources of a VM are reserved. The allocated CPU for a VM equals the number of vCPUs times the vCPU speed in MHz. The value of the attribute ranges between 0 and one. Value of 0 CPU reservation guarantee defines no CPU reservation. Value of 1 defines 100% of CPU reserved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#reservation_guarantee VmVgpuPolicy#reservation_guarantee}
    */
    readonly reservationGuarantee?: string;
    /**
    * Defines the number of CPU shares for a VM. Shares specify the relative importance of a VM within a virtual data center. If a VM has twice as many shares of CPU as another VM, it is entitled to consume twice as much CPU when these two virtual machines are competing for resources. If not defined in the VDC compute policy, normal shares are applied to the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#shares VmVgpuPolicy#shares}
    */
    readonly shares?: string;
    /**
    * Defines the vCPU speed of a core in MHz.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#speed_in_mhz VmVgpuPolicy#speed_in_mhz}
    */
    readonly speedInMhz?: string;
}
export declare function vmVgpuPolicyCpuToTerraform(struct?: VmVgpuPolicyCpuOutputReference | VmVgpuPolicyCpu): any;
export declare function vmVgpuPolicyCpuToHclTerraform(struct?: VmVgpuPolicyCpuOutputReference | VmVgpuPolicyCpu): any;
export declare class VmVgpuPolicyCpuOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmVgpuPolicyCpu | undefined;
    set internalValue(value: VmVgpuPolicyCpu | undefined);
    private _coresPerSocket?;
    get coresPerSocket(): string;
    set coresPerSocket(value: string);
    resetCoresPerSocket(): void;
    get coresPerSocketInput(): string | undefined;
    private _count?;
    get count(): string;
    set count(value: string);
    resetCount(): void;
    get countInput(): string | undefined;
    private _limitInMhz?;
    get limitInMhz(): string;
    set limitInMhz(value: string);
    resetLimitInMhz(): void;
    get limitInMhzInput(): string | undefined;
    private _reservationGuarantee?;
    get reservationGuarantee(): string;
    set reservationGuarantee(value: string);
    resetReservationGuarantee(): void;
    get reservationGuaranteeInput(): string | undefined;
    private _shares?;
    get shares(): string;
    set shares(value: string);
    resetShares(): void;
    get sharesInput(): string | undefined;
    private _speedInMhz?;
    get speedInMhz(): string;
    set speedInMhz(value: string);
    resetSpeedInMhz(): void;
    get speedInMhzInput(): string | undefined;
}
export interface VmVgpuPolicyMemory {
    /**
    * Defines the memory limit in MB for a VM. If not defined in the VM sizing policy, memory limit is equal to the allocated memory for the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#limit_in_mb VmVgpuPolicy#limit_in_mb}
    */
    readonly limitInMb?: string;
    /**
    * Defines the reserved amount of memory that is configured for a VM. The value of the attribute ranges between 0 and one. Value of 0 memory reservation guarantee defines no memory reservation. Value of 1 defines 100% of memory reserved.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#reservation_guarantee VmVgpuPolicy#reservation_guarantee}
    */
    readonly reservationGuarantee?: string;
    /**
    * Defines the number of memory shares for a VM. Shares specify the relative importance of a VM within a virtual data center. If a VM has twice as many shares of memory as another VM, it is entitled to consume twice as much memory when these two virtual machines are competing for resources. If not defined in the VDC compute policy, normal shares are applied to the VM.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#shares VmVgpuPolicy#shares}
    */
    readonly shares?: string;
    /**
    * Defines the memory configured for a VM in MB. This is a VM hardware configuration. When a tenant assigns the VM sizing policy to a VM, the VM receives the amount of memory defined by this attribute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#size_in_mb VmVgpuPolicy#size_in_mb}
    */
    readonly sizeInMb?: string;
}
export declare function vmVgpuPolicyMemoryToTerraform(struct?: VmVgpuPolicyMemoryOutputReference | VmVgpuPolicyMemory): any;
export declare function vmVgpuPolicyMemoryToHclTerraform(struct?: VmVgpuPolicyMemoryOutputReference | VmVgpuPolicyMemory): any;
export declare class VmVgpuPolicyMemoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmVgpuPolicyMemory | undefined;
    set internalValue(value: VmVgpuPolicyMemory | undefined);
    private _limitInMb?;
    get limitInMb(): string;
    set limitInMb(value: string);
    resetLimitInMb(): void;
    get limitInMbInput(): string | undefined;
    private _reservationGuarantee?;
    get reservationGuarantee(): string;
    set reservationGuarantee(value: string);
    resetReservationGuarantee(): void;
    get reservationGuaranteeInput(): string | undefined;
    private _shares?;
    get shares(): string;
    set shares(value: string);
    resetShares(): void;
    get sharesInput(): string | undefined;
    private _sizeInMb?;
    get sizeInMb(): string;
    set sizeInMb(value: string);
    resetSizeInMb(): void;
    get sizeInMbInput(): string | undefined;
}
export interface VmVgpuPolicyProviderVdcScope {
    /**
    * Set of cluster names within the provider virtual data center.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#cluster_names VmVgpuPolicy#cluster_names}
    */
    readonly clusterNames?: string[];
    /**
    * Identifier for the provider virtual data center.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#provider_vdc_id VmVgpuPolicy#provider_vdc_id}
    */
    readonly providerVdcId: string;
    /**
    * Optional identifier for a VM group within the provider VDC scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#vm_group_id VmVgpuPolicy#vm_group_id}
    */
    readonly vmGroupId?: string;
}
export declare function vmVgpuPolicyProviderVdcScopeToTerraform(struct?: VmVgpuPolicyProviderVdcScope | cdktf.IResolvable): any;
export declare function vmVgpuPolicyProviderVdcScopeToHclTerraform(struct?: VmVgpuPolicyProviderVdcScope | cdktf.IResolvable): any;
export declare class VmVgpuPolicyProviderVdcScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VmVgpuPolicyProviderVdcScope | cdktf.IResolvable | undefined;
    set internalValue(value: VmVgpuPolicyProviderVdcScope | cdktf.IResolvable | undefined);
    private _clusterNames?;
    get clusterNames(): string[];
    set clusterNames(value: string[]);
    resetClusterNames(): void;
    get clusterNamesInput(): string[] | undefined;
    private _providerVdcId?;
    get providerVdcId(): string;
    set providerVdcId(value: string);
    get providerVdcIdInput(): string | undefined;
    private _vmGroupId?;
    get vmGroupId(): string;
    set vmGroupId(value: string);
    resetVmGroupId(): void;
    get vmGroupIdInput(): string | undefined;
}
export declare class VmVgpuPolicyProviderVdcScopeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VmVgpuPolicyProviderVdcScope[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VmVgpuPolicyProviderVdcScopeOutputReference;
}
export interface VmVgpuPolicyVgpuProfile {
    /**
    * Specifies the number of vGPU profiles. Must be at least 1.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#count VmVgpuPolicy#count}
    */
    readonly count: number;
    /**
    * The identifier of the vGPU profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#id VmVgpuPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function vmVgpuPolicyVgpuProfileToTerraform(struct?: VmVgpuPolicyVgpuProfileOutputReference | VmVgpuPolicyVgpuProfile): any;
export declare function vmVgpuPolicyVgpuProfileToHclTerraform(struct?: VmVgpuPolicyVgpuProfileOutputReference | VmVgpuPolicyVgpuProfile): any;
export declare class VmVgpuPolicyVgpuProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmVgpuPolicyVgpuProfile | undefined;
    set internalValue(value: VmVgpuPolicyVgpuProfile | undefined);
    private _count?;
    get count(): number;
    set count(value: number);
    get countInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy vcd_vm_vgpu_policy}
*/
export declare class VmVgpuPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_vm_vgpu_policy";
    /**
    * Generates CDKTF code for importing a VmVgpuPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmVgpuPolicy to import
    * @param importFromId The id of the existing VmVgpuPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmVgpuPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.12.0/docs/resources/vm_vgpu_policy vcd_vm_vgpu_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmVgpuPolicyConfig
    */
    constructor(scope: Construct, id: string, config: VmVgpuPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _cpu;
    get cpu(): VmVgpuPolicyCpuOutputReference;
    putCpu(value: VmVgpuPolicyCpu): void;
    resetCpu(): void;
    get cpuInput(): VmVgpuPolicyCpu | undefined;
    private _memory;
    get memory(): VmVgpuPolicyMemoryOutputReference;
    putMemory(value: VmVgpuPolicyMemory): void;
    resetMemory(): void;
    get memoryInput(): VmVgpuPolicyMemory | undefined;
    private _providerVdcScope;
    get providerVdcScope(): VmVgpuPolicyProviderVdcScopeList;
    putProviderVdcScope(value: VmVgpuPolicyProviderVdcScope[] | cdktf.IResolvable): void;
    resetProviderVdcScope(): void;
    get providerVdcScopeInput(): cdktf.IResolvable | VmVgpuPolicyProviderVdcScope[] | undefined;
    private _vgpuProfile;
    get vgpuProfile(): VmVgpuPolicyVgpuProfileOutputReference;
    putVgpuProfile(value: VmVgpuPolicyVgpuProfile): void;
    get vgpuProfileInput(): VmVgpuPolicyVgpuProfile | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
